//----------------------------------------------------------------------------------------------------------------------
// 1. DRIVER SETUP - create driver object, midi ports and detection information
//----------------------------------------------------------------------------------------------------------------------
var midiremote_api = require('midiremote_api_v1')
var deviceDriver = midiremote_api.makeDeviceDriver('Metasystem', 'metagridMacros', 'Martin Jirsak')

var midiInput = deviceDriver.mPorts.makeMidiInput()
var midiOutput = deviceDriver.mPorts.makeMidiOutput()

deviceDriver.makeDetectionUnit().detectPortPair(midiInput, midiOutput)
	.expectInputNameContains('Metasystem - CubaseMacros - In')
	.expectOutputNameContains('Metasystem - CubaseMacros - Out')

var surface = deviceDriver.mSurface

//----------------------------------------------------------------------------------------------------------------------
// 2. SURFACE LAYOUT - create control elements and midi bindings
//----------------------------------------------------------------------------------------------------------------------
function makeSurfaceElements() {
	var surfaceElements = {}
	surfaceElements.buttons = {}
	surfaceElements.labels = {}

	surfaceElements.buttons[0] = surface.makeButton(0, 0, 10, 10)
	surfaceElements.buttons[0].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 11)
	surfaceElements.labels[0] = surface.makeLabelField(0, 5, 10, 1)

	surfaceElements.buttons[1] = surface.makeButton(11, 0, 10, 10)
	surfaceElements.buttons[1].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 12)
	surfaceElements.labels[1] = surface.makeLabelField(11, 5, 10, 1)

	surfaceElements.buttons[2] = surface.makeButton(22, 0, 10, 10)
	surfaceElements.buttons[2].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 13)
	surfaceElements.labels[2] = surface.makeLabelField(22, 5, 10, 1)

	surfaceElements.buttons[3] = surface.makeButton(33, 0, 10, 10)
	surfaceElements.buttons[3].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 14)
	surfaceElements.labels[3] = surface.makeLabelField(33, 5, 10, 1)

	surfaceElements.buttons[4] = surface.makeButton(44, 0, 10, 10)
	surfaceElements.buttons[4].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 15)
	surfaceElements.labels[4] = surface.makeLabelField(44, 5, 10, 1)

	surfaceElements.buttons[5] = surface.makeButton(55, 0, 10, 10)
	surfaceElements.buttons[5].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 16)
	surfaceElements.labels[5] = surface.makeLabelField(55, 5, 10, 1)

	surfaceElements.buttons[6] = surface.makeButton(66, 0, 10, 10)
	surfaceElements.buttons[6].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 17)
	surfaceElements.labels[6] = surface.makeLabelField(66, 5, 10, 1)

	surfaceElements.buttons[7] = surface.makeButton(77, 0, 10, 10)
	surfaceElements.buttons[7].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 18)
	surfaceElements.labels[7] = surface.makeLabelField(77, 5, 10, 1)

	surfaceElements.buttons[8] = surface.makeButton(88, 0, 10, 10)
	surfaceElements.buttons[8].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 19)
	surfaceElements.labels[8] = surface.makeLabelField(88, 5, 10, 1)

	surfaceElements.buttons[9] = surface.makeButton(99, 0, 10, 10)
	surfaceElements.buttons[9].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 20)
	surfaceElements.labels[9] = surface.makeLabelField(99, 5, 10, 1)

	surfaceElements.buttons[10] = surface.makeButton(110, 0, 10, 10)
	surfaceElements.buttons[10].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 21)
	surfaceElements.labels[10] = surface.makeLabelField(110, 5, 10, 1)

	surfaceElements.buttons[11] = surface.makeButton(121, 0, 10, 10)
	surfaceElements.buttons[11].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 22)
	surfaceElements.labels[11] = surface.makeLabelField(121, 5, 10, 1)

	surfaceElements.buttons[12] = surface.makeButton(132, 0, 10, 10)
	surfaceElements.buttons[12].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 23)
	surfaceElements.labels[12] = surface.makeLabelField(132, 5, 10, 1)

	surfaceElements.buttons[13] = surface.makeButton(143, 0, 10, 10)
	surfaceElements.buttons[13].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 24)
	surfaceElements.labels[13] = surface.makeLabelField(143, 5, 10, 1)

	surfaceElements.buttons[14] = surface.makeButton(154, 0, 10, 10)
	surfaceElements.buttons[14].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 25)
	surfaceElements.labels[14] = surface.makeLabelField(154, 5, 10, 1)

	surfaceElements.buttons[15] = surface.makeButton(165, 0, 10, 10)
	surfaceElements.buttons[15].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 26)
	surfaceElements.labels[15] = surface.makeLabelField(165, 5, 10, 1)

	surfaceElements.buttons[16] = surface.makeButton(176, 0, 10, 10)
	surfaceElements.buttons[16].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 27)
	surfaceElements.labels[16] = surface.makeLabelField(176, 5, 10, 1)

	surfaceElements.buttons[17] = surface.makeButton(187, 0, 10, 10)
	surfaceElements.buttons[17].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 28)
	surfaceElements.labels[17] = surface.makeLabelField(187, 5, 10, 1)

	surfaceElements.buttons[18] = surface.makeButton(198, 0, 10, 10)
	surfaceElements.buttons[18].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 29)
	surfaceElements.labels[18] = surface.makeLabelField(198, 5, 10, 1)

	surfaceElements.buttons[19] = surface.makeButton(209, 0, 10, 10)
	surfaceElements.buttons[19].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 30)
	surfaceElements.labels[19] = surface.makeLabelField(209, 5, 10, 1)

	surfaceElements.buttons[20] = surface.makeButton(220, 0, 10, 10)
	surfaceElements.buttons[20].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 31)
	surfaceElements.labels[20] = surface.makeLabelField(220, 5, 10, 1)

	surfaceElements.buttons[21] = surface.makeButton(231, 0, 10, 10)
	surfaceElements.buttons[21].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 32)
	surfaceElements.labels[21] = surface.makeLabelField(231, 5, 10, 1)

	surfaceElements.buttons[22] = surface.makeButton(242, 0, 10, 10)
	surfaceElements.buttons[22].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 33)
	surfaceElements.labels[22] = surface.makeLabelField(242, 5, 10, 1)

	surfaceElements.buttons[23] = surface.makeButton(0, 11, 10, 10)
	surfaceElements.buttons[23].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 34)
	surfaceElements.labels[23] = surface.makeLabelField(0, 16, 10, 1)

	surfaceElements.buttons[24] = surface.makeButton(11, 11, 10, 10)
	surfaceElements.buttons[24].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 35)
	surfaceElements.labels[24] = surface.makeLabelField(11, 16, 10, 1)

	surfaceElements.buttons[25] = surface.makeButton(22, 11, 10, 10)
	surfaceElements.buttons[25].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 36)
	surfaceElements.labels[25] = surface.makeLabelField(22, 16, 10, 1)

	surfaceElements.buttons[26] = surface.makeButton(33, 11, 10, 10)
	surfaceElements.buttons[26].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 37)
	surfaceElements.labels[26] = surface.makeLabelField(33, 16, 10, 1)

	surfaceElements.buttons[27] = surface.makeButton(44, 11, 10, 10)
	surfaceElements.buttons[27].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 38)
	surfaceElements.labels[27] = surface.makeLabelField(44, 16, 10, 1)

	surfaceElements.buttons[28] = surface.makeButton(55, 11, 10, 10)
	surfaceElements.buttons[28].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 39)
	surfaceElements.labels[28] = surface.makeLabelField(55, 16, 10, 1)

	surfaceElements.buttons[29] = surface.makeButton(66, 11, 10, 10)
	surfaceElements.buttons[29].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 40)
	surfaceElements.labels[29] = surface.makeLabelField(66, 16, 10, 1)

	surfaceElements.buttons[30] = surface.makeButton(77, 11, 10, 10)
	surfaceElements.buttons[30].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 41)
	surfaceElements.labels[30] = surface.makeLabelField(77, 16, 10, 1)

	surfaceElements.buttons[31] = surface.makeButton(88, 11, 10, 10)
	surfaceElements.buttons[31].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 42)
	surfaceElements.labels[31] = surface.makeLabelField(88, 16, 10, 1)

	surfaceElements.buttons[32] = surface.makeButton(99, 11, 10, 10)
	surfaceElements.buttons[32].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 43)
	surfaceElements.labels[32] = surface.makeLabelField(99, 16, 10, 1)

	surfaceElements.buttons[33] = surface.makeButton(110, 11, 10, 10)
	surfaceElements.buttons[33].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 44)
	surfaceElements.labels[33] = surface.makeLabelField(110, 16, 10, 1)

	surfaceElements.buttons[34] = surface.makeButton(121, 11, 10, 10)
	surfaceElements.buttons[34].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 45)
	surfaceElements.labels[34] = surface.makeLabelField(121, 16, 10, 1)

	surfaceElements.buttons[35] = surface.makeButton(132, 11, 10, 10)
	surfaceElements.buttons[35].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 46)
	surfaceElements.labels[35] = surface.makeLabelField(132, 16, 10, 1)

	surfaceElements.buttons[36] = surface.makeButton(143, 11, 10, 10)
	surfaceElements.buttons[36].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 47)
	surfaceElements.labels[36] = surface.makeLabelField(143, 16, 10, 1)

	surfaceElements.buttons[37] = surface.makeButton(154, 11, 10, 10)
	surfaceElements.buttons[37].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 48)
	surfaceElements.labels[37] = surface.makeLabelField(154, 16, 10, 1)

	surfaceElements.buttons[38] = surface.makeButton(165, 11, 10, 10)
	surfaceElements.buttons[38].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 49)
	surfaceElements.labels[38] = surface.makeLabelField(165, 16, 10, 1)

	surfaceElements.buttons[39] = surface.makeButton(176, 11, 10, 10)
	surfaceElements.buttons[39].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 50)
	surfaceElements.labels[39] = surface.makeLabelField(176, 16, 10, 1)

	surfaceElements.buttons[40] = surface.makeButton(187, 11, 10, 10)
	surfaceElements.buttons[40].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 51)
	surfaceElements.labels[40] = surface.makeLabelField(187, 16, 10, 1)

	surfaceElements.buttons[41] = surface.makeButton(198, 11, 10, 10)
	surfaceElements.buttons[41].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 52)
	surfaceElements.labels[41] = surface.makeLabelField(198, 16, 10, 1)

	surfaceElements.buttons[42] = surface.makeButton(209, 11, 10, 10)
	surfaceElements.buttons[42].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 53)
	surfaceElements.labels[42] = surface.makeLabelField(209, 16, 10, 1)

	surfaceElements.buttons[43] = surface.makeButton(220, 11, 10, 10)
	surfaceElements.buttons[43].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 54)
	surfaceElements.labels[43] = surface.makeLabelField(220, 16, 10, 1)

	surfaceElements.buttons[44] = surface.makeButton(231, 11, 10, 10)
	surfaceElements.buttons[44].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 55)
	surfaceElements.labels[44] = surface.makeLabelField(231, 16, 10, 1)

	surfaceElements.buttons[45] = surface.makeButton(242, 11, 10, 10)
	surfaceElements.buttons[45].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 56)
	surfaceElements.labels[45] = surface.makeLabelField(242, 16, 10, 1)

	surfaceElements.buttons[46] = surface.makeButton(0, 22, 10, 10)
	surfaceElements.buttons[46].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 57)
	surfaceElements.labels[46] = surface.makeLabelField(0, 27, 10, 1)

	surfaceElements.buttons[47] = surface.makeButton(11, 22, 10, 10)
	surfaceElements.buttons[47].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 58)
	surfaceElements.labels[47] = surface.makeLabelField(11, 27, 10, 1)

	surfaceElements.buttons[48] = surface.makeButton(22, 22, 10, 10)
	surfaceElements.buttons[48].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 59)
	surfaceElements.labels[48] = surface.makeLabelField(22, 27, 10, 1)

	surfaceElements.buttons[49] = surface.makeButton(33, 22, 10, 10)
	surfaceElements.buttons[49].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 60)
	surfaceElements.labels[49] = surface.makeLabelField(33, 27, 10, 1)

	surfaceElements.buttons[50] = surface.makeButton(44, 22, 10, 10)
	surfaceElements.buttons[50].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 61)
	surfaceElements.labels[50] = surface.makeLabelField(44, 27, 10, 1)

	surfaceElements.buttons[51] = surface.makeButton(55, 22, 10, 10)
	surfaceElements.buttons[51].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 62)
	surfaceElements.labels[51] = surface.makeLabelField(55, 27, 10, 1)

	surfaceElements.buttons[52] = surface.makeButton(66, 22, 10, 10)
	surfaceElements.buttons[52].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 63)
	surfaceElements.labels[52] = surface.makeLabelField(66, 27, 10, 1)

	surfaceElements.buttons[53] = surface.makeButton(77, 22, 10, 10)
	surfaceElements.buttons[53].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 64)
	surfaceElements.labels[53] = surface.makeLabelField(77, 27, 10, 1)

	surfaceElements.buttons[54] = surface.makeButton(88, 22, 10, 10)
	surfaceElements.buttons[54].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 65)
	surfaceElements.labels[54] = surface.makeLabelField(88, 27, 10, 1)

	surfaceElements.buttons[55] = surface.makeButton(99, 22, 10, 10)
	surfaceElements.buttons[55].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 66)
	surfaceElements.labels[55] = surface.makeLabelField(99, 27, 10, 1)

	surfaceElements.buttons[56] = surface.makeButton(110, 22, 10, 10)
	surfaceElements.buttons[56].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 67)
	surfaceElements.labels[56] = surface.makeLabelField(110, 27, 10, 1)

	surfaceElements.buttons[57] = surface.makeButton(121, 22, 10, 10)
	surfaceElements.buttons[57].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 68)
	surfaceElements.labels[57] = surface.makeLabelField(121, 27, 10, 1)

	surfaceElements.buttons[58] = surface.makeButton(132, 22, 10, 10)
	surfaceElements.buttons[58].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 69)
	surfaceElements.labels[58] = surface.makeLabelField(132, 27, 10, 1)

	surfaceElements.buttons[59] = surface.makeButton(143, 22, 10, 10)
	surfaceElements.buttons[59].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 70)
	surfaceElements.labels[59] = surface.makeLabelField(143, 27, 10, 1)

	surfaceElements.buttons[60] = surface.makeButton(154, 22, 10, 10)
	surfaceElements.buttons[60].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 71)
	surfaceElements.labels[60] = surface.makeLabelField(154, 27, 10, 1)

	surfaceElements.buttons[61] = surface.makeButton(165, 22, 10, 10)
	surfaceElements.buttons[61].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 72)
	surfaceElements.labels[61] = surface.makeLabelField(165, 27, 10, 1)

	surfaceElements.buttons[62] = surface.makeButton(176, 22, 10, 10)
	surfaceElements.buttons[62].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 73)
	surfaceElements.labels[62] = surface.makeLabelField(176, 27, 10, 1)

	surfaceElements.buttons[63] = surface.makeButton(187, 22, 10, 10)
	surfaceElements.buttons[63].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 74)
	surfaceElements.labels[63] = surface.makeLabelField(187, 27, 10, 1)

	surfaceElements.buttons[64] = surface.makeButton(198, 22, 10, 10)
	surfaceElements.buttons[64].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 75)
	surfaceElements.labels[64] = surface.makeLabelField(198, 27, 10, 1)

	surfaceElements.buttons[65] = surface.makeButton(209, 22, 10, 10)
	surfaceElements.buttons[65].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 76)
	surfaceElements.labels[65] = surface.makeLabelField(209, 27, 10, 1)

	surfaceElements.buttons[66] = surface.makeButton(220, 22, 10, 10)
	surfaceElements.buttons[66].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 77)
	surfaceElements.labels[66] = surface.makeLabelField(220, 27, 10, 1)

	surfaceElements.buttons[67] = surface.makeButton(231, 22, 10, 10)
	surfaceElements.buttons[67].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 78)
	surfaceElements.labels[67] = surface.makeLabelField(231, 27, 10, 1)

	surfaceElements.buttons[68] = surface.makeButton(242, 22, 10, 10)
	surfaceElements.buttons[68].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 79)
	surfaceElements.labels[68] = surface.makeLabelField(242, 27, 10, 1)

	surfaceElements.buttons[69] = surface.makeButton(0, 33, 10, 10)
	surfaceElements.buttons[69].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 80)
	surfaceElements.labels[69] = surface.makeLabelField(0, 38, 10, 1)

	surfaceElements.buttons[70] = surface.makeButton(11, 33, 10, 10)
	surfaceElements.buttons[70].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 81)
	surfaceElements.labels[70] = surface.makeLabelField(11, 38, 10, 1)

	surfaceElements.buttons[71] = surface.makeButton(22, 33, 10, 10)
	surfaceElements.buttons[71].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 82)
	surfaceElements.labels[71] = surface.makeLabelField(22, 38, 10, 1)

	surfaceElements.buttons[72] = surface.makeButton(33, 33, 10, 10)
	surfaceElements.buttons[72].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 83)
	surfaceElements.labels[72] = surface.makeLabelField(33, 38, 10, 1)

	surfaceElements.buttons[73] = surface.makeButton(44, 33, 10, 10)
	surfaceElements.buttons[73].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 84)
	surfaceElements.labels[73] = surface.makeLabelField(44, 38, 10, 1)

	surfaceElements.buttons[74] = surface.makeButton(55, 33, 10, 10)
	surfaceElements.buttons[74].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 85)
	surfaceElements.labels[74] = surface.makeLabelField(55, 38, 10, 1)

	surfaceElements.buttons[75] = surface.makeButton(66, 33, 10, 10)
	surfaceElements.buttons[75].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 86)
	surfaceElements.labels[75] = surface.makeLabelField(66, 38, 10, 1)

	surfaceElements.buttons[76] = surface.makeButton(77, 33, 10, 10)
	surfaceElements.buttons[76].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 87)
	surfaceElements.labels[76] = surface.makeLabelField(77, 38, 10, 1)

	surfaceElements.buttons[77] = surface.makeButton(88, 33, 10, 10)
	surfaceElements.buttons[77].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 88)
	surfaceElements.labels[77] = surface.makeLabelField(88, 38, 10, 1)

	surfaceElements.buttons[78] = surface.makeButton(99, 33, 10, 10)
	surfaceElements.buttons[78].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 89)
	surfaceElements.labels[78] = surface.makeLabelField(99, 38, 10, 1)

	surfaceElements.buttons[79] = surface.makeButton(110, 33, 10, 10)
	surfaceElements.buttons[79].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 90)
	surfaceElements.labels[79] = surface.makeLabelField(110, 38, 10, 1)

	surfaceElements.buttons[80] = surface.makeButton(121, 33, 10, 10)
	surfaceElements.buttons[80].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 91)
	surfaceElements.labels[80] = surface.makeLabelField(121, 38, 10, 1)

	surfaceElements.buttons[81] = surface.makeButton(132, 33, 10, 10)
	surfaceElements.buttons[81].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 92)
	surfaceElements.labels[81] = surface.makeLabelField(132, 38, 10, 1)

	surfaceElements.buttons[82] = surface.makeButton(143, 33, 10, 10)
	surfaceElements.buttons[82].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 93)
	surfaceElements.labels[82] = surface.makeLabelField(143, 38, 10, 1)

	surfaceElements.buttons[83] = surface.makeButton(154, 33, 10, 10)
	surfaceElements.buttons[83].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 94)
	surfaceElements.labels[83] = surface.makeLabelField(154, 38, 10, 1)

	surfaceElements.buttons[84] = surface.makeButton(165, 33, 10, 10)
	surfaceElements.buttons[84].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 95)
	surfaceElements.labels[84] = surface.makeLabelField(165, 38, 10, 1)

	surfaceElements.buttons[85] = surface.makeButton(176, 33, 10, 10)
	surfaceElements.buttons[85].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 96)
	surfaceElements.labels[85] = surface.makeLabelField(176, 38, 10, 1)

	surfaceElements.buttons[86] = surface.makeButton(187, 33, 10, 10)
	surfaceElements.buttons[86].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 97)
	surfaceElements.labels[86] = surface.makeLabelField(187, 38, 10, 1)

	surfaceElements.buttons[87] = surface.makeButton(198, 33, 10, 10)
	surfaceElements.buttons[87].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 98)
	surfaceElements.labels[87] = surface.makeLabelField(198, 38, 10, 1)

	surfaceElements.buttons[88] = surface.makeButton(209, 33, 10, 10)
	surfaceElements.buttons[88].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 99)
	surfaceElements.labels[88] = surface.makeLabelField(209, 38, 10, 1)

	surfaceElements.buttons[89] = surface.makeButton(220, 33, 10, 10)
	surfaceElements.buttons[89].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 100)
	surfaceElements.labels[89] = surface.makeLabelField(220, 38, 10, 1)

	surfaceElements.buttons[90] = surface.makeButton(231, 33, 10, 10)
	surfaceElements.buttons[90].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 101)
	surfaceElements.labels[90] = surface.makeLabelField(231, 38, 10, 1)

	surfaceElements.buttons[91] = surface.makeButton(242, 33, 10, 10)
	surfaceElements.buttons[91].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 102)
	surfaceElements.labels[91] = surface.makeLabelField(242, 38, 10, 1)

	surfaceElements.buttons[92] = surface.makeButton(0, 44, 10, 10)
	surfaceElements.buttons[92].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 103)
	surfaceElements.labels[92] = surface.makeLabelField(0, 49, 10, 1)

	surfaceElements.buttons[93] = surface.makeButton(11, 44, 10, 10)
	surfaceElements.buttons[93].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 104)
	surfaceElements.labels[93] = surface.makeLabelField(11, 49, 10, 1)

	surfaceElements.buttons[94] = surface.makeButton(22, 44, 10, 10)
	surfaceElements.buttons[94].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 105)
	surfaceElements.labels[94] = surface.makeLabelField(22, 49, 10, 1)

	surfaceElements.buttons[95] = surface.makeButton(33, 44, 10, 10)
	surfaceElements.buttons[95].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 106)
	surfaceElements.labels[95] = surface.makeLabelField(33, 49, 10, 1)

	surfaceElements.buttons[96] = surface.makeButton(44, 44, 10, 10)
	surfaceElements.buttons[96].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 107)
	surfaceElements.labels[96] = surface.makeLabelField(44, 49, 10, 1)

	surfaceElements.buttons[97] = surface.makeButton(55, 44, 10, 10)
	surfaceElements.buttons[97].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 108)
	surfaceElements.labels[97] = surface.makeLabelField(55, 49, 10, 1)

	surfaceElements.buttons[98] = surface.makeButton(66, 44, 10, 10)
	surfaceElements.buttons[98].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 109)
	surfaceElements.labels[98] = surface.makeLabelField(66, 49, 10, 1)

	surfaceElements.buttons[99] = surface.makeButton(77, 44, 10, 10)
	surfaceElements.buttons[99].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 110)
	surfaceElements.labels[99] = surface.makeLabelField(77, 49, 10, 1)

	surfaceElements.buttons[100] = surface.makeButton(88, 44, 10, 10)
	surfaceElements.buttons[100].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 1)
	surfaceElements.labels[100] = surface.makeLabelField(88, 49, 10, 1)

	surfaceElements.buttons[101] = surface.makeButton(99, 44, 10, 10)
	surfaceElements.buttons[101].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 2)
	surfaceElements.labels[101] = surface.makeLabelField(99, 49, 10, 1)

	surfaceElements.buttons[102] = surface.makeButton(110, 44, 10, 10)
	surfaceElements.buttons[102].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 3)
	surfaceElements.labels[102] = surface.makeLabelField(110, 49, 10, 1)

	surfaceElements.buttons[103] = surface.makeButton(121, 44, 10, 10)
	surfaceElements.buttons[103].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 4)
	surfaceElements.labels[103] = surface.makeLabelField(121, 49, 10, 1)

	surfaceElements.buttons[104] = surface.makeButton(132, 44, 10, 10)
	surfaceElements.buttons[104].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 5)
	surfaceElements.labels[104] = surface.makeLabelField(132, 49, 10, 1)

	surfaceElements.buttons[105] = surface.makeButton(143, 44, 10, 10)
	surfaceElements.buttons[105].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 6)
	surfaceElements.labels[105] = surface.makeLabelField(143, 49, 10, 1)

	surfaceElements.buttons[106] = surface.makeButton(154, 44, 10, 10)
	surfaceElements.buttons[106].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 7)
	surfaceElements.labels[106] = surface.makeLabelField(154, 49, 10, 1)

	surfaceElements.buttons[107] = surface.makeButton(165, 44, 10, 10)
	surfaceElements.buttons[107].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 8)
	surfaceElements.labels[107] = surface.makeLabelField(165, 49, 10, 1)

	surfaceElements.buttons[108] = surface.makeButton(176, 44, 10, 10)
	surfaceElements.buttons[108].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 9)
	surfaceElements.labels[108] = surface.makeLabelField(176, 49, 10, 1)

	surfaceElements.buttons[109] = surface.makeButton(187, 44, 10, 10)
	surfaceElements.buttons[109].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 10)
	surfaceElements.labels[109] = surface.makeLabelField(187, 49, 10, 1)

	surfaceElements.buttons[110] = surface.makeButton(198, 44, 10, 10)
	surfaceElements.buttons[110].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 11)
	surfaceElements.labels[110] = surface.makeLabelField(198, 49, 10, 1)

	surfaceElements.buttons[111] = surface.makeButton(209, 44, 10, 10)
	surfaceElements.buttons[111].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 12)
	surfaceElements.labels[111] = surface.makeLabelField(209, 49, 10, 1)

	surfaceElements.buttons[112] = surface.makeButton(220, 44, 10, 10)
	surfaceElements.buttons[112].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 13)
	surfaceElements.labels[112] = surface.makeLabelField(220, 49, 10, 1)

	surfaceElements.buttons[113] = surface.makeButton(231, 44, 10, 10)
	surfaceElements.buttons[113].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 14)
	surfaceElements.labels[113] = surface.makeLabelField(231, 49, 10, 1)

	surfaceElements.buttons[114] = surface.makeButton(242, 44, 10, 10)
	surfaceElements.buttons[114].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 15)
	surfaceElements.labels[114] = surface.makeLabelField(242, 49, 10, 1)

	surfaceElements.buttons[115] = surface.makeButton(0, 55, 10, 10)
	surfaceElements.buttons[115].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 16)
	surfaceElements.labels[115] = surface.makeLabelField(0, 60, 10, 1)

	surfaceElements.buttons[116] = surface.makeButton(11, 55, 10, 10)
	surfaceElements.buttons[116].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 17)
	surfaceElements.labels[116] = surface.makeLabelField(11, 60, 10, 1)

	surfaceElements.buttons[117] = surface.makeButton(22, 55, 10, 10)
	surfaceElements.buttons[117].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 18)
	surfaceElements.labels[117] = surface.makeLabelField(22, 60, 10, 1)

	surfaceElements.buttons[118] = surface.makeButton(33, 55, 10, 10)
	surfaceElements.buttons[118].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 19)
	surfaceElements.labels[118] = surface.makeLabelField(33, 60, 10, 1)

	surfaceElements.buttons[119] = surface.makeButton(44, 55, 10, 10)
	surfaceElements.buttons[119].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 20)
	surfaceElements.labels[119] = surface.makeLabelField(44, 60, 10, 1)

	surfaceElements.buttons[120] = surface.makeButton(55, 55, 10, 10)
	surfaceElements.buttons[120].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 21)
	surfaceElements.labels[120] = surface.makeLabelField(55, 60, 10, 1)

	surfaceElements.buttons[121] = surface.makeButton(66, 55, 10, 10)
	surfaceElements.buttons[121].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 22)
	surfaceElements.labels[121] = surface.makeLabelField(66, 60, 10, 1)

	surfaceElements.buttons[122] = surface.makeButton(77, 55, 10, 10)
	surfaceElements.buttons[122].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 23)
	surfaceElements.labels[122] = surface.makeLabelField(77, 60, 10, 1)

	surfaceElements.buttons[123] = surface.makeButton(88, 55, 10, 10)
	surfaceElements.buttons[123].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 24)
	surfaceElements.labels[123] = surface.makeLabelField(88, 60, 10, 1)

	surfaceElements.buttons[124] = surface.makeButton(99, 55, 10, 10)
	surfaceElements.buttons[124].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 25)
	surfaceElements.labels[124] = surface.makeLabelField(99, 60, 10, 1)

	surfaceElements.buttons[125] = surface.makeButton(110, 55, 10, 10)
	surfaceElements.buttons[125].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 26)
	surfaceElements.labels[125] = surface.makeLabelField(110, 60, 10, 1)

	surfaceElements.buttons[126] = surface.makeButton(121, 55, 10, 10)
	surfaceElements.buttons[126].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 27)
	surfaceElements.labels[126] = surface.makeLabelField(121, 60, 10, 1)

	surfaceElements.buttons[127] = surface.makeButton(132, 55, 10, 10)
	surfaceElements.buttons[127].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 28)
	surfaceElements.labels[127] = surface.makeLabelField(132, 60, 10, 1)

	surfaceElements.buttons[128] = surface.makeButton(143, 55, 10, 10)
	surfaceElements.buttons[128].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 29)
	surfaceElements.labels[128] = surface.makeLabelField(143, 60, 10, 1)

	surfaceElements.buttons[129] = surface.makeButton(154, 55, 10, 10)
	surfaceElements.buttons[129].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 30)
	surfaceElements.labels[129] = surface.makeLabelField(154, 60, 10, 1)

	surfaceElements.buttons[130] = surface.makeButton(165, 55, 10, 10)
	surfaceElements.buttons[130].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 31)
	surfaceElements.labels[130] = surface.makeLabelField(165, 60, 10, 1)

	surfaceElements.buttons[131] = surface.makeButton(176, 55, 10, 10)
	surfaceElements.buttons[131].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 32)
	surfaceElements.labels[131] = surface.makeLabelField(176, 60, 10, 1)

	surfaceElements.buttons[132] = surface.makeButton(187, 55, 10, 10)
	surfaceElements.buttons[132].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 33)
	surfaceElements.labels[132] = surface.makeLabelField(187, 60, 10, 1)

	surfaceElements.buttons[133] = surface.makeButton(198, 55, 10, 10)
	surfaceElements.buttons[133].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 34)
	surfaceElements.labels[133] = surface.makeLabelField(198, 60, 10, 1)

	surfaceElements.buttons[134] = surface.makeButton(209, 55, 10, 10)
	surfaceElements.buttons[134].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 35)
	surfaceElements.labels[134] = surface.makeLabelField(209, 60, 10, 1)

	surfaceElements.buttons[135] = surface.makeButton(220, 55, 10, 10)
	surfaceElements.buttons[135].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 36)
	surfaceElements.labels[135] = surface.makeLabelField(220, 60, 10, 1)

	surfaceElements.buttons[136] = surface.makeButton(231, 55, 10, 10)
	surfaceElements.buttons[136].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 37)
	surfaceElements.labels[136] = surface.makeLabelField(231, 60, 10, 1)

	surfaceElements.buttons[137] = surface.makeButton(242, 55, 10, 10)
	surfaceElements.buttons[137].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 38)
	surfaceElements.labels[137] = surface.makeLabelField(242, 60, 10, 1)

	surfaceElements.buttons[138] = surface.makeButton(0, 66, 10, 10)
	surfaceElements.buttons[138].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 39)
	surfaceElements.labels[138] = surface.makeLabelField(0, 71, 10, 1)

	surfaceElements.buttons[139] = surface.makeButton(11, 66, 10, 10)
	surfaceElements.buttons[139].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 40)
	surfaceElements.labels[139] = surface.makeLabelField(11, 71, 10, 1)

	surfaceElements.buttons[140] = surface.makeButton(22, 66, 10, 10)
	surfaceElements.buttons[140].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 41)
	surfaceElements.labels[140] = surface.makeLabelField(22, 71, 10, 1)

	surfaceElements.buttons[141] = surface.makeButton(33, 66, 10, 10)
	surfaceElements.buttons[141].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 42)
	surfaceElements.labels[141] = surface.makeLabelField(33, 71, 10, 1)

	surfaceElements.buttons[142] = surface.makeButton(44, 66, 10, 10)
	surfaceElements.buttons[142].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 43)
	surfaceElements.labels[142] = surface.makeLabelField(44, 71, 10, 1)

	surfaceElements.buttons[143] = surface.makeButton(55, 66, 10, 10)
	surfaceElements.buttons[143].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 44)
	surfaceElements.labels[143] = surface.makeLabelField(55, 71, 10, 1)

	surfaceElements.buttons[144] = surface.makeButton(66, 66, 10, 10)
	surfaceElements.buttons[144].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 45)
	surfaceElements.labels[144] = surface.makeLabelField(66, 71, 10, 1)

	surfaceElements.buttons[145] = surface.makeButton(77, 66, 10, 10)
	surfaceElements.buttons[145].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 46)
	surfaceElements.labels[145] = surface.makeLabelField(77, 71, 10, 1)

	surfaceElements.buttons[146] = surface.makeButton(88, 66, 10, 10)
	surfaceElements.buttons[146].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 47)
	surfaceElements.labels[146] = surface.makeLabelField(88, 71, 10, 1)

	surfaceElements.buttons[147] = surface.makeButton(99, 66, 10, 10)
	surfaceElements.buttons[147].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 48)
	surfaceElements.labels[147] = surface.makeLabelField(99, 71, 10, 1)

	surfaceElements.buttons[148] = surface.makeButton(110, 66, 10, 10)
	surfaceElements.buttons[148].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 49)
	surfaceElements.labels[148] = surface.makeLabelField(110, 71, 10, 1)

	surfaceElements.buttons[149] = surface.makeButton(121, 66, 10, 10)
	surfaceElements.buttons[149].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 50)
	surfaceElements.labels[149] = surface.makeLabelField(121, 71, 10, 1)

	surfaceElements.buttons[150] = surface.makeButton(132, 66, 10, 10)
	surfaceElements.buttons[150].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 51)
	surfaceElements.labels[150] = surface.makeLabelField(132, 71, 10, 1)

	surfaceElements.buttons[151] = surface.makeButton(143, 66, 10, 10)
	surfaceElements.buttons[151].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 52)
	surfaceElements.labels[151] = surface.makeLabelField(143, 71, 10, 1)

	surfaceElements.buttons[152] = surface.makeButton(154, 66, 10, 10)
	surfaceElements.buttons[152].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 53)
	surfaceElements.labels[152] = surface.makeLabelField(154, 71, 10, 1)

	surfaceElements.buttons[153] = surface.makeButton(165, 66, 10, 10)
	surfaceElements.buttons[153].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 54)
	surfaceElements.labels[153] = surface.makeLabelField(165, 71, 10, 1)

	surfaceElements.buttons[154] = surface.makeButton(176, 66, 10, 10)
	surfaceElements.buttons[154].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 55)
	surfaceElements.labels[154] = surface.makeLabelField(176, 71, 10, 1)

	surfaceElements.buttons[155] = surface.makeButton(187, 66, 10, 10)
	surfaceElements.buttons[155].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 56)
	surfaceElements.labels[155] = surface.makeLabelField(187, 71, 10, 1)

	surfaceElements.buttons[156] = surface.makeButton(198, 66, 10, 10)
	surfaceElements.buttons[156].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 57)
	surfaceElements.labels[156] = surface.makeLabelField(198, 71, 10, 1)

	surfaceElements.buttons[157] = surface.makeButton(209, 66, 10, 10)
	surfaceElements.buttons[157].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 58)
	surfaceElements.labels[157] = surface.makeLabelField(209, 71, 10, 1)

	surfaceElements.buttons[158] = surface.makeButton(220, 66, 10, 10)
	surfaceElements.buttons[158].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 59)
	surfaceElements.labels[158] = surface.makeLabelField(220, 71, 10, 1)

	surfaceElements.buttons[159] = surface.makeButton(231, 66, 10, 10)
	surfaceElements.buttons[159].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 60)
	surfaceElements.labels[159] = surface.makeLabelField(231, 71, 10, 1)

	surfaceElements.buttons[160] = surface.makeButton(242, 66, 10, 10)
	surfaceElements.buttons[160].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 61)
	surfaceElements.labels[160] = surface.makeLabelField(242, 71, 10, 1)

	surfaceElements.buttons[161] = surface.makeButton(0, 77, 10, 10)
	surfaceElements.buttons[161].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 62)
	surfaceElements.labels[161] = surface.makeLabelField(0, 82, 10, 1)

	surfaceElements.buttons[162] = surface.makeButton(11, 77, 10, 10)
	surfaceElements.buttons[162].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 63)
	surfaceElements.labels[162] = surface.makeLabelField(11, 82, 10, 1)

	surfaceElements.buttons[163] = surface.makeButton(22, 77, 10, 10)
	surfaceElements.buttons[163].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 64)
	surfaceElements.labels[163] = surface.makeLabelField(22, 82, 10, 1)

	surfaceElements.buttons[164] = surface.makeButton(33, 77, 10, 10)
	surfaceElements.buttons[164].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 65)
	surfaceElements.labels[164] = surface.makeLabelField(33, 82, 10, 1)

	surfaceElements.buttons[165] = surface.makeButton(44, 77, 10, 10)
	surfaceElements.buttons[165].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 66)
	surfaceElements.labels[165] = surface.makeLabelField(44, 82, 10, 1)

	surfaceElements.buttons[166] = surface.makeButton(55, 77, 10, 10)
	surfaceElements.buttons[166].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 67)
	surfaceElements.labels[166] = surface.makeLabelField(55, 82, 10, 1)

	surfaceElements.buttons[167] = surface.makeButton(66, 77, 10, 10)
	surfaceElements.buttons[167].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 68)
	surfaceElements.labels[167] = surface.makeLabelField(66, 82, 10, 1)

	surfaceElements.buttons[168] = surface.makeButton(77, 77, 10, 10)
	surfaceElements.buttons[168].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 69)
	surfaceElements.labels[168] = surface.makeLabelField(77, 82, 10, 1)

	surfaceElements.buttons[169] = surface.makeButton(88, 77, 10, 10)
	surfaceElements.buttons[169].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 70)
	surfaceElements.labels[169] = surface.makeLabelField(88, 82, 10, 1)

	surfaceElements.buttons[170] = surface.makeButton(99, 77, 10, 10)
	surfaceElements.buttons[170].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 71)
	surfaceElements.labels[170] = surface.makeLabelField(99, 82, 10, 1)

	surfaceElements.buttons[171] = surface.makeButton(110, 77, 10, 10)
	surfaceElements.buttons[171].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 72)
	surfaceElements.labels[171] = surface.makeLabelField(110, 82, 10, 1)

	surfaceElements.buttons[172] = surface.makeButton(121, 77, 10, 10)
	surfaceElements.buttons[172].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 73)
	surfaceElements.labels[172] = surface.makeLabelField(121, 82, 10, 1)

	surfaceElements.buttons[173] = surface.makeButton(132, 77, 10, 10)
	surfaceElements.buttons[173].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 74)
	surfaceElements.labels[173] = surface.makeLabelField(132, 82, 10, 1)

	surfaceElements.buttons[174] = surface.makeButton(143, 77, 10, 10)
	surfaceElements.buttons[174].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 75)
	surfaceElements.labels[174] = surface.makeLabelField(143, 82, 10, 1)

	surfaceElements.buttons[175] = surface.makeButton(154, 77, 10, 10)
	surfaceElements.buttons[175].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 76)
	surfaceElements.labels[175] = surface.makeLabelField(154, 82, 10, 1)

	surfaceElements.buttons[176] = surface.makeButton(165, 77, 10, 10)
	surfaceElements.buttons[176].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 77)
	surfaceElements.labels[176] = surface.makeLabelField(165, 82, 10, 1)

	surfaceElements.buttons[177] = surface.makeButton(176, 77, 10, 10)
	surfaceElements.buttons[177].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 78)
	surfaceElements.labels[177] = surface.makeLabelField(176, 82, 10, 1)

	surfaceElements.buttons[178] = surface.makeButton(187, 77, 10, 10)
	surfaceElements.buttons[178].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 79)
	surfaceElements.labels[178] = surface.makeLabelField(187, 82, 10, 1)

	surfaceElements.buttons[179] = surface.makeButton(198, 77, 10, 10)
	surfaceElements.buttons[179].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 80)
	surfaceElements.labels[179] = surface.makeLabelField(198, 82, 10, 1)

	surfaceElements.buttons[180] = surface.makeButton(209, 77, 10, 10)
	surfaceElements.buttons[180].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 81)
	surfaceElements.labels[180] = surface.makeLabelField(209, 82, 10, 1)

	surfaceElements.buttons[181] = surface.makeButton(220, 77, 10, 10)
	surfaceElements.buttons[181].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 82)
	surfaceElements.labels[181] = surface.makeLabelField(220, 82, 10, 1)

	surfaceElements.buttons[182] = surface.makeButton(231, 77, 10, 10)
	surfaceElements.buttons[182].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 83)
	surfaceElements.labels[182] = surface.makeLabelField(231, 82, 10, 1)

	surfaceElements.buttons[183] = surface.makeButton(242, 77, 10, 10)
	surfaceElements.buttons[183].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 84)
	surfaceElements.labels[183] = surface.makeLabelField(242, 82, 10, 1)

	surfaceElements.buttons[184] = surface.makeButton(0, 88, 10, 10)
	surfaceElements.buttons[184].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 85)
	surfaceElements.labels[184] = surface.makeLabelField(0, 93, 10, 1)

	surfaceElements.buttons[185] = surface.makeButton(11, 88, 10, 10)
	surfaceElements.buttons[185].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 86)
	surfaceElements.labels[185] = surface.makeLabelField(11, 93, 10, 1)

	surfaceElements.buttons[186] = surface.makeButton(22, 88, 10, 10)
	surfaceElements.buttons[186].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 87)
	surfaceElements.labels[186] = surface.makeLabelField(22, 93, 10, 1)

	surfaceElements.buttons[187] = surface.makeButton(33, 88, 10, 10)
	surfaceElements.buttons[187].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 88)
	surfaceElements.labels[187] = surface.makeLabelField(33, 93, 10, 1)

	surfaceElements.buttons[188] = surface.makeButton(44, 88, 10, 10)
	surfaceElements.buttons[188].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 89)
	surfaceElements.labels[188] = surface.makeLabelField(44, 93, 10, 1)

	surfaceElements.buttons[189] = surface.makeButton(55, 88, 10, 10)
	surfaceElements.buttons[189].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 90)
	surfaceElements.labels[189] = surface.makeLabelField(55, 93, 10, 1)

	surfaceElements.buttons[190] = surface.makeButton(66, 88, 10, 10)
	surfaceElements.buttons[190].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 91)
	surfaceElements.labels[190] = surface.makeLabelField(66, 93, 10, 1)

	surfaceElements.buttons[191] = surface.makeButton(77, 88, 10, 10)
	surfaceElements.buttons[191].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 92)
	surfaceElements.labels[191] = surface.makeLabelField(77, 93, 10, 1)

	surfaceElements.buttons[192] = surface.makeButton(88, 88, 10, 10)
	surfaceElements.buttons[192].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 93)
	surfaceElements.labels[192] = surface.makeLabelField(88, 93, 10, 1)

	surfaceElements.buttons[193] = surface.makeButton(99, 88, 10, 10)
	surfaceElements.buttons[193].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 94)
	surfaceElements.labels[193] = surface.makeLabelField(99, 93, 10, 1)

	surfaceElements.buttons[194] = surface.makeButton(110, 88, 10, 10)
	surfaceElements.buttons[194].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 95)
	surfaceElements.labels[194] = surface.makeLabelField(110, 93, 10, 1)

	surfaceElements.buttons[195] = surface.makeButton(121, 88, 10, 10)
	surfaceElements.buttons[195].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 96)
	surfaceElements.labels[195] = surface.makeLabelField(121, 93, 10, 1)

	surfaceElements.buttons[196] = surface.makeButton(132, 88, 10, 10)
	surfaceElements.buttons[196].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 97)
	surfaceElements.labels[196] = surface.makeLabelField(132, 93, 10, 1)

	surfaceElements.buttons[197] = surface.makeButton(143, 88, 10, 10)
	surfaceElements.buttons[197].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 98)
	surfaceElements.labels[197] = surface.makeLabelField(143, 93, 10, 1)

	surfaceElements.buttons[198] = surface.makeButton(154, 88, 10, 10)
	surfaceElements.buttons[198].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 99)
	surfaceElements.labels[198] = surface.makeLabelField(154, 93, 10, 1)

	surfaceElements.buttons[199] = surface.makeButton(165, 88, 10, 10)
	surfaceElements.buttons[199].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 100)
	surfaceElements.labels[199] = surface.makeLabelField(165, 93, 10, 1)

	surfaceElements.buttons[200] = surface.makeButton(176, 88, 10, 10)
	surfaceElements.buttons[200].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 11)
	surfaceElements.labels[200] = surface.makeLabelField(176, 93, 10, 1)

	surfaceElements.buttons[201] = surface.makeButton(187, 88, 10, 10)
	surfaceElements.buttons[201].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 12)
	surfaceElements.labels[201] = surface.makeLabelField(187, 93, 10, 1)

	surfaceElements.buttons[202] = surface.makeButton(198, 88, 10, 10)
	surfaceElements.buttons[202].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 13)
	surfaceElements.labels[202] = surface.makeLabelField(198, 93, 10, 1)

	surfaceElements.buttons[203] = surface.makeButton(209, 88, 10, 10)
	surfaceElements.buttons[203].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 14)
	surfaceElements.labels[203] = surface.makeLabelField(209, 93, 10, 1)

	surfaceElements.buttons[204] = surface.makeButton(220, 88, 10, 10)
	surfaceElements.buttons[204].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 15)
	surfaceElements.labels[204] = surface.makeLabelField(220, 93, 10, 1)

	surfaceElements.buttons[205] = surface.makeButton(231, 88, 10, 10)
	surfaceElements.buttons[205].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 16)
	surfaceElements.labels[205] = surface.makeLabelField(231, 93, 10, 1)

	surfaceElements.buttons[206] = surface.makeButton(242, 88, 10, 10)
	surfaceElements.buttons[206].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 17)
	surfaceElements.labels[206] = surface.makeLabelField(242, 93, 10, 1)

	surfaceElements.buttons[207] = surface.makeButton(0, 99, 10, 10)
	surfaceElements.buttons[207].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 18)
	surfaceElements.labels[207] = surface.makeLabelField(0, 104, 10, 1)

	surfaceElements.buttons[208] = surface.makeButton(11, 99, 10, 10)
	surfaceElements.buttons[208].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 19)
	surfaceElements.labels[208] = surface.makeLabelField(11, 104, 10, 1)

	surfaceElements.buttons[209] = surface.makeButton(22, 99, 10, 10)
	surfaceElements.buttons[209].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 20)
	surfaceElements.labels[209] = surface.makeLabelField(22, 104, 10, 1)

	surfaceElements.buttons[210] = surface.makeButton(33, 99, 10, 10)
	surfaceElements.buttons[210].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 21)
	surfaceElements.labels[210] = surface.makeLabelField(33, 104, 10, 1)

	surfaceElements.buttons[211] = surface.makeButton(44, 99, 10, 10)
	surfaceElements.buttons[211].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 22)
	surfaceElements.labels[211] = surface.makeLabelField(44, 104, 10, 1)

	surfaceElements.buttons[212] = surface.makeButton(55, 99, 10, 10)
	surfaceElements.buttons[212].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 23)
	surfaceElements.labels[212] = surface.makeLabelField(55, 104, 10, 1)

	surfaceElements.buttons[213] = surface.makeButton(66, 99, 10, 10)
	surfaceElements.buttons[213].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 24)
	surfaceElements.labels[213] = surface.makeLabelField(66, 104, 10, 1)

	surfaceElements.buttons[214] = surface.makeButton(77, 99, 10, 10)
	surfaceElements.buttons[214].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 25)
	surfaceElements.labels[214] = surface.makeLabelField(77, 104, 10, 1)

	surfaceElements.buttons[215] = surface.makeButton(88, 99, 10, 10)
	surfaceElements.buttons[215].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 26)
	surfaceElements.labels[215] = surface.makeLabelField(88, 104, 10, 1)

	surfaceElements.buttons[216] = surface.makeButton(99, 99, 10, 10)
	surfaceElements.buttons[216].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 27)
	surfaceElements.labels[216] = surface.makeLabelField(99, 104, 10, 1)

	surfaceElements.buttons[217] = surface.makeButton(110, 99, 10, 10)
	surfaceElements.buttons[217].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 28)
	surfaceElements.labels[217] = surface.makeLabelField(110, 104, 10, 1)

	surfaceElements.buttons[218] = surface.makeButton(121, 99, 10, 10)
	surfaceElements.buttons[218].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 29)
	surfaceElements.labels[218] = surface.makeLabelField(121, 104, 10, 1)

	surfaceElements.buttons[219] = surface.makeButton(132, 99, 10, 10)
	surfaceElements.buttons[219].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 30)
	surfaceElements.labels[219] = surface.makeLabelField(132, 104, 10, 1)

	surfaceElements.buttons[220] = surface.makeButton(143, 99, 10, 10)
	surfaceElements.buttons[220].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 31)
	surfaceElements.labels[220] = surface.makeLabelField(143, 104, 10, 1)

	surfaceElements.buttons[221] = surface.makeButton(154, 99, 10, 10)
	surfaceElements.buttons[221].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 32)
	surfaceElements.labels[221] = surface.makeLabelField(154, 104, 10, 1)

	surfaceElements.buttons[222] = surface.makeButton(165, 99, 10, 10)
	surfaceElements.buttons[222].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 33)
	surfaceElements.labels[222] = surface.makeLabelField(165, 104, 10, 1)

	surfaceElements.buttons[223] = surface.makeButton(176, 99, 10, 10)
	surfaceElements.buttons[223].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 34)
	surfaceElements.labels[223] = surface.makeLabelField(176, 104, 10, 1)

	surfaceElements.buttons[224] = surface.makeButton(187, 99, 10, 10)
	surfaceElements.buttons[224].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 35)
	surfaceElements.labels[224] = surface.makeLabelField(187, 104, 10, 1)

	surfaceElements.buttons[225] = surface.makeButton(198, 99, 10, 10)
	surfaceElements.buttons[225].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 36)
	surfaceElements.labels[225] = surface.makeLabelField(198, 104, 10, 1)

	surfaceElements.buttons[226] = surface.makeButton(209, 99, 10, 10)
	surfaceElements.buttons[226].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 37)
	surfaceElements.labels[226] = surface.makeLabelField(209, 104, 10, 1)

	surfaceElements.buttons[227] = surface.makeButton(220, 99, 10, 10)
	surfaceElements.buttons[227].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 38)
	surfaceElements.labels[227] = surface.makeLabelField(220, 104, 10, 1)

	surfaceElements.buttons[228] = surface.makeButton(231, 99, 10, 10)
	surfaceElements.buttons[228].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 39)
	surfaceElements.labels[228] = surface.makeLabelField(231, 104, 10, 1)

	surfaceElements.buttons[229] = surface.makeButton(242, 99, 10, 10)
	surfaceElements.buttons[229].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 40)
	surfaceElements.labels[229] = surface.makeLabelField(242, 104, 10, 1)

	surfaceElements.buttons[230] = surface.makeButton(0, 110, 10, 10)
	surfaceElements.buttons[230].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 41)
	surfaceElements.labels[230] = surface.makeLabelField(0, 115, 10, 1)

	surfaceElements.buttons[231] = surface.makeButton(11, 110, 10, 10)
	surfaceElements.buttons[231].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 42)
	surfaceElements.labels[231] = surface.makeLabelField(11, 115, 10, 1)

	surfaceElements.buttons[232] = surface.makeButton(22, 110, 10, 10)
	surfaceElements.buttons[232].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 43)
	surfaceElements.labels[232] = surface.makeLabelField(22, 115, 10, 1)

	surfaceElements.buttons[233] = surface.makeButton(33, 110, 10, 10)
	surfaceElements.buttons[233].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 44)
	surfaceElements.labels[233] = surface.makeLabelField(33, 115, 10, 1)

	surfaceElements.buttons[234] = surface.makeButton(44, 110, 10, 10)
	surfaceElements.buttons[234].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 45)
	surfaceElements.labels[234] = surface.makeLabelField(44, 115, 10, 1)

	surfaceElements.buttons[235] = surface.makeButton(55, 110, 10, 10)
	surfaceElements.buttons[235].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 46)
	surfaceElements.labels[235] = surface.makeLabelField(55, 115, 10, 1)

	surfaceElements.buttons[236] = surface.makeButton(66, 110, 10, 10)
	surfaceElements.buttons[236].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 47)
	surfaceElements.labels[236] = surface.makeLabelField(66, 115, 10, 1)

	surfaceElements.buttons[237] = surface.makeButton(77, 110, 10, 10)
	surfaceElements.buttons[237].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 48)
	surfaceElements.labels[237] = surface.makeLabelField(77, 115, 10, 1)

	surfaceElements.buttons[238] = surface.makeButton(88, 110, 10, 10)
	surfaceElements.buttons[238].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 49)
	surfaceElements.labels[238] = surface.makeLabelField(88, 115, 10, 1)

	surfaceElements.buttons[239] = surface.makeButton(99, 110, 10, 10)
	surfaceElements.buttons[239].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 50)
	surfaceElements.labels[239] = surface.makeLabelField(99, 115, 10, 1)

	surfaceElements.buttons[240] = surface.makeButton(110, 110, 10, 10)
	surfaceElements.buttons[240].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 51)
	surfaceElements.labels[240] = surface.makeLabelField(110, 115, 10, 1)

	surfaceElements.buttons[241] = surface.makeButton(121, 110, 10, 10)
	surfaceElements.buttons[241].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 52)
	surfaceElements.labels[241] = surface.makeLabelField(121, 115, 10, 1)

	surfaceElements.buttons[242] = surface.makeButton(132, 110, 10, 10)
	surfaceElements.buttons[242].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 53)
	surfaceElements.labels[242] = surface.makeLabelField(132, 115, 10, 1)

	surfaceElements.buttons[243] = surface.makeButton(143, 110, 10, 10)
	surfaceElements.buttons[243].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 54)
	surfaceElements.labels[243] = surface.makeLabelField(143, 115, 10, 1)

	surfaceElements.buttons[244] = surface.makeButton(154, 110, 10, 10)
	surfaceElements.buttons[244].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 55)
	surfaceElements.labels[244] = surface.makeLabelField(154, 115, 10, 1)

	surfaceElements.buttons[245] = surface.makeButton(165, 110, 10, 10)
	surfaceElements.buttons[245].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 56)
	surfaceElements.labels[245] = surface.makeLabelField(165, 115, 10, 1)

	surfaceElements.buttons[246] = surface.makeButton(176, 110, 10, 10)
	surfaceElements.buttons[246].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 57)
	surfaceElements.labels[246] = surface.makeLabelField(176, 115, 10, 1)

	surfaceElements.buttons[247] = surface.makeButton(187, 110, 10, 10)
	surfaceElements.buttons[247].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 58)
	surfaceElements.labels[247] = surface.makeLabelField(187, 115, 10, 1)

	surfaceElements.buttons[248] = surface.makeButton(198, 110, 10, 10)
	surfaceElements.buttons[248].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 59)
	surfaceElements.labels[248] = surface.makeLabelField(198, 115, 10, 1)

	surfaceElements.buttons[249] = surface.makeButton(209, 110, 10, 10)
	surfaceElements.buttons[249].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 60)
	surfaceElements.labels[249] = surface.makeLabelField(209, 115, 10, 1)

	surfaceElements.buttons[250] = surface.makeButton(220, 110, 10, 10)
	surfaceElements.buttons[250].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 61)
	surfaceElements.labels[250] = surface.makeLabelField(220, 115, 10, 1)

	surfaceElements.buttons[251] = surface.makeButton(231, 110, 10, 10)
	surfaceElements.buttons[251].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 62)
	surfaceElements.labels[251] = surface.makeLabelField(231, 115, 10, 1)

	surfaceElements.buttons[252] = surface.makeButton(242, 110, 10, 10)
	surfaceElements.buttons[252].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 63)
	surfaceElements.labels[252] = surface.makeLabelField(242, 115, 10, 1)

	surfaceElements.buttons[253] = surface.makeButton(0, 121, 10, 10)
	surfaceElements.buttons[253].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 64)
	surfaceElements.labels[253] = surface.makeLabelField(0, 126, 10, 1)

	surfaceElements.buttons[254] = surface.makeButton(11, 121, 10, 10)
	surfaceElements.buttons[254].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 65)
	surfaceElements.labels[254] = surface.makeLabelField(11, 126, 10, 1)

	surfaceElements.buttons[255] = surface.makeButton(22, 121, 10, 10)
	surfaceElements.buttons[255].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 66)
	surfaceElements.labels[255] = surface.makeLabelField(22, 126, 10, 1)

	surfaceElements.buttons[256] = surface.makeButton(33, 121, 10, 10)
	surfaceElements.buttons[256].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 67)
	surfaceElements.labels[256] = surface.makeLabelField(33, 126, 10, 1)

	surfaceElements.buttons[257] = surface.makeButton(44, 121, 10, 10)
	surfaceElements.buttons[257].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 68)
	surfaceElements.labels[257] = surface.makeLabelField(44, 126, 10, 1)

	surfaceElements.buttons[258] = surface.makeButton(55, 121, 10, 10)
	surfaceElements.buttons[258].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 69)
	surfaceElements.labels[258] = surface.makeLabelField(55, 126, 10, 1)

	surfaceElements.buttons[259] = surface.makeButton(66, 121, 10, 10)
	surfaceElements.buttons[259].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 70)
	surfaceElements.labels[259] = surface.makeLabelField(66, 126, 10, 1)

	surfaceElements.buttons[260] = surface.makeButton(77, 121, 10, 10)
	surfaceElements.buttons[260].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 71)
	surfaceElements.labels[260] = surface.makeLabelField(77, 126, 10, 1)

	surfaceElements.buttons[261] = surface.makeButton(88, 121, 10, 10)
	surfaceElements.buttons[261].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 72)
	surfaceElements.labels[261] = surface.makeLabelField(88, 126, 10, 1)

	surfaceElements.buttons[262] = surface.makeButton(99, 121, 10, 10)
	surfaceElements.buttons[262].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 73)
	surfaceElements.labels[262] = surface.makeLabelField(99, 126, 10, 1)

	surfaceElements.buttons[263] = surface.makeButton(110, 121, 10, 10)
	surfaceElements.buttons[263].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 74)
	surfaceElements.labels[263] = surface.makeLabelField(110, 126, 10, 1)

	surfaceElements.buttons[264] = surface.makeButton(121, 121, 10, 10)
	surfaceElements.buttons[264].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 75)
	surfaceElements.labels[264] = surface.makeLabelField(121, 126, 10, 1)

	surfaceElements.buttons[265] = surface.makeButton(132, 121, 10, 10)
	surfaceElements.buttons[265].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 76)
	surfaceElements.labels[265] = surface.makeLabelField(132, 126, 10, 1)

	surfaceElements.buttons[266] = surface.makeButton(143, 121, 10, 10)
	surfaceElements.buttons[266].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 77)
	surfaceElements.labels[266] = surface.makeLabelField(143, 126, 10, 1)

	surfaceElements.buttons[267] = surface.makeButton(154, 121, 10, 10)
	surfaceElements.buttons[267].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 78)
	surfaceElements.labels[267] = surface.makeLabelField(154, 126, 10, 1)

	surfaceElements.buttons[268] = surface.makeButton(165, 121, 10, 10)
	surfaceElements.buttons[268].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 79)
	surfaceElements.labels[268] = surface.makeLabelField(165, 126, 10, 1)

	surfaceElements.buttons[269] = surface.makeButton(176, 121, 10, 10)
	surfaceElements.buttons[269].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 80)
	surfaceElements.labels[269] = surface.makeLabelField(176, 126, 10, 1)

	surfaceElements.buttons[270] = surface.makeButton(187, 121, 10, 10)
	surfaceElements.buttons[270].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 81)
	surfaceElements.labels[270] = surface.makeLabelField(187, 126, 10, 1)

	surfaceElements.buttons[271] = surface.makeButton(198, 121, 10, 10)
	surfaceElements.buttons[271].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 82)
	surfaceElements.labels[271] = surface.makeLabelField(198, 126, 10, 1)

	surfaceElements.buttons[272] = surface.makeButton(209, 121, 10, 10)
	surfaceElements.buttons[272].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 83)
	surfaceElements.labels[272] = surface.makeLabelField(209, 126, 10, 1)

	surfaceElements.buttons[273] = surface.makeButton(220, 121, 10, 10)
	surfaceElements.buttons[273].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 84)
	surfaceElements.labels[273] = surface.makeLabelField(220, 126, 10, 1)

	surfaceElements.buttons[274] = surface.makeButton(231, 121, 10, 10)
	surfaceElements.buttons[274].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 85)
	surfaceElements.labels[274] = surface.makeLabelField(231, 126, 10, 1)

	surfaceElements.buttons[275] = surface.makeButton(242, 121, 10, 10)
	surfaceElements.buttons[275].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 86)
	surfaceElements.labels[275] = surface.makeLabelField(242, 126, 10, 1)

	surfaceElements.buttons[276] = surface.makeButton(0, 132, 10, 10)
	surfaceElements.buttons[276].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 87)
	surfaceElements.labels[276] = surface.makeLabelField(0, 137, 10, 1)

	surfaceElements.buttons[277] = surface.makeButton(11, 132, 10, 10)
	surfaceElements.buttons[277].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 88)
	surfaceElements.labels[277] = surface.makeLabelField(11, 137, 10, 1)

	surfaceElements.buttons[278] = surface.makeButton(22, 132, 10, 10)
	surfaceElements.buttons[278].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 89)
	surfaceElements.labels[278] = surface.makeLabelField(22, 137, 10, 1)

	surfaceElements.buttons[279] = surface.makeButton(33, 132, 10, 10)
	surfaceElements.buttons[279].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 90)
	surfaceElements.labels[279] = surface.makeLabelField(33, 137, 10, 1)

	surfaceElements.buttons[280] = surface.makeButton(44, 132, 10, 10)
	surfaceElements.buttons[280].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 91)
	surfaceElements.labels[280] = surface.makeLabelField(44, 137, 10, 1)

	surfaceElements.buttons[281] = surface.makeButton(55, 132, 10, 10)
	surfaceElements.buttons[281].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 92)
	surfaceElements.labels[281] = surface.makeLabelField(55, 137, 10, 1)

	surfaceElements.buttons[282] = surface.makeButton(66, 132, 10, 10)
	surfaceElements.buttons[282].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 93)
	surfaceElements.labels[282] = surface.makeLabelField(66, 137, 10, 1)

	surfaceElements.buttons[283] = surface.makeButton(77, 132, 10, 10)
	surfaceElements.buttons[283].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 94)
	surfaceElements.labels[283] = surface.makeLabelField(77, 137, 10, 1)

	surfaceElements.buttons[284] = surface.makeButton(88, 132, 10, 10)
	surfaceElements.buttons[284].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 95)
	surfaceElements.labels[284] = surface.makeLabelField(88, 137, 10, 1)

	surfaceElements.buttons[285] = surface.makeButton(99, 132, 10, 10)
	surfaceElements.buttons[285].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 96)
	surfaceElements.labels[285] = surface.makeLabelField(99, 137, 10, 1)

	surfaceElements.buttons[286] = surface.makeButton(110, 132, 10, 10)
	surfaceElements.buttons[286].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 97)
	surfaceElements.labels[286] = surface.makeLabelField(110, 137, 10, 1)

	surfaceElements.buttons[287] = surface.makeButton(121, 132, 10, 10)
	surfaceElements.buttons[287].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 98)
	surfaceElements.labels[287] = surface.makeLabelField(121, 137, 10, 1)

	surfaceElements.buttons[288] = surface.makeButton(132, 132, 10, 10)
	surfaceElements.buttons[288].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 99)
	surfaceElements.labels[288] = surface.makeLabelField(132, 137, 10, 1)

	surfaceElements.buttons[289] = surface.makeButton(143, 132, 10, 10)
	surfaceElements.buttons[289].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 100)
	surfaceElements.labels[289] = surface.makeLabelField(143, 137, 10, 1)

	surfaceElements.buttons[290] = surface.makeButton(154, 132, 10, 10)
	surfaceElements.buttons[290].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 101)
	surfaceElements.labels[290] = surface.makeLabelField(154, 137, 10, 1)

	surfaceElements.buttons[291] = surface.makeButton(165, 132, 10, 10)
	surfaceElements.buttons[291].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 102)
	surfaceElements.labels[291] = surface.makeLabelField(165, 137, 10, 1)

	surfaceElements.buttons[292] = surface.makeButton(176, 132, 10, 10)
	surfaceElements.buttons[292].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 103)
	surfaceElements.labels[292] = surface.makeLabelField(176, 137, 10, 1)

	surfaceElements.buttons[293] = surface.makeButton(187, 132, 10, 10)
	surfaceElements.buttons[293].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 104)
	surfaceElements.labels[293] = surface.makeLabelField(187, 137, 10, 1)

	surfaceElements.buttons[294] = surface.makeButton(198, 132, 10, 10)
	surfaceElements.buttons[294].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 105)
	surfaceElements.labels[294] = surface.makeLabelField(198, 137, 10, 1)

	surfaceElements.buttons[295] = surface.makeButton(209, 132, 10, 10)
	surfaceElements.buttons[295].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 106)
	surfaceElements.labels[295] = surface.makeLabelField(209, 137, 10, 1)

	surfaceElements.buttons[296] = surface.makeButton(220, 132, 10, 10)
	surfaceElements.buttons[296].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 107)
	surfaceElements.labels[296] = surface.makeLabelField(220, 137, 10, 1)

	surfaceElements.buttons[297] = surface.makeButton(231, 132, 10, 10)
	surfaceElements.buttons[297].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 108)
	surfaceElements.labels[297] = surface.makeLabelField(231, 137, 10, 1)

	surfaceElements.buttons[298] = surface.makeButton(242, 132, 10, 10)
	surfaceElements.buttons[298].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 109)
	surfaceElements.labels[298] = surface.makeLabelField(242, 137, 10, 1)

	surfaceElements.buttons[299] = surface.makeButton(0, 143, 10, 10)
	surfaceElements.buttons[299].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 110)
	surfaceElements.labels[299] = surface.makeLabelField(0, 148, 10, 1)

	surfaceElements.buttons[300] = surface.makeButton(11, 143, 10, 10)
	surfaceElements.buttons[300].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 9)
	surfaceElements.labels[300] = surface.makeLabelField(11, 148, 10, 1)

	surfaceElements.buttons[301] = surface.makeButton(22, 143, 10, 10)
	surfaceElements.buttons[301].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 10)
	surfaceElements.labels[301] = surface.makeLabelField(22, 148, 10, 1)

	surfaceElements.buttons[302] = surface.makeButton(33, 143, 10, 10)
	surfaceElements.buttons[302].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 101)
	surfaceElements.labels[302] = surface.makeLabelField(33, 148, 10, 1)

	surfaceElements.buttons[303] = surface.makeButton(44, 143, 10, 10)
	surfaceElements.buttons[303].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 102)
	surfaceElements.labels[303] = surface.makeLabelField(44, 148, 10, 1)

	surfaceElements.buttons[304] = surface.makeButton(55, 143, 10, 10)
	surfaceElements.buttons[304].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 103)
	surfaceElements.labels[304] = surface.makeLabelField(55, 148, 10, 1)

	surfaceElements.buttons[305] = surface.makeButton(66, 143, 10, 10)
	surfaceElements.buttons[305].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 104)
	surfaceElements.labels[305] = surface.makeLabelField(66, 148, 10, 1)

	surfaceElements.buttons[306] = surface.makeButton(77, 143, 10, 10)
	surfaceElements.buttons[306].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 105)
	surfaceElements.labels[306] = surface.makeLabelField(77, 148, 10, 1)

	surfaceElements.buttons[307] = surface.makeButton(88, 143, 10, 10)
	surfaceElements.buttons[307].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 106)
	surfaceElements.labels[307] = surface.makeLabelField(88, 148, 10, 1)

	surfaceElements.buttons[308] = surface.makeButton(99, 143, 10, 10)
	surfaceElements.buttons[308].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 107)
	surfaceElements.labels[308] = surface.makeLabelField(99, 148, 10, 1)

	surfaceElements.buttons[309] = surface.makeButton(110, 143, 10, 10)
	surfaceElements.buttons[309].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 108)
	surfaceElements.labels[309] = surface.makeLabelField(110, 148, 10, 1)

	surfaceElements.buttons[310] = surface.makeButton(121, 143, 10, 10)
	surfaceElements.buttons[310].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 109)
	surfaceElements.labels[310] = surface.makeLabelField(121, 148, 10, 1)

	surfaceElements.buttons[311] = surface.makeButton(132, 143, 10, 10)
	surfaceElements.buttons[311].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 110)
	surfaceElements.labels[311] = surface.makeLabelField(132, 148, 10, 1)

	surfaceElements.buttons[312] = surface.makeButton(143, 143, 10, 10)
	surfaceElements.buttons[312].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 111)
	surfaceElements.labels[312] = surface.makeLabelField(143, 148, 10, 1)

	surfaceElements.buttons[313] = surface.makeButton(154, 143, 10, 10)
	surfaceElements.buttons[313].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 112)
	surfaceElements.labels[313] = surface.makeLabelField(154, 148, 10, 1)

	surfaceElements.buttons[314] = surface.makeButton(165, 143, 10, 10)
	surfaceElements.buttons[314].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 113)
	surfaceElements.labels[314] = surface.makeLabelField(165, 148, 10, 1)

	surfaceElements.buttons[315] = surface.makeButton(176, 143, 10, 10)
	surfaceElements.buttons[315].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 114)
	surfaceElements.labels[315] = surface.makeLabelField(176, 148, 10, 1)

	surfaceElements.buttons[316] = surface.makeButton(187, 143, 10, 10)
	surfaceElements.buttons[316].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 115)
	surfaceElements.labels[316] = surface.makeLabelField(187, 148, 10, 1)

	surfaceElements.buttons[317] = surface.makeButton(198, 143, 10, 10)
	surfaceElements.buttons[317].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 116)
	surfaceElements.labels[317] = surface.makeLabelField(198, 148, 10, 1)

	surfaceElements.buttons[318] = surface.makeButton(209, 143, 10, 10)
	surfaceElements.buttons[318].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 117)
	surfaceElements.labels[318] = surface.makeLabelField(209, 148, 10, 1)

	surfaceElements.buttons[319] = surface.makeButton(220, 143, 10, 10)
	surfaceElements.buttons[319].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 118)
	surfaceElements.labels[319] = surface.makeLabelField(220, 148, 10, 1)

	surfaceElements.buttons[320] = surface.makeButton(231, 143, 10, 10)
	surfaceElements.buttons[320].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 119)
	surfaceElements.labels[320] = surface.makeLabelField(231, 148, 10, 1)

	surfaceElements.buttons[321] = surface.makeButton(242, 143, 10, 10)
	surfaceElements.buttons[321].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 120)
	surfaceElements.labels[321] = surface.makeLabelField(242, 148, 10, 1)

	surfaceElements.buttons[322] = surface.makeButton(0, 154, 10, 10)
	surfaceElements.buttons[322].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 121)
	surfaceElements.labels[322] = surface.makeLabelField(0, 159, 10, 1)

	surfaceElements.buttons[323] = surface.makeButton(11, 154, 10, 10)
	surfaceElements.buttons[323].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 122)
	surfaceElements.labels[323] = surface.makeLabelField(11, 159, 10, 1)

	surfaceElements.buttons[324] = surface.makeButton(22, 154, 10, 10)
	surfaceElements.buttons[324].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 123)
	surfaceElements.labels[324] = surface.makeLabelField(22, 159, 10, 1)

	surfaceElements.buttons[325] = surface.makeButton(33, 154, 10, 10)
	surfaceElements.buttons[325].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 124)
	surfaceElements.labels[325] = surface.makeLabelField(33, 159, 10, 1)

	surfaceElements.buttons[326] = surface.makeButton(44, 154, 10, 10)
	surfaceElements.buttons[326].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 125)
	surfaceElements.labels[326] = surface.makeLabelField(44, 159, 10, 1)

	surfaceElements.buttons[327] = surface.makeButton(55, 154, 10, 10)
	surfaceElements.buttons[327].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 126)
	surfaceElements.labels[327] = surface.makeLabelField(55, 159, 10, 1)

	surfaceElements.buttons[328] = surface.makeButton(66, 154, 10, 10)
	surfaceElements.buttons[328].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 111)
	surfaceElements.labels[328] = surface.makeLabelField(66, 159, 10, 1)

	surfaceElements.buttons[329] = surface.makeButton(77, 154, 10, 10)
	surfaceElements.buttons[329].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 112)
	surfaceElements.labels[329] = surface.makeLabelField(77, 159, 10, 1)

	surfaceElements.buttons[330] = surface.makeButton(88, 154, 10, 10)
	surfaceElements.buttons[330].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 113)
	surfaceElements.labels[330] = surface.makeLabelField(88, 159, 10, 1)

	surfaceElements.buttons[331] = surface.makeButton(99, 154, 10, 10)
	surfaceElements.buttons[331].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 114)
	surfaceElements.labels[331] = surface.makeLabelField(99, 159, 10, 1)

	surfaceElements.buttons[332] = surface.makeButton(110, 154, 10, 10)
	surfaceElements.buttons[332].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 115)
	surfaceElements.labels[332] = surface.makeLabelField(110, 159, 10, 1)

	surfaceElements.buttons[333] = surface.makeButton(121, 154, 10, 10)
	surfaceElements.buttons[333].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 116)
	surfaceElements.labels[333] = surface.makeLabelField(121, 159, 10, 1)

	surfaceElements.buttons[334] = surface.makeButton(132, 154, 10, 10)
	surfaceElements.buttons[334].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 117)
	surfaceElements.labels[334] = surface.makeLabelField(132, 159, 10, 1)

	surfaceElements.buttons[335] = surface.makeButton(143, 154, 10, 10)
	surfaceElements.buttons[335].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 118)
	surfaceElements.labels[335] = surface.makeLabelField(143, 159, 10, 1)

	surfaceElements.buttons[336] = surface.makeButton(154, 154, 10, 10)
	surfaceElements.buttons[336].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 119)
	surfaceElements.labels[336] = surface.makeLabelField(154, 159, 10, 1)

	surfaceElements.buttons[337] = surface.makeButton(165, 154, 10, 10)
	surfaceElements.buttons[337].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 120)
	surfaceElements.labels[337] = surface.makeLabelField(165, 159, 10, 1)

	surfaceElements.buttons[338] = surface.makeButton(176, 154, 10, 10)
	surfaceElements.buttons[338].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 121)
	surfaceElements.labels[338] = surface.makeLabelField(176, 159, 10, 1)

	surfaceElements.buttons[339] = surface.makeButton(187, 154, 10, 10)
	surfaceElements.buttons[339].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 122)
	surfaceElements.labels[339] = surface.makeLabelField(187, 159, 10, 1)

	surfaceElements.buttons[340] = surface.makeButton(198, 154, 10, 10)
	surfaceElements.buttons[340].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 123)
	surfaceElements.labels[340] = surface.makeLabelField(198, 159, 10, 1)

	surfaceElements.buttons[341] = surface.makeButton(209, 154, 10, 10)
	surfaceElements.buttons[341].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 124)
	surfaceElements.labels[341] = surface.makeLabelField(209, 159, 10, 1)

	surfaceElements.buttons[342] = surface.makeButton(220, 154, 10, 10)
	surfaceElements.buttons[342].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 125)
	surfaceElements.labels[342] = surface.makeLabelField(220, 159, 10, 1)

	surfaceElements.buttons[343] = surface.makeButton(231, 154, 10, 10)
	surfaceElements.buttons[343].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 126)
	surfaceElements.labels[343] = surface.makeLabelField(231, 159, 10, 1)

	surfaceElements.buttons[344] = surface.makeButton(242, 154, 10, 10)
	surfaceElements.buttons[344].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 127)
	surfaceElements.labels[344] = surface.makeLabelField(242, 159, 10, 1)

	surfaceElements.buttons[345] = surface.makeButton(0, 165, 10, 10)
	surfaceElements.buttons[345].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 87)
	surfaceElements.labels[345] = surface.makeLabelField(0, 170, 10, 1)

	surfaceElements.buttons[346] = surface.makeButton(11, 165, 10, 10)
	surfaceElements.buttons[346].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 88)
	surfaceElements.labels[346] = surface.makeLabelField(11, 170, 10, 1)

	surfaceElements.buttons[347] = surface.makeButton(22, 165, 10, 10)
	surfaceElements.buttons[347].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 89)
	surfaceElements.labels[347] = surface.makeLabelField(22, 170, 10, 1)

	surfaceElements.buttons[348] = surface.makeButton(33, 165, 10, 10)
	surfaceElements.buttons[348].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 90)
	surfaceElements.labels[348] = surface.makeLabelField(33, 170, 10, 1)

	surfaceElements.buttons[349] = surface.makeButton(44, 165, 10, 10)
	surfaceElements.buttons[349].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 91)
	surfaceElements.labels[349] = surface.makeLabelField(44, 170, 10, 1)

	surfaceElements.buttons[350] = surface.makeButton(55, 165, 10, 10)
	surfaceElements.buttons[350].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 92)
	surfaceElements.labels[350] = surface.makeLabelField(55, 170, 10, 1)

	surfaceElements.buttons[351] = surface.makeButton(66, 165, 10, 10)
	surfaceElements.buttons[351].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 93)
	surfaceElements.labels[351] = surface.makeLabelField(66, 170, 10, 1)

	surfaceElements.buttons[352] = surface.makeButton(77, 165, 10, 10)
	surfaceElements.buttons[352].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 94)
	surfaceElements.labels[352] = surface.makeLabelField(77, 170, 10, 1)

	surfaceElements.buttons[353] = surface.makeButton(88, 165, 10, 10)
	surfaceElements.buttons[353].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 95)
	surfaceElements.labels[353] = surface.makeLabelField(88, 170, 10, 1)

	surfaceElements.buttons[354] = surface.makeButton(99, 165, 10, 10)
	surfaceElements.buttons[354].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 96)
	surfaceElements.labels[354] = surface.makeLabelField(99, 170, 10, 1)

	surfaceElements.buttons[355] = surface.makeButton(110, 165, 10, 10)
	surfaceElements.buttons[355].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 97)
	surfaceElements.labels[355] = surface.makeLabelField(110, 170, 10, 1)

	surfaceElements.buttons[356] = surface.makeButton(121, 165, 10, 10)
	surfaceElements.buttons[356].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 98)
	surfaceElements.labels[356] = surface.makeLabelField(121, 170, 10, 1)

	surfaceElements.buttons[357] = surface.makeButton(132, 165, 10, 10)
	surfaceElements.buttons[357].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 99)
	surfaceElements.labels[357] = surface.makeLabelField(132, 170, 10, 1)

	surfaceElements.buttons[358] = surface.makeButton(143, 165, 10, 10)
	surfaceElements.buttons[358].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 100)
	surfaceElements.labels[358] = surface.makeLabelField(143, 170, 10, 1)

	surfaceElements.buttons[359] = surface.makeButton(154, 165, 10, 10)
	surfaceElements.buttons[359].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 101)
	surfaceElements.labels[359] = surface.makeLabelField(154, 170, 10, 1)

	surfaceElements.buttons[360] = surface.makeButton(165, 165, 10, 10)
	surfaceElements.buttons[360].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 102)
	surfaceElements.labels[360] = surface.makeLabelField(165, 170, 10, 1)

	surfaceElements.buttons[361] = surface.makeButton(176, 165, 10, 10)
	surfaceElements.buttons[361].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 103)
	surfaceElements.labels[361] = surface.makeLabelField(176, 170, 10, 1)

	surfaceElements.buttons[362] = surface.makeButton(187, 165, 10, 10)
	surfaceElements.buttons[362].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 104)
	surfaceElements.labels[362] = surface.makeLabelField(187, 170, 10, 1)

	surfaceElements.buttons[363] = surface.makeButton(198, 165, 10, 10)
	surfaceElements.buttons[363].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 105)
	surfaceElements.labels[363] = surface.makeLabelField(198, 170, 10, 1)

	surfaceElements.buttons[364] = surface.makeButton(209, 165, 10, 10)
	surfaceElements.buttons[364].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 106)
	surfaceElements.labels[364] = surface.makeLabelField(209, 170, 10, 1)

	surfaceElements.buttons[365] = surface.makeButton(220, 165, 10, 10)
	surfaceElements.buttons[365].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 107)
	surfaceElements.labels[365] = surface.makeLabelField(220, 170, 10, 1)

	surfaceElements.buttons[366] = surface.makeButton(231, 165, 10, 10)
	surfaceElements.buttons[366].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 108)
	surfaceElements.labels[366] = surface.makeLabelField(231, 170, 10, 1)

	surfaceElements.buttons[367] = surface.makeButton(242, 165, 10, 10)
	surfaceElements.buttons[367].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 109)
	surfaceElements.labels[367] = surface.makeLabelField(242, 170, 10, 1)

	surfaceElements.buttons[368] = surface.makeButton(0, 176, 10, 10)
	surfaceElements.buttons[368].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 110)
	surfaceElements.labels[368] = surface.makeLabelField(0, 181, 10, 1)

	surfaceElements.buttons[369] = surface.makeButton(11, 176, 10, 10)
	surfaceElements.buttons[369].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 111)
	surfaceElements.labels[369] = surface.makeLabelField(11, 181, 10, 1)

	surfaceElements.buttons[370] = surface.makeButton(22, 176, 10, 10)
	surfaceElements.buttons[370].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 112)
	surfaceElements.labels[370] = surface.makeLabelField(22, 181, 10, 1)

	surfaceElements.buttons[371] = surface.makeButton(33, 176, 10, 10)
	surfaceElements.buttons[371].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 113)
	surfaceElements.labels[371] = surface.makeLabelField(33, 181, 10, 1)

	surfaceElements.buttons[372] = surface.makeButton(44, 176, 10, 10)
	surfaceElements.buttons[372].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 114)
	surfaceElements.labels[372] = surface.makeLabelField(44, 181, 10, 1)

	surfaceElements.buttons[373] = surface.makeButton(55, 176, 10, 10)
	surfaceElements.buttons[373].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 115)
	surfaceElements.labels[373] = surface.makeLabelField(55, 181, 10, 1)

	surfaceElements.buttons[374] = surface.makeButton(66, 176, 10, 10)
	surfaceElements.buttons[374].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 83)
	surfaceElements.labels[374] = surface.makeLabelField(66, 181, 10, 1)

	surfaceElements.buttons[375] = surface.makeButton(77, 176, 10, 10)
	surfaceElements.buttons[375].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 84)
	surfaceElements.labels[375] = surface.makeLabelField(77, 181, 10, 1)

	surfaceElements.buttons[376] = surface.makeButton(88, 176, 10, 10)
	surfaceElements.buttons[376].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 85)
	surfaceElements.labels[376] = surface.makeLabelField(88, 181, 10, 1)

	surfaceElements.buttons[377] = surface.makeButton(99, 176, 10, 10)
	surfaceElements.buttons[377].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 86)
	surfaceElements.labels[377] = surface.makeLabelField(99, 181, 10, 1)

	surfaceElements.buttons[378] = surface.makeButton(110, 176, 10, 10)
	surfaceElements.buttons[378].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 87)
	surfaceElements.labels[378] = surface.makeLabelField(110, 181, 10, 1)

	surfaceElements.buttons[379] = surface.makeButton(121, 176, 10, 10)
	surfaceElements.buttons[379].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 88)
	surfaceElements.labels[379] = surface.makeLabelField(121, 181, 10, 1)

	surfaceElements.buttons[380] = surface.makeButton(132, 176, 10, 10)
	surfaceElements.buttons[380].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 89)
	surfaceElements.labels[380] = surface.makeLabelField(132, 181, 10, 1)

	surfaceElements.buttons[381] = surface.makeButton(143, 176, 10, 10)
	surfaceElements.buttons[381].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 90)
	surfaceElements.labels[381] = surface.makeLabelField(143, 181, 10, 1)

	surfaceElements.buttons[382] = surface.makeButton(154, 176, 10, 10)
	surfaceElements.buttons[382].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 91)
	surfaceElements.labels[382] = surface.makeLabelField(154, 181, 10, 1)

	surfaceElements.buttons[383] = surface.makeButton(165, 176, 10, 10)
	surfaceElements.buttons[383].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 92)
	surfaceElements.labels[383] = surface.makeLabelField(165, 181, 10, 1)

	surfaceElements.buttons[384] = surface.makeButton(176, 176, 10, 10)
	surfaceElements.buttons[384].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 93)
	surfaceElements.labels[384] = surface.makeLabelField(176, 181, 10, 1)

	surfaceElements.buttons[385] = surface.makeButton(187, 176, 10, 10)
	surfaceElements.buttons[385].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 94)
	surfaceElements.labels[385] = surface.makeLabelField(187, 181, 10, 1)

	surfaceElements.buttons[386] = surface.makeButton(198, 176, 10, 10)
	surfaceElements.buttons[386].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 95)
	surfaceElements.labels[386] = surface.makeLabelField(198, 181, 10, 1)

	surfaceElements.buttons[387] = surface.makeButton(209, 176, 10, 10)
	surfaceElements.buttons[387].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 96)
	surfaceElements.labels[387] = surface.makeLabelField(209, 181, 10, 1)

	surfaceElements.buttons[388] = surface.makeButton(220, 176, 10, 10)
	surfaceElements.buttons[388].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 97)
	surfaceElements.labels[388] = surface.makeLabelField(220, 181, 10, 1)

	surfaceElements.buttons[389] = surface.makeButton(231, 176, 10, 10)
	surfaceElements.buttons[389].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 98)
	surfaceElements.labels[389] = surface.makeLabelField(231, 181, 10, 1)

	surfaceElements.buttons[390] = surface.makeButton(242, 176, 10, 10)
	surfaceElements.buttons[390].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 99)
	surfaceElements.labels[390] = surface.makeLabelField(242, 181, 10, 1)

	surfaceElements.buttons[391] = surface.makeButton(0, 187, 10, 10)
	surfaceElements.buttons[391].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 100)
	surfaceElements.labels[391] = surface.makeLabelField(0, 192, 10, 1)

	surfaceElements.buttons[392] = surface.makeButton(11, 187, 10, 10)
	surfaceElements.buttons[392].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 101)
	surfaceElements.labels[392] = surface.makeLabelField(11, 192, 10, 1)

	surfaceElements.buttons[393] = surface.makeButton(22, 187, 10, 10)
	surfaceElements.buttons[393].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 102)
	surfaceElements.labels[393] = surface.makeLabelField(22, 192, 10, 1)

	surfaceElements.buttons[394] = surface.makeButton(33, 187, 10, 10)
	surfaceElements.buttons[394].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 103)
	surfaceElements.labels[394] = surface.makeLabelField(33, 192, 10, 1)

	surfaceElements.buttons[395] = surface.makeButton(44, 187, 10, 10)
	surfaceElements.buttons[395].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 104)
	surfaceElements.labels[395] = surface.makeLabelField(44, 192, 10, 1)

	surfaceElements.buttons[396] = surface.makeButton(55, 187, 10, 10)
	surfaceElements.buttons[396].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 105)
	surfaceElements.labels[396] = surface.makeLabelField(55, 192, 10, 1)

	surfaceElements.buttons[397] = surface.makeButton(66, 187, 10, 10)
	surfaceElements.buttons[397].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 106)
	surfaceElements.labels[397] = surface.makeLabelField(66, 192, 10, 1)

	surfaceElements.buttons[398] = surface.makeButton(77, 187, 10, 10)
	surfaceElements.buttons[398].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 107)
	surfaceElements.labels[398] = surface.makeLabelField(77, 192, 10, 1)

	surfaceElements.buttons[399] = surface.makeButton(88, 187, 10, 10)
	surfaceElements.buttons[399].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 108)
	surfaceElements.labels[399] = surface.makeLabelField(88, 192, 10, 1)

	surfaceElements.buttons[400] = surface.makeButton(99, 187, 10, 10)
	surfaceElements.buttons[400].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 109)
	surfaceElements.labels[400] = surface.makeLabelField(99, 192, 10, 1)

	surfaceElements.buttons[401] = surface.makeButton(110, 187, 10, 10)
	surfaceElements.buttons[401].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 110)
	surfaceElements.labels[401] = surface.makeLabelField(110, 192, 10, 1)

	surfaceElements.buttons[402] = surface.makeButton(121, 187, 10, 10)
	surfaceElements.buttons[402].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 111)
	surfaceElements.labels[402] = surface.makeLabelField(121, 192, 10, 1)

	surfaceElements.buttons[403] = surface.makeButton(132, 187, 10, 10)
	surfaceElements.buttons[403].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 112)
	surfaceElements.labels[403] = surface.makeLabelField(132, 192, 10, 1)

	surfaceElements.buttons[404] = surface.makeButton(143, 187, 10, 10)
	surfaceElements.buttons[404].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 113)
	surfaceElements.labels[404] = surface.makeLabelField(143, 192, 10, 1)

	surfaceElements.buttons[405] = surface.makeButton(154, 187, 10, 10)
	surfaceElements.buttons[405].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 114)
	surfaceElements.labels[405] = surface.makeLabelField(154, 192, 10, 1)

	surfaceElements.buttons[406] = surface.makeButton(165, 187, 10, 10)
	surfaceElements.buttons[406].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 115)
	surfaceElements.labels[406] = surface.makeLabelField(165, 192, 10, 1)

	surfaceElements.buttons[407] = surface.makeButton(176, 187, 10, 10)
	surfaceElements.buttons[407].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 116)
	surfaceElements.labels[407] = surface.makeLabelField(176, 192, 10, 1)

	surfaceElements.buttons[408] = surface.makeButton(187, 187, 10, 10)
	surfaceElements.buttons[408].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 117)
	surfaceElements.labels[408] = surface.makeLabelField(187, 192, 10, 1)

	surfaceElements.buttons[409] = surface.makeButton(198, 187, 10, 10)
	surfaceElements.buttons[409].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 118)
	surfaceElements.labels[409] = surface.makeLabelField(198, 192, 10, 1)

	surfaceElements.buttons[410] = surface.makeButton(209, 187, 10, 10)
	surfaceElements.buttons[410].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 119)
	surfaceElements.labels[410] = surface.makeLabelField(209, 192, 10, 1)

	surfaceElements.buttons[411] = surface.makeButton(220, 187, 10, 10)
	surfaceElements.buttons[411].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 120)
	surfaceElements.labels[411] = surface.makeLabelField(220, 192, 10, 1)

	surfaceElements.buttons[412] = surface.makeButton(231, 187, 10, 10)
	surfaceElements.buttons[412].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 121)
	surfaceElements.labels[412] = surface.makeLabelField(231, 192, 10, 1)

	surfaceElements.buttons[413] = surface.makeButton(242, 187, 10, 10)
	surfaceElements.buttons[413].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 122)
	surfaceElements.labels[413] = surface.makeLabelField(242, 192, 10, 1)

	surfaceElements.buttons[414] = surface.makeButton(0, 198, 10, 10)
	surfaceElements.buttons[414].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 123)
	surfaceElements.labels[414] = surface.makeLabelField(0, 203, 10, 1)

	surfaceElements.buttons[415] = surface.makeButton(11, 198, 10, 10)
	surfaceElements.buttons[415].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 124)
	surfaceElements.labels[415] = surface.makeLabelField(11, 203, 10, 1)

	surfaceElements.buttons[416] = surface.makeButton(22, 198, 10, 10)
	surfaceElements.buttons[416].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 125)
	surfaceElements.labels[416] = surface.makeLabelField(22, 203, 10, 1)

	surfaceElements.buttons[417] = surface.makeButton(33, 198, 10, 10)
	surfaceElements.buttons[417].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 126)
	surfaceElements.labels[417] = surface.makeLabelField(33, 203, 10, 1)

	surfaceElements.buttons[418] = surface.makeButton(44, 198, 10, 10)
	surfaceElements.buttons[418].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 127)
	surfaceElements.labels[418] = surface.makeLabelField(44, 203, 10, 1)

	surfaceElements.buttons[419] = surface.makeButton(55, 198, 10, 10)
	surfaceElements.buttons[419].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 67)
	surfaceElements.labels[419] = surface.makeLabelField(55, 203, 10, 1)

	surfaceElements.buttons[420] = surface.makeButton(66, 198, 10, 10)
	surfaceElements.buttons[420].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 68)
	surfaceElements.labels[420] = surface.makeLabelField(66, 203, 10, 1)

	surfaceElements.buttons[421] = surface.makeButton(77, 198, 10, 10)
	surfaceElements.buttons[421].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 69)
	surfaceElements.labels[421] = surface.makeLabelField(77, 203, 10, 1)

	surfaceElements.buttons[422] = surface.makeButton(88, 198, 10, 10)
	surfaceElements.buttons[422].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 70)
	surfaceElements.labels[422] = surface.makeLabelField(88, 203, 10, 1)

	surfaceElements.buttons[423] = surface.makeButton(99, 198, 10, 10)
	surfaceElements.buttons[423].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 71)
	surfaceElements.labels[423] = surface.makeLabelField(99, 203, 10, 1)

	surfaceElements.buttons[424] = surface.makeButton(110, 198, 10, 10)
	surfaceElements.buttons[424].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 72)
	surfaceElements.labels[424] = surface.makeLabelField(110, 203, 10, 1)

	surfaceElements.buttons[425] = surface.makeButton(121, 198, 10, 10)
	surfaceElements.buttons[425].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 73)
	surfaceElements.labels[425] = surface.makeLabelField(121, 203, 10, 1)

	surfaceElements.buttons[426] = surface.makeButton(132, 198, 10, 10)
	surfaceElements.buttons[426].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 74)
	surfaceElements.labels[426] = surface.makeLabelField(132, 203, 10, 1)

	surfaceElements.buttons[427] = surface.makeButton(143, 198, 10, 10)
	surfaceElements.buttons[427].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 75)
	surfaceElements.labels[427] = surface.makeLabelField(143, 203, 10, 1)

	surfaceElements.buttons[428] = surface.makeButton(154, 198, 10, 10)
	surfaceElements.buttons[428].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 76)
	surfaceElements.labels[428] = surface.makeLabelField(154, 203, 10, 1)

	surfaceElements.buttons[429] = surface.makeButton(165, 198, 10, 10)
	surfaceElements.buttons[429].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 77)
	surfaceElements.labels[429] = surface.makeLabelField(165, 203, 10, 1)

	surfaceElements.buttons[430] = surface.makeButton(176, 198, 10, 10)
	surfaceElements.buttons[430].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 78)
	surfaceElements.labels[430] = surface.makeLabelField(176, 203, 10, 1)

	surfaceElements.buttons[431] = surface.makeButton(187, 198, 10, 10)
	surfaceElements.buttons[431].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 79)
	surfaceElements.labels[431] = surface.makeLabelField(187, 203, 10, 1)

	surfaceElements.buttons[432] = surface.makeButton(198, 198, 10, 10)
	surfaceElements.buttons[432].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 80)
	surfaceElements.labels[432] = surface.makeLabelField(198, 203, 10, 1)

	surfaceElements.buttons[433] = surface.makeButton(209, 198, 10, 10)
	surfaceElements.buttons[433].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 81)
	surfaceElements.labels[433] = surface.makeLabelField(209, 203, 10, 1)

	surfaceElements.buttons[434] = surface.makeButton(220, 198, 10, 10)
	surfaceElements.buttons[434].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 82)
	surfaceElements.labels[434] = surface.makeLabelField(220, 203, 10, 1)

	surfaceElements.buttons[435] = surface.makeButton(231, 198, 10, 10)
	surfaceElements.buttons[435].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 83)
	surfaceElements.labels[435] = surface.makeLabelField(231, 203, 10, 1)

	surfaceElements.buttons[436] = surface.makeButton(242, 198, 10, 10)
	surfaceElements.buttons[436].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 84)
	surfaceElements.labels[436] = surface.makeLabelField(242, 203, 10, 1)

	surfaceElements.buttons[437] = surface.makeButton(0, 209, 10, 10)
	surfaceElements.buttons[437].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 85)
	surfaceElements.labels[437] = surface.makeLabelField(0, 214, 10, 1)

	surfaceElements.buttons[438] = surface.makeButton(11, 209, 10, 10)
	surfaceElements.buttons[438].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 86)
	surfaceElements.labels[438] = surface.makeLabelField(11, 214, 10, 1)

	surfaceElements.buttons[439] = surface.makeButton(22, 209, 10, 10)
	surfaceElements.buttons[439].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 87)
	surfaceElements.labels[439] = surface.makeLabelField(22, 214, 10, 1)

	surfaceElements.buttons[440] = surface.makeButton(33, 209, 10, 10)
	surfaceElements.buttons[440].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 88)
	surfaceElements.labels[440] = surface.makeLabelField(33, 214, 10, 1)

	surfaceElements.buttons[441] = surface.makeButton(44, 209, 10, 10)
	surfaceElements.buttons[441].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 89)
	surfaceElements.labels[441] = surface.makeLabelField(44, 214, 10, 1)

	surfaceElements.buttons[442] = surface.makeButton(55, 209, 10, 10)
	surfaceElements.buttons[442].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 90)
	surfaceElements.labels[442] = surface.makeLabelField(55, 214, 10, 1)

	surfaceElements.buttons[443] = surface.makeButton(66, 209, 10, 10)
	surfaceElements.buttons[443].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 91)
	surfaceElements.labels[443] = surface.makeLabelField(66, 214, 10, 1)

	surfaceElements.buttons[444] = surface.makeButton(77, 209, 10, 10)
	surfaceElements.buttons[444].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 92)
	surfaceElements.labels[444] = surface.makeLabelField(77, 214, 10, 1)

	surfaceElements.buttons[445] = surface.makeButton(88, 209, 10, 10)
	surfaceElements.buttons[445].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 93)
	surfaceElements.labels[445] = surface.makeLabelField(88, 214, 10, 1)

	surfaceElements.buttons[446] = surface.makeButton(99, 209, 10, 10)
	surfaceElements.buttons[446].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 94)
	surfaceElements.labels[446] = surface.makeLabelField(99, 214, 10, 1)

	surfaceElements.buttons[447] = surface.makeButton(110, 209, 10, 10)
	surfaceElements.buttons[447].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 95)
	surfaceElements.labels[447] = surface.makeLabelField(110, 214, 10, 1)

	surfaceElements.buttons[448] = surface.makeButton(121, 209, 10, 10)
	surfaceElements.buttons[448].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 96)
	surfaceElements.labels[448] = surface.makeLabelField(121, 214, 10, 1)

	surfaceElements.buttons[449] = surface.makeButton(132, 209, 10, 10)
	surfaceElements.buttons[449].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 97)
	surfaceElements.labels[449] = surface.makeLabelField(132, 214, 10, 1)

	surfaceElements.buttons[450] = surface.makeButton(143, 209, 10, 10)
	surfaceElements.buttons[450].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 98)
	surfaceElements.labels[450] = surface.makeLabelField(143, 214, 10, 1)

	surfaceElements.buttons[451] = surface.makeButton(154, 209, 10, 10)
	surfaceElements.buttons[451].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 99)
	surfaceElements.labels[451] = surface.makeLabelField(154, 214, 10, 1)

	surfaceElements.buttons[452] = surface.makeButton(165, 209, 10, 10)
	surfaceElements.buttons[452].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 100)
	surfaceElements.labels[452] = surface.makeLabelField(165, 214, 10, 1)

	surfaceElements.buttons[453] = surface.makeButton(176, 209, 10, 10)
	surfaceElements.buttons[453].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 101)
	surfaceElements.labels[453] = surface.makeLabelField(176, 214, 10, 1)

	surfaceElements.buttons[454] = surface.makeButton(187, 209, 10, 10)
	surfaceElements.buttons[454].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 102)
	surfaceElements.labels[454] = surface.makeLabelField(187, 214, 10, 1)

	surfaceElements.buttons[455] = surface.makeButton(198, 209, 10, 10)
	surfaceElements.buttons[455].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 103)
	surfaceElements.labels[455] = surface.makeLabelField(198, 214, 10, 1)

	surfaceElements.buttons[456] = surface.makeButton(209, 209, 10, 10)
	surfaceElements.buttons[456].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 104)
	surfaceElements.labels[456] = surface.makeLabelField(209, 214, 10, 1)

	surfaceElements.buttons[457] = surface.makeButton(220, 209, 10, 10)
	surfaceElements.buttons[457].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 105)
	surfaceElements.labels[457] = surface.makeLabelField(220, 214, 10, 1)

	surfaceElements.buttons[458] = surface.makeButton(231, 209, 10, 10)
	surfaceElements.buttons[458].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 106)
	surfaceElements.labels[458] = surface.makeLabelField(231, 214, 10, 1)

	surfaceElements.buttons[459] = surface.makeButton(242, 209, 10, 10)
	surfaceElements.buttons[459].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 107)
	surfaceElements.labels[459] = surface.makeLabelField(242, 214, 10, 1)

	surfaceElements.buttons[460] = surface.makeButton(0, 220, 10, 10)
	surfaceElements.buttons[460].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 108)
	surfaceElements.labels[460] = surface.makeLabelField(0, 225, 10, 1)

	surfaceElements.buttons[461] = surface.makeButton(11, 220, 10, 10)
	surfaceElements.buttons[461].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 109)
	surfaceElements.labels[461] = surface.makeLabelField(11, 225, 10, 1)

	surfaceElements.buttons[462] = surface.makeButton(22, 220, 10, 10)
	surfaceElements.buttons[462].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 110)
	surfaceElements.labels[462] = surface.makeLabelField(22, 225, 10, 1)

	surfaceElements.buttons[463] = surface.makeButton(33, 220, 10, 10)
	surfaceElements.buttons[463].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 111)
	surfaceElements.labels[463] = surface.makeLabelField(33, 225, 10, 1)

	surfaceElements.buttons[464] = surface.makeButton(44, 220, 10, 10)
	surfaceElements.buttons[464].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 112)
	surfaceElements.labels[464] = surface.makeLabelField(44, 225, 10, 1)

	surfaceElements.buttons[465] = surface.makeButton(55, 220, 10, 10)
	surfaceElements.buttons[465].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 113)
	surfaceElements.labels[465] = surface.makeLabelField(55, 225, 10, 1)

	surfaceElements.buttons[466] = surface.makeButton(66, 220, 10, 10)
	surfaceElements.buttons[466].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 114)
	surfaceElements.labels[466] = surface.makeLabelField(66, 225, 10, 1)

	surfaceElements.buttons[467] = surface.makeButton(77, 220, 10, 10)
	surfaceElements.buttons[467].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 115)
	surfaceElements.labels[467] = surface.makeLabelField(77, 225, 10, 1)

	surfaceElements.buttons[468] = surface.makeButton(88, 220, 10, 10)
	surfaceElements.buttons[468].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 116)
	surfaceElements.labels[468] = surface.makeLabelField(88, 225, 10, 1)

	surfaceElements.buttons[469] = surface.makeButton(99, 220, 10, 10)
	surfaceElements.buttons[469].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 117)
	surfaceElements.labels[469] = surface.makeLabelField(99, 225, 10, 1)

	surfaceElements.buttons[470] = surface.makeButton(110, 220, 10, 10)
	surfaceElements.buttons[470].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 118)
	surfaceElements.labels[470] = surface.makeLabelField(110, 225, 10, 1)

	surfaceElements.buttons[471] = surface.makeButton(121, 220, 10, 10)
	surfaceElements.buttons[471].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 119)
	surfaceElements.labels[471] = surface.makeLabelField(121, 225, 10, 1)

	surfaceElements.buttons[472] = surface.makeButton(132, 220, 10, 10)
	surfaceElements.buttons[472].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 120)
	surfaceElements.labels[472] = surface.makeLabelField(132, 225, 10, 1)

	surfaceElements.buttons[473] = surface.makeButton(143, 220, 10, 10)
	surfaceElements.buttons[473].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 121)
	surfaceElements.labels[473] = surface.makeLabelField(143, 225, 10, 1)

	surfaceElements.buttons[474] = surface.makeButton(154, 220, 10, 10)
	surfaceElements.buttons[474].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 122)
	surfaceElements.labels[474] = surface.makeLabelField(154, 225, 10, 1)

	surfaceElements.buttons[475] = surface.makeButton(165, 220, 10, 10)
	surfaceElements.buttons[475].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 123)
	surfaceElements.labels[475] = surface.makeLabelField(165, 225, 10, 1)

	surfaceElements.buttons[476] = surface.makeButton(176, 220, 10, 10)
	surfaceElements.buttons[476].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 124)
	surfaceElements.labels[476] = surface.makeLabelField(176, 225, 10, 1)

	surfaceElements.buttons[477] = surface.makeButton(187, 220, 10, 10)
	surfaceElements.buttons[477].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 125)
	surfaceElements.labels[477] = surface.makeLabelField(187, 225, 10, 1)

	surfaceElements.buttons[478] = surface.makeButton(198, 220, 10, 10)
	surfaceElements.buttons[478].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 126)
	surfaceElements.labels[478] = surface.makeLabelField(198, 225, 10, 1)

	surfaceElements.buttons[479] = surface.makeButton(209, 220, 10, 10)
	surfaceElements.buttons[479].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 127)
	surfaceElements.labels[479] = surface.makeLabelField(209, 225, 10, 1)

	surfaceElements.buttons[480] = surface.makeButton(220, 220, 10, 10)
	surfaceElements.buttons[480].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 111)
	surfaceElements.labels[480] = surface.makeLabelField(220, 225, 10, 1)

	surfaceElements.buttons[481] = surface.makeButton(231, 220, 10, 10)
	surfaceElements.buttons[481].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 112)
	surfaceElements.labels[481] = surface.makeLabelField(231, 225, 10, 1)

	surfaceElements.buttons[482] = surface.makeButton(242, 220, 10, 10)
	surfaceElements.buttons[482].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 113)
	surfaceElements.labels[482] = surface.makeLabelField(242, 225, 10, 1)

	surfaceElements.buttons[483] = surface.makeButton(0, 231, 10, 10)
	surfaceElements.buttons[483].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 114)
	surfaceElements.labels[483] = surface.makeLabelField(0, 236, 10, 1)

	surfaceElements.buttons[484] = surface.makeButton(11, 231, 10, 10)
	surfaceElements.buttons[484].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 115)
	surfaceElements.labels[484] = surface.makeLabelField(11, 236, 10, 1)

	surfaceElements.buttons[485] = surface.makeButton(22, 231, 10, 10)
	surfaceElements.buttons[485].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 116)
	surfaceElements.labels[485] = surface.makeLabelField(22, 236, 10, 1)

	surfaceElements.buttons[486] = surface.makeButton(33, 231, 10, 10)
	surfaceElements.buttons[486].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 117)
	surfaceElements.labels[486] = surface.makeLabelField(33, 236, 10, 1)

	surfaceElements.buttons[487] = surface.makeButton(44, 231, 10, 10)
	surfaceElements.buttons[487].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 118)
	surfaceElements.labels[487] = surface.makeLabelField(44, 236, 10, 1)

	surfaceElements.buttons[488] = surface.makeButton(55, 231, 10, 10)
	surfaceElements.buttons[488].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 119)
	surfaceElements.labels[488] = surface.makeLabelField(55, 236, 10, 1)

	surfaceElements.buttons[489] = surface.makeButton(66, 231, 10, 10)
	surfaceElements.buttons[489].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 120)
	surfaceElements.labels[489] = surface.makeLabelField(66, 236, 10, 1)

	surfaceElements.buttons[490] = surface.makeButton(77, 231, 10, 10)
	surfaceElements.buttons[490].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 121)
	surfaceElements.labels[490] = surface.makeLabelField(77, 236, 10, 1)

	surfaceElements.buttons[491] = surface.makeButton(88, 231, 10, 10)
	surfaceElements.buttons[491].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 122)
	surfaceElements.labels[491] = surface.makeLabelField(88, 236, 10, 1)

	surfaceElements.buttons[492] = surface.makeButton(99, 231, 10, 10)
	surfaceElements.buttons[492].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 123)
	surfaceElements.labels[492] = surface.makeLabelField(99, 236, 10, 1)

	surfaceElements.buttons[493] = surface.makeButton(110, 231, 10, 10)
	surfaceElements.buttons[493].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 124)
	surfaceElements.labels[493] = surface.makeLabelField(110, 236, 10, 1)

	surfaceElements.buttons[494] = surface.makeButton(121, 231, 10, 10)
	surfaceElements.buttons[494].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 125)
	surfaceElements.labels[494] = surface.makeLabelField(121, 236, 10, 1)

	surfaceElements.buttons[495] = surface.makeButton(132, 231, 10, 10)
	surfaceElements.buttons[495].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 126)
	surfaceElements.labels[495] = surface.makeLabelField(132, 236, 10, 1)

	surfaceElements.buttons[496] = surface.makeButton(143, 231, 10, 10)
	surfaceElements.buttons[496].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 127)
	surfaceElements.labels[496] = surface.makeLabelField(143, 236, 10, 1)

	surfaceElements.buttons[497] = surface.makeButton(154, 231, 10, 10)
	surfaceElements.buttons[497].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 121)
	surfaceElements.labels[497] = surface.makeLabelField(154, 236, 10, 1)

	surfaceElements.buttons[498] = surface.makeButton(165, 231, 10, 10)
	surfaceElements.buttons[498].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 122)
	surfaceElements.labels[498] = surface.makeLabelField(165, 236, 10, 1)

	surfaceElements.buttons[499] = surface.makeButton(176, 231, 10, 10)
	surfaceElements.buttons[499].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 123)
	surfaceElements.labels[499] = surface.makeLabelField(176, 236, 10, 1)

	surfaceElements.buttons[500] = surface.makeButton(187, 231, 10, 10)
	surfaceElements.buttons[500].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 124)
	surfaceElements.labels[500] = surface.makeLabelField(187, 236, 10, 1)

	surfaceElements.buttons[501] = surface.makeButton(198, 231, 10, 10)
	surfaceElements.buttons[501].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 125)
	surfaceElements.labels[501] = surface.makeLabelField(198, 236, 10, 1)

	return surfaceElements
}

var surfaceElements = makeSurfaceElements()
// var labelElements = makeLabelElements()

//----------------------------------------------------------------------------------------------------------------------
// 3. HOST MAPPING - create mapping pages and host bindings
//----------------------------------------------------------------------------------------------------------------------
function makePageWithDefaults(name) {
	var page = deviceDriver.mMapping.makePage(name)
	return page
}

//----------------------------------------------------------------------------------------------------------------------
function makePageMacros() {
	var page = makePageWithDefaults('Macros')

	page.makeCommandBinding(surfaceElements.buttons[200].mSurfaceValue, "Process Project Logical Editor", "Scene001")
	page.setLabelFieldText(surfaceElements.labels[200], "Scene 001")

	page.makeCommandBinding(surfaceElements.buttons[201].mSurfaceValue, "Process Project Logical Editor", "Scene002")
	page.setLabelFieldText(surfaceElements.labels[201], "Scene 002")

	page.makeCommandBinding(surfaceElements.buttons[202].mSurfaceValue, "Process Project Logical Editor", "Scene003")
	page.setLabelFieldText(surfaceElements.labels[202], "Scene 003")

	page.makeCommandBinding(surfaceElements.buttons[203].mSurfaceValue, "Process Project Logical Editor", "Scene004")
	page.setLabelFieldText(surfaceElements.labels[203], "Scene 004")

	page.makeCommandBinding(surfaceElements.buttons[204].mSurfaceValue, "Process Project Logical Editor", "Scene005")
	page.setLabelFieldText(surfaceElements.labels[204], "Scene 005")

	page.makeCommandBinding(surfaceElements.buttons[205].mSurfaceValue, "Process Project Logical Editor", "Scene006")
	page.setLabelFieldText(surfaceElements.labels[205], "Scene 006")

	page.makeCommandBinding(surfaceElements.buttons[206].mSurfaceValue, "Process Project Logical Editor", "Scene007")
	page.setLabelFieldText(surfaceElements.labels[206], "Scene 007")

	page.makeCommandBinding(surfaceElements.buttons[207].mSurfaceValue, "Process Project Logical Editor", "Scene008")
	page.setLabelFieldText(surfaceElements.labels[207], "Scene 008")

	page.makeCommandBinding(surfaceElements.buttons[208].mSurfaceValue, "Process Project Logical Editor", "Scene009")
	page.setLabelFieldText(surfaceElements.labels[208], "Scene 009")

	page.makeCommandBinding(surfaceElements.buttons[209].mSurfaceValue, "Process Project Logical Editor", "Scene010")
	page.setLabelFieldText(surfaceElements.labels[209], "Scene 010")

	page.makeCommandBinding(surfaceElements.buttons[210].mSurfaceValue, "Process Project Logical Editor", "Scene011")
	page.setLabelFieldText(surfaceElements.labels[210], "Scene 011")

	page.makeCommandBinding(surfaceElements.buttons[211].mSurfaceValue, "Process Project Logical Editor", "Scene012")
	page.setLabelFieldText(surfaceElements.labels[211], "Scene 012")

	page.makeCommandBinding(surfaceElements.buttons[212].mSurfaceValue, "Process Project Logical Editor", "Scene013")
	page.setLabelFieldText(surfaceElements.labels[212], "Scene 013")

	page.makeCommandBinding(surfaceElements.buttons[213].mSurfaceValue, "Process Project Logical Editor", "Scene014")
	page.setLabelFieldText(surfaceElements.labels[213], "Scene 014")

	page.makeCommandBinding(surfaceElements.buttons[214].mSurfaceValue, "Process Project Logical Editor", "Scene015")
	page.setLabelFieldText(surfaceElements.labels[214], "Scene 015")

	page.makeCommandBinding(surfaceElements.buttons[215].mSurfaceValue, "Process Project Logical Editor", "Scene016")
	page.setLabelFieldText(surfaceElements.labels[215], "Scene 016")

	page.makeCommandBinding(surfaceElements.buttons[216].mSurfaceValue, "Process Project Logical Editor", "Scene017")
	page.setLabelFieldText(surfaceElements.labels[216], "Scene 017")

	page.makeCommandBinding(surfaceElements.buttons[217].mSurfaceValue, "Process Project Logical Editor", "Scene018")
	page.setLabelFieldText(surfaceElements.labels[217], "Scene 018")

	page.makeCommandBinding(surfaceElements.buttons[218].mSurfaceValue, "Process Project Logical Editor", "Scene019")
	page.setLabelFieldText(surfaceElements.labels[218], "Scene 019")

	page.makeCommandBinding(surfaceElements.buttons[219].mSurfaceValue, "Process Project Logical Editor", "Scene020")
	page.setLabelFieldText(surfaceElements.labels[219], "Scene 020")

	page.makeCommandBinding(surfaceElements.buttons[220].mSurfaceValue, "Process Project Logical Editor", "Scene021")
	page.setLabelFieldText(surfaceElements.labels[220], "Scene 021")

	page.makeCommandBinding(surfaceElements.buttons[221].mSurfaceValue, "Process Project Logical Editor", "Scene022")
	page.setLabelFieldText(surfaceElements.labels[221], "Scene 022")

	page.makeCommandBinding(surfaceElements.buttons[222].mSurfaceValue, "Process Project Logical Editor", "Scene023")
	page.setLabelFieldText(surfaceElements.labels[222], "Scene 023")

	page.makeCommandBinding(surfaceElements.buttons[223].mSurfaceValue, "Process Project Logical Editor", "Scene024")
	page.setLabelFieldText(surfaceElements.labels[223], "Scene 024")

	page.makeCommandBinding(surfaceElements.buttons[224].mSurfaceValue, "Process Project Logical Editor", "Scene025")
	page.setLabelFieldText(surfaceElements.labels[224], "Scene 025")

	page.makeCommandBinding(surfaceElements.buttons[225].mSurfaceValue, "Process Project Logical Editor", "Scene026")
	page.setLabelFieldText(surfaceElements.labels[225], "Scene 026")

	page.makeCommandBinding(surfaceElements.buttons[226].mSurfaceValue, "Process Project Logical Editor", "Scene027")
	page.setLabelFieldText(surfaceElements.labels[226], "Scene 027")

	page.makeCommandBinding(surfaceElements.buttons[227].mSurfaceValue, "Process Project Logical Editor", "Scene028")
	page.setLabelFieldText(surfaceElements.labels[227], "Scene 028")

	page.makeCommandBinding(surfaceElements.buttons[228].mSurfaceValue, "Process Project Logical Editor", "Scene029")
	page.setLabelFieldText(surfaceElements.labels[228], "Scene 029")

	page.makeCommandBinding(surfaceElements.buttons[229].mSurfaceValue, "Process Project Logical Editor", "Scene030")
	page.setLabelFieldText(surfaceElements.labels[229], "Scene 030")

	page.makeCommandBinding(surfaceElements.buttons[230].mSurfaceValue, "Process Project Logical Editor", "Scene031")
	page.setLabelFieldText(surfaceElements.labels[230], "Scene 031")

	page.makeCommandBinding(surfaceElements.buttons[231].mSurfaceValue, "Process Project Logical Editor", "Scene032")
	page.setLabelFieldText(surfaceElements.labels[231], "Scene 032")

	page.makeCommandBinding(surfaceElements.buttons[232].mSurfaceValue, "Process Project Logical Editor", "Scene033")
	page.setLabelFieldText(surfaceElements.labels[232], "Scene 033")

	page.makeCommandBinding(surfaceElements.buttons[233].mSurfaceValue, "Process Project Logical Editor", "Scene034")
	page.setLabelFieldText(surfaceElements.labels[233], "Scene 034")

	page.makeCommandBinding(surfaceElements.buttons[234].mSurfaceValue, "Process Project Logical Editor", "Scene035")
	page.setLabelFieldText(surfaceElements.labels[234], "Scene 035")

	page.makeCommandBinding(surfaceElements.buttons[235].mSurfaceValue, "Process Project Logical Editor", "Scene036")
	page.setLabelFieldText(surfaceElements.labels[235], "Scene 036")

	page.makeCommandBinding(surfaceElements.buttons[236].mSurfaceValue, "Process Project Logical Editor", "Scene037")
	page.setLabelFieldText(surfaceElements.labels[236], "Scene 037")

	page.makeCommandBinding(surfaceElements.buttons[237].mSurfaceValue, "Process Project Logical Editor", "Scene038")
	page.setLabelFieldText(surfaceElements.labels[237], "Scene 038")

	page.makeCommandBinding(surfaceElements.buttons[238].mSurfaceValue, "Process Project Logical Editor", "Scene039")
	page.setLabelFieldText(surfaceElements.labels[238], "Scene 039")

	page.makeCommandBinding(surfaceElements.buttons[239].mSurfaceValue, "Process Project Logical Editor", "Scene040")
	page.setLabelFieldText(surfaceElements.labels[239], "Scene 040")

	page.makeCommandBinding(surfaceElements.buttons[240].mSurfaceValue, "Process Project Logical Editor", "Scene041")
	page.setLabelFieldText(surfaceElements.labels[240], "Scene 041")

	page.makeCommandBinding(surfaceElements.buttons[241].mSurfaceValue, "Process Project Logical Editor", "Scene042")
	page.setLabelFieldText(surfaceElements.labels[241], "Scene 042")

	page.makeCommandBinding(surfaceElements.buttons[242].mSurfaceValue, "Process Project Logical Editor", "Scene043")
	page.setLabelFieldText(surfaceElements.labels[242], "Scene 043")

	page.makeCommandBinding(surfaceElements.buttons[243].mSurfaceValue, "Process Project Logical Editor", "Scene044")
	page.setLabelFieldText(surfaceElements.labels[243], "Scene 044")

	page.makeCommandBinding(surfaceElements.buttons[244].mSurfaceValue, "Process Project Logical Editor", "Scene045")
	page.setLabelFieldText(surfaceElements.labels[244], "Scene 045")

	page.makeCommandBinding(surfaceElements.buttons[245].mSurfaceValue, "Process Project Logical Editor", "Scene046")
	page.setLabelFieldText(surfaceElements.labels[245], "Scene 046")

	page.makeCommandBinding(surfaceElements.buttons[246].mSurfaceValue, "Process Project Logical Editor", "Scene047")
	page.setLabelFieldText(surfaceElements.labels[246], "Scene 047")

	page.makeCommandBinding(surfaceElements.buttons[247].mSurfaceValue, "Process Project Logical Editor", "Scene048")
	page.setLabelFieldText(surfaceElements.labels[247], "Scene 048")

	page.makeCommandBinding(surfaceElements.buttons[248].mSurfaceValue, "Process Project Logical Editor", "Scene049")
	page.setLabelFieldText(surfaceElements.labels[248], "Scene 049")

	page.makeCommandBinding(surfaceElements.buttons[249].mSurfaceValue, "Process Project Logical Editor", "Scene050")
	page.setLabelFieldText(surfaceElements.labels[249], "Scene 050")

	page.makeCommandBinding(surfaceElements.buttons[250].mSurfaceValue, "Process Project Logical Editor", "Scene051")
	page.setLabelFieldText(surfaceElements.labels[250], "Scene 051")

	page.makeCommandBinding(surfaceElements.buttons[251].mSurfaceValue, "Process Project Logical Editor", "Scene052")
	page.setLabelFieldText(surfaceElements.labels[251], "Scene 052")

	page.makeCommandBinding(surfaceElements.buttons[252].mSurfaceValue, "Process Project Logical Editor", "Scene053")
	page.setLabelFieldText(surfaceElements.labels[252], "Scene 053")

	page.makeCommandBinding(surfaceElements.buttons[253].mSurfaceValue, "Process Project Logical Editor", "Scene054")
	page.setLabelFieldText(surfaceElements.labels[253], "Scene 054")

	page.makeCommandBinding(surfaceElements.buttons[254].mSurfaceValue, "Process Project Logical Editor", "Scene055")
	page.setLabelFieldText(surfaceElements.labels[254], "Scene 055")

	page.makeCommandBinding(surfaceElements.buttons[255].mSurfaceValue, "Process Project Logical Editor", "Scene056")
	page.setLabelFieldText(surfaceElements.labels[255], "Scene 056")

	page.makeCommandBinding(surfaceElements.buttons[256].mSurfaceValue, "Process Project Logical Editor", "Scene057")
	page.setLabelFieldText(surfaceElements.labels[256], "Scene 057")

	page.makeCommandBinding(surfaceElements.buttons[257].mSurfaceValue, "Process Project Logical Editor", "Scene058")
	page.setLabelFieldText(surfaceElements.labels[257], "Scene 058")

	page.makeCommandBinding(surfaceElements.buttons[258].mSurfaceValue, "Process Project Logical Editor", "Scene059")
	page.setLabelFieldText(surfaceElements.labels[258], "Scene 059")

	page.makeCommandBinding(surfaceElements.buttons[259].mSurfaceValue, "Process Project Logical Editor", "Scene060")
	page.setLabelFieldText(surfaceElements.labels[259], "Scene 060")

	page.makeCommandBinding(surfaceElements.buttons[260].mSurfaceValue, "Process Project Logical Editor", "Scene061")
	page.setLabelFieldText(surfaceElements.labels[260], "Scene 061")

	page.makeCommandBinding(surfaceElements.buttons[261].mSurfaceValue, "Process Project Logical Editor", "Scene062")
	page.setLabelFieldText(surfaceElements.labels[261], "Scene 062")

	page.makeCommandBinding(surfaceElements.buttons[262].mSurfaceValue, "Process Project Logical Editor", "Scene063")
	page.setLabelFieldText(surfaceElements.labels[262], "Scene 063")

	page.makeCommandBinding(surfaceElements.buttons[263].mSurfaceValue, "Process Project Logical Editor", "Scene064")
	page.setLabelFieldText(surfaceElements.labels[263], "Scene 064")

	page.makeCommandBinding(surfaceElements.buttons[264].mSurfaceValue, "Process Project Logical Editor", "Scene065")
	page.setLabelFieldText(surfaceElements.labels[264], "Scene 065")

	page.makeCommandBinding(surfaceElements.buttons[265].mSurfaceValue, "Process Project Logical Editor", "Scene066")
	page.setLabelFieldText(surfaceElements.labels[265], "Scene 066")

	page.makeCommandBinding(surfaceElements.buttons[266].mSurfaceValue, "Process Project Logical Editor", "Scene067")
	page.setLabelFieldText(surfaceElements.labels[266], "Scene 067")

	page.makeCommandBinding(surfaceElements.buttons[267].mSurfaceValue, "Process Project Logical Editor", "Scene068")
	page.setLabelFieldText(surfaceElements.labels[267], "Scene 068")

	page.makeCommandBinding(surfaceElements.buttons[268].mSurfaceValue, "Process Project Logical Editor", "Scene069")
	page.setLabelFieldText(surfaceElements.labels[268], "Scene 069")

	page.makeCommandBinding(surfaceElements.buttons[269].mSurfaceValue, "Process Project Logical Editor", "Scene070")
	page.setLabelFieldText(surfaceElements.labels[269], "Scene 070")

	page.makeCommandBinding(surfaceElements.buttons[270].mSurfaceValue, "Process Project Logical Editor", "Scene071")
	page.setLabelFieldText(surfaceElements.labels[270], "Scene 071")

	page.makeCommandBinding(surfaceElements.buttons[271].mSurfaceValue, "Process Project Logical Editor", "Scene072")
	page.setLabelFieldText(surfaceElements.labels[271], "Scene 072")

	page.makeCommandBinding(surfaceElements.buttons[272].mSurfaceValue, "Process Project Logical Editor", "Scene073")
	page.setLabelFieldText(surfaceElements.labels[272], "Scene 073")

	page.makeCommandBinding(surfaceElements.buttons[273].mSurfaceValue, "Process Project Logical Editor", "Scene074")
	page.setLabelFieldText(surfaceElements.labels[273], "Scene 074")

	page.makeCommandBinding(surfaceElements.buttons[274].mSurfaceValue, "Process Project Logical Editor", "Scene075")
	page.setLabelFieldText(surfaceElements.labels[274], "Scene 075")

	page.makeCommandBinding(surfaceElements.buttons[275].mSurfaceValue, "Process Project Logical Editor", "Scene076")
	page.setLabelFieldText(surfaceElements.labels[275], "Scene 076")

	page.makeCommandBinding(surfaceElements.buttons[276].mSurfaceValue, "Process Project Logical Editor", "Scene077")
	page.setLabelFieldText(surfaceElements.labels[276], "Scene 077")

	page.makeCommandBinding(surfaceElements.buttons[277].mSurfaceValue, "Process Project Logical Editor", "Scene078")
	page.setLabelFieldText(surfaceElements.labels[277], "Scene 078")

	page.makeCommandBinding(surfaceElements.buttons[278].mSurfaceValue, "Process Project Logical Editor", "Scene079")
	page.setLabelFieldText(surfaceElements.labels[278], "Scene 079")

	page.makeCommandBinding(surfaceElements.buttons[279].mSurfaceValue, "Process Project Logical Editor", "Scene080")
	page.setLabelFieldText(surfaceElements.labels[279], "Scene 080")

	page.makeCommandBinding(surfaceElements.buttons[280].mSurfaceValue, "Process Project Logical Editor", "Scene081")
	page.setLabelFieldText(surfaceElements.labels[280], "Scene 081")

	page.makeCommandBinding(surfaceElements.buttons[281].mSurfaceValue, "Process Project Logical Editor", "Scene082")
	page.setLabelFieldText(surfaceElements.labels[281], "Scene 082")

	page.makeCommandBinding(surfaceElements.buttons[282].mSurfaceValue, "Process Project Logical Editor", "Scene083")
	page.setLabelFieldText(surfaceElements.labels[282], "Scene 083")

	page.makeCommandBinding(surfaceElements.buttons[283].mSurfaceValue, "Process Project Logical Editor", "Scene084")
	page.setLabelFieldText(surfaceElements.labels[283], "Scene 084")

	page.makeCommandBinding(surfaceElements.buttons[284].mSurfaceValue, "Process Project Logical Editor", "Scene085")
	page.setLabelFieldText(surfaceElements.labels[284], "Scene 085")

	page.makeCommandBinding(surfaceElements.buttons[285].mSurfaceValue, "Process Project Logical Editor", "Scene086")
	page.setLabelFieldText(surfaceElements.labels[285], "Scene 086")

	page.makeCommandBinding(surfaceElements.buttons[286].mSurfaceValue, "Process Project Logical Editor", "Scene087")
	page.setLabelFieldText(surfaceElements.labels[286], "Scene 087")

	page.makeCommandBinding(surfaceElements.buttons[287].mSurfaceValue, "Process Project Logical Editor", "Scene088")
	page.setLabelFieldText(surfaceElements.labels[287], "Scene 088")

	page.makeCommandBinding(surfaceElements.buttons[288].mSurfaceValue, "Process Project Logical Editor", "Scene089")
	page.setLabelFieldText(surfaceElements.labels[288], "Scene 089")

	page.makeCommandBinding(surfaceElements.buttons[289].mSurfaceValue, "Process Project Logical Editor", "Scene090")
	page.setLabelFieldText(surfaceElements.labels[289], "Scene 090")

	page.makeCommandBinding(surfaceElements.buttons[290].mSurfaceValue, "Process Project Logical Editor", "Scene091")
	page.setLabelFieldText(surfaceElements.labels[290], "Scene 091")

	page.makeCommandBinding(surfaceElements.buttons[291].mSurfaceValue, "Process Project Logical Editor", "Scene092")
	page.setLabelFieldText(surfaceElements.labels[291], "Scene 092")

	page.makeCommandBinding(surfaceElements.buttons[292].mSurfaceValue, "Process Project Logical Editor", "Scene093")
	page.setLabelFieldText(surfaceElements.labels[292], "Scene 093")

	page.makeCommandBinding(surfaceElements.buttons[293].mSurfaceValue, "Process Project Logical Editor", "Scene094")
	page.setLabelFieldText(surfaceElements.labels[293], "Scene 094")

	page.makeCommandBinding(surfaceElements.buttons[294].mSurfaceValue, "Process Project Logical Editor", "Scene095")
	page.setLabelFieldText(surfaceElements.labels[294], "Scene 095")

	page.makeCommandBinding(surfaceElements.buttons[295].mSurfaceValue, "Process Project Logical Editor", "Scene096")
	page.setLabelFieldText(surfaceElements.labels[295], "Scene 096")

	page.makeCommandBinding(surfaceElements.buttons[296].mSurfaceValue, "Process Project Logical Editor", "Scene097")
	page.setLabelFieldText(surfaceElements.labels[296], "Scene 097")

	page.makeCommandBinding(surfaceElements.buttons[297].mSurfaceValue, "Process Project Logical Editor", "Scene098")
	page.setLabelFieldText(surfaceElements.labels[297], "Scene 098")

	page.makeCommandBinding(surfaceElements.buttons[298].mSurfaceValue, "Process Project Logical Editor", "Scene099")
	page.setLabelFieldText(surfaceElements.labels[298], "Scene 099")

	page.makeCommandBinding(surfaceElements.buttons[299].mSurfaceValue, "Process Project Logical Editor", "Scene100")
	page.setLabelFieldText(surfaceElements.labels[299], "Scene 100")

	page.makeCommandBinding(surfaceElements.buttons[300].mSurfaceValue, "Process Project Logical Editor", "Hide All")
	page.setLabelFieldText(surfaceElements.labels[300], "Hide All")

	page.makeCommandBinding(surfaceElements.buttons[301].mSurfaceValue, "Process Project Logical Editor", "MG_Unfold_All_Visible")
	page.setLabelFieldText(surfaceElements.labels[301], "Unfold All")

	return page
}

//----------------------------------------------------------------------------------------------------------------------
// Construct Pages
//----------------------------------------------------------------------------------------------------------------------
function onActivatePageDefault(context) {
}

deviceDriver.mOnActivate = function (context) {
	console.log('Metagrid Macros script has been activated.')
}

var pageMacros = makePageMacros()

pageMacros.mOnActivate = function (context) {
	onActivatePageDefault(context)
	console.log('from script: Metagrid Macros page activated')
}
//----------------------------------------------------------------------------------------------------------------------
// 1. DRIVER SETUP - create driver object, midi ports and detection information
//----------------------------------------------------------------------------------------------------------------------
var midiremote_api = require('midiremote_api_v1')
var deviceDriver = midiremote_api.makeDeviceDriver('Metasystem', 'metagridMacros', 'Martin Jirsak')

var midiInput = deviceDriver.mPorts.makeMidiInput()
var midiOutput = deviceDriver.mPorts.makeMidiOutput()

deviceDriver.makeDetectionUnit().detectPortPair(midiInput, midiOutput)
	.expectInputNameContains('Metasystem - CubaseMacros - In')
	.expectOutputNameContains('Metasystem - CubaseMacros - Out')

var surface = deviceDriver.mSurface

//----------------------------------------------------------------------------------------------------------------------
// 2. SURFACE LAYOUT - create control elements and midi bindings
//----------------------------------------------------------------------------------------------------------------------
function makeSurfaceElements() {
	var surfaceElements = {}
	surfaceElements.buttons = {}
	surfaceElements.labels = {}

	surfaceElements.buttons[0] = surface.makeButton(0, 0, 10, 10)
	surfaceElements.buttons[0].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 11)
	surfaceElements.labels[0] = surface.makeLabelField(0, 5, 10, 1)

	surfaceElements.buttons[1] = surface.makeButton(11, 0, 10, 10)
	surfaceElements.buttons[1].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 12)
	surfaceElements.labels[1] = surface.makeLabelField(11, 5, 10, 1)

	surfaceElements.buttons[2] = surface.makeButton(22, 0, 10, 10)
	surfaceElements.buttons[2].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 13)
	surfaceElements.labels[2] = surface.makeLabelField(22, 5, 10, 1)

	surfaceElements.buttons[3] = surface.makeButton(33, 0, 10, 10)
	surfaceElements.buttons[3].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 14)
	surfaceElements.labels[3] = surface.makeLabelField(33, 5, 10, 1)

	surfaceElements.buttons[4] = surface.makeButton(44, 0, 10, 10)
	surfaceElements.buttons[4].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 15)
	surfaceElements.labels[4] = surface.makeLabelField(44, 5, 10, 1)

	surfaceElements.buttons[5] = surface.makeButton(55, 0, 10, 10)
	surfaceElements.buttons[5].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 16)
	surfaceElements.labels[5] = surface.makeLabelField(55, 5, 10, 1)

	surfaceElements.buttons[6] = surface.makeButton(66, 0, 10, 10)
	surfaceElements.buttons[6].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 17)
	surfaceElements.labels[6] = surface.makeLabelField(66, 5, 10, 1)

	surfaceElements.buttons[7] = surface.makeButton(77, 0, 10, 10)
	surfaceElements.buttons[7].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 18)
	surfaceElements.labels[7] = surface.makeLabelField(77, 5, 10, 1)

	surfaceElements.buttons[8] = surface.makeButton(88, 0, 10, 10)
	surfaceElements.buttons[8].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 19)
	surfaceElements.labels[8] = surface.makeLabelField(88, 5, 10, 1)

	surfaceElements.buttons[9] = surface.makeButton(99, 0, 10, 10)
	surfaceElements.buttons[9].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 20)
	surfaceElements.labels[9] = surface.makeLabelField(99, 5, 10, 1)

	surfaceElements.buttons[10] = surface.makeButton(110, 0, 10, 10)
	surfaceElements.buttons[10].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 21)
	surfaceElements.labels[10] = surface.makeLabelField(110, 5, 10, 1)

	surfaceElements.buttons[11] = surface.makeButton(121, 0, 10, 10)
	surfaceElements.buttons[11].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 22)
	surfaceElements.labels[11] = surface.makeLabelField(121, 5, 10, 1)

	surfaceElements.buttons[12] = surface.makeButton(132, 0, 10, 10)
	surfaceElements.buttons[12].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 23)
	surfaceElements.labels[12] = surface.makeLabelField(132, 5, 10, 1)

	surfaceElements.buttons[13] = surface.makeButton(143, 0, 10, 10)
	surfaceElements.buttons[13].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 24)
	surfaceElements.labels[13] = surface.makeLabelField(143, 5, 10, 1)

	surfaceElements.buttons[14] = surface.makeButton(154, 0, 10, 10)
	surfaceElements.buttons[14].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 25)
	surfaceElements.labels[14] = surface.makeLabelField(154, 5, 10, 1)

	surfaceElements.buttons[15] = surface.makeButton(165, 0, 10, 10)
	surfaceElements.buttons[15].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 26)
	surfaceElements.labels[15] = surface.makeLabelField(165, 5, 10, 1)

	surfaceElements.buttons[16] = surface.makeButton(176, 0, 10, 10)
	surfaceElements.buttons[16].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 27)
	surfaceElements.labels[16] = surface.makeLabelField(176, 5, 10, 1)

	surfaceElements.buttons[17] = surface.makeButton(187, 0, 10, 10)
	surfaceElements.buttons[17].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 28)
	surfaceElements.labels[17] = surface.makeLabelField(187, 5, 10, 1)

	surfaceElements.buttons[18] = surface.makeButton(198, 0, 10, 10)
	surfaceElements.buttons[18].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 29)
	surfaceElements.labels[18] = surface.makeLabelField(198, 5, 10, 1)

	surfaceElements.buttons[19] = surface.makeButton(209, 0, 10, 10)
	surfaceElements.buttons[19].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 30)
	surfaceElements.labels[19] = surface.makeLabelField(209, 5, 10, 1)

	surfaceElements.buttons[20] = surface.makeButton(220, 0, 10, 10)
	surfaceElements.buttons[20].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 31)
	surfaceElements.labels[20] = surface.makeLabelField(220, 5, 10, 1)

	surfaceElements.buttons[21] = surface.makeButton(231, 0, 10, 10)
	surfaceElements.buttons[21].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 32)
	surfaceElements.labels[21] = surface.makeLabelField(231, 5, 10, 1)

	surfaceElements.buttons[22] = surface.makeButton(242, 0, 10, 10)
	surfaceElements.buttons[22].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 33)
	surfaceElements.labels[22] = surface.makeLabelField(242, 5, 10, 1)

	surfaceElements.buttons[23] = surface.makeButton(0, 11, 10, 10)
	surfaceElements.buttons[23].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 34)
	surfaceElements.labels[23] = surface.makeLabelField(0, 16, 10, 1)

	surfaceElements.buttons[24] = surface.makeButton(11, 11, 10, 10)
	surfaceElements.buttons[24].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 35)
	surfaceElements.labels[24] = surface.makeLabelField(11, 16, 10, 1)

	surfaceElements.buttons[25] = surface.makeButton(22, 11, 10, 10)
	surfaceElements.buttons[25].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 36)
	surfaceElements.labels[25] = surface.makeLabelField(22, 16, 10, 1)

	surfaceElements.buttons[26] = surface.makeButton(33, 11, 10, 10)
	surfaceElements.buttons[26].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 37)
	surfaceElements.labels[26] = surface.makeLabelField(33, 16, 10, 1)

	surfaceElements.buttons[27] = surface.makeButton(44, 11, 10, 10)
	surfaceElements.buttons[27].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 38)
	surfaceElements.labels[27] = surface.makeLabelField(44, 16, 10, 1)

	surfaceElements.buttons[28] = surface.makeButton(55, 11, 10, 10)
	surfaceElements.buttons[28].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 39)
	surfaceElements.labels[28] = surface.makeLabelField(55, 16, 10, 1)

	surfaceElements.buttons[29] = surface.makeButton(66, 11, 10, 10)
	surfaceElements.buttons[29].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 40)
	surfaceElements.labels[29] = surface.makeLabelField(66, 16, 10, 1)

	surfaceElements.buttons[30] = surface.makeButton(77, 11, 10, 10)
	surfaceElements.buttons[30].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 41)
	surfaceElements.labels[30] = surface.makeLabelField(77, 16, 10, 1)

	surfaceElements.buttons[31] = surface.makeButton(88, 11, 10, 10)
	surfaceElements.buttons[31].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 42)
	surfaceElements.labels[31] = surface.makeLabelField(88, 16, 10, 1)

	surfaceElements.buttons[32] = surface.makeButton(99, 11, 10, 10)
	surfaceElements.buttons[32].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 43)
	surfaceElements.labels[32] = surface.makeLabelField(99, 16, 10, 1)

	surfaceElements.buttons[33] = surface.makeButton(110, 11, 10, 10)
	surfaceElements.buttons[33].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 44)
	surfaceElements.labels[33] = surface.makeLabelField(110, 16, 10, 1)

	surfaceElements.buttons[34] = surface.makeButton(121, 11, 10, 10)
	surfaceElements.buttons[34].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 45)
	surfaceElements.labels[34] = surface.makeLabelField(121, 16, 10, 1)

	surfaceElements.buttons[35] = surface.makeButton(132, 11, 10, 10)
	surfaceElements.buttons[35].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 46)
	surfaceElements.labels[35] = surface.makeLabelField(132, 16, 10, 1)

	surfaceElements.buttons[36] = surface.makeButton(143, 11, 10, 10)
	surfaceElements.buttons[36].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 47)
	surfaceElements.labels[36] = surface.makeLabelField(143, 16, 10, 1)

	surfaceElements.buttons[37] = surface.makeButton(154, 11, 10, 10)
	surfaceElements.buttons[37].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 48)
	surfaceElements.labels[37] = surface.makeLabelField(154, 16, 10, 1)

	surfaceElements.buttons[38] = surface.makeButton(165, 11, 10, 10)
	surfaceElements.buttons[38].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 49)
	surfaceElements.labels[38] = surface.makeLabelField(165, 16, 10, 1)

	surfaceElements.buttons[39] = surface.makeButton(176, 11, 10, 10)
	surfaceElements.buttons[39].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 50)
	surfaceElements.labels[39] = surface.makeLabelField(176, 16, 10, 1)

	surfaceElements.buttons[40] = surface.makeButton(187, 11, 10, 10)
	surfaceElements.buttons[40].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 51)
	surfaceElements.labels[40] = surface.makeLabelField(187, 16, 10, 1)

	surfaceElements.buttons[41] = surface.makeButton(198, 11, 10, 10)
	surfaceElements.buttons[41].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 52)
	surfaceElements.labels[41] = surface.makeLabelField(198, 16, 10, 1)

	surfaceElements.buttons[42] = surface.makeButton(209, 11, 10, 10)
	surfaceElements.buttons[42].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 53)
	surfaceElements.labels[42] = surface.makeLabelField(209, 16, 10, 1)

	surfaceElements.buttons[43] = surface.makeButton(220, 11, 10, 10)
	surfaceElements.buttons[43].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 54)
	surfaceElements.labels[43] = surface.makeLabelField(220, 16, 10, 1)

	surfaceElements.buttons[44] = surface.makeButton(231, 11, 10, 10)
	surfaceElements.buttons[44].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 55)
	surfaceElements.labels[44] = surface.makeLabelField(231, 16, 10, 1)

	surfaceElements.buttons[45] = surface.makeButton(242, 11, 10, 10)
	surfaceElements.buttons[45].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 56)
	surfaceElements.labels[45] = surface.makeLabelField(242, 16, 10, 1)

	surfaceElements.buttons[46] = surface.makeButton(0, 22, 10, 10)
	surfaceElements.buttons[46].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 57)
	surfaceElements.labels[46] = surface.makeLabelField(0, 27, 10, 1)

	surfaceElements.buttons[47] = surface.makeButton(11, 22, 10, 10)
	surfaceElements.buttons[47].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 58)
	surfaceElements.labels[47] = surface.makeLabelField(11, 27, 10, 1)

	surfaceElements.buttons[48] = surface.makeButton(22, 22, 10, 10)
	surfaceElements.buttons[48].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 59)
	surfaceElements.labels[48] = surface.makeLabelField(22, 27, 10, 1)

	surfaceElements.buttons[49] = surface.makeButton(33, 22, 10, 10)
	surfaceElements.buttons[49].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 60)
	surfaceElements.labels[49] = surface.makeLabelField(33, 27, 10, 1)

	surfaceElements.buttons[50] = surface.makeButton(44, 22, 10, 10)
	surfaceElements.buttons[50].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 61)
	surfaceElements.labels[50] = surface.makeLabelField(44, 27, 10, 1)

	surfaceElements.buttons[51] = surface.makeButton(55, 22, 10, 10)
	surfaceElements.buttons[51].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 62)
	surfaceElements.labels[51] = surface.makeLabelField(55, 27, 10, 1)

	surfaceElements.buttons[52] = surface.makeButton(66, 22, 10, 10)
	surfaceElements.buttons[52].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 63)
	surfaceElements.labels[52] = surface.makeLabelField(66, 27, 10, 1)

	surfaceElements.buttons[53] = surface.makeButton(77, 22, 10, 10)
	surfaceElements.buttons[53].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 64)
	surfaceElements.labels[53] = surface.makeLabelField(77, 27, 10, 1)

	surfaceElements.buttons[54] = surface.makeButton(88, 22, 10, 10)
	surfaceElements.buttons[54].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 65)
	surfaceElements.labels[54] = surface.makeLabelField(88, 27, 10, 1)

	surfaceElements.buttons[55] = surface.makeButton(99, 22, 10, 10)
	surfaceElements.buttons[55].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 66)
	surfaceElements.labels[55] = surface.makeLabelField(99, 27, 10, 1)

	surfaceElements.buttons[56] = surface.makeButton(110, 22, 10, 10)
	surfaceElements.buttons[56].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 67)
	surfaceElements.labels[56] = surface.makeLabelField(110, 27, 10, 1)

	surfaceElements.buttons[57] = surface.makeButton(121, 22, 10, 10)
	surfaceElements.buttons[57].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 68)
	surfaceElements.labels[57] = surface.makeLabelField(121, 27, 10, 1)

	surfaceElements.buttons[58] = surface.makeButton(132, 22, 10, 10)
	surfaceElements.buttons[58].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 69)
	surfaceElements.labels[58] = surface.makeLabelField(132, 27, 10, 1)

	surfaceElements.buttons[59] = surface.makeButton(143, 22, 10, 10)
	surfaceElements.buttons[59].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 70)
	surfaceElements.labels[59] = surface.makeLabelField(143, 27, 10, 1)

	surfaceElements.buttons[60] = surface.makeButton(154, 22, 10, 10)
	surfaceElements.buttons[60].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 71)
	surfaceElements.labels[60] = surface.makeLabelField(154, 27, 10, 1)

	surfaceElements.buttons[61] = surface.makeButton(165, 22, 10, 10)
	surfaceElements.buttons[61].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 72)
	surfaceElements.labels[61] = surface.makeLabelField(165, 27, 10, 1)

	surfaceElements.buttons[62] = surface.makeButton(176, 22, 10, 10)
	surfaceElements.buttons[62].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 73)
	surfaceElements.labels[62] = surface.makeLabelField(176, 27, 10, 1)

	surfaceElements.buttons[63] = surface.makeButton(187, 22, 10, 10)
	surfaceElements.buttons[63].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 74)
	surfaceElements.labels[63] = surface.makeLabelField(187, 27, 10, 1)

	surfaceElements.buttons[64] = surface.makeButton(198, 22, 10, 10)
	surfaceElements.buttons[64].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 75)
	surfaceElements.labels[64] = surface.makeLabelField(198, 27, 10, 1)

	surfaceElements.buttons[65] = surface.makeButton(209, 22, 10, 10)
	surfaceElements.buttons[65].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 76)
	surfaceElements.labels[65] = surface.makeLabelField(209, 27, 10, 1)

	surfaceElements.buttons[66] = surface.makeButton(220, 22, 10, 10)
	surfaceElements.buttons[66].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 77)
	surfaceElements.labels[66] = surface.makeLabelField(220, 27, 10, 1)

	surfaceElements.buttons[67] = surface.makeButton(231, 22, 10, 10)
	surfaceElements.buttons[67].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 78)
	surfaceElements.labels[67] = surface.makeLabelField(231, 27, 10, 1)

	surfaceElements.buttons[68] = surface.makeButton(242, 22, 10, 10)
	surfaceElements.buttons[68].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 79)
	surfaceElements.labels[68] = surface.makeLabelField(242, 27, 10, 1)

	surfaceElements.buttons[69] = surface.makeButton(0, 33, 10, 10)
	surfaceElements.buttons[69].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 80)
	surfaceElements.labels[69] = surface.makeLabelField(0, 38, 10, 1)

	surfaceElements.buttons[70] = surface.makeButton(11, 33, 10, 10)
	surfaceElements.buttons[70].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 81)
	surfaceElements.labels[70] = surface.makeLabelField(11, 38, 10, 1)

	surfaceElements.buttons[71] = surface.makeButton(22, 33, 10, 10)
	surfaceElements.buttons[71].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 82)
	surfaceElements.labels[71] = surface.makeLabelField(22, 38, 10, 1)

	surfaceElements.buttons[72] = surface.makeButton(33, 33, 10, 10)
	surfaceElements.buttons[72].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 83)
	surfaceElements.labels[72] = surface.makeLabelField(33, 38, 10, 1)

	surfaceElements.buttons[73] = surface.makeButton(44, 33, 10, 10)
	surfaceElements.buttons[73].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 84)
	surfaceElements.labels[73] = surface.makeLabelField(44, 38, 10, 1)

	surfaceElements.buttons[74] = surface.makeButton(55, 33, 10, 10)
	surfaceElements.buttons[74].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 85)
	surfaceElements.labels[74] = surface.makeLabelField(55, 38, 10, 1)

	surfaceElements.buttons[75] = surface.makeButton(66, 33, 10, 10)
	surfaceElements.buttons[75].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 86)
	surfaceElements.labels[75] = surface.makeLabelField(66, 38, 10, 1)

	surfaceElements.buttons[76] = surface.makeButton(77, 33, 10, 10)
	surfaceElements.buttons[76].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 87)
	surfaceElements.labels[76] = surface.makeLabelField(77, 38, 10, 1)

	surfaceElements.buttons[77] = surface.makeButton(88, 33, 10, 10)
	surfaceElements.buttons[77].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 88)
	surfaceElements.labels[77] = surface.makeLabelField(88, 38, 10, 1)

	surfaceElements.buttons[78] = surface.makeButton(99, 33, 10, 10)
	surfaceElements.buttons[78].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 89)
	surfaceElements.labels[78] = surface.makeLabelField(99, 38, 10, 1)

	surfaceElements.buttons[79] = surface.makeButton(110, 33, 10, 10)
	surfaceElements.buttons[79].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 90)
	surfaceElements.labels[79] = surface.makeLabelField(110, 38, 10, 1)

	surfaceElements.buttons[80] = surface.makeButton(121, 33, 10, 10)
	surfaceElements.buttons[80].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 91)
	surfaceElements.labels[80] = surface.makeLabelField(121, 38, 10, 1)

	surfaceElements.buttons[81] = surface.makeButton(132, 33, 10, 10)
	surfaceElements.buttons[81].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 92)
	surfaceElements.labels[81] = surface.makeLabelField(132, 38, 10, 1)

	surfaceElements.buttons[82] = surface.makeButton(143, 33, 10, 10)
	surfaceElements.buttons[82].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 93)
	surfaceElements.labels[82] = surface.makeLabelField(143, 38, 10, 1)

	surfaceElements.buttons[83] = surface.makeButton(154, 33, 10, 10)
	surfaceElements.buttons[83].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 94)
	surfaceElements.labels[83] = surface.makeLabelField(154, 38, 10, 1)

	surfaceElements.buttons[84] = surface.makeButton(165, 33, 10, 10)
	surfaceElements.buttons[84].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 95)
	surfaceElements.labels[84] = surface.makeLabelField(165, 38, 10, 1)

	surfaceElements.buttons[85] = surface.makeButton(176, 33, 10, 10)
	surfaceElements.buttons[85].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 96)
	surfaceElements.labels[85] = surface.makeLabelField(176, 38, 10, 1)

	surfaceElements.buttons[86] = surface.makeButton(187, 33, 10, 10)
	surfaceElements.buttons[86].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 97)
	surfaceElements.labels[86] = surface.makeLabelField(187, 38, 10, 1)

	surfaceElements.buttons[87] = surface.makeButton(198, 33, 10, 10)
	surfaceElements.buttons[87].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 98)
	surfaceElements.labels[87] = surface.makeLabelField(198, 38, 10, 1)

	surfaceElements.buttons[88] = surface.makeButton(209, 33, 10, 10)
	surfaceElements.buttons[88].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 99)
	surfaceElements.labels[88] = surface.makeLabelField(209, 38, 10, 1)

	surfaceElements.buttons[89] = surface.makeButton(220, 33, 10, 10)
	surfaceElements.buttons[89].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 100)
	surfaceElements.labels[89] = surface.makeLabelField(220, 38, 10, 1)

	surfaceElements.buttons[90] = surface.makeButton(231, 33, 10, 10)
	surfaceElements.buttons[90].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 101)
	surfaceElements.labels[90] = surface.makeLabelField(231, 38, 10, 1)

	surfaceElements.buttons[91] = surface.makeButton(242, 33, 10, 10)
	surfaceElements.buttons[91].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 102)
	surfaceElements.labels[91] = surface.makeLabelField(242, 38, 10, 1)

	surfaceElements.buttons[92] = surface.makeButton(0, 44, 10, 10)
	surfaceElements.buttons[92].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 103)
	surfaceElements.labels[92] = surface.makeLabelField(0, 49, 10, 1)

	surfaceElements.buttons[93] = surface.makeButton(11, 44, 10, 10)
	surfaceElements.buttons[93].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 104)
	surfaceElements.labels[93] = surface.makeLabelField(11, 49, 10, 1)

	surfaceElements.buttons[94] = surface.makeButton(22, 44, 10, 10)
	surfaceElements.buttons[94].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 105)
	surfaceElements.labels[94] = surface.makeLabelField(22, 49, 10, 1)

	surfaceElements.buttons[95] = surface.makeButton(33, 44, 10, 10)
	surfaceElements.buttons[95].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 106)
	surfaceElements.labels[95] = surface.makeLabelField(33, 49, 10, 1)

	surfaceElements.buttons[96] = surface.makeButton(44, 44, 10, 10)
	surfaceElements.buttons[96].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 107)
	surfaceElements.labels[96] = surface.makeLabelField(44, 49, 10, 1)

	surfaceElements.buttons[97] = surface.makeButton(55, 44, 10, 10)
	surfaceElements.buttons[97].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 108)
	surfaceElements.labels[97] = surface.makeLabelField(55, 49, 10, 1)

	surfaceElements.buttons[98] = surface.makeButton(66, 44, 10, 10)
	surfaceElements.buttons[98].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 109)
	surfaceElements.labels[98] = surface.makeLabelField(66, 49, 10, 1)

	surfaceElements.buttons[99] = surface.makeButton(77, 44, 10, 10)
	surfaceElements.buttons[99].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 110)
	surfaceElements.labels[99] = surface.makeLabelField(77, 49, 10, 1)

	surfaceElements.buttons[100] = surface.makeButton(88, 44, 10, 10)
	surfaceElements.buttons[100].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 1)
	surfaceElements.labels[100] = surface.makeLabelField(88, 49, 10, 1)

	surfaceElements.buttons[101] = surface.makeButton(99, 44, 10, 10)
	surfaceElements.buttons[101].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 2)
	surfaceElements.labels[101] = surface.makeLabelField(99, 49, 10, 1)

	surfaceElements.buttons[102] = surface.makeButton(110, 44, 10, 10)
	surfaceElements.buttons[102].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 3)
	surfaceElements.labels[102] = surface.makeLabelField(110, 49, 10, 1)

	surfaceElements.buttons[103] = surface.makeButton(121, 44, 10, 10)
	surfaceElements.buttons[103].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 4)
	surfaceElements.labels[103] = surface.makeLabelField(121, 49, 10, 1)

	surfaceElements.buttons[104] = surface.makeButton(132, 44, 10, 10)
	surfaceElements.buttons[104].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 5)
	surfaceElements.labels[104] = surface.makeLabelField(132, 49, 10, 1)

	surfaceElements.buttons[105] = surface.makeButton(143, 44, 10, 10)
	surfaceElements.buttons[105].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 6)
	surfaceElements.labels[105] = surface.makeLabelField(143, 49, 10, 1)

	surfaceElements.buttons[106] = surface.makeButton(154, 44, 10, 10)
	surfaceElements.buttons[106].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 7)
	surfaceElements.labels[106] = surface.makeLabelField(154, 49, 10, 1)

	surfaceElements.buttons[107] = surface.makeButton(165, 44, 10, 10)
	surfaceElements.buttons[107].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 8)
	surfaceElements.labels[107] = surface.makeLabelField(165, 49, 10, 1)

	surfaceElements.buttons[108] = surface.makeButton(176, 44, 10, 10)
	surfaceElements.buttons[108].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 9)
	surfaceElements.labels[108] = surface.makeLabelField(176, 49, 10, 1)

	surfaceElements.buttons[109] = surface.makeButton(187, 44, 10, 10)
	surfaceElements.buttons[109].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 10)
	surfaceElements.labels[109] = surface.makeLabelField(187, 49, 10, 1)

	surfaceElements.buttons[110] = surface.makeButton(198, 44, 10, 10)
	surfaceElements.buttons[110].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 11)
	surfaceElements.labels[110] = surface.makeLabelField(198, 49, 10, 1)

	surfaceElements.buttons[111] = surface.makeButton(209, 44, 10, 10)
	surfaceElements.buttons[111].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 12)
	surfaceElements.labels[111] = surface.makeLabelField(209, 49, 10, 1)

	surfaceElements.buttons[112] = surface.makeButton(220, 44, 10, 10)
	surfaceElements.buttons[112].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 13)
	surfaceElements.labels[112] = surface.makeLabelField(220, 49, 10, 1)

	surfaceElements.buttons[113] = surface.makeButton(231, 44, 10, 10)
	surfaceElements.buttons[113].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 14)
	surfaceElements.labels[113] = surface.makeLabelField(231, 49, 10, 1)

	surfaceElements.buttons[114] = surface.makeButton(242, 44, 10, 10)
	surfaceElements.buttons[114].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 15)
	surfaceElements.labels[114] = surface.makeLabelField(242, 49, 10, 1)

	surfaceElements.buttons[115] = surface.makeButton(0, 55, 10, 10)
	surfaceElements.buttons[115].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 16)
	surfaceElements.labels[115] = surface.makeLabelField(0, 60, 10, 1)

	surfaceElements.buttons[116] = surface.makeButton(11, 55, 10, 10)
	surfaceElements.buttons[116].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 17)
	surfaceElements.labels[116] = surface.makeLabelField(11, 60, 10, 1)

	surfaceElements.buttons[117] = surface.makeButton(22, 55, 10, 10)
	surfaceElements.buttons[117].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 18)
	surfaceElements.labels[117] = surface.makeLabelField(22, 60, 10, 1)

	surfaceElements.buttons[118] = surface.makeButton(33, 55, 10, 10)
	surfaceElements.buttons[118].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 19)
	surfaceElements.labels[118] = surface.makeLabelField(33, 60, 10, 1)

	surfaceElements.buttons[119] = surface.makeButton(44, 55, 10, 10)
	surfaceElements.buttons[119].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 20)
	surfaceElements.labels[119] = surface.makeLabelField(44, 60, 10, 1)

	surfaceElements.buttons[120] = surface.makeButton(55, 55, 10, 10)
	surfaceElements.buttons[120].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 21)
	surfaceElements.labels[120] = surface.makeLabelField(55, 60, 10, 1)

	surfaceElements.buttons[121] = surface.makeButton(66, 55, 10, 10)
	surfaceElements.buttons[121].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 22)
	surfaceElements.labels[121] = surface.makeLabelField(66, 60, 10, 1)

	surfaceElements.buttons[122] = surface.makeButton(77, 55, 10, 10)
	surfaceElements.buttons[122].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 23)
	surfaceElements.labels[122] = surface.makeLabelField(77, 60, 10, 1)

	surfaceElements.buttons[123] = surface.makeButton(88, 55, 10, 10)
	surfaceElements.buttons[123].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 24)
	surfaceElements.labels[123] = surface.makeLabelField(88, 60, 10, 1)

	surfaceElements.buttons[124] = surface.makeButton(99, 55, 10, 10)
	surfaceElements.buttons[124].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 25)
	surfaceElements.labels[124] = surface.makeLabelField(99, 60, 10, 1)

	surfaceElements.buttons[125] = surface.makeButton(110, 55, 10, 10)
	surfaceElements.buttons[125].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 26)
	surfaceElements.labels[125] = surface.makeLabelField(110, 60, 10, 1)

	surfaceElements.buttons[126] = surface.makeButton(121, 55, 10, 10)
	surfaceElements.buttons[126].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 27)
	surfaceElements.labels[126] = surface.makeLabelField(121, 60, 10, 1)

	surfaceElements.buttons[127] = surface.makeButton(132, 55, 10, 10)
	surfaceElements.buttons[127].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 28)
	surfaceElements.labels[127] = surface.makeLabelField(132, 60, 10, 1)

	surfaceElements.buttons[128] = surface.makeButton(143, 55, 10, 10)
	surfaceElements.buttons[128].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 29)
	surfaceElements.labels[128] = surface.makeLabelField(143, 60, 10, 1)

	surfaceElements.buttons[129] = surface.makeButton(154, 55, 10, 10)
	surfaceElements.buttons[129].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 30)
	surfaceElements.labels[129] = surface.makeLabelField(154, 60, 10, 1)

	surfaceElements.buttons[130] = surface.makeButton(165, 55, 10, 10)
	surfaceElements.buttons[130].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 31)
	surfaceElements.labels[130] = surface.makeLabelField(165, 60, 10, 1)

	surfaceElements.buttons[131] = surface.makeButton(176, 55, 10, 10)
	surfaceElements.buttons[131].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 32)
	surfaceElements.labels[131] = surface.makeLabelField(176, 60, 10, 1)

	surfaceElements.buttons[132] = surface.makeButton(187, 55, 10, 10)
	surfaceElements.buttons[132].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 33)
	surfaceElements.labels[132] = surface.makeLabelField(187, 60, 10, 1)

	surfaceElements.buttons[133] = surface.makeButton(198, 55, 10, 10)
	surfaceElements.buttons[133].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 34)
	surfaceElements.labels[133] = surface.makeLabelField(198, 60, 10, 1)

	surfaceElements.buttons[134] = surface.makeButton(209, 55, 10, 10)
	surfaceElements.buttons[134].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 35)
	surfaceElements.labels[134] = surface.makeLabelField(209, 60, 10, 1)

	surfaceElements.buttons[135] = surface.makeButton(220, 55, 10, 10)
	surfaceElements.buttons[135].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 36)
	surfaceElements.labels[135] = surface.makeLabelField(220, 60, 10, 1)

	surfaceElements.buttons[136] = surface.makeButton(231, 55, 10, 10)
	surfaceElements.buttons[136].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 37)
	surfaceElements.labels[136] = surface.makeLabelField(231, 60, 10, 1)

	surfaceElements.buttons[137] = surface.makeButton(242, 55, 10, 10)
	surfaceElements.buttons[137].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 38)
	surfaceElements.labels[137] = surface.makeLabelField(242, 60, 10, 1)

	surfaceElements.buttons[138] = surface.makeButton(0, 66, 10, 10)
	surfaceElements.buttons[138].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 39)
	surfaceElements.labels[138] = surface.makeLabelField(0, 71, 10, 1)

	surfaceElements.buttons[139] = surface.makeButton(11, 66, 10, 10)
	surfaceElements.buttons[139].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 40)
	surfaceElements.labels[139] = surface.makeLabelField(11, 71, 10, 1)

	surfaceElements.buttons[140] = surface.makeButton(22, 66, 10, 10)
	surfaceElements.buttons[140].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 41)
	surfaceElements.labels[140] = surface.makeLabelField(22, 71, 10, 1)

	surfaceElements.buttons[141] = surface.makeButton(33, 66, 10, 10)
	surfaceElements.buttons[141].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 42)
	surfaceElements.labels[141] = surface.makeLabelField(33, 71, 10, 1)

	surfaceElements.buttons[142] = surface.makeButton(44, 66, 10, 10)
	surfaceElements.buttons[142].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 43)
	surfaceElements.labels[142] = surface.makeLabelField(44, 71, 10, 1)

	surfaceElements.buttons[143] = surface.makeButton(55, 66, 10, 10)
	surfaceElements.buttons[143].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 44)
	surfaceElements.labels[143] = surface.makeLabelField(55, 71, 10, 1)

	surfaceElements.buttons[144] = surface.makeButton(66, 66, 10, 10)
	surfaceElements.buttons[144].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 45)
	surfaceElements.labels[144] = surface.makeLabelField(66, 71, 10, 1)

	surfaceElements.buttons[145] = surface.makeButton(77, 66, 10, 10)
	surfaceElements.buttons[145].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 46)
	surfaceElements.labels[145] = surface.makeLabelField(77, 71, 10, 1)

	surfaceElements.buttons[146] = surface.makeButton(88, 66, 10, 10)
	surfaceElements.buttons[146].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 47)
	surfaceElements.labels[146] = surface.makeLabelField(88, 71, 10, 1)

	surfaceElements.buttons[147] = surface.makeButton(99, 66, 10, 10)
	surfaceElements.buttons[147].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 48)
	surfaceElements.labels[147] = surface.makeLabelField(99, 71, 10, 1)

	surfaceElements.buttons[148] = surface.makeButton(110, 66, 10, 10)
	surfaceElements.buttons[148].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 49)
	surfaceElements.labels[148] = surface.makeLabelField(110, 71, 10, 1)

	surfaceElements.buttons[149] = surface.makeButton(121, 66, 10, 10)
	surfaceElements.buttons[149].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 50)
	surfaceElements.labels[149] = surface.makeLabelField(121, 71, 10, 1)

	surfaceElements.buttons[150] = surface.makeButton(132, 66, 10, 10)
	surfaceElements.buttons[150].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 51)
	surfaceElements.labels[150] = surface.makeLabelField(132, 71, 10, 1)

	surfaceElements.buttons[151] = surface.makeButton(143, 66, 10, 10)
	surfaceElements.buttons[151].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 52)
	surfaceElements.labels[151] = surface.makeLabelField(143, 71, 10, 1)

	surfaceElements.buttons[152] = surface.makeButton(154, 66, 10, 10)
	surfaceElements.buttons[152].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 53)
	surfaceElements.labels[152] = surface.makeLabelField(154, 71, 10, 1)

	surfaceElements.buttons[153] = surface.makeButton(165, 66, 10, 10)
	surfaceElements.buttons[153].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 54)
	surfaceElements.labels[153] = surface.makeLabelField(165, 71, 10, 1)

	surfaceElements.buttons[154] = surface.makeButton(176, 66, 10, 10)
	surfaceElements.buttons[154].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 55)
	surfaceElements.labels[154] = surface.makeLabelField(176, 71, 10, 1)

	surfaceElements.buttons[155] = surface.makeButton(187, 66, 10, 10)
	surfaceElements.buttons[155].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 56)
	surfaceElements.labels[155] = surface.makeLabelField(187, 71, 10, 1)

	surfaceElements.buttons[156] = surface.makeButton(198, 66, 10, 10)
	surfaceElements.buttons[156].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 57)
	surfaceElements.labels[156] = surface.makeLabelField(198, 71, 10, 1)

	surfaceElements.buttons[157] = surface.makeButton(209, 66, 10, 10)
	surfaceElements.buttons[157].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 58)
	surfaceElements.labels[157] = surface.makeLabelField(209, 71, 10, 1)

	surfaceElements.buttons[158] = surface.makeButton(220, 66, 10, 10)
	surfaceElements.buttons[158].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 59)
	surfaceElements.labels[158] = surface.makeLabelField(220, 71, 10, 1)

	surfaceElements.buttons[159] = surface.makeButton(231, 66, 10, 10)
	surfaceElements.buttons[159].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 60)
	surfaceElements.labels[159] = surface.makeLabelField(231, 71, 10, 1)

	surfaceElements.buttons[160] = surface.makeButton(242, 66, 10, 10)
	surfaceElements.buttons[160].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 61)
	surfaceElements.labels[160] = surface.makeLabelField(242, 71, 10, 1)

	surfaceElements.buttons[161] = surface.makeButton(0, 77, 10, 10)
	surfaceElements.buttons[161].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 62)
	surfaceElements.labels[161] = surface.makeLabelField(0, 82, 10, 1)

	surfaceElements.buttons[162] = surface.makeButton(11, 77, 10, 10)
	surfaceElements.buttons[162].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 63)
	surfaceElements.labels[162] = surface.makeLabelField(11, 82, 10, 1)

	surfaceElements.buttons[163] = surface.makeButton(22, 77, 10, 10)
	surfaceElements.buttons[163].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 64)
	surfaceElements.labels[163] = surface.makeLabelField(22, 82, 10, 1)

	surfaceElements.buttons[164] = surface.makeButton(33, 77, 10, 10)
	surfaceElements.buttons[164].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 65)
	surfaceElements.labels[164] = surface.makeLabelField(33, 82, 10, 1)

	surfaceElements.buttons[165] = surface.makeButton(44, 77, 10, 10)
	surfaceElements.buttons[165].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 66)
	surfaceElements.labels[165] = surface.makeLabelField(44, 82, 10, 1)

	surfaceElements.buttons[166] = surface.makeButton(55, 77, 10, 10)
	surfaceElements.buttons[166].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 67)
	surfaceElements.labels[166] = surface.makeLabelField(55, 82, 10, 1)

	surfaceElements.buttons[167] = surface.makeButton(66, 77, 10, 10)
	surfaceElements.buttons[167].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 68)
	surfaceElements.labels[167] = surface.makeLabelField(66, 82, 10, 1)

	surfaceElements.buttons[168] = surface.makeButton(77, 77, 10, 10)
	surfaceElements.buttons[168].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 69)
	surfaceElements.labels[168] = surface.makeLabelField(77, 82, 10, 1)

	surfaceElements.buttons[169] = surface.makeButton(88, 77, 10, 10)
	surfaceElements.buttons[169].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 70)
	surfaceElements.labels[169] = surface.makeLabelField(88, 82, 10, 1)

	surfaceElements.buttons[170] = surface.makeButton(99, 77, 10, 10)
	surfaceElements.buttons[170].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 71)
	surfaceElements.labels[170] = surface.makeLabelField(99, 82, 10, 1)

	surfaceElements.buttons[171] = surface.makeButton(110, 77, 10, 10)
	surfaceElements.buttons[171].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 72)
	surfaceElements.labels[171] = surface.makeLabelField(110, 82, 10, 1)

	surfaceElements.buttons[172] = surface.makeButton(121, 77, 10, 10)
	surfaceElements.buttons[172].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 73)
	surfaceElements.labels[172] = surface.makeLabelField(121, 82, 10, 1)

	surfaceElements.buttons[173] = surface.makeButton(132, 77, 10, 10)
	surfaceElements.buttons[173].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 74)
	surfaceElements.labels[173] = surface.makeLabelField(132, 82, 10, 1)

	surfaceElements.buttons[174] = surface.makeButton(143, 77, 10, 10)
	surfaceElements.buttons[174].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 75)
	surfaceElements.labels[174] = surface.makeLabelField(143, 82, 10, 1)

	surfaceElements.buttons[175] = surface.makeButton(154, 77, 10, 10)
	surfaceElements.buttons[175].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 76)
	surfaceElements.labels[175] = surface.makeLabelField(154, 82, 10, 1)

	surfaceElements.buttons[176] = surface.makeButton(165, 77, 10, 10)
	surfaceElements.buttons[176].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 77)
	surfaceElements.labels[176] = surface.makeLabelField(165, 82, 10, 1)

	surfaceElements.buttons[177] = surface.makeButton(176, 77, 10, 10)
	surfaceElements.buttons[177].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 78)
	surfaceElements.labels[177] = surface.makeLabelField(176, 82, 10, 1)

	surfaceElements.buttons[178] = surface.makeButton(187, 77, 10, 10)
	surfaceElements.buttons[178].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 79)
	surfaceElements.labels[178] = surface.makeLabelField(187, 82, 10, 1)

	surfaceElements.buttons[179] = surface.makeButton(198, 77, 10, 10)
	surfaceElements.buttons[179].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 80)
	surfaceElements.labels[179] = surface.makeLabelField(198, 82, 10, 1)

	surfaceElements.buttons[180] = surface.makeButton(209, 77, 10, 10)
	surfaceElements.buttons[180].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 81)
	surfaceElements.labels[180] = surface.makeLabelField(209, 82, 10, 1)

	surfaceElements.buttons[181] = surface.makeButton(220, 77, 10, 10)
	surfaceElements.buttons[181].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 82)
	surfaceElements.labels[181] = surface.makeLabelField(220, 82, 10, 1)

	surfaceElements.buttons[182] = surface.makeButton(231, 77, 10, 10)
	surfaceElements.buttons[182].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 83)
	surfaceElements.labels[182] = surface.makeLabelField(231, 82, 10, 1)

	surfaceElements.buttons[183] = surface.makeButton(242, 77, 10, 10)
	surfaceElements.buttons[183].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 84)
	surfaceElements.labels[183] = surface.makeLabelField(242, 82, 10, 1)

	surfaceElements.buttons[184] = surface.makeButton(0, 88, 10, 10)
	surfaceElements.buttons[184].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 85)
	surfaceElements.labels[184] = surface.makeLabelField(0, 93, 10, 1)

	surfaceElements.buttons[185] = surface.makeButton(11, 88, 10, 10)
	surfaceElements.buttons[185].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 86)
	surfaceElements.labels[185] = surface.makeLabelField(11, 93, 10, 1)

	surfaceElements.buttons[186] = surface.makeButton(22, 88, 10, 10)
	surfaceElements.buttons[186].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 87)
	surfaceElements.labels[186] = surface.makeLabelField(22, 93, 10, 1)

	surfaceElements.buttons[187] = surface.makeButton(33, 88, 10, 10)
	surfaceElements.buttons[187].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 88)
	surfaceElements.labels[187] = surface.makeLabelField(33, 93, 10, 1)

	surfaceElements.buttons[188] = surface.makeButton(44, 88, 10, 10)
	surfaceElements.buttons[188].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 89)
	surfaceElements.labels[188] = surface.makeLabelField(44, 93, 10, 1)

	surfaceElements.buttons[189] = surface.makeButton(55, 88, 10, 10)
	surfaceElements.buttons[189].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 90)
	surfaceElements.labels[189] = surface.makeLabelField(55, 93, 10, 1)

	surfaceElements.buttons[190] = surface.makeButton(66, 88, 10, 10)
	surfaceElements.buttons[190].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 91)
	surfaceElements.labels[190] = surface.makeLabelField(66, 93, 10, 1)

	surfaceElements.buttons[191] = surface.makeButton(77, 88, 10, 10)
	surfaceElements.buttons[191].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 92)
	surfaceElements.labels[191] = surface.makeLabelField(77, 93, 10, 1)

	surfaceElements.buttons[192] = surface.makeButton(88, 88, 10, 10)
	surfaceElements.buttons[192].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 93)
	surfaceElements.labels[192] = surface.makeLabelField(88, 93, 10, 1)

	surfaceElements.buttons[193] = surface.makeButton(99, 88, 10, 10)
	surfaceElements.buttons[193].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 94)
	surfaceElements.labels[193] = surface.makeLabelField(99, 93, 10, 1)

	surfaceElements.buttons[194] = surface.makeButton(110, 88, 10, 10)
	surfaceElements.buttons[194].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 95)
	surfaceElements.labels[194] = surface.makeLabelField(110, 93, 10, 1)

	surfaceElements.buttons[195] = surface.makeButton(121, 88, 10, 10)
	surfaceElements.buttons[195].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 96)
	surfaceElements.labels[195] = surface.makeLabelField(121, 93, 10, 1)

	surfaceElements.buttons[196] = surface.makeButton(132, 88, 10, 10)
	surfaceElements.buttons[196].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 97)
	surfaceElements.labels[196] = surface.makeLabelField(132, 93, 10, 1)

	surfaceElements.buttons[197] = surface.makeButton(143, 88, 10, 10)
	surfaceElements.buttons[197].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 98)
	surfaceElements.labels[197] = surface.makeLabelField(143, 93, 10, 1)

	surfaceElements.buttons[198] = surface.makeButton(154, 88, 10, 10)
	surfaceElements.buttons[198].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 99)
	surfaceElements.labels[198] = surface.makeLabelField(154, 93, 10, 1)

	surfaceElements.buttons[199] = surface.makeButton(165, 88, 10, 10)
	surfaceElements.buttons[199].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 100)
	surfaceElements.labels[199] = surface.makeLabelField(165, 93, 10, 1)

	surfaceElements.buttons[200] = surface.makeButton(176, 88, 10, 10)
	surfaceElements.buttons[200].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 11)
	surfaceElements.labels[200] = surface.makeLabelField(176, 93, 10, 1)

	surfaceElements.buttons[201] = surface.makeButton(187, 88, 10, 10)
	surfaceElements.buttons[201].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 12)
	surfaceElements.labels[201] = surface.makeLabelField(187, 93, 10, 1)

	surfaceElements.buttons[202] = surface.makeButton(198, 88, 10, 10)
	surfaceElements.buttons[202].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 13)
	surfaceElements.labels[202] = surface.makeLabelField(198, 93, 10, 1)

	surfaceElements.buttons[203] = surface.makeButton(209, 88, 10, 10)
	surfaceElements.buttons[203].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 14)
	surfaceElements.labels[203] = surface.makeLabelField(209, 93, 10, 1)

	surfaceElements.buttons[204] = surface.makeButton(220, 88, 10, 10)
	surfaceElements.buttons[204].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 15)
	surfaceElements.labels[204] = surface.makeLabelField(220, 93, 10, 1)

	surfaceElements.buttons[205] = surface.makeButton(231, 88, 10, 10)
	surfaceElements.buttons[205].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 16)
	surfaceElements.labels[205] = surface.makeLabelField(231, 93, 10, 1)

	surfaceElements.buttons[206] = surface.makeButton(242, 88, 10, 10)
	surfaceElements.buttons[206].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 17)
	surfaceElements.labels[206] = surface.makeLabelField(242, 93, 10, 1)

	surfaceElements.buttons[207] = surface.makeButton(0, 99, 10, 10)
	surfaceElements.buttons[207].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 18)
	surfaceElements.labels[207] = surface.makeLabelField(0, 104, 10, 1)

	surfaceElements.buttons[208] = surface.makeButton(11, 99, 10, 10)
	surfaceElements.buttons[208].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 19)
	surfaceElements.labels[208] = surface.makeLabelField(11, 104, 10, 1)

	surfaceElements.buttons[209] = surface.makeButton(22, 99, 10, 10)
	surfaceElements.buttons[209].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 20)
	surfaceElements.labels[209] = surface.makeLabelField(22, 104, 10, 1)

	surfaceElements.buttons[210] = surface.makeButton(33, 99, 10, 10)
	surfaceElements.buttons[210].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 21)
	surfaceElements.labels[210] = surface.makeLabelField(33, 104, 10, 1)

	surfaceElements.buttons[211] = surface.makeButton(44, 99, 10, 10)
	surfaceElements.buttons[211].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 22)
	surfaceElements.labels[211] = surface.makeLabelField(44, 104, 10, 1)

	surfaceElements.buttons[212] = surface.makeButton(55, 99, 10, 10)
	surfaceElements.buttons[212].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 23)
	surfaceElements.labels[212] = surface.makeLabelField(55, 104, 10, 1)

	surfaceElements.buttons[213] = surface.makeButton(66, 99, 10, 10)
	surfaceElements.buttons[213].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 24)
	surfaceElements.labels[213] = surface.makeLabelField(66, 104, 10, 1)

	surfaceElements.buttons[214] = surface.makeButton(77, 99, 10, 10)
	surfaceElements.buttons[214].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 25)
	surfaceElements.labels[214] = surface.makeLabelField(77, 104, 10, 1)

	surfaceElements.buttons[215] = surface.makeButton(88, 99, 10, 10)
	surfaceElements.buttons[215].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 26)
	surfaceElements.labels[215] = surface.makeLabelField(88, 104, 10, 1)

	surfaceElements.buttons[216] = surface.makeButton(99, 99, 10, 10)
	surfaceElements.buttons[216].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 27)
	surfaceElements.labels[216] = surface.makeLabelField(99, 104, 10, 1)

	surfaceElements.buttons[217] = surface.makeButton(110, 99, 10, 10)
	surfaceElements.buttons[217].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 28)
	surfaceElements.labels[217] = surface.makeLabelField(110, 104, 10, 1)

	surfaceElements.buttons[218] = surface.makeButton(121, 99, 10, 10)
	surfaceElements.buttons[218].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 29)
	surfaceElements.labels[218] = surface.makeLabelField(121, 104, 10, 1)

	surfaceElements.buttons[219] = surface.makeButton(132, 99, 10, 10)
	surfaceElements.buttons[219].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 30)
	surfaceElements.labels[219] = surface.makeLabelField(132, 104, 10, 1)

	surfaceElements.buttons[220] = surface.makeButton(143, 99, 10, 10)
	surfaceElements.buttons[220].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 31)
	surfaceElements.labels[220] = surface.makeLabelField(143, 104, 10, 1)

	surfaceElements.buttons[221] = surface.makeButton(154, 99, 10, 10)
	surfaceElements.buttons[221].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 32)
	surfaceElements.labels[221] = surface.makeLabelField(154, 104, 10, 1)

	surfaceElements.buttons[222] = surface.makeButton(165, 99, 10, 10)
	surfaceElements.buttons[222].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 33)
	surfaceElements.labels[222] = surface.makeLabelField(165, 104, 10, 1)

	surfaceElements.buttons[223] = surface.makeButton(176, 99, 10, 10)
	surfaceElements.buttons[223].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 34)
	surfaceElements.labels[223] = surface.makeLabelField(176, 104, 10, 1)

	surfaceElements.buttons[224] = surface.makeButton(187, 99, 10, 10)
	surfaceElements.buttons[224].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 35)
	surfaceElements.labels[224] = surface.makeLabelField(187, 104, 10, 1)

	surfaceElements.buttons[225] = surface.makeButton(198, 99, 10, 10)
	surfaceElements.buttons[225].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 36)
	surfaceElements.labels[225] = surface.makeLabelField(198, 104, 10, 1)

	surfaceElements.buttons[226] = surface.makeButton(209, 99, 10, 10)
	surfaceElements.buttons[226].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 37)
	surfaceElements.labels[226] = surface.makeLabelField(209, 104, 10, 1)

	surfaceElements.buttons[227] = surface.makeButton(220, 99, 10, 10)
	surfaceElements.buttons[227].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 38)
	surfaceElements.labels[227] = surface.makeLabelField(220, 104, 10, 1)

	surfaceElements.buttons[228] = surface.makeButton(231, 99, 10, 10)
	surfaceElements.buttons[228].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 39)
	surfaceElements.labels[228] = surface.makeLabelField(231, 104, 10, 1)

	surfaceElements.buttons[229] = surface.makeButton(242, 99, 10, 10)
	surfaceElements.buttons[229].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 40)
	surfaceElements.labels[229] = surface.makeLabelField(242, 104, 10, 1)

	surfaceElements.buttons[230] = surface.makeButton(0, 110, 10, 10)
	surfaceElements.buttons[230].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 41)
	surfaceElements.labels[230] = surface.makeLabelField(0, 115, 10, 1)

	surfaceElements.buttons[231] = surface.makeButton(11, 110, 10, 10)
	surfaceElements.buttons[231].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 42)
	surfaceElements.labels[231] = surface.makeLabelField(11, 115, 10, 1)

	surfaceElements.buttons[232] = surface.makeButton(22, 110, 10, 10)
	surfaceElements.buttons[232].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 43)
	surfaceElements.labels[232] = surface.makeLabelField(22, 115, 10, 1)

	surfaceElements.buttons[233] = surface.makeButton(33, 110, 10, 10)
	surfaceElements.buttons[233].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 44)
	surfaceElements.labels[233] = surface.makeLabelField(33, 115, 10, 1)

	surfaceElements.buttons[234] = surface.makeButton(44, 110, 10, 10)
	surfaceElements.buttons[234].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 45)
	surfaceElements.labels[234] = surface.makeLabelField(44, 115, 10, 1)

	surfaceElements.buttons[235] = surface.makeButton(55, 110, 10, 10)
	surfaceElements.buttons[235].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 46)
	surfaceElements.labels[235] = surface.makeLabelField(55, 115, 10, 1)

	surfaceElements.buttons[236] = surface.makeButton(66, 110, 10, 10)
	surfaceElements.buttons[236].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 47)
	surfaceElements.labels[236] = surface.makeLabelField(66, 115, 10, 1)

	surfaceElements.buttons[237] = surface.makeButton(77, 110, 10, 10)
	surfaceElements.buttons[237].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 48)
	surfaceElements.labels[237] = surface.makeLabelField(77, 115, 10, 1)

	surfaceElements.buttons[238] = surface.makeButton(88, 110, 10, 10)
	surfaceElements.buttons[238].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 49)
	surfaceElements.labels[238] = surface.makeLabelField(88, 115, 10, 1)

	surfaceElements.buttons[239] = surface.makeButton(99, 110, 10, 10)
	surfaceElements.buttons[239].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 50)
	surfaceElements.labels[239] = surface.makeLabelField(99, 115, 10, 1)

	surfaceElements.buttons[240] = surface.makeButton(110, 110, 10, 10)
	surfaceElements.buttons[240].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 51)
	surfaceElements.labels[240] = surface.makeLabelField(110, 115, 10, 1)

	surfaceElements.buttons[241] = surface.makeButton(121, 110, 10, 10)
	surfaceElements.buttons[241].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 52)
	surfaceElements.labels[241] = surface.makeLabelField(121, 115, 10, 1)

	surfaceElements.buttons[242] = surface.makeButton(132, 110, 10, 10)
	surfaceElements.buttons[242].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 53)
	surfaceElements.labels[242] = surface.makeLabelField(132, 115, 10, 1)

	surfaceElements.buttons[243] = surface.makeButton(143, 110, 10, 10)
	surfaceElements.buttons[243].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 54)
	surfaceElements.labels[243] = surface.makeLabelField(143, 115, 10, 1)

	surfaceElements.buttons[244] = surface.makeButton(154, 110, 10, 10)
	surfaceElements.buttons[244].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 55)
	surfaceElements.labels[244] = surface.makeLabelField(154, 115, 10, 1)

	surfaceElements.buttons[245] = surface.makeButton(165, 110, 10, 10)
	surfaceElements.buttons[245].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 56)
	surfaceElements.labels[245] = surface.makeLabelField(165, 115, 10, 1)

	surfaceElements.buttons[246] = surface.makeButton(176, 110, 10, 10)
	surfaceElements.buttons[246].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 57)
	surfaceElements.labels[246] = surface.makeLabelField(176, 115, 10, 1)

	surfaceElements.buttons[247] = surface.makeButton(187, 110, 10, 10)
	surfaceElements.buttons[247].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 58)
	surfaceElements.labels[247] = surface.makeLabelField(187, 115, 10, 1)

	surfaceElements.buttons[248] = surface.makeButton(198, 110, 10, 10)
	surfaceElements.buttons[248].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 59)
	surfaceElements.labels[248] = surface.makeLabelField(198, 115, 10, 1)

	surfaceElements.buttons[249] = surface.makeButton(209, 110, 10, 10)
	surfaceElements.buttons[249].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 60)
	surfaceElements.labels[249] = surface.makeLabelField(209, 115, 10, 1)

	surfaceElements.buttons[250] = surface.makeButton(220, 110, 10, 10)
	surfaceElements.buttons[250].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 61)
	surfaceElements.labels[250] = surface.makeLabelField(220, 115, 10, 1)

	surfaceElements.buttons[251] = surface.makeButton(231, 110, 10, 10)
	surfaceElements.buttons[251].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 62)
	surfaceElements.labels[251] = surface.makeLabelField(231, 115, 10, 1)

	surfaceElements.buttons[252] = surface.makeButton(242, 110, 10, 10)
	surfaceElements.buttons[252].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 63)
	surfaceElements.labels[252] = surface.makeLabelField(242, 115, 10, 1)

	surfaceElements.buttons[253] = surface.makeButton(0, 121, 10, 10)
	surfaceElements.buttons[253].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 64)
	surfaceElements.labels[253] = surface.makeLabelField(0, 126, 10, 1)

	surfaceElements.buttons[254] = surface.makeButton(11, 121, 10, 10)
	surfaceElements.buttons[254].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 65)
	surfaceElements.labels[254] = surface.makeLabelField(11, 126, 10, 1)

	surfaceElements.buttons[255] = surface.makeButton(22, 121, 10, 10)
	surfaceElements.buttons[255].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 66)
	surfaceElements.labels[255] = surface.makeLabelField(22, 126, 10, 1)

	surfaceElements.buttons[256] = surface.makeButton(33, 121, 10, 10)
	surfaceElements.buttons[256].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 67)
	surfaceElements.labels[256] = surface.makeLabelField(33, 126, 10, 1)

	surfaceElements.buttons[257] = surface.makeButton(44, 121, 10, 10)
	surfaceElements.buttons[257].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 68)
	surfaceElements.labels[257] = surface.makeLabelField(44, 126, 10, 1)

	surfaceElements.buttons[258] = surface.makeButton(55, 121, 10, 10)
	surfaceElements.buttons[258].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 69)
	surfaceElements.labels[258] = surface.makeLabelField(55, 126, 10, 1)

	surfaceElements.buttons[259] = surface.makeButton(66, 121, 10, 10)
	surfaceElements.buttons[259].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 70)
	surfaceElements.labels[259] = surface.makeLabelField(66, 126, 10, 1)

	surfaceElements.buttons[260] = surface.makeButton(77, 121, 10, 10)
	surfaceElements.buttons[260].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 71)
	surfaceElements.labels[260] = surface.makeLabelField(77, 126, 10, 1)

	surfaceElements.buttons[261] = surface.makeButton(88, 121, 10, 10)
	surfaceElements.buttons[261].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 72)
	surfaceElements.labels[261] = surface.makeLabelField(88, 126, 10, 1)

	surfaceElements.buttons[262] = surface.makeButton(99, 121, 10, 10)
	surfaceElements.buttons[262].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 73)
	surfaceElements.labels[262] = surface.makeLabelField(99, 126, 10, 1)

	surfaceElements.buttons[263] = surface.makeButton(110, 121, 10, 10)
	surfaceElements.buttons[263].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 74)
	surfaceElements.labels[263] = surface.makeLabelField(110, 126, 10, 1)

	surfaceElements.buttons[264] = surface.makeButton(121, 121, 10, 10)
	surfaceElements.buttons[264].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 75)
	surfaceElements.labels[264] = surface.makeLabelField(121, 126, 10, 1)

	surfaceElements.buttons[265] = surface.makeButton(132, 121, 10, 10)
	surfaceElements.buttons[265].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 76)
	surfaceElements.labels[265] = surface.makeLabelField(132, 126, 10, 1)

	surfaceElements.buttons[266] = surface.makeButton(143, 121, 10, 10)
	surfaceElements.buttons[266].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 77)
	surfaceElements.labels[266] = surface.makeLabelField(143, 126, 10, 1)

	surfaceElements.buttons[267] = surface.makeButton(154, 121, 10, 10)
	surfaceElements.buttons[267].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 78)
	surfaceElements.labels[267] = surface.makeLabelField(154, 126, 10, 1)

	surfaceElements.buttons[268] = surface.makeButton(165, 121, 10, 10)
	surfaceElements.buttons[268].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 79)
	surfaceElements.labels[268] = surface.makeLabelField(165, 126, 10, 1)

	surfaceElements.buttons[269] = surface.makeButton(176, 121, 10, 10)
	surfaceElements.buttons[269].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 80)
	surfaceElements.labels[269] = surface.makeLabelField(176, 126, 10, 1)

	surfaceElements.buttons[270] = surface.makeButton(187, 121, 10, 10)
	surfaceElements.buttons[270].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 81)
	surfaceElements.labels[270] = surface.makeLabelField(187, 126, 10, 1)

	surfaceElements.buttons[271] = surface.makeButton(198, 121, 10, 10)
	surfaceElements.buttons[271].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 82)
	surfaceElements.labels[271] = surface.makeLabelField(198, 126, 10, 1)

	surfaceElements.buttons[272] = surface.makeButton(209, 121, 10, 10)
	surfaceElements.buttons[272].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 83)
	surfaceElements.labels[272] = surface.makeLabelField(209, 126, 10, 1)

	surfaceElements.buttons[273] = surface.makeButton(220, 121, 10, 10)
	surfaceElements.buttons[273].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 84)
	surfaceElements.labels[273] = surface.makeLabelField(220, 126, 10, 1)

	surfaceElements.buttons[274] = surface.makeButton(231, 121, 10, 10)
	surfaceElements.buttons[274].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 85)
	surfaceElements.labels[274] = surface.makeLabelField(231, 126, 10, 1)

	surfaceElements.buttons[275] = surface.makeButton(242, 121, 10, 10)
	surfaceElements.buttons[275].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 86)
	surfaceElements.labels[275] = surface.makeLabelField(242, 126, 10, 1)

	surfaceElements.buttons[276] = surface.makeButton(0, 132, 10, 10)
	surfaceElements.buttons[276].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 87)
	surfaceElements.labels[276] = surface.makeLabelField(0, 137, 10, 1)

	surfaceElements.buttons[277] = surface.makeButton(11, 132, 10, 10)
	surfaceElements.buttons[277].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 88)
	surfaceElements.labels[277] = surface.makeLabelField(11, 137, 10, 1)

	surfaceElements.buttons[278] = surface.makeButton(22, 132, 10, 10)
	surfaceElements.buttons[278].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 89)
	surfaceElements.labels[278] = surface.makeLabelField(22, 137, 10, 1)

	surfaceElements.buttons[279] = surface.makeButton(33, 132, 10, 10)
	surfaceElements.buttons[279].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 90)
	surfaceElements.labels[279] = surface.makeLabelField(33, 137, 10, 1)

	surfaceElements.buttons[280] = surface.makeButton(44, 132, 10, 10)
	surfaceElements.buttons[280].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 91)
	surfaceElements.labels[280] = surface.makeLabelField(44, 137, 10, 1)

	surfaceElements.buttons[281] = surface.makeButton(55, 132, 10, 10)
	surfaceElements.buttons[281].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 92)
	surfaceElements.labels[281] = surface.makeLabelField(55, 137, 10, 1)

	surfaceElements.buttons[282] = surface.makeButton(66, 132, 10, 10)
	surfaceElements.buttons[282].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 93)
	surfaceElements.labels[282] = surface.makeLabelField(66, 137, 10, 1)

	surfaceElements.buttons[283] = surface.makeButton(77, 132, 10, 10)
	surfaceElements.buttons[283].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 94)
	surfaceElements.labels[283] = surface.makeLabelField(77, 137, 10, 1)

	surfaceElements.buttons[284] = surface.makeButton(88, 132, 10, 10)
	surfaceElements.buttons[284].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 95)
	surfaceElements.labels[284] = surface.makeLabelField(88, 137, 10, 1)

	surfaceElements.buttons[285] = surface.makeButton(99, 132, 10, 10)
	surfaceElements.buttons[285].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 96)
	surfaceElements.labels[285] = surface.makeLabelField(99, 137, 10, 1)

	surfaceElements.buttons[286] = surface.makeButton(110, 132, 10, 10)
	surfaceElements.buttons[286].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 97)
	surfaceElements.labels[286] = surface.makeLabelField(110, 137, 10, 1)

	surfaceElements.buttons[287] = surface.makeButton(121, 132, 10, 10)
	surfaceElements.buttons[287].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 98)
	surfaceElements.labels[287] = surface.makeLabelField(121, 137, 10, 1)

	surfaceElements.buttons[288] = surface.makeButton(132, 132, 10, 10)
	surfaceElements.buttons[288].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 99)
	surfaceElements.labels[288] = surface.makeLabelField(132, 137, 10, 1)

	surfaceElements.buttons[289] = surface.makeButton(143, 132, 10, 10)
	surfaceElements.buttons[289].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 100)
	surfaceElements.labels[289] = surface.makeLabelField(143, 137, 10, 1)

	surfaceElements.buttons[290] = surface.makeButton(154, 132, 10, 10)
	surfaceElements.buttons[290].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 101)
	surfaceElements.labels[290] = surface.makeLabelField(154, 137, 10, 1)

	surfaceElements.buttons[291] = surface.makeButton(165, 132, 10, 10)
	surfaceElements.buttons[291].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 102)
	surfaceElements.labels[291] = surface.makeLabelField(165, 137, 10, 1)

	surfaceElements.buttons[292] = surface.makeButton(176, 132, 10, 10)
	surfaceElements.buttons[292].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 103)
	surfaceElements.labels[292] = surface.makeLabelField(176, 137, 10, 1)

	surfaceElements.buttons[293] = surface.makeButton(187, 132, 10, 10)
	surfaceElements.buttons[293].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 104)
	surfaceElements.labels[293] = surface.makeLabelField(187, 137, 10, 1)

	surfaceElements.buttons[294] = surface.makeButton(198, 132, 10, 10)
	surfaceElements.buttons[294].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 105)
	surfaceElements.labels[294] = surface.makeLabelField(198, 137, 10, 1)

	surfaceElements.buttons[295] = surface.makeButton(209, 132, 10, 10)
	surfaceElements.buttons[295].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 106)
	surfaceElements.labels[295] = surface.makeLabelField(209, 137, 10, 1)

	surfaceElements.buttons[296] = surface.makeButton(220, 132, 10, 10)
	surfaceElements.buttons[296].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 107)
	surfaceElements.labels[296] = surface.makeLabelField(220, 137, 10, 1)

	surfaceElements.buttons[297] = surface.makeButton(231, 132, 10, 10)
	surfaceElements.buttons[297].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 108)
	surfaceElements.labels[297] = surface.makeLabelField(231, 137, 10, 1)

	surfaceElements.buttons[298] = surface.makeButton(242, 132, 10, 10)
	surfaceElements.buttons[298].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 109)
	surfaceElements.labels[298] = surface.makeLabelField(242, 137, 10, 1)

	surfaceElements.buttons[299] = surface.makeButton(0, 143, 10, 10)
	surfaceElements.buttons[299].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 110)
	surfaceElements.labels[299] = surface.makeLabelField(0, 148, 10, 1)

	surfaceElements.buttons[300] = surface.makeButton(11, 143, 10, 10)
	surfaceElements.buttons[300].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 9)
	surfaceElements.labels[300] = surface.makeLabelField(11, 148, 10, 1)

	surfaceElements.buttons[301] = surface.makeButton(22, 143, 10, 10)
	surfaceElements.buttons[301].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 10)
	surfaceElements.labels[301] = surface.makeLabelField(22, 148, 10, 1)

	surfaceElements.buttons[302] = surface.makeButton(33, 143, 10, 10)
	surfaceElements.buttons[302].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 101)
	surfaceElements.labels[302] = surface.makeLabelField(33, 148, 10, 1)

	surfaceElements.buttons[303] = surface.makeButton(44, 143, 10, 10)
	surfaceElements.buttons[303].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 102)
	surfaceElements.labels[303] = surface.makeLabelField(44, 148, 10, 1)

	surfaceElements.buttons[304] = surface.makeButton(55, 143, 10, 10)
	surfaceElements.buttons[304].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 103)
	surfaceElements.labels[304] = surface.makeLabelField(55, 148, 10, 1)

	surfaceElements.buttons[305] = surface.makeButton(66, 143, 10, 10)
	surfaceElements.buttons[305].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 104)
	surfaceElements.labels[305] = surface.makeLabelField(66, 148, 10, 1)

	surfaceElements.buttons[306] = surface.makeButton(77, 143, 10, 10)
	surfaceElements.buttons[306].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 105)
	surfaceElements.labels[306] = surface.makeLabelField(77, 148, 10, 1)

	surfaceElements.buttons[307] = surface.makeButton(88, 143, 10, 10)
	surfaceElements.buttons[307].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 106)
	surfaceElements.labels[307] = surface.makeLabelField(88, 148, 10, 1)

	surfaceElements.buttons[308] = surface.makeButton(99, 143, 10, 10)
	surfaceElements.buttons[308].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 107)
	surfaceElements.labels[308] = surface.makeLabelField(99, 148, 10, 1)

	surfaceElements.buttons[309] = surface.makeButton(110, 143, 10, 10)
	surfaceElements.buttons[309].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 108)
	surfaceElements.labels[309] = surface.makeLabelField(110, 148, 10, 1)

	surfaceElements.buttons[310] = surface.makeButton(121, 143, 10, 10)
	surfaceElements.buttons[310].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 109)
	surfaceElements.labels[310] = surface.makeLabelField(121, 148, 10, 1)

	surfaceElements.buttons[311] = surface.makeButton(132, 143, 10, 10)
	surfaceElements.buttons[311].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 110)
	surfaceElements.labels[311] = surface.makeLabelField(132, 148, 10, 1)

	surfaceElements.buttons[312] = surface.makeButton(143, 143, 10, 10)
	surfaceElements.buttons[312].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 111)
	surfaceElements.labels[312] = surface.makeLabelField(143, 148, 10, 1)

	surfaceElements.buttons[313] = surface.makeButton(154, 143, 10, 10)
	surfaceElements.buttons[313].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 112)
	surfaceElements.labels[313] = surface.makeLabelField(154, 148, 10, 1)

	surfaceElements.buttons[314] = surface.makeButton(165, 143, 10, 10)
	surfaceElements.buttons[314].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 113)
	surfaceElements.labels[314] = surface.makeLabelField(165, 148, 10, 1)

	surfaceElements.buttons[315] = surface.makeButton(176, 143, 10, 10)
	surfaceElements.buttons[315].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 114)
	surfaceElements.labels[315] = surface.makeLabelField(176, 148, 10, 1)

	surfaceElements.buttons[316] = surface.makeButton(187, 143, 10, 10)
	surfaceElements.buttons[316].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 115)
	surfaceElements.labels[316] = surface.makeLabelField(187, 148, 10, 1)

	surfaceElements.buttons[317] = surface.makeButton(198, 143, 10, 10)
	surfaceElements.buttons[317].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 116)
	surfaceElements.labels[317] = surface.makeLabelField(198, 148, 10, 1)

	surfaceElements.buttons[318] = surface.makeButton(209, 143, 10, 10)
	surfaceElements.buttons[318].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 117)
	surfaceElements.labels[318] = surface.makeLabelField(209, 148, 10, 1)

	surfaceElements.buttons[319] = surface.makeButton(220, 143, 10, 10)
	surfaceElements.buttons[319].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 118)
	surfaceElements.labels[319] = surface.makeLabelField(220, 148, 10, 1)

	surfaceElements.buttons[320] = surface.makeButton(231, 143, 10, 10)
	surfaceElements.buttons[320].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 119)
	surfaceElements.labels[320] = surface.makeLabelField(231, 148, 10, 1)

	surfaceElements.buttons[321] = surface.makeButton(242, 143, 10, 10)
	surfaceElements.buttons[321].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 120)
	surfaceElements.labels[321] = surface.makeLabelField(242, 148, 10, 1)

	surfaceElements.buttons[322] = surface.makeButton(0, 154, 10, 10)
	surfaceElements.buttons[322].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 121)
	surfaceElements.labels[322] = surface.makeLabelField(0, 159, 10, 1)

	surfaceElements.buttons[323] = surface.makeButton(11, 154, 10, 10)
	surfaceElements.buttons[323].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 122)
	surfaceElements.labels[323] = surface.makeLabelField(11, 159, 10, 1)

	surfaceElements.buttons[324] = surface.makeButton(22, 154, 10, 10)
	surfaceElements.buttons[324].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 123)
	surfaceElements.labels[324] = surface.makeLabelField(22, 159, 10, 1)

	surfaceElements.buttons[325] = surface.makeButton(33, 154, 10, 10)
	surfaceElements.buttons[325].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 124)
	surfaceElements.labels[325] = surface.makeLabelField(33, 159, 10, 1)

	surfaceElements.buttons[326] = surface.makeButton(44, 154, 10, 10)
	surfaceElements.buttons[326].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 125)
	surfaceElements.labels[326] = surface.makeLabelField(44, 159, 10, 1)

	surfaceElements.buttons[327] = surface.makeButton(55, 154, 10, 10)
	surfaceElements.buttons[327].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 126)
	surfaceElements.labels[327] = surface.makeLabelField(55, 159, 10, 1)

	surfaceElements.buttons[328] = surface.makeButton(66, 154, 10, 10)
	surfaceElements.buttons[328].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 111)
	surfaceElements.labels[328] = surface.makeLabelField(66, 159, 10, 1)

	surfaceElements.buttons[329] = surface.makeButton(77, 154, 10, 10)
	surfaceElements.buttons[329].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 112)
	surfaceElements.labels[329] = surface.makeLabelField(77, 159, 10, 1)

	surfaceElements.buttons[330] = surface.makeButton(88, 154, 10, 10)
	surfaceElements.buttons[330].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 113)
	surfaceElements.labels[330] = surface.makeLabelField(88, 159, 10, 1)

	surfaceElements.buttons[331] = surface.makeButton(99, 154, 10, 10)
	surfaceElements.buttons[331].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 114)
	surfaceElements.labels[331] = surface.makeLabelField(99, 159, 10, 1)

	surfaceElements.buttons[332] = surface.makeButton(110, 154, 10, 10)
	surfaceElements.buttons[332].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 115)
	surfaceElements.labels[332] = surface.makeLabelField(110, 159, 10, 1)

	surfaceElements.buttons[333] = surface.makeButton(121, 154, 10, 10)
	surfaceElements.buttons[333].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 116)
	surfaceElements.labels[333] = surface.makeLabelField(121, 159, 10, 1)

	surfaceElements.buttons[334] = surface.makeButton(132, 154, 10, 10)
	surfaceElements.buttons[334].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 117)
	surfaceElements.labels[334] = surface.makeLabelField(132, 159, 10, 1)

	surfaceElements.buttons[335] = surface.makeButton(143, 154, 10, 10)
	surfaceElements.buttons[335].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 118)
	surfaceElements.labels[335] = surface.makeLabelField(143, 159, 10, 1)

	surfaceElements.buttons[336] = surface.makeButton(154, 154, 10, 10)
	surfaceElements.buttons[336].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 119)
	surfaceElements.labels[336] = surface.makeLabelField(154, 159, 10, 1)

	surfaceElements.buttons[337] = surface.makeButton(165, 154, 10, 10)
	surfaceElements.buttons[337].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 120)
	surfaceElements.labels[337] = surface.makeLabelField(165, 159, 10, 1)

	surfaceElements.buttons[338] = surface.makeButton(176, 154, 10, 10)
	surfaceElements.buttons[338].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 121)
	surfaceElements.labels[338] = surface.makeLabelField(176, 159, 10, 1)

	surfaceElements.buttons[339] = surface.makeButton(187, 154, 10, 10)
	surfaceElements.buttons[339].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 122)
	surfaceElements.labels[339] = surface.makeLabelField(187, 159, 10, 1)

	surfaceElements.buttons[340] = surface.makeButton(198, 154, 10, 10)
	surfaceElements.buttons[340].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 123)
	surfaceElements.labels[340] = surface.makeLabelField(198, 159, 10, 1)

	surfaceElements.buttons[341] = surface.makeButton(209, 154, 10, 10)
	surfaceElements.buttons[341].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 124)
	surfaceElements.labels[341] = surface.makeLabelField(209, 159, 10, 1)

	surfaceElements.buttons[342] = surface.makeButton(220, 154, 10, 10)
	surfaceElements.buttons[342].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 125)
	surfaceElements.labels[342] = surface.makeLabelField(220, 159, 10, 1)

	surfaceElements.buttons[343] = surface.makeButton(231, 154, 10, 10)
	surfaceElements.buttons[343].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 126)
	surfaceElements.labels[343] = surface.makeLabelField(231, 159, 10, 1)

	surfaceElements.buttons[344] = surface.makeButton(242, 154, 10, 10)
	surfaceElements.buttons[344].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 127)
	surfaceElements.labels[344] = surface.makeLabelField(242, 159, 10, 1)

	surfaceElements.buttons[345] = surface.makeButton(0, 165, 10, 10)
	surfaceElements.buttons[345].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 87)
	surfaceElements.labels[345] = surface.makeLabelField(0, 170, 10, 1)

	surfaceElements.buttons[346] = surface.makeButton(11, 165, 10, 10)
	surfaceElements.buttons[346].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 88)
	surfaceElements.labels[346] = surface.makeLabelField(11, 170, 10, 1)

	surfaceElements.buttons[347] = surface.makeButton(22, 165, 10, 10)
	surfaceElements.buttons[347].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 89)
	surfaceElements.labels[347] = surface.makeLabelField(22, 170, 10, 1)

	surfaceElements.buttons[348] = surface.makeButton(33, 165, 10, 10)
	surfaceElements.buttons[348].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 90)
	surfaceElements.labels[348] = surface.makeLabelField(33, 170, 10, 1)

	surfaceElements.buttons[349] = surface.makeButton(44, 165, 10, 10)
	surfaceElements.buttons[349].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 91)
	surfaceElements.labels[349] = surface.makeLabelField(44, 170, 10, 1)

	surfaceElements.buttons[350] = surface.makeButton(55, 165, 10, 10)
	surfaceElements.buttons[350].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 92)
	surfaceElements.labels[350] = surface.makeLabelField(55, 170, 10, 1)

	surfaceElements.buttons[351] = surface.makeButton(66, 165, 10, 10)
	surfaceElements.buttons[351].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 93)
	surfaceElements.labels[351] = surface.makeLabelField(66, 170, 10, 1)

	surfaceElements.buttons[352] = surface.makeButton(77, 165, 10, 10)
	surfaceElements.buttons[352].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 94)
	surfaceElements.labels[352] = surface.makeLabelField(77, 170, 10, 1)

	surfaceElements.buttons[353] = surface.makeButton(88, 165, 10, 10)
	surfaceElements.buttons[353].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 95)
	surfaceElements.labels[353] = surface.makeLabelField(88, 170, 10, 1)

	surfaceElements.buttons[354] = surface.makeButton(99, 165, 10, 10)
	surfaceElements.buttons[354].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 96)
	surfaceElements.labels[354] = surface.makeLabelField(99, 170, 10, 1)

	surfaceElements.buttons[355] = surface.makeButton(110, 165, 10, 10)
	surfaceElements.buttons[355].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 97)
	surfaceElements.labels[355] = surface.makeLabelField(110, 170, 10, 1)

	surfaceElements.buttons[356] = surface.makeButton(121, 165, 10, 10)
	surfaceElements.buttons[356].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 98)
	surfaceElements.labels[356] = surface.makeLabelField(121, 170, 10, 1)

	surfaceElements.buttons[357] = surface.makeButton(132, 165, 10, 10)
	surfaceElements.buttons[357].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 99)
	surfaceElements.labels[357] = surface.makeLabelField(132, 170, 10, 1)

	surfaceElements.buttons[358] = surface.makeButton(143, 165, 10, 10)
	surfaceElements.buttons[358].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 100)
	surfaceElements.labels[358] = surface.makeLabelField(143, 170, 10, 1)

	surfaceElements.buttons[359] = surface.makeButton(154, 165, 10, 10)
	surfaceElements.buttons[359].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 101)
	surfaceElements.labels[359] = surface.makeLabelField(154, 170, 10, 1)

	surfaceElements.buttons[360] = surface.makeButton(165, 165, 10, 10)
	surfaceElements.buttons[360].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 102)
	surfaceElements.labels[360] = surface.makeLabelField(165, 170, 10, 1)

	surfaceElements.buttons[361] = surface.makeButton(176, 165, 10, 10)
	surfaceElements.buttons[361].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 103)
	surfaceElements.labels[361] = surface.makeLabelField(176, 170, 10, 1)

	surfaceElements.buttons[362] = surface.makeButton(187, 165, 10, 10)
	surfaceElements.buttons[362].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 104)
	surfaceElements.labels[362] = surface.makeLabelField(187, 170, 10, 1)

	surfaceElements.buttons[363] = surface.makeButton(198, 165, 10, 10)
	surfaceElements.buttons[363].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 105)
	surfaceElements.labels[363] = surface.makeLabelField(198, 170, 10, 1)

	surfaceElements.buttons[364] = surface.makeButton(209, 165, 10, 10)
	surfaceElements.buttons[364].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 106)
	surfaceElements.labels[364] = surface.makeLabelField(209, 170, 10, 1)

	surfaceElements.buttons[365] = surface.makeButton(220, 165, 10, 10)
	surfaceElements.buttons[365].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 107)
	surfaceElements.labels[365] = surface.makeLabelField(220, 170, 10, 1)

	surfaceElements.buttons[366] = surface.makeButton(231, 165, 10, 10)
	surfaceElements.buttons[366].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 108)
	surfaceElements.labels[366] = surface.makeLabelField(231, 170, 10, 1)

	surfaceElements.buttons[367] = surface.makeButton(242, 165, 10, 10)
	surfaceElements.buttons[367].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 109)
	surfaceElements.labels[367] = surface.makeLabelField(242, 170, 10, 1)

	surfaceElements.buttons[368] = surface.makeButton(0, 176, 10, 10)
	surfaceElements.buttons[368].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 110)
	surfaceElements.labels[368] = surface.makeLabelField(0, 181, 10, 1)

	surfaceElements.buttons[369] = surface.makeButton(11, 176, 10, 10)
	surfaceElements.buttons[369].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 111)
	surfaceElements.labels[369] = surface.makeLabelField(11, 181, 10, 1)

	surfaceElements.buttons[370] = surface.makeButton(22, 176, 10, 10)
	surfaceElements.buttons[370].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 112)
	surfaceElements.labels[370] = surface.makeLabelField(22, 181, 10, 1)

	surfaceElements.buttons[371] = surface.makeButton(33, 176, 10, 10)
	surfaceElements.buttons[371].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 113)
	surfaceElements.labels[371] = surface.makeLabelField(33, 181, 10, 1)

	surfaceElements.buttons[372] = surface.makeButton(44, 176, 10, 10)
	surfaceElements.buttons[372].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 114)
	surfaceElements.labels[372] = surface.makeLabelField(44, 181, 10, 1)

	surfaceElements.buttons[373] = surface.makeButton(55, 176, 10, 10)
	surfaceElements.buttons[373].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 115)
	surfaceElements.labels[373] = surface.makeLabelField(55, 181, 10, 1)

	surfaceElements.buttons[374] = surface.makeButton(66, 176, 10, 10)
	surfaceElements.buttons[374].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 83)
	surfaceElements.labels[374] = surface.makeLabelField(66, 181, 10, 1)

	surfaceElements.buttons[375] = surface.makeButton(77, 176, 10, 10)
	surfaceElements.buttons[375].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 84)
	surfaceElements.labels[375] = surface.makeLabelField(77, 181, 10, 1)

	surfaceElements.buttons[376] = surface.makeButton(88, 176, 10, 10)
	surfaceElements.buttons[376].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 85)
	surfaceElements.labels[376] = surface.makeLabelField(88, 181, 10, 1)

	surfaceElements.buttons[377] = surface.makeButton(99, 176, 10, 10)
	surfaceElements.buttons[377].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 86)
	surfaceElements.labels[377] = surface.makeLabelField(99, 181, 10, 1)

	surfaceElements.buttons[378] = surface.makeButton(110, 176, 10, 10)
	surfaceElements.buttons[378].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 87)
	surfaceElements.labels[378] = surface.makeLabelField(110, 181, 10, 1)

	surfaceElements.buttons[379] = surface.makeButton(121, 176, 10, 10)
	surfaceElements.buttons[379].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 88)
	surfaceElements.labels[379] = surface.makeLabelField(121, 181, 10, 1)

	surfaceElements.buttons[380] = surface.makeButton(132, 176, 10, 10)
	surfaceElements.buttons[380].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 89)
	surfaceElements.labels[380] = surface.makeLabelField(132, 181, 10, 1)

	surfaceElements.buttons[381] = surface.makeButton(143, 176, 10, 10)
	surfaceElements.buttons[381].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 90)
	surfaceElements.labels[381] = surface.makeLabelField(143, 181, 10, 1)

	surfaceElements.buttons[382] = surface.makeButton(154, 176, 10, 10)
	surfaceElements.buttons[382].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 91)
	surfaceElements.labels[382] = surface.makeLabelField(154, 181, 10, 1)

	surfaceElements.buttons[383] = surface.makeButton(165, 176, 10, 10)
	surfaceElements.buttons[383].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 92)
	surfaceElements.labels[383] = surface.makeLabelField(165, 181, 10, 1)

	surfaceElements.buttons[384] = surface.makeButton(176, 176, 10, 10)
	surfaceElements.buttons[384].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 93)
	surfaceElements.labels[384] = surface.makeLabelField(176, 181, 10, 1)

	surfaceElements.buttons[385] = surface.makeButton(187, 176, 10, 10)
	surfaceElements.buttons[385].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 94)
	surfaceElements.labels[385] = surface.makeLabelField(187, 181, 10, 1)

	surfaceElements.buttons[386] = surface.makeButton(198, 176, 10, 10)
	surfaceElements.buttons[386].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 95)
	surfaceElements.labels[386] = surface.makeLabelField(198, 181, 10, 1)

	surfaceElements.buttons[387] = surface.makeButton(209, 176, 10, 10)
	surfaceElements.buttons[387].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 96)
	surfaceElements.labels[387] = surface.makeLabelField(209, 181, 10, 1)

	surfaceElements.buttons[388] = surface.makeButton(220, 176, 10, 10)
	surfaceElements.buttons[388].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 97)
	surfaceElements.labels[388] = surface.makeLabelField(220, 181, 10, 1)

	surfaceElements.buttons[389] = surface.makeButton(231, 176, 10, 10)
	surfaceElements.buttons[389].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 98)
	surfaceElements.labels[389] = surface.makeLabelField(231, 181, 10, 1)

	surfaceElements.buttons[390] = surface.makeButton(242, 176, 10, 10)
	surfaceElements.buttons[390].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 99)
	surfaceElements.labels[390] = surface.makeLabelField(242, 181, 10, 1)

	surfaceElements.buttons[391] = surface.makeButton(0, 187, 10, 10)
	surfaceElements.buttons[391].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 100)
	surfaceElements.labels[391] = surface.makeLabelField(0, 192, 10, 1)

	surfaceElements.buttons[392] = surface.makeButton(11, 187, 10, 10)
	surfaceElements.buttons[392].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 101)
	surfaceElements.labels[392] = surface.makeLabelField(11, 192, 10, 1)

	surfaceElements.buttons[393] = surface.makeButton(22, 187, 10, 10)
	surfaceElements.buttons[393].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 102)
	surfaceElements.labels[393] = surface.makeLabelField(22, 192, 10, 1)

	surfaceElements.buttons[394] = surface.makeButton(33, 187, 10, 10)
	surfaceElements.buttons[394].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 103)
	surfaceElements.labels[394] = surface.makeLabelField(33, 192, 10, 1)

	surfaceElements.buttons[395] = surface.makeButton(44, 187, 10, 10)
	surfaceElements.buttons[395].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 104)
	surfaceElements.labels[395] = surface.makeLabelField(44, 192, 10, 1)

	surfaceElements.buttons[396] = surface.makeButton(55, 187, 10, 10)
	surfaceElements.buttons[396].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 105)
	surfaceElements.labels[396] = surface.makeLabelField(55, 192, 10, 1)

	surfaceElements.buttons[397] = surface.makeButton(66, 187, 10, 10)
	surfaceElements.buttons[397].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 106)
	surfaceElements.labels[397] = surface.makeLabelField(66, 192, 10, 1)

	surfaceElements.buttons[398] = surface.makeButton(77, 187, 10, 10)
	surfaceElements.buttons[398].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 107)
	surfaceElements.labels[398] = surface.makeLabelField(77, 192, 10, 1)

	surfaceElements.buttons[399] = surface.makeButton(88, 187, 10, 10)
	surfaceElements.buttons[399].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 108)
	surfaceElements.labels[399] = surface.makeLabelField(88, 192, 10, 1)

	surfaceElements.buttons[400] = surface.makeButton(99, 187, 10, 10)
	surfaceElements.buttons[400].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 109)
	surfaceElements.labels[400] = surface.makeLabelField(99, 192, 10, 1)

	surfaceElements.buttons[401] = surface.makeButton(110, 187, 10, 10)
	surfaceElements.buttons[401].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 110)
	surfaceElements.labels[401] = surface.makeLabelField(110, 192, 10, 1)

	surfaceElements.buttons[402] = surface.makeButton(121, 187, 10, 10)
	surfaceElements.buttons[402].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 111)
	surfaceElements.labels[402] = surface.makeLabelField(121, 192, 10, 1)

	surfaceElements.buttons[403] = surface.makeButton(132, 187, 10, 10)
	surfaceElements.buttons[403].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 112)
	surfaceElements.labels[403] = surface.makeLabelField(132, 192, 10, 1)

	surfaceElements.buttons[404] = surface.makeButton(143, 187, 10, 10)
	surfaceElements.buttons[404].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 113)
	surfaceElements.labels[404] = surface.makeLabelField(143, 192, 10, 1)

	surfaceElements.buttons[405] = surface.makeButton(154, 187, 10, 10)
	surfaceElements.buttons[405].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 114)
	surfaceElements.labels[405] = surface.makeLabelField(154, 192, 10, 1)

	surfaceElements.buttons[406] = surface.makeButton(165, 187, 10, 10)
	surfaceElements.buttons[406].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 115)
	surfaceElements.labels[406] = surface.makeLabelField(165, 192, 10, 1)

	surfaceElements.buttons[407] = surface.makeButton(176, 187, 10, 10)
	surfaceElements.buttons[407].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 116)
	surfaceElements.labels[407] = surface.makeLabelField(176, 192, 10, 1)

	surfaceElements.buttons[408] = surface.makeButton(187, 187, 10, 10)
	surfaceElements.buttons[408].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 117)
	surfaceElements.labels[408] = surface.makeLabelField(187, 192, 10, 1)

	surfaceElements.buttons[409] = surface.makeButton(198, 187, 10, 10)
	surfaceElements.buttons[409].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 118)
	surfaceElements.labels[409] = surface.makeLabelField(198, 192, 10, 1)

	surfaceElements.buttons[410] = surface.makeButton(209, 187, 10, 10)
	surfaceElements.buttons[410].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 119)
	surfaceElements.labels[410] = surface.makeLabelField(209, 192, 10, 1)

	surfaceElements.buttons[411] = surface.makeButton(220, 187, 10, 10)
	surfaceElements.buttons[411].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 120)
	surfaceElements.labels[411] = surface.makeLabelField(220, 192, 10, 1)

	surfaceElements.buttons[412] = surface.makeButton(231, 187, 10, 10)
	surfaceElements.buttons[412].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 121)
	surfaceElements.labels[412] = surface.makeLabelField(231, 192, 10, 1)

	surfaceElements.buttons[413] = surface.makeButton(242, 187, 10, 10)
	surfaceElements.buttons[413].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 122)
	surfaceElements.labels[413] = surface.makeLabelField(242, 192, 10, 1)

	surfaceElements.buttons[414] = surface.makeButton(0, 198, 10, 10)
	surfaceElements.buttons[414].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 123)
	surfaceElements.labels[414] = surface.makeLabelField(0, 203, 10, 1)

	surfaceElements.buttons[415] = surface.makeButton(11, 198, 10, 10)
	surfaceElements.buttons[415].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 124)
	surfaceElements.labels[415] = surface.makeLabelField(11, 203, 10, 1)

	surfaceElements.buttons[416] = surface.makeButton(22, 198, 10, 10)
	surfaceElements.buttons[416].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 125)
	surfaceElements.labels[416] = surface.makeLabelField(22, 203, 10, 1)

	surfaceElements.buttons[417] = surface.makeButton(33, 198, 10, 10)
	surfaceElements.buttons[417].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 126)
	surfaceElements.labels[417] = surface.makeLabelField(33, 203, 10, 1)

	surfaceElements.buttons[418] = surface.makeButton(44, 198, 10, 10)
	surfaceElements.buttons[418].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 127)
	surfaceElements.labels[418] = surface.makeLabelField(44, 203, 10, 1)

	surfaceElements.buttons[419] = surface.makeButton(55, 198, 10, 10)
	surfaceElements.buttons[419].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 67)
	surfaceElements.labels[419] = surface.makeLabelField(55, 203, 10, 1)

	surfaceElements.buttons[420] = surface.makeButton(66, 198, 10, 10)
	surfaceElements.buttons[420].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 68)
	surfaceElements.labels[420] = surface.makeLabelField(66, 203, 10, 1)

	surfaceElements.buttons[421] = surface.makeButton(77, 198, 10, 10)
	surfaceElements.buttons[421].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 69)
	surfaceElements.labels[421] = surface.makeLabelField(77, 203, 10, 1)

	surfaceElements.buttons[422] = surface.makeButton(88, 198, 10, 10)
	surfaceElements.buttons[422].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 70)
	surfaceElements.labels[422] = surface.makeLabelField(88, 203, 10, 1)

	surfaceElements.buttons[423] = surface.makeButton(99, 198, 10, 10)
	surfaceElements.buttons[423].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 71)
	surfaceElements.labels[423] = surface.makeLabelField(99, 203, 10, 1)

	surfaceElements.buttons[424] = surface.makeButton(110, 198, 10, 10)
	surfaceElements.buttons[424].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 72)
	surfaceElements.labels[424] = surface.makeLabelField(110, 203, 10, 1)

	surfaceElements.buttons[425] = surface.makeButton(121, 198, 10, 10)
	surfaceElements.buttons[425].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 73)
	surfaceElements.labels[425] = surface.makeLabelField(121, 203, 10, 1)

	surfaceElements.buttons[426] = surface.makeButton(132, 198, 10, 10)
	surfaceElements.buttons[426].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 74)
	surfaceElements.labels[426] = surface.makeLabelField(132, 203, 10, 1)

	surfaceElements.buttons[427] = surface.makeButton(143, 198, 10, 10)
	surfaceElements.buttons[427].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 75)
	surfaceElements.labels[427] = surface.makeLabelField(143, 203, 10, 1)

	surfaceElements.buttons[428] = surface.makeButton(154, 198, 10, 10)
	surfaceElements.buttons[428].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 76)
	surfaceElements.labels[428] = surface.makeLabelField(154, 203, 10, 1)

	surfaceElements.buttons[429] = surface.makeButton(165, 198, 10, 10)
	surfaceElements.buttons[429].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 77)
	surfaceElements.labels[429] = surface.makeLabelField(165, 203, 10, 1)

	surfaceElements.buttons[430] = surface.makeButton(176, 198, 10, 10)
	surfaceElements.buttons[430].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 78)
	surfaceElements.labels[430] = surface.makeLabelField(176, 203, 10, 1)

	surfaceElements.buttons[431] = surface.makeButton(187, 198, 10, 10)
	surfaceElements.buttons[431].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 79)
	surfaceElements.labels[431] = surface.makeLabelField(187, 203, 10, 1)

	surfaceElements.buttons[432] = surface.makeButton(198, 198, 10, 10)
	surfaceElements.buttons[432].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 80)
	surfaceElements.labels[432] = surface.makeLabelField(198, 203, 10, 1)

	surfaceElements.buttons[433] = surface.makeButton(209, 198, 10, 10)
	surfaceElements.buttons[433].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 81)
	surfaceElements.labels[433] = surface.makeLabelField(209, 203, 10, 1)

	surfaceElements.buttons[434] = surface.makeButton(220, 198, 10, 10)
	surfaceElements.buttons[434].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 82)
	surfaceElements.labels[434] = surface.makeLabelField(220, 203, 10, 1)

	surfaceElements.buttons[435] = surface.makeButton(231, 198, 10, 10)
	surfaceElements.buttons[435].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 83)
	surfaceElements.labels[435] = surface.makeLabelField(231, 203, 10, 1)

	surfaceElements.buttons[436] = surface.makeButton(242, 198, 10, 10)
	surfaceElements.buttons[436].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 84)
	surfaceElements.labels[436] = surface.makeLabelField(242, 203, 10, 1)

	surfaceElements.buttons[437] = surface.makeButton(0, 209, 10, 10)
	surfaceElements.buttons[437].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 85)
	surfaceElements.labels[437] = surface.makeLabelField(0, 214, 10, 1)

	surfaceElements.buttons[438] = surface.makeButton(11, 209, 10, 10)
	surfaceElements.buttons[438].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 86)
	surfaceElements.labels[438] = surface.makeLabelField(11, 214, 10, 1)

	surfaceElements.buttons[439] = surface.makeButton(22, 209, 10, 10)
	surfaceElements.buttons[439].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 87)
	surfaceElements.labels[439] = surface.makeLabelField(22, 214, 10, 1)

	surfaceElements.buttons[440] = surface.makeButton(33, 209, 10, 10)
	surfaceElements.buttons[440].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 88)
	surfaceElements.labels[440] = surface.makeLabelField(33, 214, 10, 1)

	surfaceElements.buttons[441] = surface.makeButton(44, 209, 10, 10)
	surfaceElements.buttons[441].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 89)
	surfaceElements.labels[441] = surface.makeLabelField(44, 214, 10, 1)

	surfaceElements.buttons[442] = surface.makeButton(55, 209, 10, 10)
	surfaceElements.buttons[442].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 90)
	surfaceElements.labels[442] = surface.makeLabelField(55, 214, 10, 1)

	surfaceElements.buttons[443] = surface.makeButton(66, 209, 10, 10)
	surfaceElements.buttons[443].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 91)
	surfaceElements.labels[443] = surface.makeLabelField(66, 214, 10, 1)

	surfaceElements.buttons[444] = surface.makeButton(77, 209, 10, 10)
	surfaceElements.buttons[444].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 92)
	surfaceElements.labels[444] = surface.makeLabelField(77, 214, 10, 1)

	surfaceElements.buttons[445] = surface.makeButton(88, 209, 10, 10)
	surfaceElements.buttons[445].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 93)
	surfaceElements.labels[445] = surface.makeLabelField(88, 214, 10, 1)

	surfaceElements.buttons[446] = surface.makeButton(99, 209, 10, 10)
	surfaceElements.buttons[446].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 94)
	surfaceElements.labels[446] = surface.makeLabelField(99, 214, 10, 1)

	surfaceElements.buttons[447] = surface.makeButton(110, 209, 10, 10)
	surfaceElements.buttons[447].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 95)
	surfaceElements.labels[447] = surface.makeLabelField(110, 214, 10, 1)

	surfaceElements.buttons[448] = surface.makeButton(121, 209, 10, 10)
	surfaceElements.buttons[448].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 96)
	surfaceElements.labels[448] = surface.makeLabelField(121, 214, 10, 1)

	surfaceElements.buttons[449] = surface.makeButton(132, 209, 10, 10)
	surfaceElements.buttons[449].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 97)
	surfaceElements.labels[449] = surface.makeLabelField(132, 214, 10, 1)

	surfaceElements.buttons[450] = surface.makeButton(143, 209, 10, 10)
	surfaceElements.buttons[450].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 98)
	surfaceElements.labels[450] = surface.makeLabelField(143, 214, 10, 1)

	surfaceElements.buttons[451] = surface.makeButton(154, 209, 10, 10)
	surfaceElements.buttons[451].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 99)
	surfaceElements.labels[451] = surface.makeLabelField(154, 214, 10, 1)

	surfaceElements.buttons[452] = surface.makeButton(165, 209, 10, 10)
	surfaceElements.buttons[452].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 100)
	surfaceElements.labels[452] = surface.makeLabelField(165, 214, 10, 1)

	surfaceElements.buttons[453] = surface.makeButton(176, 209, 10, 10)
	surfaceElements.buttons[453].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 101)
	surfaceElements.labels[453] = surface.makeLabelField(176, 214, 10, 1)

	surfaceElements.buttons[454] = surface.makeButton(187, 209, 10, 10)
	surfaceElements.buttons[454].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 102)
	surfaceElements.labels[454] = surface.makeLabelField(187, 214, 10, 1)

	surfaceElements.buttons[455] = surface.makeButton(198, 209, 10, 10)
	surfaceElements.buttons[455].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 103)
	surfaceElements.labels[455] = surface.makeLabelField(198, 214, 10, 1)

	surfaceElements.buttons[456] = surface.makeButton(209, 209, 10, 10)
	surfaceElements.buttons[456].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 104)
	surfaceElements.labels[456] = surface.makeLabelField(209, 214, 10, 1)

	surfaceElements.buttons[457] = surface.makeButton(220, 209, 10, 10)
	surfaceElements.buttons[457].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 105)
	surfaceElements.labels[457] = surface.makeLabelField(220, 214, 10, 1)

	surfaceElements.buttons[458] = surface.makeButton(231, 209, 10, 10)
	surfaceElements.buttons[458].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 106)
	surfaceElements.labels[458] = surface.makeLabelField(231, 214, 10, 1)

	surfaceElements.buttons[459] = surface.makeButton(242, 209, 10, 10)
	surfaceElements.buttons[459].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 107)
	surfaceElements.labels[459] = surface.makeLabelField(242, 214, 10, 1)

	surfaceElements.buttons[460] = surface.makeButton(0, 220, 10, 10)
	surfaceElements.buttons[460].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 108)
	surfaceElements.labels[460] = surface.makeLabelField(0, 225, 10, 1)

	surfaceElements.buttons[461] = surface.makeButton(11, 220, 10, 10)
	surfaceElements.buttons[461].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 109)
	surfaceElements.labels[461] = surface.makeLabelField(11, 225, 10, 1)

	surfaceElements.buttons[462] = surface.makeButton(22, 220, 10, 10)
	surfaceElements.buttons[462].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 110)
	surfaceElements.labels[462] = surface.makeLabelField(22, 225, 10, 1)

	surfaceElements.buttons[463] = surface.makeButton(33, 220, 10, 10)
	surfaceElements.buttons[463].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 111)
	surfaceElements.labels[463] = surface.makeLabelField(33, 225, 10, 1)

	surfaceElements.buttons[464] = surface.makeButton(44, 220, 10, 10)
	surfaceElements.buttons[464].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 112)
	surfaceElements.labels[464] = surface.makeLabelField(44, 225, 10, 1)

	surfaceElements.buttons[465] = surface.makeButton(55, 220, 10, 10)
	surfaceElements.buttons[465].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 113)
	surfaceElements.labels[465] = surface.makeLabelField(55, 225, 10, 1)

	surfaceElements.buttons[466] = surface.makeButton(66, 220, 10, 10)
	surfaceElements.buttons[466].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 114)
	surfaceElements.labels[466] = surface.makeLabelField(66, 225, 10, 1)

	surfaceElements.buttons[467] = surface.makeButton(77, 220, 10, 10)
	surfaceElements.buttons[467].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 115)
	surfaceElements.labels[467] = surface.makeLabelField(77, 225, 10, 1)

	surfaceElements.buttons[468] = surface.makeButton(88, 220, 10, 10)
	surfaceElements.buttons[468].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 116)
	surfaceElements.labels[468] = surface.makeLabelField(88, 225, 10, 1)

	surfaceElements.buttons[469] = surface.makeButton(99, 220, 10, 10)
	surfaceElements.buttons[469].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 117)
	surfaceElements.labels[469] = surface.makeLabelField(99, 225, 10, 1)

	surfaceElements.buttons[470] = surface.makeButton(110, 220, 10, 10)
	surfaceElements.buttons[470].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 118)
	surfaceElements.labels[470] = surface.makeLabelField(110, 225, 10, 1)

	surfaceElements.buttons[471] = surface.makeButton(121, 220, 10, 10)
	surfaceElements.buttons[471].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 119)
	surfaceElements.labels[471] = surface.makeLabelField(121, 225, 10, 1)

	surfaceElements.buttons[472] = surface.makeButton(132, 220, 10, 10)
	surfaceElements.buttons[472].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 120)
	surfaceElements.labels[472] = surface.makeLabelField(132, 225, 10, 1)

	surfaceElements.buttons[473] = surface.makeButton(143, 220, 10, 10)
	surfaceElements.buttons[473].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 121)
	surfaceElements.labels[473] = surface.makeLabelField(143, 225, 10, 1)

	surfaceElements.buttons[474] = surface.makeButton(154, 220, 10, 10)
	surfaceElements.buttons[474].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 122)
	surfaceElements.labels[474] = surface.makeLabelField(154, 225, 10, 1)

	surfaceElements.buttons[475] = surface.makeButton(165, 220, 10, 10)
	surfaceElements.buttons[475].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 123)
	surfaceElements.labels[475] = surface.makeLabelField(165, 225, 10, 1)

	surfaceElements.buttons[476] = surface.makeButton(176, 220, 10, 10)
	surfaceElements.buttons[476].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 124)
	surfaceElements.labels[476] = surface.makeLabelField(176, 225, 10, 1)

	surfaceElements.buttons[477] = surface.makeButton(187, 220, 10, 10)
	surfaceElements.buttons[477].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 125)
	surfaceElements.labels[477] = surface.makeLabelField(187, 225, 10, 1)

	surfaceElements.buttons[478] = surface.makeButton(198, 220, 10, 10)
	surfaceElements.buttons[478].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 126)
	surfaceElements.labels[478] = surface.makeLabelField(198, 225, 10, 1)

	surfaceElements.buttons[479] = surface.makeButton(209, 220, 10, 10)
	surfaceElements.buttons[479].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 127)
	surfaceElements.labels[479] = surface.makeLabelField(209, 225, 10, 1)

	surfaceElements.buttons[480] = surface.makeButton(220, 220, 10, 10)
	surfaceElements.buttons[480].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 111)
	surfaceElements.labels[480] = surface.makeLabelField(220, 225, 10, 1)

	surfaceElements.buttons[481] = surface.makeButton(231, 220, 10, 10)
	surfaceElements.buttons[481].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 112)
	surfaceElements.labels[481] = surface.makeLabelField(231, 225, 10, 1)

	surfaceElements.buttons[482] = surface.makeButton(242, 220, 10, 10)
	surfaceElements.buttons[482].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 113)
	surfaceElements.labels[482] = surface.makeLabelField(242, 225, 10, 1)

	surfaceElements.buttons[483] = surface.makeButton(0, 231, 10, 10)
	surfaceElements.buttons[483].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 114)
	surfaceElements.labels[483] = surface.makeLabelField(0, 236, 10, 1)

	surfaceElements.buttons[484] = surface.makeButton(11, 231, 10, 10)
	surfaceElements.buttons[484].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 115)
	surfaceElements.labels[484] = surface.makeLabelField(11, 236, 10, 1)

	surfaceElements.buttons[485] = surface.makeButton(22, 231, 10, 10)
	surfaceElements.buttons[485].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 116)
	surfaceElements.labels[485] = surface.makeLabelField(22, 236, 10, 1)

	surfaceElements.buttons[486] = surface.makeButton(33, 231, 10, 10)
	surfaceElements.buttons[486].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 117)
	surfaceElements.labels[486] = surface.makeLabelField(33, 236, 10, 1)

	surfaceElements.buttons[487] = surface.makeButton(44, 231, 10, 10)
	surfaceElements.buttons[487].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 118)
	surfaceElements.labels[487] = surface.makeLabelField(44, 236, 10, 1)

	surfaceElements.buttons[488] = surface.makeButton(55, 231, 10, 10)
	surfaceElements.buttons[488].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 119)
	surfaceElements.labels[488] = surface.makeLabelField(55, 236, 10, 1)

	surfaceElements.buttons[489] = surface.makeButton(66, 231, 10, 10)
	surfaceElements.buttons[489].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 120)
	surfaceElements.labels[489] = surface.makeLabelField(66, 236, 10, 1)

	surfaceElements.buttons[490] = surface.makeButton(77, 231, 10, 10)
	surfaceElements.buttons[490].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 121)
	surfaceElements.labels[490] = surface.makeLabelField(77, 236, 10, 1)

	surfaceElements.buttons[491] = surface.makeButton(88, 231, 10, 10)
	surfaceElements.buttons[491].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 122)
	surfaceElements.labels[491] = surface.makeLabelField(88, 236, 10, 1)

	surfaceElements.buttons[492] = surface.makeButton(99, 231, 10, 10)
	surfaceElements.buttons[492].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 123)
	surfaceElements.labels[492] = surface.makeLabelField(99, 236, 10, 1)

	surfaceElements.buttons[493] = surface.makeButton(110, 231, 10, 10)
	surfaceElements.buttons[493].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 124)
	surfaceElements.labels[493] = surface.makeLabelField(110, 236, 10, 1)

	surfaceElements.buttons[494] = surface.makeButton(121, 231, 10, 10)
	surfaceElements.buttons[494].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 125)
	surfaceElements.labels[494] = surface.makeLabelField(121, 236, 10, 1)

	surfaceElements.buttons[495] = surface.makeButton(132, 231, 10, 10)
	surfaceElements.buttons[495].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 126)
	surfaceElements.labels[495] = surface.makeLabelField(132, 236, 10, 1)

	surfaceElements.buttons[496] = surface.makeButton(143, 231, 10, 10)
	surfaceElements.buttons[496].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 127)
	surfaceElements.labels[496] = surface.makeLabelField(143, 236, 10, 1)

	surfaceElements.buttons[497] = surface.makeButton(154, 231, 10, 10)
	surfaceElements.buttons[497].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 121)
	surfaceElements.labels[497] = surface.makeLabelField(154, 236, 10, 1)

	surfaceElements.buttons[498] = surface.makeButton(165, 231, 10, 10)
	surfaceElements.buttons[498].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 122)
	surfaceElements.labels[498] = surface.makeLabelField(165, 236, 10, 1)

	surfaceElements.buttons[499] = surface.makeButton(176, 231, 10, 10)
	surfaceElements.buttons[499].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 123)
	surfaceElements.labels[499] = surface.makeLabelField(176, 236, 10, 1)

	surfaceElements.buttons[500] = surface.makeButton(187, 231, 10, 10)
	surfaceElements.buttons[500].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 124)
	surfaceElements.labels[500] = surface.makeLabelField(187, 236, 10, 1)

	surfaceElements.buttons[501] = surface.makeButton(198, 231, 10, 10)
	surfaceElements.buttons[501].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 125)
	surfaceElements.labels[501] = surface.makeLabelField(198, 236, 10, 1)

	return surfaceElements
}

var surfaceElements = makeSurfaceElements()
// var labelElements = makeLabelElements()

//----------------------------------------------------------------------------------------------------------------------
// 3. HOST MAPPING - create mapping pages and host bindings
//----------------------------------------------------------------------------------------------------------------------
function makePageWithDefaults(name) {
	var page = deviceDriver.mMapping.makePage(name)
	return page
}

//----------------------------------------------------------------------------------------------------------------------
function makePageMacros() {
	var page = makePageWithDefaults('Macros')

	page.makeCommandBinding(surfaceElements.buttons[200].mSurfaceValue, "Process Project Logical Editor", "Scene001")
	page.setLabelFieldText(surfaceElements.labels[200], "Scene 001")

	page.makeCommandBinding(surfaceElements.buttons[201].mSurfaceValue, "Process Project Logical Editor", "Scene002")
	page.setLabelFieldText(surfaceElements.labels[201], "Scene 002")

	page.makeCommandBinding(surfaceElements.buttons[202].mSurfaceValue, "Process Project Logical Editor", "Scene003")
	page.setLabelFieldText(surfaceElements.labels[202], "Scene 003")

	page.makeCommandBinding(surfaceElements.buttons[203].mSurfaceValue, "Process Project Logical Editor", "Scene004")
	page.setLabelFieldText(surfaceElements.labels[203], "Scene 004")

	page.makeCommandBinding(surfaceElements.buttons[204].mSurfaceValue, "Process Project Logical Editor", "Scene005")
	page.setLabelFieldText(surfaceElements.labels[204], "Scene 005")

	page.makeCommandBinding(surfaceElements.buttons[205].mSurfaceValue, "Process Project Logical Editor", "Scene006")
	page.setLabelFieldText(surfaceElements.labels[205], "Scene 006")

	page.makeCommandBinding(surfaceElements.buttons[206].mSurfaceValue, "Process Project Logical Editor", "Scene007")
	page.setLabelFieldText(surfaceElements.labels[206], "Scene 007")

	page.makeCommandBinding(surfaceElements.buttons[207].mSurfaceValue, "Process Project Logical Editor", "Scene008")
	page.setLabelFieldText(surfaceElements.labels[207], "Scene 008")

	page.makeCommandBinding(surfaceElements.buttons[208].mSurfaceValue, "Process Project Logical Editor", "Scene009")
	page.setLabelFieldText(surfaceElements.labels[208], "Scene 009")

	page.makeCommandBinding(surfaceElements.buttons[209].mSurfaceValue, "Process Project Logical Editor", "Scene010")
	page.setLabelFieldText(surfaceElements.labels[209], "Scene 010")

	page.makeCommandBinding(surfaceElements.buttons[210].mSurfaceValue, "Process Project Logical Editor", "Scene011")
	page.setLabelFieldText(surfaceElements.labels[210], "Scene 011")

	page.makeCommandBinding(surfaceElements.buttons[211].mSurfaceValue, "Process Project Logical Editor", "Scene012")
	page.setLabelFieldText(surfaceElements.labels[211], "Scene 012")

	page.makeCommandBinding(surfaceElements.buttons[212].mSurfaceValue, "Process Project Logical Editor", "Scene013")
	page.setLabelFieldText(surfaceElements.labels[212], "Scene 013")

	page.makeCommandBinding(surfaceElements.buttons[213].mSurfaceValue, "Process Project Logical Editor", "Scene014")
	page.setLabelFieldText(surfaceElements.labels[213], "Scene 014")

	page.makeCommandBinding(surfaceElements.buttons[214].mSurfaceValue, "Process Project Logical Editor", "Scene015")
	page.setLabelFieldText(surfaceElements.labels[214], "Scene 015")

	page.makeCommandBinding(surfaceElements.buttons[215].mSurfaceValue, "Process Project Logical Editor", "Scene016")
	page.setLabelFieldText(surfaceElements.labels[215], "Scene 016")

	page.makeCommandBinding(surfaceElements.buttons[216].mSurfaceValue, "Process Project Logical Editor", "Scene017")
	page.setLabelFieldText(surfaceElements.labels[216], "Scene 017")

	page.makeCommandBinding(surfaceElements.buttons[217].mSurfaceValue, "Process Project Logical Editor", "Scene018")
	page.setLabelFieldText(surfaceElements.labels[217], "Scene 018")

	page.makeCommandBinding(surfaceElements.buttons[218].mSurfaceValue, "Process Project Logical Editor", "Scene019")
	page.setLabelFieldText(surfaceElements.labels[218], "Scene 019")

	page.makeCommandBinding(surfaceElements.buttons[219].mSurfaceValue, "Process Project Logical Editor", "Scene020")
	page.setLabelFieldText(surfaceElements.labels[219], "Scene 020")

	page.makeCommandBinding(surfaceElements.buttons[220].mSurfaceValue, "Process Project Logical Editor", "Scene021")
	page.setLabelFieldText(surfaceElements.labels[220], "Scene 021")

	page.makeCommandBinding(surfaceElements.buttons[221].mSurfaceValue, "Process Project Logical Editor", "Scene022")
	page.setLabelFieldText(surfaceElements.labels[221], "Scene 022")

	page.makeCommandBinding(surfaceElements.buttons[222].mSurfaceValue, "Process Project Logical Editor", "Scene023")
	page.setLabelFieldText(surfaceElements.labels[222], "Scene 023")

	page.makeCommandBinding(surfaceElements.buttons[223].mSurfaceValue, "Process Project Logical Editor", "Scene024")
	page.setLabelFieldText(surfaceElements.labels[223], "Scene 024")

	page.makeCommandBinding(surfaceElements.buttons[224].mSurfaceValue, "Process Project Logical Editor", "Scene025")
	page.setLabelFieldText(surfaceElements.labels[224], "Scene 025")

	page.makeCommandBinding(surfaceElements.buttons[225].mSurfaceValue, "Process Project Logical Editor", "Scene026")
	page.setLabelFieldText(surfaceElements.labels[225], "Scene 026")

	page.makeCommandBinding(surfaceElements.buttons[226].mSurfaceValue, "Process Project Logical Editor", "Scene027")
	page.setLabelFieldText(surfaceElements.labels[226], "Scene 027")

	page.makeCommandBinding(surfaceElements.buttons[227].mSurfaceValue, "Process Project Logical Editor", "Scene028")
	page.setLabelFieldText(surfaceElements.labels[227], "Scene 028")

	page.makeCommandBinding(surfaceElements.buttons[228].mSurfaceValue, "Process Project Logical Editor", "Scene029")
	page.setLabelFieldText(surfaceElements.labels[228], "Scene 029")

	page.makeCommandBinding(surfaceElements.buttons[229].mSurfaceValue, "Process Project Logical Editor", "Scene030")
	page.setLabelFieldText(surfaceElements.labels[229], "Scene 030")

	page.makeCommandBinding(surfaceElements.buttons[230].mSurfaceValue, "Process Project Logical Editor", "Scene031")
	page.setLabelFieldText(surfaceElements.labels[230], "Scene 031")

	page.makeCommandBinding(surfaceElements.buttons[231].mSurfaceValue, "Process Project Logical Editor", "Scene032")
	page.setLabelFieldText(surfaceElements.labels[231], "Scene 032")

	page.makeCommandBinding(surfaceElements.buttons[232].mSurfaceValue, "Process Project Logical Editor", "Scene033")
	page.setLabelFieldText(surfaceElements.labels[232], "Scene 033")

	page.makeCommandBinding(surfaceElements.buttons[233].mSurfaceValue, "Process Project Logical Editor", "Scene034")
	page.setLabelFieldText(surfaceElements.labels[233], "Scene 034")

	page.makeCommandBinding(surfaceElements.buttons[234].mSurfaceValue, "Process Project Logical Editor", "Scene035")
	page.setLabelFieldText(surfaceElements.labels[234], "Scene 035")

	page.makeCommandBinding(surfaceElements.buttons[235].mSurfaceValue, "Process Project Logical Editor", "Scene036")
	page.setLabelFieldText(surfaceElements.labels[235], "Scene 036")

	page.makeCommandBinding(surfaceElements.buttons[236].mSurfaceValue, "Process Project Logical Editor", "Scene037")
	page.setLabelFieldText(surfaceElements.labels[236], "Scene 037")

	page.makeCommandBinding(surfaceElements.buttons[237].mSurfaceValue, "Process Project Logical Editor", "Scene038")
	page.setLabelFieldText(surfaceElements.labels[237], "Scene 038")

	page.makeCommandBinding(surfaceElements.buttons[238].mSurfaceValue, "Process Project Logical Editor", "Scene039")
	page.setLabelFieldText(surfaceElements.labels[238], "Scene 039")

	page.makeCommandBinding(surfaceElements.buttons[239].mSurfaceValue, "Process Project Logical Editor", "Scene040")
	page.setLabelFieldText(surfaceElements.labels[239], "Scene 040")

	page.makeCommandBinding(surfaceElements.buttons[240].mSurfaceValue, "Process Project Logical Editor", "Scene041")
	page.setLabelFieldText(surfaceElements.labels[240], "Scene 041")

	page.makeCommandBinding(surfaceElements.buttons[241].mSurfaceValue, "Process Project Logical Editor", "Scene042")
	page.setLabelFieldText(surfaceElements.labels[241], "Scene 042")

	page.makeCommandBinding(surfaceElements.buttons[242].mSurfaceValue, "Process Project Logical Editor", "Scene043")
	page.setLabelFieldText(surfaceElements.labels[242], "Scene 043")

	page.makeCommandBinding(surfaceElements.buttons[243].mSurfaceValue, "Process Project Logical Editor", "Scene044")
	page.setLabelFieldText(surfaceElements.labels[243], "Scene 044")

	page.makeCommandBinding(surfaceElements.buttons[244].mSurfaceValue, "Process Project Logical Editor", "Scene045")
	page.setLabelFieldText(surfaceElements.labels[244], "Scene 045")

	page.makeCommandBinding(surfaceElements.buttons[245].mSurfaceValue, "Process Project Logical Editor", "Scene046")
	page.setLabelFieldText(surfaceElements.labels[245], "Scene 046")

	page.makeCommandBinding(surfaceElements.buttons[246].mSurfaceValue, "Process Project Logical Editor", "Scene047")
	page.setLabelFieldText(surfaceElements.labels[246], "Scene 047")

	page.makeCommandBinding(surfaceElements.buttons[247].mSurfaceValue, "Process Project Logical Editor", "Scene048")
	page.setLabelFieldText(surfaceElements.labels[247], "Scene 048")

	page.makeCommandBinding(surfaceElements.buttons[248].mSurfaceValue, "Process Project Logical Editor", "Scene049")
	page.setLabelFieldText(surfaceElements.labels[248], "Scene 049")

	page.makeCommandBinding(surfaceElements.buttons[249].mSurfaceValue, "Process Project Logical Editor", "Scene050")
	page.setLabelFieldText(surfaceElements.labels[249], "Scene 050")

	page.makeCommandBinding(surfaceElements.buttons[250].mSurfaceValue, "Process Project Logical Editor", "Scene051")
	page.setLabelFieldText(surfaceElements.labels[250], "Scene 051")

	page.makeCommandBinding(surfaceElements.buttons[251].mSurfaceValue, "Process Project Logical Editor", "Scene052")
	page.setLabelFieldText(surfaceElements.labels[251], "Scene 052")

	page.makeCommandBinding(surfaceElements.buttons[252].mSurfaceValue, "Process Project Logical Editor", "Scene053")
	page.setLabelFieldText(surfaceElements.labels[252], "Scene 053")

	page.makeCommandBinding(surfaceElements.buttons[253].mSurfaceValue, "Process Project Logical Editor", "Scene054")
	page.setLabelFieldText(surfaceElements.labels[253], "Scene 054")

	page.makeCommandBinding(surfaceElements.buttons[254].mSurfaceValue, "Process Project Logical Editor", "Scene055")
	page.setLabelFieldText(surfaceElements.labels[254], "Scene 055")

	page.makeCommandBinding(surfaceElements.buttons[255].mSurfaceValue, "Process Project Logical Editor", "Scene056")
	page.setLabelFieldText(surfaceElements.labels[255], "Scene 056")

	page.makeCommandBinding(surfaceElements.buttons[256].mSurfaceValue, "Process Project Logical Editor", "Scene057")
	page.setLabelFieldText(surfaceElements.labels[256], "Scene 057")

	page.makeCommandBinding(surfaceElements.buttons[257].mSurfaceValue, "Process Project Logical Editor", "Scene058")
	page.setLabelFieldText(surfaceElements.labels[257], "Scene 058")

	page.makeCommandBinding(surfaceElements.buttons[258].mSurfaceValue, "Process Project Logical Editor", "Scene059")
	page.setLabelFieldText(surfaceElements.labels[258], "Scene 059")

	page.makeCommandBinding(surfaceElements.buttons[259].mSurfaceValue, "Process Project Logical Editor", "Scene060")
	page.setLabelFieldText(surfaceElements.labels[259], "Scene 060")

	page.makeCommandBinding(surfaceElements.buttons[260].mSurfaceValue, "Process Project Logical Editor", "Scene061")
	page.setLabelFieldText(surfaceElements.labels[260], "Scene 061")

	page.makeCommandBinding(surfaceElements.buttons[261].mSurfaceValue, "Process Project Logical Editor", "Scene062")
	page.setLabelFieldText(surfaceElements.labels[261], "Scene 062")

	page.makeCommandBinding(surfaceElements.buttons[262].mSurfaceValue, "Process Project Logical Editor", "Scene063")
	page.setLabelFieldText(surfaceElements.labels[262], "Scene 063")

	page.makeCommandBinding(surfaceElements.buttons[263].mSurfaceValue, "Process Project Logical Editor", "Scene064")
	page.setLabelFieldText(surfaceElements.labels[263], "Scene 064")

	page.makeCommandBinding(surfaceElements.buttons[264].mSurfaceValue, "Process Project Logical Editor", "Scene065")
	page.setLabelFieldText(surfaceElements.labels[264], "Scene 065")

	page.makeCommandBinding(surfaceElements.buttons[265].mSurfaceValue, "Process Project Logical Editor", "Scene066")
	page.setLabelFieldText(surfaceElements.labels[265], "Scene 066")

	page.makeCommandBinding(surfaceElements.buttons[266].mSurfaceValue, "Process Project Logical Editor", "Scene067")
	page.setLabelFieldText(surfaceElements.labels[266], "Scene 067")

	page.makeCommandBinding(surfaceElements.buttons[267].mSurfaceValue, "Process Project Logical Editor", "Scene068")
	page.setLabelFieldText(surfaceElements.labels[267], "Scene 068")

	page.makeCommandBinding(surfaceElements.buttons[268].mSurfaceValue, "Process Project Logical Editor", "Scene069")
	page.setLabelFieldText(surfaceElements.labels[268], "Scene 069")

	page.makeCommandBinding(surfaceElements.buttons[269].mSurfaceValue, "Process Project Logical Editor", "Scene070")
	page.setLabelFieldText(surfaceElements.labels[269], "Scene 070")

	page.makeCommandBinding(surfaceElements.buttons[270].mSurfaceValue, "Process Project Logical Editor", "Scene071")
	page.setLabelFieldText(surfaceElements.labels[270], "Scene 071")

	page.makeCommandBinding(surfaceElements.buttons[271].mSurfaceValue, "Process Project Logical Editor", "Scene072")
	page.setLabelFieldText(surfaceElements.labels[271], "Scene 072")

	page.makeCommandBinding(surfaceElements.buttons[272].mSurfaceValue, "Process Project Logical Editor", "Scene073")
	page.setLabelFieldText(surfaceElements.labels[272], "Scene 073")

	page.makeCommandBinding(surfaceElements.buttons[273].mSurfaceValue, "Process Project Logical Editor", "Scene074")
	page.setLabelFieldText(surfaceElements.labels[273], "Scene 074")

	page.makeCommandBinding(surfaceElements.buttons[274].mSurfaceValue, "Process Project Logical Editor", "Scene075")
	page.setLabelFieldText(surfaceElements.labels[274], "Scene 075")

	page.makeCommandBinding(surfaceElements.buttons[275].mSurfaceValue, "Process Project Logical Editor", "Scene076")
	page.setLabelFieldText(surfaceElements.labels[275], "Scene 076")

	page.makeCommandBinding(surfaceElements.buttons[276].mSurfaceValue, "Process Project Logical Editor", "Scene077")
	page.setLabelFieldText(surfaceElements.labels[276], "Scene 077")

	page.makeCommandBinding(surfaceElements.buttons[277].mSurfaceValue, "Process Project Logical Editor", "Scene078")
	page.setLabelFieldText(surfaceElements.labels[277], "Scene 078")

	page.makeCommandBinding(surfaceElements.buttons[278].mSurfaceValue, "Process Project Logical Editor", "Scene079")
	page.setLabelFieldText(surfaceElements.labels[278], "Scene 079")

	page.makeCommandBinding(surfaceElements.buttons[279].mSurfaceValue, "Process Project Logical Editor", "Scene080")
	page.setLabelFieldText(surfaceElements.labels[279], "Scene 080")

	page.makeCommandBinding(surfaceElements.buttons[280].mSurfaceValue, "Process Project Logical Editor", "Scene081")
	page.setLabelFieldText(surfaceElements.labels[280], "Scene 081")

	page.makeCommandBinding(surfaceElements.buttons[281].mSurfaceValue, "Process Project Logical Editor", "Scene082")
	page.setLabelFieldText(surfaceElements.labels[281], "Scene 082")

	page.makeCommandBinding(surfaceElements.buttons[282].mSurfaceValue, "Process Project Logical Editor", "Scene083")
	page.setLabelFieldText(surfaceElements.labels[282], "Scene 083")

	page.makeCommandBinding(surfaceElements.buttons[283].mSurfaceValue, "Process Project Logical Editor", "Scene084")
	page.setLabelFieldText(surfaceElements.labels[283], "Scene 084")

	page.makeCommandBinding(surfaceElements.buttons[284].mSurfaceValue, "Process Project Logical Editor", "Scene085")
	page.setLabelFieldText(surfaceElements.labels[284], "Scene 085")

	page.makeCommandBinding(surfaceElements.buttons[285].mSurfaceValue, "Process Project Logical Editor", "Scene086")
	page.setLabelFieldText(surfaceElements.labels[285], "Scene 086")

	page.makeCommandBinding(surfaceElements.buttons[286].mSurfaceValue, "Process Project Logical Editor", "Scene087")
	page.setLabelFieldText(surfaceElements.labels[286], "Scene 087")

	page.makeCommandBinding(surfaceElements.buttons[287].mSurfaceValue, "Process Project Logical Editor", "Scene088")
	page.setLabelFieldText(surfaceElements.labels[287], "Scene 088")

	page.makeCommandBinding(surfaceElements.buttons[288].mSurfaceValue, "Process Project Logical Editor", "Scene089")
	page.setLabelFieldText(surfaceElements.labels[288], "Scene 089")

	page.makeCommandBinding(surfaceElements.buttons[289].mSurfaceValue, "Process Project Logical Editor", "Scene090")
	page.setLabelFieldText(surfaceElements.labels[289], "Scene 090")

	page.makeCommandBinding(surfaceElements.buttons[290].mSurfaceValue, "Process Project Logical Editor", "Scene091")
	page.setLabelFieldText(surfaceElements.labels[290], "Scene 091")

	page.makeCommandBinding(surfaceElements.buttons[291].mSurfaceValue, "Process Project Logical Editor", "Scene092")
	page.setLabelFieldText(surfaceElements.labels[291], "Scene 092")

	page.makeCommandBinding(surfaceElements.buttons[292].mSurfaceValue, "Process Project Logical Editor", "Scene093")
	page.setLabelFieldText(surfaceElements.labels[292], "Scene 093")

	page.makeCommandBinding(surfaceElements.buttons[293].mSurfaceValue, "Process Project Logical Editor", "Scene094")
	page.setLabelFieldText(surfaceElements.labels[293], "Scene 094")

	page.makeCommandBinding(surfaceElements.buttons[294].mSurfaceValue, "Process Project Logical Editor", "Scene095")
	page.setLabelFieldText(surfaceElements.labels[294], "Scene 095")

	page.makeCommandBinding(surfaceElements.buttons[295].mSurfaceValue, "Process Project Logical Editor", "Scene096")
	page.setLabelFieldText(surfaceElements.labels[295], "Scene 096")

	page.makeCommandBinding(surfaceElements.buttons[296].mSurfaceValue, "Process Project Logical Editor", "Scene097")
	page.setLabelFieldText(surfaceElements.labels[296], "Scene 097")

	page.makeCommandBinding(surfaceElements.buttons[297].mSurfaceValue, "Process Project Logical Editor", "Scene098")
	page.setLabelFieldText(surfaceElements.labels[297], "Scene 098")

	page.makeCommandBinding(surfaceElements.buttons[298].mSurfaceValue, "Process Project Logical Editor", "Scene099")
	page.setLabelFieldText(surfaceElements.labels[298], "Scene 099")

	page.makeCommandBinding(surfaceElements.buttons[299].mSurfaceValue, "Process Project Logical Editor", "Scene100")
	page.setLabelFieldText(surfaceElements.labels[299], "Scene 100")

	page.makeCommandBinding(surfaceElements.buttons[300].mSurfaceValue, "Process Project Logical Editor", "Hide All")
	page.setLabelFieldText(surfaceElements.labels[300], "Hide All")

	page.makeCommandBinding(surfaceElements.buttons[301].mSurfaceValue, "Process Project Logical Editor", "MG_Unfold_All_Visible")
	page.setLabelFieldText(surfaceElements.labels[301], "Unfold All")

	return page
}

//----------------------------------------------------------------------------------------------------------------------
// Construct Pages
//----------------------------------------------------------------------------------------------------------------------
function onActivatePageDefault(context) {
}

deviceDriver.mOnActivate = function (context) {
	console.log('Metagrid Macros script has been activated.')
}

var pageMacros = makePageMacros()

pageMacros.mOnActivate = function (context) {
	onActivatePageDefault(context)
	console.log('from script: Metagrid Macros page activated')
}
//----------------------------------------------------------------------------------------------------------------------
// 1. DRIVER SETUP - create driver object, midi ports and detection information
//----------------------------------------------------------------------------------------------------------------------
var midiremote_api = require('midiremote_api_v1')
var deviceDriver = midiremote_api.makeDeviceDriver('Metasystem', 'metagridMacros', 'Martin Jirsak')

var midiInput = deviceDriver.mPorts.makeMidiInput()
var midiOutput = deviceDriver.mPorts.makeMidiOutput()

deviceDriver.makeDetectionUnit().detectPortPair(midiInput, midiOutput)
	.expectInputNameContains('Metasystem - CubaseMacros - In')
	.expectOutputNameContains('Metasystem - CubaseMacros - Out')

var surface = deviceDriver.mSurface

//----------------------------------------------------------------------------------------------------------------------
// 2. SURFACE LAYOUT - create control elements and midi bindings
//----------------------------------------------------------------------------------------------------------------------
function makeSurfaceElements() {
	var surfaceElements = {}
	surfaceElements.buttons = {}
	surfaceElements.labels = {}

	surfaceElements.buttons[0] = surface.makeButton(0, 0, 10, 10)
	surfaceElements.buttons[0].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 11)
	surfaceElements.labels[0] = surface.makeLabelField(0, 5, 10, 1)

	surfaceElements.buttons[1] = surface.makeButton(11, 0, 10, 10)
	surfaceElements.buttons[1].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 12)
	surfaceElements.labels[1] = surface.makeLabelField(11, 5, 10, 1)

	surfaceElements.buttons[2] = surface.makeButton(22, 0, 10, 10)
	surfaceElements.buttons[2].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 13)
	surfaceElements.labels[2] = surface.makeLabelField(22, 5, 10, 1)

	surfaceElements.buttons[3] = surface.makeButton(33, 0, 10, 10)
	surfaceElements.buttons[3].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 14)
	surfaceElements.labels[3] = surface.makeLabelField(33, 5, 10, 1)

	surfaceElements.buttons[4] = surface.makeButton(44, 0, 10, 10)
	surfaceElements.buttons[4].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 15)
	surfaceElements.labels[4] = surface.makeLabelField(44, 5, 10, 1)

	surfaceElements.buttons[5] = surface.makeButton(55, 0, 10, 10)
	surfaceElements.buttons[5].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 16)
	surfaceElements.labels[5] = surface.makeLabelField(55, 5, 10, 1)

	surfaceElements.buttons[6] = surface.makeButton(66, 0, 10, 10)
	surfaceElements.buttons[6].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 17)
	surfaceElements.labels[6] = surface.makeLabelField(66, 5, 10, 1)

	surfaceElements.buttons[7] = surface.makeButton(77, 0, 10, 10)
	surfaceElements.buttons[7].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 18)
	surfaceElements.labels[7] = surface.makeLabelField(77, 5, 10, 1)

	surfaceElements.buttons[8] = surface.makeButton(88, 0, 10, 10)
	surfaceElements.buttons[8].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 19)
	surfaceElements.labels[8] = surface.makeLabelField(88, 5, 10, 1)

	surfaceElements.buttons[9] = surface.makeButton(99, 0, 10, 10)
	surfaceElements.buttons[9].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 20)
	surfaceElements.labels[9] = surface.makeLabelField(99, 5, 10, 1)

	surfaceElements.buttons[10] = surface.makeButton(110, 0, 10, 10)
	surfaceElements.buttons[10].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 21)
	surfaceElements.labels[10] = surface.makeLabelField(110, 5, 10, 1)

	surfaceElements.buttons[11] = surface.makeButton(121, 0, 10, 10)
	surfaceElements.buttons[11].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 22)
	surfaceElements.labels[11] = surface.makeLabelField(121, 5, 10, 1)

	surfaceElements.buttons[12] = surface.makeButton(132, 0, 10, 10)
	surfaceElements.buttons[12].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 23)
	surfaceElements.labels[12] = surface.makeLabelField(132, 5, 10, 1)

	surfaceElements.buttons[13] = surface.makeButton(143, 0, 10, 10)
	surfaceElements.buttons[13].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 24)
	surfaceElements.labels[13] = surface.makeLabelField(143, 5, 10, 1)

	surfaceElements.buttons[14] = surface.makeButton(154, 0, 10, 10)
	surfaceElements.buttons[14].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 25)
	surfaceElements.labels[14] = surface.makeLabelField(154, 5, 10, 1)

	surfaceElements.buttons[15] = surface.makeButton(165, 0, 10, 10)
	surfaceElements.buttons[15].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 26)
	surfaceElements.labels[15] = surface.makeLabelField(165, 5, 10, 1)

	surfaceElements.buttons[16] = surface.makeButton(176, 0, 10, 10)
	surfaceElements.buttons[16].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 27)
	surfaceElements.labels[16] = surface.makeLabelField(176, 5, 10, 1)

	surfaceElements.buttons[17] = surface.makeButton(187, 0, 10, 10)
	surfaceElements.buttons[17].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 28)
	surfaceElements.labels[17] = surface.makeLabelField(187, 5, 10, 1)

	surfaceElements.buttons[18] = surface.makeButton(198, 0, 10, 10)
	surfaceElements.buttons[18].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 29)
	surfaceElements.labels[18] = surface.makeLabelField(198, 5, 10, 1)

	surfaceElements.buttons[19] = surface.makeButton(209, 0, 10, 10)
	surfaceElements.buttons[19].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 30)
	surfaceElements.labels[19] = surface.makeLabelField(209, 5, 10, 1)

	surfaceElements.buttons[20] = surface.makeButton(220, 0, 10, 10)
	surfaceElements.buttons[20].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 31)
	surfaceElements.labels[20] = surface.makeLabelField(220, 5, 10, 1)

	surfaceElements.buttons[21] = surface.makeButton(231, 0, 10, 10)
	surfaceElements.buttons[21].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 32)
	surfaceElements.labels[21] = surface.makeLabelField(231, 5, 10, 1)

	surfaceElements.buttons[22] = surface.makeButton(242, 0, 10, 10)
	surfaceElements.buttons[22].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 33)
	surfaceElements.labels[22] = surface.makeLabelField(242, 5, 10, 1)

	surfaceElements.buttons[23] = surface.makeButton(253, 0, 10, 10)
	surfaceElements.buttons[23].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 34)
	surfaceElements.labels[23] = surface.makeLabelField(253, 5, 10, 1)

	surfaceElements.buttons[24] = surface.makeButton(264, 0, 10, 10)
	surfaceElements.buttons[24].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 35)
	surfaceElements.labels[24] = surface.makeLabelField(264, 5, 10, 1)

	surfaceElements.buttons[25] = surface.makeButton(275, 0, 10, 10)
	surfaceElements.buttons[25].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 36)
	surfaceElements.labels[25] = surface.makeLabelField(275, 5, 10, 1)

	surfaceElements.buttons[26] = surface.makeButton(286, 0, 10, 10)
	surfaceElements.buttons[26].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 37)
	surfaceElements.labels[26] = surface.makeLabelField(286, 5, 10, 1)

	surfaceElements.buttons[27] = surface.makeButton(297, 0, 10, 10)
	surfaceElements.buttons[27].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 38)
	surfaceElements.labels[27] = surface.makeLabelField(297, 5, 10, 1)

	surfaceElements.buttons[28] = surface.makeButton(308, 0, 10, 10)
	surfaceElements.buttons[28].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 39)
	surfaceElements.labels[28] = surface.makeLabelField(308, 5, 10, 1)

	surfaceElements.buttons[29] = surface.makeButton(319, 0, 10, 10)
	surfaceElements.buttons[29].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 40)
	surfaceElements.labels[29] = surface.makeLabelField(319, 5, 10, 1)

	surfaceElements.buttons[30] = surface.makeButton(330, 0, 10, 10)
	surfaceElements.buttons[30].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 41)
	surfaceElements.labels[30] = surface.makeLabelField(330, 5, 10, 1)

	surfaceElements.buttons[31] = surface.makeButton(341, 0, 10, 10)
	surfaceElements.buttons[31].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 42)
	surfaceElements.labels[31] = surface.makeLabelField(341, 5, 10, 1)

	surfaceElements.buttons[32] = surface.makeButton(0, 11, 10, 10)
	surfaceElements.buttons[32].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 43)
	surfaceElements.labels[32] = surface.makeLabelField(0, 16, 10, 1)

	surfaceElements.buttons[33] = surface.makeButton(11, 11, 10, 10)
	surfaceElements.buttons[33].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 44)
	surfaceElements.labels[33] = surface.makeLabelField(11, 16, 10, 1)

	surfaceElements.buttons[34] = surface.makeButton(22, 11, 10, 10)
	surfaceElements.buttons[34].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 45)
	surfaceElements.labels[34] = surface.makeLabelField(22, 16, 10, 1)

	surfaceElements.buttons[35] = surface.makeButton(33, 11, 10, 10)
	surfaceElements.buttons[35].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 46)
	surfaceElements.labels[35] = surface.makeLabelField(33, 16, 10, 1)

	surfaceElements.buttons[36] = surface.makeButton(44, 11, 10, 10)
	surfaceElements.buttons[36].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 47)
	surfaceElements.labels[36] = surface.makeLabelField(44, 16, 10, 1)

	surfaceElements.buttons[37] = surface.makeButton(55, 11, 10, 10)
	surfaceElements.buttons[37].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 48)
	surfaceElements.labels[37] = surface.makeLabelField(55, 16, 10, 1)

	surfaceElements.buttons[38] = surface.makeButton(66, 11, 10, 10)
	surfaceElements.buttons[38].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 49)
	surfaceElements.labels[38] = surface.makeLabelField(66, 16, 10, 1)

	surfaceElements.buttons[39] = surface.makeButton(77, 11, 10, 10)
	surfaceElements.buttons[39].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 50)
	surfaceElements.labels[39] = surface.makeLabelField(77, 16, 10, 1)

	surfaceElements.buttons[40] = surface.makeButton(88, 11, 10, 10)
	surfaceElements.buttons[40].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 51)
	surfaceElements.labels[40] = surface.makeLabelField(88, 16, 10, 1)

	surfaceElements.buttons[41] = surface.makeButton(99, 11, 10, 10)
	surfaceElements.buttons[41].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 52)
	surfaceElements.labels[41] = surface.makeLabelField(99, 16, 10, 1)

	surfaceElements.buttons[42] = surface.makeButton(110, 11, 10, 10)
	surfaceElements.buttons[42].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 53)
	surfaceElements.labels[42] = surface.makeLabelField(110, 16, 10, 1)

	surfaceElements.buttons[43] = surface.makeButton(121, 11, 10, 10)
	surfaceElements.buttons[43].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 54)
	surfaceElements.labels[43] = surface.makeLabelField(121, 16, 10, 1)

	surfaceElements.buttons[44] = surface.makeButton(132, 11, 10, 10)
	surfaceElements.buttons[44].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 55)
	surfaceElements.labels[44] = surface.makeLabelField(132, 16, 10, 1)

	surfaceElements.buttons[45] = surface.makeButton(143, 11, 10, 10)
	surfaceElements.buttons[45].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 56)
	surfaceElements.labels[45] = surface.makeLabelField(143, 16, 10, 1)

	surfaceElements.buttons[46] = surface.makeButton(154, 11, 10, 10)
	surfaceElements.buttons[46].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 57)
	surfaceElements.labels[46] = surface.makeLabelField(154, 16, 10, 1)

	surfaceElements.buttons[47] = surface.makeButton(165, 11, 10, 10)
	surfaceElements.buttons[47].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 58)
	surfaceElements.labels[47] = surface.makeLabelField(165, 16, 10, 1)

	surfaceElements.buttons[48] = surface.makeButton(176, 11, 10, 10)
	surfaceElements.buttons[48].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 59)
	surfaceElements.labels[48] = surface.makeLabelField(176, 16, 10, 1)

	surfaceElements.buttons[49] = surface.makeButton(187, 11, 10, 10)
	surfaceElements.buttons[49].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 60)
	surfaceElements.labels[49] = surface.makeLabelField(187, 16, 10, 1)

	surfaceElements.buttons[50] = surface.makeButton(198, 11, 10, 10)
	surfaceElements.buttons[50].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 61)
	surfaceElements.labels[50] = surface.makeLabelField(198, 16, 10, 1)

	surfaceElements.buttons[51] = surface.makeButton(209, 11, 10, 10)
	surfaceElements.buttons[51].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 62)
	surfaceElements.labels[51] = surface.makeLabelField(209, 16, 10, 1)

	surfaceElements.buttons[52] = surface.makeButton(220, 11, 10, 10)
	surfaceElements.buttons[52].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 63)
	surfaceElements.labels[52] = surface.makeLabelField(220, 16, 10, 1)

	surfaceElements.buttons[53] = surface.makeButton(231, 11, 10, 10)
	surfaceElements.buttons[53].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 64)
	surfaceElements.labels[53] = surface.makeLabelField(231, 16, 10, 1)

	surfaceElements.buttons[54] = surface.makeButton(242, 11, 10, 10)
	surfaceElements.buttons[54].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 65)
	surfaceElements.labels[54] = surface.makeLabelField(242, 16, 10, 1)

	surfaceElements.buttons[55] = surface.makeButton(253, 11, 10, 10)
	surfaceElements.buttons[55].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 66)
	surfaceElements.labels[55] = surface.makeLabelField(253, 16, 10, 1)

	surfaceElements.buttons[56] = surface.makeButton(264, 11, 10, 10)
	surfaceElements.buttons[56].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 67)
	surfaceElements.labels[56] = surface.makeLabelField(264, 16, 10, 1)

	surfaceElements.buttons[57] = surface.makeButton(275, 11, 10, 10)
	surfaceElements.buttons[57].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 68)
	surfaceElements.labels[57] = surface.makeLabelField(275, 16, 10, 1)

	surfaceElements.buttons[58] = surface.makeButton(286, 11, 10, 10)
	surfaceElements.buttons[58].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 69)
	surfaceElements.labels[58] = surface.makeLabelField(286, 16, 10, 1)

	surfaceElements.buttons[59] = surface.makeButton(297, 11, 10, 10)
	surfaceElements.buttons[59].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 70)
	surfaceElements.labels[59] = surface.makeLabelField(297, 16, 10, 1)

	surfaceElements.buttons[60] = surface.makeButton(308, 11, 10, 10)
	surfaceElements.buttons[60].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 71)
	surfaceElements.labels[60] = surface.makeLabelField(308, 16, 10, 1)

	surfaceElements.buttons[61] = surface.makeButton(319, 11, 10, 10)
	surfaceElements.buttons[61].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 72)
	surfaceElements.labels[61] = surface.makeLabelField(319, 16, 10, 1)

	surfaceElements.buttons[62] = surface.makeButton(330, 11, 10, 10)
	surfaceElements.buttons[62].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 73)
	surfaceElements.labels[62] = surface.makeLabelField(330, 16, 10, 1)

	surfaceElements.buttons[63] = surface.makeButton(341, 11, 10, 10)
	surfaceElements.buttons[63].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 74)
	surfaceElements.labels[63] = surface.makeLabelField(341, 16, 10, 1)

	surfaceElements.buttons[64] = surface.makeButton(0, 22, 10, 10)
	surfaceElements.buttons[64].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 75)
	surfaceElements.labels[64] = surface.makeLabelField(0, 27, 10, 1)

	surfaceElements.buttons[65] = surface.makeButton(11, 22, 10, 10)
	surfaceElements.buttons[65].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 76)
	surfaceElements.labels[65] = surface.makeLabelField(11, 27, 10, 1)

	surfaceElements.buttons[66] = surface.makeButton(22, 22, 10, 10)
	surfaceElements.buttons[66].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 77)
	surfaceElements.labels[66] = surface.makeLabelField(22, 27, 10, 1)

	surfaceElements.buttons[67] = surface.makeButton(33, 22, 10, 10)
	surfaceElements.buttons[67].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 78)
	surfaceElements.labels[67] = surface.makeLabelField(33, 27, 10, 1)

	surfaceElements.buttons[68] = surface.makeButton(44, 22, 10, 10)
	surfaceElements.buttons[68].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 79)
	surfaceElements.labels[68] = surface.makeLabelField(44, 27, 10, 1)

	surfaceElements.buttons[69] = surface.makeButton(55, 22, 10, 10)
	surfaceElements.buttons[69].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 80)
	surfaceElements.labels[69] = surface.makeLabelField(55, 27, 10, 1)

	surfaceElements.buttons[70] = surface.makeButton(66, 22, 10, 10)
	surfaceElements.buttons[70].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 81)
	surfaceElements.labels[70] = surface.makeLabelField(66, 27, 10, 1)

	surfaceElements.buttons[71] = surface.makeButton(77, 22, 10, 10)
	surfaceElements.buttons[71].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 82)
	surfaceElements.labels[71] = surface.makeLabelField(77, 27, 10, 1)

	surfaceElements.buttons[72] = surface.makeButton(88, 22, 10, 10)
	surfaceElements.buttons[72].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 83)
	surfaceElements.labels[72] = surface.makeLabelField(88, 27, 10, 1)

	surfaceElements.buttons[73] = surface.makeButton(99, 22, 10, 10)
	surfaceElements.buttons[73].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 84)
	surfaceElements.labels[73] = surface.makeLabelField(99, 27, 10, 1)

	surfaceElements.buttons[74] = surface.makeButton(110, 22, 10, 10)
	surfaceElements.buttons[74].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 85)
	surfaceElements.labels[74] = surface.makeLabelField(110, 27, 10, 1)

	surfaceElements.buttons[75] = surface.makeButton(121, 22, 10, 10)
	surfaceElements.buttons[75].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 86)
	surfaceElements.labels[75] = surface.makeLabelField(121, 27, 10, 1)

	surfaceElements.buttons[76] = surface.makeButton(132, 22, 10, 10)
	surfaceElements.buttons[76].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 87)
	surfaceElements.labels[76] = surface.makeLabelField(132, 27, 10, 1)

	surfaceElements.buttons[77] = surface.makeButton(143, 22, 10, 10)
	surfaceElements.buttons[77].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 88)
	surfaceElements.labels[77] = surface.makeLabelField(143, 27, 10, 1)

	surfaceElements.buttons[78] = surface.makeButton(154, 22, 10, 10)
	surfaceElements.buttons[78].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 89)
	surfaceElements.labels[78] = surface.makeLabelField(154, 27, 10, 1)

	surfaceElements.buttons[79] = surface.makeButton(165, 22, 10, 10)
	surfaceElements.buttons[79].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 90)
	surfaceElements.labels[79] = surface.makeLabelField(165, 27, 10, 1)

	surfaceElements.buttons[80] = surface.makeButton(176, 22, 10, 10)
	surfaceElements.buttons[80].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 91)
	surfaceElements.labels[80] = surface.makeLabelField(176, 27, 10, 1)

	surfaceElements.buttons[81] = surface.makeButton(187, 22, 10, 10)
	surfaceElements.buttons[81].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 92)
	surfaceElements.labels[81] = surface.makeLabelField(187, 27, 10, 1)

	surfaceElements.buttons[82] = surface.makeButton(198, 22, 10, 10)
	surfaceElements.buttons[82].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 93)
	surfaceElements.labels[82] = surface.makeLabelField(198, 27, 10, 1)

	surfaceElements.buttons[83] = surface.makeButton(209, 22, 10, 10)
	surfaceElements.buttons[83].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 94)
	surfaceElements.labels[83] = surface.makeLabelField(209, 27, 10, 1)

	surfaceElements.buttons[84] = surface.makeButton(220, 22, 10, 10)
	surfaceElements.buttons[84].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 95)
	surfaceElements.labels[84] = surface.makeLabelField(220, 27, 10, 1)

	surfaceElements.buttons[85] = surface.makeButton(231, 22, 10, 10)
	surfaceElements.buttons[85].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 96)
	surfaceElements.labels[85] = surface.makeLabelField(231, 27, 10, 1)

	surfaceElements.buttons[86] = surface.makeButton(242, 22, 10, 10)
	surfaceElements.buttons[86].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 97)
	surfaceElements.labels[86] = surface.makeLabelField(242, 27, 10, 1)

	surfaceElements.buttons[87] = surface.makeButton(253, 22, 10, 10)
	surfaceElements.buttons[87].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 98)
	surfaceElements.labels[87] = surface.makeLabelField(253, 27, 10, 1)

	surfaceElements.buttons[88] = surface.makeButton(264, 22, 10, 10)
	surfaceElements.buttons[88].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 99)
	surfaceElements.labels[88] = surface.makeLabelField(264, 27, 10, 1)

	surfaceElements.buttons[89] = surface.makeButton(275, 22, 10, 10)
	surfaceElements.buttons[89].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 100)
	surfaceElements.labels[89] = surface.makeLabelField(275, 27, 10, 1)

	surfaceElements.buttons[90] = surface.makeButton(286, 22, 10, 10)
	surfaceElements.buttons[90].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 101)
	surfaceElements.labels[90] = surface.makeLabelField(286, 27, 10, 1)

	surfaceElements.buttons[91] = surface.makeButton(297, 22, 10, 10)
	surfaceElements.buttons[91].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 102)
	surfaceElements.labels[91] = surface.makeLabelField(297, 27, 10, 1)

	surfaceElements.buttons[92] = surface.makeButton(308, 22, 10, 10)
	surfaceElements.buttons[92].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 103)
	surfaceElements.labels[92] = surface.makeLabelField(308, 27, 10, 1)

	surfaceElements.buttons[93] = surface.makeButton(319, 22, 10, 10)
	surfaceElements.buttons[93].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 104)
	surfaceElements.labels[93] = surface.makeLabelField(319, 27, 10, 1)

	surfaceElements.buttons[94] = surface.makeButton(330, 22, 10, 10)
	surfaceElements.buttons[94].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 105)
	surfaceElements.labels[94] = surface.makeLabelField(330, 27, 10, 1)

	surfaceElements.buttons[95] = surface.makeButton(341, 22, 10, 10)
	surfaceElements.buttons[95].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 106)
	surfaceElements.labels[95] = surface.makeLabelField(341, 27, 10, 1)

	surfaceElements.buttons[96] = surface.makeButton(0, 33, 10, 10)
	surfaceElements.buttons[96].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 107)
	surfaceElements.labels[96] = surface.makeLabelField(0, 38, 10, 1)

	surfaceElements.buttons[97] = surface.makeButton(11, 33, 10, 10)
	surfaceElements.buttons[97].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 108)
	surfaceElements.labels[97] = surface.makeLabelField(11, 38, 10, 1)

	surfaceElements.buttons[98] = surface.makeButton(22, 33, 10, 10)
	surfaceElements.buttons[98].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 109)
	surfaceElements.labels[98] = surface.makeLabelField(22, 38, 10, 1)

	surfaceElements.buttons[99] = surface.makeButton(33, 33, 10, 10)
	surfaceElements.buttons[99].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 110)
	surfaceElements.labels[99] = surface.makeLabelField(33, 38, 10, 1)

	surfaceElements.buttons[100] = surface.makeButton(44, 33, 10, 10)
	surfaceElements.buttons[100].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 1)
	surfaceElements.labels[100] = surface.makeLabelField(44, 38, 10, 1)

	surfaceElements.buttons[101] = surface.makeButton(55, 33, 10, 10)
	surfaceElements.buttons[101].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 2)
	surfaceElements.labels[101] = surface.makeLabelField(55, 38, 10, 1)

	surfaceElements.buttons[102] = surface.makeButton(66, 33, 10, 10)
	surfaceElements.buttons[102].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 3)
	surfaceElements.labels[102] = surface.makeLabelField(66, 38, 10, 1)

	surfaceElements.buttons[103] = surface.makeButton(77, 33, 10, 10)
	surfaceElements.buttons[103].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 4)
	surfaceElements.labels[103] = surface.makeLabelField(77, 38, 10, 1)

	surfaceElements.buttons[104] = surface.makeButton(88, 33, 10, 10)
	surfaceElements.buttons[104].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 5)
	surfaceElements.labels[104] = surface.makeLabelField(88, 38, 10, 1)

	surfaceElements.buttons[105] = surface.makeButton(99, 33, 10, 10)
	surfaceElements.buttons[105].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 6)
	surfaceElements.labels[105] = surface.makeLabelField(99, 38, 10, 1)

	surfaceElements.buttons[106] = surface.makeButton(110, 33, 10, 10)
	surfaceElements.buttons[106].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 7)
	surfaceElements.labels[106] = surface.makeLabelField(110, 38, 10, 1)

	surfaceElements.buttons[107] = surface.makeButton(121, 33, 10, 10)
	surfaceElements.buttons[107].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 8)
	surfaceElements.labels[107] = surface.makeLabelField(121, 38, 10, 1)

	surfaceElements.buttons[108] = surface.makeButton(132, 33, 10, 10)
	surfaceElements.buttons[108].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 9)
	surfaceElements.labels[108] = surface.makeLabelField(132, 38, 10, 1)

	surfaceElements.buttons[109] = surface.makeButton(143, 33, 10, 10)
	surfaceElements.buttons[109].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 10)
	surfaceElements.labels[109] = surface.makeLabelField(143, 38, 10, 1)

	surfaceElements.buttons[110] = surface.makeButton(154, 33, 10, 10)
	surfaceElements.buttons[110].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 11)
	surfaceElements.labels[110] = surface.makeLabelField(154, 38, 10, 1)

	surfaceElements.buttons[111] = surface.makeButton(165, 33, 10, 10)
	surfaceElements.buttons[111].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 12)
	surfaceElements.labels[111] = surface.makeLabelField(165, 38, 10, 1)

	surfaceElements.buttons[112] = surface.makeButton(176, 33, 10, 10)
	surfaceElements.buttons[112].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 13)
	surfaceElements.labels[112] = surface.makeLabelField(176, 38, 10, 1)

	surfaceElements.buttons[113] = surface.makeButton(187, 33, 10, 10)
	surfaceElements.buttons[113].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 14)
	surfaceElements.labels[113] = surface.makeLabelField(187, 38, 10, 1)

	surfaceElements.buttons[114] = surface.makeButton(198, 33, 10, 10)
	surfaceElements.buttons[114].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 15)
	surfaceElements.labels[114] = surface.makeLabelField(198, 38, 10, 1)

	surfaceElements.buttons[115] = surface.makeButton(209, 33, 10, 10)
	surfaceElements.buttons[115].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 16)
	surfaceElements.labels[115] = surface.makeLabelField(209, 38, 10, 1)

	surfaceElements.buttons[116] = surface.makeButton(220, 33, 10, 10)
	surfaceElements.buttons[116].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 17)
	surfaceElements.labels[116] = surface.makeLabelField(220, 38, 10, 1)

	surfaceElements.buttons[117] = surface.makeButton(231, 33, 10, 10)
	surfaceElements.buttons[117].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 18)
	surfaceElements.labels[117] = surface.makeLabelField(231, 38, 10, 1)

	surfaceElements.buttons[118] = surface.makeButton(242, 33, 10, 10)
	surfaceElements.buttons[118].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 19)
	surfaceElements.labels[118] = surface.makeLabelField(242, 38, 10, 1)

	surfaceElements.buttons[119] = surface.makeButton(253, 33, 10, 10)
	surfaceElements.buttons[119].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 20)
	surfaceElements.labels[119] = surface.makeLabelField(253, 38, 10, 1)

	surfaceElements.buttons[120] = surface.makeButton(264, 33, 10, 10)
	surfaceElements.buttons[120].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 21)
	surfaceElements.labels[120] = surface.makeLabelField(264, 38, 10, 1)

	surfaceElements.buttons[121] = surface.makeButton(275, 33, 10, 10)
	surfaceElements.buttons[121].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 22)
	surfaceElements.labels[121] = surface.makeLabelField(275, 38, 10, 1)

	surfaceElements.buttons[122] = surface.makeButton(286, 33, 10, 10)
	surfaceElements.buttons[122].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 23)
	surfaceElements.labels[122] = surface.makeLabelField(286, 38, 10, 1)

	surfaceElements.buttons[123] = surface.makeButton(297, 33, 10, 10)
	surfaceElements.buttons[123].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 24)
	surfaceElements.labels[123] = surface.makeLabelField(297, 38, 10, 1)

	surfaceElements.buttons[124] = surface.makeButton(308, 33, 10, 10)
	surfaceElements.buttons[124].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 25)
	surfaceElements.labels[124] = surface.makeLabelField(308, 38, 10, 1)

	surfaceElements.buttons[125] = surface.makeButton(319, 33, 10, 10)
	surfaceElements.buttons[125].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 26)
	surfaceElements.labels[125] = surface.makeLabelField(319, 38, 10, 1)

	surfaceElements.buttons[126] = surface.makeButton(330, 33, 10, 10)
	surfaceElements.buttons[126].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 27)
	surfaceElements.labels[126] = surface.makeLabelField(330, 38, 10, 1)

	surfaceElements.buttons[127] = surface.makeButton(341, 33, 10, 10)
	surfaceElements.buttons[127].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 28)
	surfaceElements.labels[127] = surface.makeLabelField(341, 38, 10, 1)

	surfaceElements.buttons[128] = surface.makeButton(0, 44, 10, 10)
	surfaceElements.buttons[128].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 29)
	surfaceElements.labels[128] = surface.makeLabelField(0, 49, 10, 1)

	surfaceElements.buttons[129] = surface.makeButton(11, 44, 10, 10)
	surfaceElements.buttons[129].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 30)
	surfaceElements.labels[129] = surface.makeLabelField(11, 49, 10, 1)

	surfaceElements.buttons[130] = surface.makeButton(22, 44, 10, 10)
	surfaceElements.buttons[130].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 31)
	surfaceElements.labels[130] = surface.makeLabelField(22, 49, 10, 1)

	surfaceElements.buttons[131] = surface.makeButton(33, 44, 10, 10)
	surfaceElements.buttons[131].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 32)
	surfaceElements.labels[131] = surface.makeLabelField(33, 49, 10, 1)

	surfaceElements.buttons[132] = surface.makeButton(44, 44, 10, 10)
	surfaceElements.buttons[132].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 33)
	surfaceElements.labels[132] = surface.makeLabelField(44, 49, 10, 1)

	surfaceElements.buttons[133] = surface.makeButton(55, 44, 10, 10)
	surfaceElements.buttons[133].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 34)
	surfaceElements.labels[133] = surface.makeLabelField(55, 49, 10, 1)

	surfaceElements.buttons[134] = surface.makeButton(66, 44, 10, 10)
	surfaceElements.buttons[134].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 35)
	surfaceElements.labels[134] = surface.makeLabelField(66, 49, 10, 1)

	surfaceElements.buttons[135] = surface.makeButton(77, 44, 10, 10)
	surfaceElements.buttons[135].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 36)
	surfaceElements.labels[135] = surface.makeLabelField(77, 49, 10, 1)

	surfaceElements.buttons[136] = surface.makeButton(88, 44, 10, 10)
	surfaceElements.buttons[136].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 37)
	surfaceElements.labels[136] = surface.makeLabelField(88, 49, 10, 1)

	surfaceElements.buttons[137] = surface.makeButton(99, 44, 10, 10)
	surfaceElements.buttons[137].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 38)
	surfaceElements.labels[137] = surface.makeLabelField(99, 49, 10, 1)

	surfaceElements.buttons[138] = surface.makeButton(110, 44, 10, 10)
	surfaceElements.buttons[138].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 39)
	surfaceElements.labels[138] = surface.makeLabelField(110, 49, 10, 1)

	surfaceElements.buttons[139] = surface.makeButton(121, 44, 10, 10)
	surfaceElements.buttons[139].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 40)
	surfaceElements.labels[139] = surface.makeLabelField(121, 49, 10, 1)

	surfaceElements.buttons[140] = surface.makeButton(132, 44, 10, 10)
	surfaceElements.buttons[140].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 41)
	surfaceElements.labels[140] = surface.makeLabelField(132, 49, 10, 1)

	surfaceElements.buttons[141] = surface.makeButton(143, 44, 10, 10)
	surfaceElements.buttons[141].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 42)
	surfaceElements.labels[141] = surface.makeLabelField(143, 49, 10, 1)

	surfaceElements.buttons[142] = surface.makeButton(154, 44, 10, 10)
	surfaceElements.buttons[142].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 43)
	surfaceElements.labels[142] = surface.makeLabelField(154, 49, 10, 1)

	surfaceElements.buttons[143] = surface.makeButton(165, 44, 10, 10)
	surfaceElements.buttons[143].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 44)
	surfaceElements.labels[143] = surface.makeLabelField(165, 49, 10, 1)

	surfaceElements.buttons[144] = surface.makeButton(176, 44, 10, 10)
	surfaceElements.buttons[144].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 45)
	surfaceElements.labels[144] = surface.makeLabelField(176, 49, 10, 1)

	surfaceElements.buttons[145] = surface.makeButton(187, 44, 10, 10)
	surfaceElements.buttons[145].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 46)
	surfaceElements.labels[145] = surface.makeLabelField(187, 49, 10, 1)

	surfaceElements.buttons[146] = surface.makeButton(198, 44, 10, 10)
	surfaceElements.buttons[146].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 47)
	surfaceElements.labels[146] = surface.makeLabelField(198, 49, 10, 1)

	surfaceElements.buttons[147] = surface.makeButton(209, 44, 10, 10)
	surfaceElements.buttons[147].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 48)
	surfaceElements.labels[147] = surface.makeLabelField(209, 49, 10, 1)

	surfaceElements.buttons[148] = surface.makeButton(220, 44, 10, 10)
	surfaceElements.buttons[148].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 49)
	surfaceElements.labels[148] = surface.makeLabelField(220, 49, 10, 1)

	surfaceElements.buttons[149] = surface.makeButton(231, 44, 10, 10)
	surfaceElements.buttons[149].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 50)
	surfaceElements.labels[149] = surface.makeLabelField(231, 49, 10, 1)

	surfaceElements.buttons[150] = surface.makeButton(242, 44, 10, 10)
	surfaceElements.buttons[150].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 51)
	surfaceElements.labels[150] = surface.makeLabelField(242, 49, 10, 1)

	surfaceElements.buttons[151] = surface.makeButton(253, 44, 10, 10)
	surfaceElements.buttons[151].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 52)
	surfaceElements.labels[151] = surface.makeLabelField(253, 49, 10, 1)

	surfaceElements.buttons[152] = surface.makeButton(264, 44, 10, 10)
	surfaceElements.buttons[152].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 53)
	surfaceElements.labels[152] = surface.makeLabelField(264, 49, 10, 1)

	surfaceElements.buttons[153] = surface.makeButton(275, 44, 10, 10)
	surfaceElements.buttons[153].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 54)
	surfaceElements.labels[153] = surface.makeLabelField(275, 49, 10, 1)

	surfaceElements.buttons[154] = surface.makeButton(286, 44, 10, 10)
	surfaceElements.buttons[154].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 55)
	surfaceElements.labels[154] = surface.makeLabelField(286, 49, 10, 1)

	surfaceElements.buttons[155] = surface.makeButton(297, 44, 10, 10)
	surfaceElements.buttons[155].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 56)
	surfaceElements.labels[155] = surface.makeLabelField(297, 49, 10, 1)

	surfaceElements.buttons[156] = surface.makeButton(308, 44, 10, 10)
	surfaceElements.buttons[156].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 57)
	surfaceElements.labels[156] = surface.makeLabelField(308, 49, 10, 1)

	surfaceElements.buttons[157] = surface.makeButton(319, 44, 10, 10)
	surfaceElements.buttons[157].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 58)
	surfaceElements.labels[157] = surface.makeLabelField(319, 49, 10, 1)

	surfaceElements.buttons[158] = surface.makeButton(330, 44, 10, 10)
	surfaceElements.buttons[158].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 59)
	surfaceElements.labels[158] = surface.makeLabelField(330, 49, 10, 1)

	surfaceElements.buttons[159] = surface.makeButton(341, 44, 10, 10)
	surfaceElements.buttons[159].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 60)
	surfaceElements.labels[159] = surface.makeLabelField(341, 49, 10, 1)

	surfaceElements.buttons[160] = surface.makeButton(0, 55, 10, 10)
	surfaceElements.buttons[160].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 61)
	surfaceElements.labels[160] = surface.makeLabelField(0, 60, 10, 1)

	surfaceElements.buttons[161] = surface.makeButton(11, 55, 10, 10)
	surfaceElements.buttons[161].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 62)
	surfaceElements.labels[161] = surface.makeLabelField(11, 60, 10, 1)

	surfaceElements.buttons[162] = surface.makeButton(22, 55, 10, 10)
	surfaceElements.buttons[162].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 63)
	surfaceElements.labels[162] = surface.makeLabelField(22, 60, 10, 1)

	surfaceElements.buttons[163] = surface.makeButton(33, 55, 10, 10)
	surfaceElements.buttons[163].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 64)
	surfaceElements.labels[163] = surface.makeLabelField(33, 60, 10, 1)

	surfaceElements.buttons[164] = surface.makeButton(44, 55, 10, 10)
	surfaceElements.buttons[164].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 65)
	surfaceElements.labels[164] = surface.makeLabelField(44, 60, 10, 1)

	surfaceElements.buttons[165] = surface.makeButton(55, 55, 10, 10)
	surfaceElements.buttons[165].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 66)
	surfaceElements.labels[165] = surface.makeLabelField(55, 60, 10, 1)

	surfaceElements.buttons[166] = surface.makeButton(66, 55, 10, 10)
	surfaceElements.buttons[166].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 67)
	surfaceElements.labels[166] = surface.makeLabelField(66, 60, 10, 1)

	surfaceElements.buttons[167] = surface.makeButton(77, 55, 10, 10)
	surfaceElements.buttons[167].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 68)
	surfaceElements.labels[167] = surface.makeLabelField(77, 60, 10, 1)

	surfaceElements.buttons[168] = surface.makeButton(88, 55, 10, 10)
	surfaceElements.buttons[168].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 69)
	surfaceElements.labels[168] = surface.makeLabelField(88, 60, 10, 1)

	surfaceElements.buttons[169] = surface.makeButton(99, 55, 10, 10)
	surfaceElements.buttons[169].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 70)
	surfaceElements.labels[169] = surface.makeLabelField(99, 60, 10, 1)

	surfaceElements.buttons[170] = surface.makeButton(110, 55, 10, 10)
	surfaceElements.buttons[170].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 71)
	surfaceElements.labels[170] = surface.makeLabelField(110, 60, 10, 1)

	surfaceElements.buttons[171] = surface.makeButton(121, 55, 10, 10)
	surfaceElements.buttons[171].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 72)
	surfaceElements.labels[171] = surface.makeLabelField(121, 60, 10, 1)

	surfaceElements.buttons[172] = surface.makeButton(132, 55, 10, 10)
	surfaceElements.buttons[172].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 73)
	surfaceElements.labels[172] = surface.makeLabelField(132, 60, 10, 1)

	surfaceElements.buttons[173] = surface.makeButton(143, 55, 10, 10)
	surfaceElements.buttons[173].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 74)
	surfaceElements.labels[173] = surface.makeLabelField(143, 60, 10, 1)

	surfaceElements.buttons[174] = surface.makeButton(154, 55, 10, 10)
	surfaceElements.buttons[174].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 75)
	surfaceElements.labels[174] = surface.makeLabelField(154, 60, 10, 1)

	surfaceElements.buttons[175] = surface.makeButton(165, 55, 10, 10)
	surfaceElements.buttons[175].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 76)
	surfaceElements.labels[175] = surface.makeLabelField(165, 60, 10, 1)

	surfaceElements.buttons[176] = surface.makeButton(176, 55, 10, 10)
	surfaceElements.buttons[176].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 77)
	surfaceElements.labels[176] = surface.makeLabelField(176, 60, 10, 1)

	surfaceElements.buttons[177] = surface.makeButton(187, 55, 10, 10)
	surfaceElements.buttons[177].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 78)
	surfaceElements.labels[177] = surface.makeLabelField(187, 60, 10, 1)

	surfaceElements.buttons[178] = surface.makeButton(198, 55, 10, 10)
	surfaceElements.buttons[178].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 79)
	surfaceElements.labels[178] = surface.makeLabelField(198, 60, 10, 1)

	surfaceElements.buttons[179] = surface.makeButton(209, 55, 10, 10)
	surfaceElements.buttons[179].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 80)
	surfaceElements.labels[179] = surface.makeLabelField(209, 60, 10, 1)

	surfaceElements.buttons[180] = surface.makeButton(220, 55, 10, 10)
	surfaceElements.buttons[180].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 81)
	surfaceElements.labels[180] = surface.makeLabelField(220, 60, 10, 1)

	surfaceElements.buttons[181] = surface.makeButton(231, 55, 10, 10)
	surfaceElements.buttons[181].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 82)
	surfaceElements.labels[181] = surface.makeLabelField(231, 60, 10, 1)

	surfaceElements.buttons[182] = surface.makeButton(242, 55, 10, 10)
	surfaceElements.buttons[182].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 83)
	surfaceElements.labels[182] = surface.makeLabelField(242, 60, 10, 1)

	surfaceElements.buttons[183] = surface.makeButton(253, 55, 10, 10)
	surfaceElements.buttons[183].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 84)
	surfaceElements.labels[183] = surface.makeLabelField(253, 60, 10, 1)

	surfaceElements.buttons[184] = surface.makeButton(264, 55, 10, 10)
	surfaceElements.buttons[184].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 85)
	surfaceElements.labels[184] = surface.makeLabelField(264, 60, 10, 1)

	surfaceElements.buttons[185] = surface.makeButton(275, 55, 10, 10)
	surfaceElements.buttons[185].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 86)
	surfaceElements.labels[185] = surface.makeLabelField(275, 60, 10, 1)

	surfaceElements.buttons[186] = surface.makeButton(286, 55, 10, 10)
	surfaceElements.buttons[186].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 87)
	surfaceElements.labels[186] = surface.makeLabelField(286, 60, 10, 1)

	surfaceElements.buttons[187] = surface.makeButton(297, 55, 10, 10)
	surfaceElements.buttons[187].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 88)
	surfaceElements.labels[187] = surface.makeLabelField(297, 60, 10, 1)

	surfaceElements.buttons[188] = surface.makeButton(308, 55, 10, 10)
	surfaceElements.buttons[188].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 89)
	surfaceElements.labels[188] = surface.makeLabelField(308, 60, 10, 1)

	surfaceElements.buttons[189] = surface.makeButton(319, 55, 10, 10)
	surfaceElements.buttons[189].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 90)
	surfaceElements.labels[189] = surface.makeLabelField(319, 60, 10, 1)

	surfaceElements.buttons[190] = surface.makeButton(330, 55, 10, 10)
	surfaceElements.buttons[190].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 91)
	surfaceElements.labels[190] = surface.makeLabelField(330, 60, 10, 1)

	surfaceElements.buttons[191] = surface.makeButton(341, 55, 10, 10)
	surfaceElements.buttons[191].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 92)
	surfaceElements.labels[191] = surface.makeLabelField(341, 60, 10, 1)

	surfaceElements.buttons[192] = surface.makeButton(0, 66, 10, 10)
	surfaceElements.buttons[192].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 93)
	surfaceElements.labels[192] = surface.makeLabelField(0, 71, 10, 1)

	surfaceElements.buttons[193] = surface.makeButton(11, 66, 10, 10)
	surfaceElements.buttons[193].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 94)
	surfaceElements.labels[193] = surface.makeLabelField(11, 71, 10, 1)

	surfaceElements.buttons[194] = surface.makeButton(22, 66, 10, 10)
	surfaceElements.buttons[194].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 95)
	surfaceElements.labels[194] = surface.makeLabelField(22, 71, 10, 1)

	surfaceElements.buttons[195] = surface.makeButton(33, 66, 10, 10)
	surfaceElements.buttons[195].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 96)
	surfaceElements.labels[195] = surface.makeLabelField(33, 71, 10, 1)

	surfaceElements.buttons[196] = surface.makeButton(44, 66, 10, 10)
	surfaceElements.buttons[196].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 97)
	surfaceElements.labels[196] = surface.makeLabelField(44, 71, 10, 1)

	surfaceElements.buttons[197] = surface.makeButton(55, 66, 10, 10)
	surfaceElements.buttons[197].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 98)
	surfaceElements.labels[197] = surface.makeLabelField(55, 71, 10, 1)

	surfaceElements.buttons[198] = surface.makeButton(66, 66, 10, 10)
	surfaceElements.buttons[198].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 99)
	surfaceElements.labels[198] = surface.makeLabelField(66, 71, 10, 1)

	surfaceElements.buttons[199] = surface.makeButton(77, 66, 10, 10)
	surfaceElements.buttons[199].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 100)
	surfaceElements.labels[199] = surface.makeLabelField(77, 71, 10, 1)

	surfaceElements.buttons[200] = surface.makeButton(88, 66, 10, 10)
	surfaceElements.buttons[200].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 11)
	surfaceElements.labels[200] = surface.makeLabelField(88, 71, 10, 1)

	surfaceElements.buttons[201] = surface.makeButton(99, 66, 10, 10)
	surfaceElements.buttons[201].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 12)
	surfaceElements.labels[201] = surface.makeLabelField(99, 71, 10, 1)

	surfaceElements.buttons[202] = surface.makeButton(110, 66, 10, 10)
	surfaceElements.buttons[202].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 13)
	surfaceElements.labels[202] = surface.makeLabelField(110, 71, 10, 1)

	surfaceElements.buttons[203] = surface.makeButton(121, 66, 10, 10)
	surfaceElements.buttons[203].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 14)
	surfaceElements.labels[203] = surface.makeLabelField(121, 71, 10, 1)

	surfaceElements.buttons[204] = surface.makeButton(132, 66, 10, 10)
	surfaceElements.buttons[204].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 15)
	surfaceElements.labels[204] = surface.makeLabelField(132, 71, 10, 1)

	surfaceElements.buttons[205] = surface.makeButton(143, 66, 10, 10)
	surfaceElements.buttons[205].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 16)
	surfaceElements.labels[205] = surface.makeLabelField(143, 71, 10, 1)

	surfaceElements.buttons[206] = surface.makeButton(154, 66, 10, 10)
	surfaceElements.buttons[206].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 17)
	surfaceElements.labels[206] = surface.makeLabelField(154, 71, 10, 1)

	surfaceElements.buttons[207] = surface.makeButton(165, 66, 10, 10)
	surfaceElements.buttons[207].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 18)
	surfaceElements.labels[207] = surface.makeLabelField(165, 71, 10, 1)

	surfaceElements.buttons[208] = surface.makeButton(176, 66, 10, 10)
	surfaceElements.buttons[208].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 19)
	surfaceElements.labels[208] = surface.makeLabelField(176, 71, 10, 1)

	surfaceElements.buttons[209] = surface.makeButton(187, 66, 10, 10)
	surfaceElements.buttons[209].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 20)
	surfaceElements.labels[209] = surface.makeLabelField(187, 71, 10, 1)

	surfaceElements.buttons[210] = surface.makeButton(198, 66, 10, 10)
	surfaceElements.buttons[210].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 21)
	surfaceElements.labels[210] = surface.makeLabelField(198, 71, 10, 1)

	surfaceElements.buttons[211] = surface.makeButton(209, 66, 10, 10)
	surfaceElements.buttons[211].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 22)
	surfaceElements.labels[211] = surface.makeLabelField(209, 71, 10, 1)

	surfaceElements.buttons[212] = surface.makeButton(220, 66, 10, 10)
	surfaceElements.buttons[212].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 23)
	surfaceElements.labels[212] = surface.makeLabelField(220, 71, 10, 1)

	surfaceElements.buttons[213] = surface.makeButton(231, 66, 10, 10)
	surfaceElements.buttons[213].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 24)
	surfaceElements.labels[213] = surface.makeLabelField(231, 71, 10, 1)

	surfaceElements.buttons[214] = surface.makeButton(242, 66, 10, 10)
	surfaceElements.buttons[214].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 25)
	surfaceElements.labels[214] = surface.makeLabelField(242, 71, 10, 1)

	surfaceElements.buttons[215] = surface.makeButton(253, 66, 10, 10)
	surfaceElements.buttons[215].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 26)
	surfaceElements.labels[215] = surface.makeLabelField(253, 71, 10, 1)

	surfaceElements.buttons[216] = surface.makeButton(264, 66, 10, 10)
	surfaceElements.buttons[216].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 27)
	surfaceElements.labels[216] = surface.makeLabelField(264, 71, 10, 1)

	surfaceElements.buttons[217] = surface.makeButton(275, 66, 10, 10)
	surfaceElements.buttons[217].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 28)
	surfaceElements.labels[217] = surface.makeLabelField(275, 71, 10, 1)

	surfaceElements.buttons[218] = surface.makeButton(286, 66, 10, 10)
	surfaceElements.buttons[218].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 29)
	surfaceElements.labels[218] = surface.makeLabelField(286, 71, 10, 1)

	surfaceElements.buttons[219] = surface.makeButton(297, 66, 10, 10)
	surfaceElements.buttons[219].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 30)
	surfaceElements.labels[219] = surface.makeLabelField(297, 71, 10, 1)

	surfaceElements.buttons[220] = surface.makeButton(308, 66, 10, 10)
	surfaceElements.buttons[220].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 31)
	surfaceElements.labels[220] = surface.makeLabelField(308, 71, 10, 1)

	surfaceElements.buttons[221] = surface.makeButton(319, 66, 10, 10)
	surfaceElements.buttons[221].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 32)
	surfaceElements.labels[221] = surface.makeLabelField(319, 71, 10, 1)

	surfaceElements.buttons[222] = surface.makeButton(330, 66, 10, 10)
	surfaceElements.buttons[222].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 33)
	surfaceElements.labels[222] = surface.makeLabelField(330, 71, 10, 1)

	surfaceElements.buttons[223] = surface.makeButton(341, 66, 10, 10)
	surfaceElements.buttons[223].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 34)
	surfaceElements.labels[223] = surface.makeLabelField(341, 71, 10, 1)

	surfaceElements.buttons[224] = surface.makeButton(0, 77, 10, 10)
	surfaceElements.buttons[224].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 35)
	surfaceElements.labels[224] = surface.makeLabelField(0, 82, 10, 1)

	surfaceElements.buttons[225] = surface.makeButton(11, 77, 10, 10)
	surfaceElements.buttons[225].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 36)
	surfaceElements.labels[225] = surface.makeLabelField(11, 82, 10, 1)

	surfaceElements.buttons[226] = surface.makeButton(22, 77, 10, 10)
	surfaceElements.buttons[226].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 37)
	surfaceElements.labels[226] = surface.makeLabelField(22, 82, 10, 1)

	surfaceElements.buttons[227] = surface.makeButton(33, 77, 10, 10)
	surfaceElements.buttons[227].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 38)
	surfaceElements.labels[227] = surface.makeLabelField(33, 82, 10, 1)

	surfaceElements.buttons[228] = surface.makeButton(44, 77, 10, 10)
	surfaceElements.buttons[228].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 39)
	surfaceElements.labels[228] = surface.makeLabelField(44, 82, 10, 1)

	surfaceElements.buttons[229] = surface.makeButton(55, 77, 10, 10)
	surfaceElements.buttons[229].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 40)
	surfaceElements.labels[229] = surface.makeLabelField(55, 82, 10, 1)

	surfaceElements.buttons[230] = surface.makeButton(66, 77, 10, 10)
	surfaceElements.buttons[230].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 41)
	surfaceElements.labels[230] = surface.makeLabelField(66, 82, 10, 1)

	surfaceElements.buttons[231] = surface.makeButton(77, 77, 10, 10)
	surfaceElements.buttons[231].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 42)
	surfaceElements.labels[231] = surface.makeLabelField(77, 82, 10, 1)

	surfaceElements.buttons[232] = surface.makeButton(88, 77, 10, 10)
	surfaceElements.buttons[232].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 43)
	surfaceElements.labels[232] = surface.makeLabelField(88, 82, 10, 1)

	surfaceElements.buttons[233] = surface.makeButton(99, 77, 10, 10)
	surfaceElements.buttons[233].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 44)
	surfaceElements.labels[233] = surface.makeLabelField(99, 82, 10, 1)

	surfaceElements.buttons[234] = surface.makeButton(110, 77, 10, 10)
	surfaceElements.buttons[234].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 45)
	surfaceElements.labels[234] = surface.makeLabelField(110, 82, 10, 1)

	surfaceElements.buttons[235] = surface.makeButton(121, 77, 10, 10)
	surfaceElements.buttons[235].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 46)
	surfaceElements.labels[235] = surface.makeLabelField(121, 82, 10, 1)

	surfaceElements.buttons[236] = surface.makeButton(132, 77, 10, 10)
	surfaceElements.buttons[236].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 47)
	surfaceElements.labels[236] = surface.makeLabelField(132, 82, 10, 1)

	surfaceElements.buttons[237] = surface.makeButton(143, 77, 10, 10)
	surfaceElements.buttons[237].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 48)
	surfaceElements.labels[237] = surface.makeLabelField(143, 82, 10, 1)

	surfaceElements.buttons[238] = surface.makeButton(154, 77, 10, 10)
	surfaceElements.buttons[238].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 49)
	surfaceElements.labels[238] = surface.makeLabelField(154, 82, 10, 1)

	surfaceElements.buttons[239] = surface.makeButton(165, 77, 10, 10)
	surfaceElements.buttons[239].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 50)
	surfaceElements.labels[239] = surface.makeLabelField(165, 82, 10, 1)

	surfaceElements.buttons[240] = surface.makeButton(176, 77, 10, 10)
	surfaceElements.buttons[240].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 51)
	surfaceElements.labels[240] = surface.makeLabelField(176, 82, 10, 1)

	surfaceElements.buttons[241] = surface.makeButton(187, 77, 10, 10)
	surfaceElements.buttons[241].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 52)
	surfaceElements.labels[241] = surface.makeLabelField(187, 82, 10, 1)

	surfaceElements.buttons[242] = surface.makeButton(198, 77, 10, 10)
	surfaceElements.buttons[242].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 53)
	surfaceElements.labels[242] = surface.makeLabelField(198, 82, 10, 1)

	surfaceElements.buttons[243] = surface.makeButton(209, 77, 10, 10)
	surfaceElements.buttons[243].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 54)
	surfaceElements.labels[243] = surface.makeLabelField(209, 82, 10, 1)

	surfaceElements.buttons[244] = surface.makeButton(220, 77, 10, 10)
	surfaceElements.buttons[244].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 55)
	surfaceElements.labels[244] = surface.makeLabelField(220, 82, 10, 1)

	surfaceElements.buttons[245] = surface.makeButton(231, 77, 10, 10)
	surfaceElements.buttons[245].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 56)
	surfaceElements.labels[245] = surface.makeLabelField(231, 82, 10, 1)

	surfaceElements.buttons[246] = surface.makeButton(242, 77, 10, 10)
	surfaceElements.buttons[246].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 57)
	surfaceElements.labels[246] = surface.makeLabelField(242, 82, 10, 1)

	surfaceElements.buttons[247] = surface.makeButton(253, 77, 10, 10)
	surfaceElements.buttons[247].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 58)
	surfaceElements.labels[247] = surface.makeLabelField(253, 82, 10, 1)

	surfaceElements.buttons[248] = surface.makeButton(264, 77, 10, 10)
	surfaceElements.buttons[248].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 59)
	surfaceElements.labels[248] = surface.makeLabelField(264, 82, 10, 1)

	surfaceElements.buttons[249] = surface.makeButton(275, 77, 10, 10)
	surfaceElements.buttons[249].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 60)
	surfaceElements.labels[249] = surface.makeLabelField(275, 82, 10, 1)

	surfaceElements.buttons[250] = surface.makeButton(286, 77, 10, 10)
	surfaceElements.buttons[250].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 61)
	surfaceElements.labels[250] = surface.makeLabelField(286, 82, 10, 1)

	surfaceElements.buttons[251] = surface.makeButton(297, 77, 10, 10)
	surfaceElements.buttons[251].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 62)
	surfaceElements.labels[251] = surface.makeLabelField(297, 82, 10, 1)

	surfaceElements.buttons[252] = surface.makeButton(308, 77, 10, 10)
	surfaceElements.buttons[252].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 63)
	surfaceElements.labels[252] = surface.makeLabelField(308, 82, 10, 1)

	surfaceElements.buttons[253] = surface.makeButton(319, 77, 10, 10)
	surfaceElements.buttons[253].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 64)
	surfaceElements.labels[253] = surface.makeLabelField(319, 82, 10, 1)

	surfaceElements.buttons[254] = surface.makeButton(330, 77, 10, 10)
	surfaceElements.buttons[254].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 65)
	surfaceElements.labels[254] = surface.makeLabelField(330, 82, 10, 1)

	surfaceElements.buttons[255] = surface.makeButton(341, 77, 10, 10)
	surfaceElements.buttons[255].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 66)
	surfaceElements.labels[255] = surface.makeLabelField(341, 82, 10, 1)

	surfaceElements.buttons[256] = surface.makeButton(0, 88, 10, 10)
	surfaceElements.buttons[256].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 67)
	surfaceElements.labels[256] = surface.makeLabelField(0, 93, 10, 1)

	surfaceElements.buttons[257] = surface.makeButton(11, 88, 10, 10)
	surfaceElements.buttons[257].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 68)
	surfaceElements.labels[257] = surface.makeLabelField(11, 93, 10, 1)

	surfaceElements.buttons[258] = surface.makeButton(22, 88, 10, 10)
	surfaceElements.buttons[258].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 69)
	surfaceElements.labels[258] = surface.makeLabelField(22, 93, 10, 1)

	surfaceElements.buttons[259] = surface.makeButton(33, 88, 10, 10)
	surfaceElements.buttons[259].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 70)
	surfaceElements.labels[259] = surface.makeLabelField(33, 93, 10, 1)

	surfaceElements.buttons[260] = surface.makeButton(44, 88, 10, 10)
	surfaceElements.buttons[260].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 71)
	surfaceElements.labels[260] = surface.makeLabelField(44, 93, 10, 1)

	surfaceElements.buttons[261] = surface.makeButton(55, 88, 10, 10)
	surfaceElements.buttons[261].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 72)
	surfaceElements.labels[261] = surface.makeLabelField(55, 93, 10, 1)

	surfaceElements.buttons[262] = surface.makeButton(66, 88, 10, 10)
	surfaceElements.buttons[262].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 73)
	surfaceElements.labels[262] = surface.makeLabelField(66, 93, 10, 1)

	surfaceElements.buttons[263] = surface.makeButton(77, 88, 10, 10)
	surfaceElements.buttons[263].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 74)
	surfaceElements.labels[263] = surface.makeLabelField(77, 93, 10, 1)

	surfaceElements.buttons[264] = surface.makeButton(88, 88, 10, 10)
	surfaceElements.buttons[264].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 75)
	surfaceElements.labels[264] = surface.makeLabelField(88, 93, 10, 1)

	surfaceElements.buttons[265] = surface.makeButton(99, 88, 10, 10)
	surfaceElements.buttons[265].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 76)
	surfaceElements.labels[265] = surface.makeLabelField(99, 93, 10, 1)

	surfaceElements.buttons[266] = surface.makeButton(110, 88, 10, 10)
	surfaceElements.buttons[266].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 77)
	surfaceElements.labels[266] = surface.makeLabelField(110, 93, 10, 1)

	surfaceElements.buttons[267] = surface.makeButton(121, 88, 10, 10)
	surfaceElements.buttons[267].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 78)
	surfaceElements.labels[267] = surface.makeLabelField(121, 93, 10, 1)

	surfaceElements.buttons[268] = surface.makeButton(132, 88, 10, 10)
	surfaceElements.buttons[268].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 79)
	surfaceElements.labels[268] = surface.makeLabelField(132, 93, 10, 1)

	surfaceElements.buttons[269] = surface.makeButton(143, 88, 10, 10)
	surfaceElements.buttons[269].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 80)
	surfaceElements.labels[269] = surface.makeLabelField(143, 93, 10, 1)

	surfaceElements.buttons[270] = surface.makeButton(154, 88, 10, 10)
	surfaceElements.buttons[270].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 81)
	surfaceElements.labels[270] = surface.makeLabelField(154, 93, 10, 1)

	surfaceElements.buttons[271] = surface.makeButton(165, 88, 10, 10)
	surfaceElements.buttons[271].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 82)
	surfaceElements.labels[271] = surface.makeLabelField(165, 93, 10, 1)

	surfaceElements.buttons[272] = surface.makeButton(176, 88, 10, 10)
	surfaceElements.buttons[272].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 83)
	surfaceElements.labels[272] = surface.makeLabelField(176, 93, 10, 1)

	surfaceElements.buttons[273] = surface.makeButton(187, 88, 10, 10)
	surfaceElements.buttons[273].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 84)
	surfaceElements.labels[273] = surface.makeLabelField(187, 93, 10, 1)

	surfaceElements.buttons[274] = surface.makeButton(198, 88, 10, 10)
	surfaceElements.buttons[274].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 85)
	surfaceElements.labels[274] = surface.makeLabelField(198, 93, 10, 1)

	surfaceElements.buttons[275] = surface.makeButton(209, 88, 10, 10)
	surfaceElements.buttons[275].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 86)
	surfaceElements.labels[275] = surface.makeLabelField(209, 93, 10, 1)

	surfaceElements.buttons[276] = surface.makeButton(220, 88, 10, 10)
	surfaceElements.buttons[276].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 87)
	surfaceElements.labels[276] = surface.makeLabelField(220, 93, 10, 1)

	surfaceElements.buttons[277] = surface.makeButton(231, 88, 10, 10)
	surfaceElements.buttons[277].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 88)
	surfaceElements.labels[277] = surface.makeLabelField(231, 93, 10, 1)

	surfaceElements.buttons[278] = surface.makeButton(242, 88, 10, 10)
	surfaceElements.buttons[278].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 89)
	surfaceElements.labels[278] = surface.makeLabelField(242, 93, 10, 1)

	surfaceElements.buttons[279] = surface.makeButton(253, 88, 10, 10)
	surfaceElements.buttons[279].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 90)
	surfaceElements.labels[279] = surface.makeLabelField(253, 93, 10, 1)

	surfaceElements.buttons[280] = surface.makeButton(264, 88, 10, 10)
	surfaceElements.buttons[280].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 91)
	surfaceElements.labels[280] = surface.makeLabelField(264, 93, 10, 1)

	surfaceElements.buttons[281] = surface.makeButton(275, 88, 10, 10)
	surfaceElements.buttons[281].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 92)
	surfaceElements.labels[281] = surface.makeLabelField(275, 93, 10, 1)

	surfaceElements.buttons[282] = surface.makeButton(286, 88, 10, 10)
	surfaceElements.buttons[282].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 93)
	surfaceElements.labels[282] = surface.makeLabelField(286, 93, 10, 1)

	surfaceElements.buttons[283] = surface.makeButton(297, 88, 10, 10)
	surfaceElements.buttons[283].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 94)
	surfaceElements.labels[283] = surface.makeLabelField(297, 93, 10, 1)

	surfaceElements.buttons[284] = surface.makeButton(308, 88, 10, 10)
	surfaceElements.buttons[284].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 95)
	surfaceElements.labels[284] = surface.makeLabelField(308, 93, 10, 1)

	surfaceElements.buttons[285] = surface.makeButton(319, 88, 10, 10)
	surfaceElements.buttons[285].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 96)
	surfaceElements.labels[285] = surface.makeLabelField(319, 93, 10, 1)

	surfaceElements.buttons[286] = surface.makeButton(330, 88, 10, 10)
	surfaceElements.buttons[286].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 97)
	surfaceElements.labels[286] = surface.makeLabelField(330, 93, 10, 1)

	surfaceElements.buttons[287] = surface.makeButton(341, 88, 10, 10)
	surfaceElements.buttons[287].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 98)
	surfaceElements.labels[287] = surface.makeLabelField(341, 93, 10, 1)

	surfaceElements.buttons[288] = surface.makeButton(0, 99, 10, 10)
	surfaceElements.buttons[288].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 99)
	surfaceElements.labels[288] = surface.makeLabelField(0, 104, 10, 1)

	surfaceElements.buttons[289] = surface.makeButton(11, 99, 10, 10)
	surfaceElements.buttons[289].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 100)
	surfaceElements.labels[289] = surface.makeLabelField(11, 104, 10, 1)

	surfaceElements.buttons[290] = surface.makeButton(22, 99, 10, 10)
	surfaceElements.buttons[290].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 101)
	surfaceElements.labels[290] = surface.makeLabelField(22, 104, 10, 1)

	surfaceElements.buttons[291] = surface.makeButton(33, 99, 10, 10)
	surfaceElements.buttons[291].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 102)
	surfaceElements.labels[291] = surface.makeLabelField(33, 104, 10, 1)

	surfaceElements.buttons[292] = surface.makeButton(44, 99, 10, 10)
	surfaceElements.buttons[292].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 103)
	surfaceElements.labels[292] = surface.makeLabelField(44, 104, 10, 1)

	surfaceElements.buttons[293] = surface.makeButton(55, 99, 10, 10)
	surfaceElements.buttons[293].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 104)
	surfaceElements.labels[293] = surface.makeLabelField(55, 104, 10, 1)

	surfaceElements.buttons[294] = surface.makeButton(66, 99, 10, 10)
	surfaceElements.buttons[294].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 105)
	surfaceElements.labels[294] = surface.makeLabelField(66, 104, 10, 1)

	surfaceElements.buttons[295] = surface.makeButton(77, 99, 10, 10)
	surfaceElements.buttons[295].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 106)
	surfaceElements.labels[295] = surface.makeLabelField(77, 104, 10, 1)

	surfaceElements.buttons[296] = surface.makeButton(88, 99, 10, 10)
	surfaceElements.buttons[296].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 107)
	surfaceElements.labels[296] = surface.makeLabelField(88, 104, 10, 1)

	surfaceElements.buttons[297] = surface.makeButton(99, 99, 10, 10)
	surfaceElements.buttons[297].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 108)
	surfaceElements.labels[297] = surface.makeLabelField(99, 104, 10, 1)

	surfaceElements.buttons[298] = surface.makeButton(110, 99, 10, 10)
	surfaceElements.buttons[298].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 109)
	surfaceElements.labels[298] = surface.makeLabelField(110, 104, 10, 1)

	surfaceElements.buttons[299] = surface.makeButton(121, 99, 10, 10)
	surfaceElements.buttons[299].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 110)
	surfaceElements.labels[299] = surface.makeLabelField(121, 104, 10, 1)

	surfaceElements.buttons[300] = surface.makeButton(132, 99, 10, 10)
	surfaceElements.buttons[300].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 9)
	surfaceElements.labels[300] = surface.makeLabelField(132, 104, 10, 1)

	surfaceElements.buttons[301] = surface.makeButton(143, 99, 10, 10)
	surfaceElements.buttons[301].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 10)
	surfaceElements.labels[301] = surface.makeLabelField(143, 104, 10, 1)

	surfaceElements.buttons[302] = surface.makeButton(154, 99, 10, 10)
	surfaceElements.buttons[302].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 101)
	surfaceElements.labels[302] = surface.makeLabelField(154, 104, 10, 1)

	surfaceElements.buttons[303] = surface.makeButton(165, 99, 10, 10)
	surfaceElements.buttons[303].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 102)
	surfaceElements.labels[303] = surface.makeLabelField(165, 104, 10, 1)

	surfaceElements.buttons[304] = surface.makeButton(176, 99, 10, 10)
	surfaceElements.buttons[304].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 103)
	surfaceElements.labels[304] = surface.makeLabelField(176, 104, 10, 1)

	surfaceElements.buttons[305] = surface.makeButton(187, 99, 10, 10)
	surfaceElements.buttons[305].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 104)
	surfaceElements.labels[305] = surface.makeLabelField(187, 104, 10, 1)

	surfaceElements.buttons[306] = surface.makeButton(198, 99, 10, 10)
	surfaceElements.buttons[306].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 105)
	surfaceElements.labels[306] = surface.makeLabelField(198, 104, 10, 1)

	surfaceElements.buttons[307] = surface.makeButton(209, 99, 10, 10)
	surfaceElements.buttons[307].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 106)
	surfaceElements.labels[307] = surface.makeLabelField(209, 104, 10, 1)

	surfaceElements.buttons[308] = surface.makeButton(220, 99, 10, 10)
	surfaceElements.buttons[308].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 107)
	surfaceElements.labels[308] = surface.makeLabelField(220, 104, 10, 1)

	surfaceElements.buttons[309] = surface.makeButton(231, 99, 10, 10)
	surfaceElements.buttons[309].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 108)
	surfaceElements.labels[309] = surface.makeLabelField(231, 104, 10, 1)

	surfaceElements.buttons[310] = surface.makeButton(242, 99, 10, 10)
	surfaceElements.buttons[310].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 109)
	surfaceElements.labels[310] = surface.makeLabelField(242, 104, 10, 1)

	surfaceElements.buttons[311] = surface.makeButton(253, 99, 10, 10)
	surfaceElements.buttons[311].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 110)
	surfaceElements.labels[311] = surface.makeLabelField(253, 104, 10, 1)

	surfaceElements.buttons[312] = surface.makeButton(264, 99, 10, 10)
	surfaceElements.buttons[312].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 111)
	surfaceElements.labels[312] = surface.makeLabelField(264, 104, 10, 1)

	surfaceElements.buttons[313] = surface.makeButton(275, 99, 10, 10)
	surfaceElements.buttons[313].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 112)
	surfaceElements.labels[313] = surface.makeLabelField(275, 104, 10, 1)

	surfaceElements.buttons[314] = surface.makeButton(286, 99, 10, 10)
	surfaceElements.buttons[314].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 113)
	surfaceElements.labels[314] = surface.makeLabelField(286, 104, 10, 1)

	surfaceElements.buttons[315] = surface.makeButton(297, 99, 10, 10)
	surfaceElements.buttons[315].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 114)
	surfaceElements.labels[315] = surface.makeLabelField(297, 104, 10, 1)

	surfaceElements.buttons[316] = surface.makeButton(308, 99, 10, 10)
	surfaceElements.buttons[316].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 115)
	surfaceElements.labels[316] = surface.makeLabelField(308, 104, 10, 1)

	surfaceElements.buttons[317] = surface.makeButton(319, 99, 10, 10)
	surfaceElements.buttons[317].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 116)
	surfaceElements.labels[317] = surface.makeLabelField(319, 104, 10, 1)

	surfaceElements.buttons[318] = surface.makeButton(330, 99, 10, 10)
	surfaceElements.buttons[318].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 117)
	surfaceElements.labels[318] = surface.makeLabelField(330, 104, 10, 1)

	surfaceElements.buttons[319] = surface.makeButton(341, 99, 10, 10)
	surfaceElements.buttons[319].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 118)
	surfaceElements.labels[319] = surface.makeLabelField(341, 104, 10, 1)

	surfaceElements.buttons[320] = surface.makeButton(0, 110, 10, 10)
	surfaceElements.buttons[320].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 119)
	surfaceElements.labels[320] = surface.makeLabelField(0, 115, 10, 1)

	surfaceElements.buttons[321] = surface.makeButton(11, 110, 10, 10)
	surfaceElements.buttons[321].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 120)
	surfaceElements.labels[321] = surface.makeLabelField(11, 115, 10, 1)

	surfaceElements.buttons[322] = surface.makeButton(22, 110, 10, 10)
	surfaceElements.buttons[322].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 121)
	surfaceElements.labels[322] = surface.makeLabelField(22, 115, 10, 1)

	surfaceElements.buttons[323] = surface.makeButton(33, 110, 10, 10)
	surfaceElements.buttons[323].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 122)
	surfaceElements.labels[323] = surface.makeLabelField(33, 115, 10, 1)

	surfaceElements.buttons[324] = surface.makeButton(44, 110, 10, 10)
	surfaceElements.buttons[324].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 123)
	surfaceElements.labels[324] = surface.makeLabelField(44, 115, 10, 1)

	surfaceElements.buttons[325] = surface.makeButton(55, 110, 10, 10)
	surfaceElements.buttons[325].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 124)
	surfaceElements.labels[325] = surface.makeLabelField(55, 115, 10, 1)

	surfaceElements.buttons[326] = surface.makeButton(66, 110, 10, 10)
	surfaceElements.buttons[326].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 125)
	surfaceElements.labels[326] = surface.makeLabelField(66, 115, 10, 1)

	surfaceElements.buttons[327] = surface.makeButton(77, 110, 10, 10)
	surfaceElements.buttons[327].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 126)
	surfaceElements.labels[327] = surface.makeLabelField(77, 115, 10, 1)

	surfaceElements.buttons[328] = surface.makeButton(88, 110, 10, 10)
	surfaceElements.buttons[328].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 111)
	surfaceElements.labels[328] = surface.makeLabelField(88, 115, 10, 1)

	surfaceElements.buttons[329] = surface.makeButton(99, 110, 10, 10)
	surfaceElements.buttons[329].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 112)
	surfaceElements.labels[329] = surface.makeLabelField(99, 115, 10, 1)

	surfaceElements.buttons[330] = surface.makeButton(110, 110, 10, 10)
	surfaceElements.buttons[330].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 113)
	surfaceElements.labels[330] = surface.makeLabelField(110, 115, 10, 1)

	surfaceElements.buttons[331] = surface.makeButton(121, 110, 10, 10)
	surfaceElements.buttons[331].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 114)
	surfaceElements.labels[331] = surface.makeLabelField(121, 115, 10, 1)

	surfaceElements.buttons[332] = surface.makeButton(132, 110, 10, 10)
	surfaceElements.buttons[332].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 115)
	surfaceElements.labels[332] = surface.makeLabelField(132, 115, 10, 1)

	surfaceElements.buttons[333] = surface.makeButton(143, 110, 10, 10)
	surfaceElements.buttons[333].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 116)
	surfaceElements.labels[333] = surface.makeLabelField(143, 115, 10, 1)

	surfaceElements.buttons[334] = surface.makeButton(154, 110, 10, 10)
	surfaceElements.buttons[334].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 117)
	surfaceElements.labels[334] = surface.makeLabelField(154, 115, 10, 1)

	surfaceElements.buttons[335] = surface.makeButton(165, 110, 10, 10)
	surfaceElements.buttons[335].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 118)
	surfaceElements.labels[335] = surface.makeLabelField(165, 115, 10, 1)

	surfaceElements.buttons[336] = surface.makeButton(176, 110, 10, 10)
	surfaceElements.buttons[336].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 119)
	surfaceElements.labels[336] = surface.makeLabelField(176, 115, 10, 1)

	surfaceElements.buttons[337] = surface.makeButton(187, 110, 10, 10)
	surfaceElements.buttons[337].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 120)
	surfaceElements.labels[337] = surface.makeLabelField(187, 115, 10, 1)

	surfaceElements.buttons[338] = surface.makeButton(198, 110, 10, 10)
	surfaceElements.buttons[338].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 121)
	surfaceElements.labels[338] = surface.makeLabelField(198, 115, 10, 1)

	surfaceElements.buttons[339] = surface.makeButton(209, 110, 10, 10)
	surfaceElements.buttons[339].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 122)
	surfaceElements.labels[339] = surface.makeLabelField(209, 115, 10, 1)

	surfaceElements.buttons[340] = surface.makeButton(220, 110, 10, 10)
	surfaceElements.buttons[340].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 123)
	surfaceElements.labels[340] = surface.makeLabelField(220, 115, 10, 1)

	surfaceElements.buttons[341] = surface.makeButton(231, 110, 10, 10)
	surfaceElements.buttons[341].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 124)
	surfaceElements.labels[341] = surface.makeLabelField(231, 115, 10, 1)

	surfaceElements.buttons[342] = surface.makeButton(242, 110, 10, 10)
	surfaceElements.buttons[342].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 125)
	surfaceElements.labels[342] = surface.makeLabelField(242, 115, 10, 1)

	surfaceElements.buttons[343] = surface.makeButton(253, 110, 10, 10)
	surfaceElements.buttons[343].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 126)
	surfaceElements.labels[343] = surface.makeLabelField(253, 115, 10, 1)

	surfaceElements.buttons[344] = surface.makeButton(264, 110, 10, 10)
	surfaceElements.buttons[344].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 127)
	surfaceElements.labels[344] = surface.makeLabelField(264, 115, 10, 1)

	surfaceElements.buttons[345] = surface.makeButton(275, 110, 10, 10)
	surfaceElements.buttons[345].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 87)
	surfaceElements.labels[345] = surface.makeLabelField(275, 115, 10, 1)

	surfaceElements.buttons[346] = surface.makeButton(286, 110, 10, 10)
	surfaceElements.buttons[346].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 88)
	surfaceElements.labels[346] = surface.makeLabelField(286, 115, 10, 1)

	surfaceElements.buttons[347] = surface.makeButton(297, 110, 10, 10)
	surfaceElements.buttons[347].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 89)
	surfaceElements.labels[347] = surface.makeLabelField(297, 115, 10, 1)

	surfaceElements.buttons[348] = surface.makeButton(308, 110, 10, 10)
	surfaceElements.buttons[348].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 90)
	surfaceElements.labels[348] = surface.makeLabelField(308, 115, 10, 1)

	surfaceElements.buttons[349] = surface.makeButton(319, 110, 10, 10)
	surfaceElements.buttons[349].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 91)
	surfaceElements.labels[349] = surface.makeLabelField(319, 115, 10, 1)

	surfaceElements.buttons[350] = surface.makeButton(330, 110, 10, 10)
	surfaceElements.buttons[350].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 92)
	surfaceElements.labels[350] = surface.makeLabelField(330, 115, 10, 1)

	surfaceElements.buttons[351] = surface.makeButton(341, 110, 10, 10)
	surfaceElements.buttons[351].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 93)
	surfaceElements.labels[351] = surface.makeLabelField(341, 115, 10, 1)

	surfaceElements.buttons[352] = surface.makeButton(0, 121, 10, 10)
	surfaceElements.buttons[352].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 94)
	surfaceElements.labels[352] = surface.makeLabelField(0, 126, 10, 1)

	surfaceElements.buttons[353] = surface.makeButton(11, 121, 10, 10)
	surfaceElements.buttons[353].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 95)
	surfaceElements.labels[353] = surface.makeLabelField(11, 126, 10, 1)

	surfaceElements.buttons[354] = surface.makeButton(22, 121, 10, 10)
	surfaceElements.buttons[354].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 96)
	surfaceElements.labels[354] = surface.makeLabelField(22, 126, 10, 1)

	surfaceElements.buttons[355] = surface.makeButton(33, 121, 10, 10)
	surfaceElements.buttons[355].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 97)
	surfaceElements.labels[355] = surface.makeLabelField(33, 126, 10, 1)

	surfaceElements.buttons[356] = surface.makeButton(44, 121, 10, 10)
	surfaceElements.buttons[356].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 98)
	surfaceElements.labels[356] = surface.makeLabelField(44, 126, 10, 1)

	surfaceElements.buttons[357] = surface.makeButton(55, 121, 10, 10)
	surfaceElements.buttons[357].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 99)
	surfaceElements.labels[357] = surface.makeLabelField(55, 126, 10, 1)

	surfaceElements.buttons[358] = surface.makeButton(66, 121, 10, 10)
	surfaceElements.buttons[358].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 100)
	surfaceElements.labels[358] = surface.makeLabelField(66, 126, 10, 1)

	surfaceElements.buttons[359] = surface.makeButton(77, 121, 10, 10)
	surfaceElements.buttons[359].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 101)
	surfaceElements.labels[359] = surface.makeLabelField(77, 126, 10, 1)

	surfaceElements.buttons[360] = surface.makeButton(88, 121, 10, 10)
	surfaceElements.buttons[360].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 102)
	surfaceElements.labels[360] = surface.makeLabelField(88, 126, 10, 1)

	surfaceElements.buttons[361] = surface.makeButton(99, 121, 10, 10)
	surfaceElements.buttons[361].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 103)
	surfaceElements.labels[361] = surface.makeLabelField(99, 126, 10, 1)

	surfaceElements.buttons[362] = surface.makeButton(110, 121, 10, 10)
	surfaceElements.buttons[362].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 104)
	surfaceElements.labels[362] = surface.makeLabelField(110, 126, 10, 1)

	surfaceElements.buttons[363] = surface.makeButton(121, 121, 10, 10)
	surfaceElements.buttons[363].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 105)
	surfaceElements.labels[363] = surface.makeLabelField(121, 126, 10, 1)

	surfaceElements.buttons[364] = surface.makeButton(132, 121, 10, 10)
	surfaceElements.buttons[364].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 106)
	surfaceElements.labels[364] = surface.makeLabelField(132, 126, 10, 1)

	surfaceElements.buttons[365] = surface.makeButton(143, 121, 10, 10)
	surfaceElements.buttons[365].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 107)
	surfaceElements.labels[365] = surface.makeLabelField(143, 126, 10, 1)

	surfaceElements.buttons[366] = surface.makeButton(154, 121, 10, 10)
	surfaceElements.buttons[366].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 108)
	surfaceElements.labels[366] = surface.makeLabelField(154, 126, 10, 1)

	surfaceElements.buttons[367] = surface.makeButton(165, 121, 10, 10)
	surfaceElements.buttons[367].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 109)
	surfaceElements.labels[367] = surface.makeLabelField(165, 126, 10, 1)

	surfaceElements.buttons[368] = surface.makeButton(176, 121, 10, 10)
	surfaceElements.buttons[368].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 110)
	surfaceElements.labels[368] = surface.makeLabelField(176, 126, 10, 1)

	surfaceElements.buttons[369] = surface.makeButton(187, 121, 10, 10)
	surfaceElements.buttons[369].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 111)
	surfaceElements.labels[369] = surface.makeLabelField(187, 126, 10, 1)

	surfaceElements.buttons[370] = surface.makeButton(198, 121, 10, 10)
	surfaceElements.buttons[370].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 112)
	surfaceElements.labels[370] = surface.makeLabelField(198, 126, 10, 1)

	surfaceElements.buttons[371] = surface.makeButton(209, 121, 10, 10)
	surfaceElements.buttons[371].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 113)
	surfaceElements.labels[371] = surface.makeLabelField(209, 126, 10, 1)

	surfaceElements.buttons[372] = surface.makeButton(220, 121, 10, 10)
	surfaceElements.buttons[372].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 114)
	surfaceElements.labels[372] = surface.makeLabelField(220, 126, 10, 1)

	surfaceElements.buttons[373] = surface.makeButton(231, 121, 10, 10)
	surfaceElements.buttons[373].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 115)
	surfaceElements.labels[373] = surface.makeLabelField(231, 126, 10, 1)

	surfaceElements.buttons[374] = surface.makeButton(242, 121, 10, 10)
	surfaceElements.buttons[374].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 83)
	surfaceElements.labels[374] = surface.makeLabelField(242, 126, 10, 1)

	surfaceElements.buttons[375] = surface.makeButton(253, 121, 10, 10)
	surfaceElements.buttons[375].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 84)
	surfaceElements.labels[375] = surface.makeLabelField(253, 126, 10, 1)

	surfaceElements.buttons[376] = surface.makeButton(264, 121, 10, 10)
	surfaceElements.buttons[376].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 85)
	surfaceElements.labels[376] = surface.makeLabelField(264, 126, 10, 1)

	surfaceElements.buttons[377] = surface.makeButton(275, 121, 10, 10)
	surfaceElements.buttons[377].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 86)
	surfaceElements.labels[377] = surface.makeLabelField(275, 126, 10, 1)

	surfaceElements.buttons[378] = surface.makeButton(286, 121, 10, 10)
	surfaceElements.buttons[378].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 87)
	surfaceElements.labels[378] = surface.makeLabelField(286, 126, 10, 1)

	surfaceElements.buttons[379] = surface.makeButton(297, 121, 10, 10)
	surfaceElements.buttons[379].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 88)
	surfaceElements.labels[379] = surface.makeLabelField(297, 126, 10, 1)

	surfaceElements.buttons[380] = surface.makeButton(308, 121, 10, 10)
	surfaceElements.buttons[380].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 89)
	surfaceElements.labels[380] = surface.makeLabelField(308, 126, 10, 1)

	surfaceElements.buttons[381] = surface.makeButton(319, 121, 10, 10)
	surfaceElements.buttons[381].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 90)
	surfaceElements.labels[381] = surface.makeLabelField(319, 126, 10, 1)

	surfaceElements.buttons[382] = surface.makeButton(330, 121, 10, 10)
	surfaceElements.buttons[382].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 91)
	surfaceElements.labels[382] = surface.makeLabelField(330, 126, 10, 1)

	surfaceElements.buttons[383] = surface.makeButton(341, 121, 10, 10)
	surfaceElements.buttons[383].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 92)
	surfaceElements.labels[383] = surface.makeLabelField(341, 126, 10, 1)

	surfaceElements.buttons[384] = surface.makeButton(0, 132, 10, 10)
	surfaceElements.buttons[384].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 93)
	surfaceElements.labels[384] = surface.makeLabelField(0, 137, 10, 1)

	surfaceElements.buttons[385] = surface.makeButton(11, 132, 10, 10)
	surfaceElements.buttons[385].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 94)
	surfaceElements.labels[385] = surface.makeLabelField(11, 137, 10, 1)

	surfaceElements.buttons[386] = surface.makeButton(22, 132, 10, 10)
	surfaceElements.buttons[386].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 95)
	surfaceElements.labels[386] = surface.makeLabelField(22, 137, 10, 1)

	surfaceElements.buttons[387] = surface.makeButton(33, 132, 10, 10)
	surfaceElements.buttons[387].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 96)
	surfaceElements.labels[387] = surface.makeLabelField(33, 137, 10, 1)

	surfaceElements.buttons[388] = surface.makeButton(44, 132, 10, 10)
	surfaceElements.buttons[388].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 97)
	surfaceElements.labels[388] = surface.makeLabelField(44, 137, 10, 1)

	surfaceElements.buttons[389] = surface.makeButton(55, 132, 10, 10)
	surfaceElements.buttons[389].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 98)
	surfaceElements.labels[389] = surface.makeLabelField(55, 137, 10, 1)

	surfaceElements.buttons[390] = surface.makeButton(66, 132, 10, 10)
	surfaceElements.buttons[390].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 99)
	surfaceElements.labels[390] = surface.makeLabelField(66, 137, 10, 1)

	surfaceElements.buttons[391] = surface.makeButton(77, 132, 10, 10)
	surfaceElements.buttons[391].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 100)
	surfaceElements.labels[391] = surface.makeLabelField(77, 137, 10, 1)

	surfaceElements.buttons[392] = surface.makeButton(88, 132, 10, 10)
	surfaceElements.buttons[392].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 101)
	surfaceElements.labels[392] = surface.makeLabelField(88, 137, 10, 1)

	surfaceElements.buttons[393] = surface.makeButton(99, 132, 10, 10)
	surfaceElements.buttons[393].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 102)
	surfaceElements.labels[393] = surface.makeLabelField(99, 137, 10, 1)

	surfaceElements.buttons[394] = surface.makeButton(110, 132, 10, 10)
	surfaceElements.buttons[394].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 103)
	surfaceElements.labels[394] = surface.makeLabelField(110, 137, 10, 1)

	surfaceElements.buttons[395] = surface.makeButton(121, 132, 10, 10)
	surfaceElements.buttons[395].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 104)
	surfaceElements.labels[395] = surface.makeLabelField(121, 137, 10, 1)

	surfaceElements.buttons[396] = surface.makeButton(132, 132, 10, 10)
	surfaceElements.buttons[396].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 105)
	surfaceElements.labels[396] = surface.makeLabelField(132, 137, 10, 1)

	surfaceElements.buttons[397] = surface.makeButton(143, 132, 10, 10)
	surfaceElements.buttons[397].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 106)
	surfaceElements.labels[397] = surface.makeLabelField(143, 137, 10, 1)

	surfaceElements.buttons[398] = surface.makeButton(154, 132, 10, 10)
	surfaceElements.buttons[398].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 107)
	surfaceElements.labels[398] = surface.makeLabelField(154, 137, 10, 1)

	surfaceElements.buttons[399] = surface.makeButton(165, 132, 10, 10)
	surfaceElements.buttons[399].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 108)
	surfaceElements.labels[399] = surface.makeLabelField(165, 137, 10, 1)

	surfaceElements.buttons[400] = surface.makeButton(176, 132, 10, 10)
	surfaceElements.buttons[400].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 109)
	surfaceElements.labels[400] = surface.makeLabelField(176, 137, 10, 1)

	surfaceElements.buttons[401] = surface.makeButton(187, 132, 10, 10)
	surfaceElements.buttons[401].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 110)
	surfaceElements.labels[401] = surface.makeLabelField(187, 137, 10, 1)

	surfaceElements.buttons[402] = surface.makeButton(198, 132, 10, 10)
	surfaceElements.buttons[402].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 111)
	surfaceElements.labels[402] = surface.makeLabelField(198, 137, 10, 1)

	surfaceElements.buttons[403] = surface.makeButton(209, 132, 10, 10)
	surfaceElements.buttons[403].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 112)
	surfaceElements.labels[403] = surface.makeLabelField(209, 137, 10, 1)

	surfaceElements.buttons[404] = surface.makeButton(220, 132, 10, 10)
	surfaceElements.buttons[404].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 113)
	surfaceElements.labels[404] = surface.makeLabelField(220, 137, 10, 1)

	surfaceElements.buttons[405] = surface.makeButton(231, 132, 10, 10)
	surfaceElements.buttons[405].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 114)
	surfaceElements.labels[405] = surface.makeLabelField(231, 137, 10, 1)

	surfaceElements.buttons[406] = surface.makeButton(242, 132, 10, 10)
	surfaceElements.buttons[406].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 115)
	surfaceElements.labels[406] = surface.makeLabelField(242, 137, 10, 1)

	surfaceElements.buttons[407] = surface.makeButton(253, 132, 10, 10)
	surfaceElements.buttons[407].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 116)
	surfaceElements.labels[407] = surface.makeLabelField(253, 137, 10, 1)

	surfaceElements.buttons[408] = surface.makeButton(264, 132, 10, 10)
	surfaceElements.buttons[408].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 117)
	surfaceElements.labels[408] = surface.makeLabelField(264, 137, 10, 1)

	surfaceElements.buttons[409] = surface.makeButton(275, 132, 10, 10)
	surfaceElements.buttons[409].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 118)
	surfaceElements.labels[409] = surface.makeLabelField(275, 137, 10, 1)

	surfaceElements.buttons[410] = surface.makeButton(286, 132, 10, 10)
	surfaceElements.buttons[410].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 119)
	surfaceElements.labels[410] = surface.makeLabelField(286, 137, 10, 1)

	surfaceElements.buttons[411] = surface.makeButton(297, 132, 10, 10)
	surfaceElements.buttons[411].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 120)
	surfaceElements.labels[411] = surface.makeLabelField(297, 137, 10, 1)

	surfaceElements.buttons[412] = surface.makeButton(308, 132, 10, 10)
	surfaceElements.buttons[412].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 121)
	surfaceElements.labels[412] = surface.makeLabelField(308, 137, 10, 1)

	surfaceElements.buttons[413] = surface.makeButton(319, 132, 10, 10)
	surfaceElements.buttons[413].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 122)
	surfaceElements.labels[413] = surface.makeLabelField(319, 137, 10, 1)

	surfaceElements.buttons[414] = surface.makeButton(330, 132, 10, 10)
	surfaceElements.buttons[414].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 123)
	surfaceElements.labels[414] = surface.makeLabelField(330, 137, 10, 1)

	surfaceElements.buttons[415] = surface.makeButton(341, 132, 10, 10)
	surfaceElements.buttons[415].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 124)
	surfaceElements.labels[415] = surface.makeLabelField(341, 137, 10, 1)

	surfaceElements.buttons[416] = surface.makeButton(0, 143, 10, 10)
	surfaceElements.buttons[416].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 125)
	surfaceElements.labels[416] = surface.makeLabelField(0, 148, 10, 1)

	surfaceElements.buttons[417] = surface.makeButton(11, 143, 10, 10)
	surfaceElements.buttons[417].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 126)
	surfaceElements.labels[417] = surface.makeLabelField(11, 148, 10, 1)

	surfaceElements.buttons[418] = surface.makeButton(22, 143, 10, 10)
	surfaceElements.buttons[418].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 127)
	surfaceElements.labels[418] = surface.makeLabelField(22, 148, 10, 1)

	surfaceElements.buttons[419] = surface.makeButton(33, 143, 10, 10)
	surfaceElements.buttons[419].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 67)
	surfaceElements.labels[419] = surface.makeLabelField(33, 148, 10, 1)

	surfaceElements.buttons[420] = surface.makeButton(44, 143, 10, 10)
	surfaceElements.buttons[420].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 68)
	surfaceElements.labels[420] = surface.makeLabelField(44, 148, 10, 1)

	surfaceElements.buttons[421] = surface.makeButton(55, 143, 10, 10)
	surfaceElements.buttons[421].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 69)
	surfaceElements.labels[421] = surface.makeLabelField(55, 148, 10, 1)

	surfaceElements.buttons[422] = surface.makeButton(66, 143, 10, 10)
	surfaceElements.buttons[422].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 70)
	surfaceElements.labels[422] = surface.makeLabelField(66, 148, 10, 1)

	surfaceElements.buttons[423] = surface.makeButton(77, 143, 10, 10)
	surfaceElements.buttons[423].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 71)
	surfaceElements.labels[423] = surface.makeLabelField(77, 148, 10, 1)

	surfaceElements.buttons[424] = surface.makeButton(88, 143, 10, 10)
	surfaceElements.buttons[424].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 72)
	surfaceElements.labels[424] = surface.makeLabelField(88, 148, 10, 1)

	surfaceElements.buttons[425] = surface.makeButton(99, 143, 10, 10)
	surfaceElements.buttons[425].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 73)
	surfaceElements.labels[425] = surface.makeLabelField(99, 148, 10, 1)

	surfaceElements.buttons[426] = surface.makeButton(110, 143, 10, 10)
	surfaceElements.buttons[426].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 74)
	surfaceElements.labels[426] = surface.makeLabelField(110, 148, 10, 1)

	surfaceElements.buttons[427] = surface.makeButton(121, 143, 10, 10)
	surfaceElements.buttons[427].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 75)
	surfaceElements.labels[427] = surface.makeLabelField(121, 148, 10, 1)

	surfaceElements.buttons[428] = surface.makeButton(132, 143, 10, 10)
	surfaceElements.buttons[428].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 76)
	surfaceElements.labels[428] = surface.makeLabelField(132, 148, 10, 1)

	surfaceElements.buttons[429] = surface.makeButton(143, 143, 10, 10)
	surfaceElements.buttons[429].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 77)
	surfaceElements.labels[429] = surface.makeLabelField(143, 148, 10, 1)

	surfaceElements.buttons[430] = surface.makeButton(154, 143, 10, 10)
	surfaceElements.buttons[430].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 78)
	surfaceElements.labels[430] = surface.makeLabelField(154, 148, 10, 1)

	surfaceElements.buttons[431] = surface.makeButton(165, 143, 10, 10)
	surfaceElements.buttons[431].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 79)
	surfaceElements.labels[431] = surface.makeLabelField(165, 148, 10, 1)

	surfaceElements.buttons[432] = surface.makeButton(176, 143, 10, 10)
	surfaceElements.buttons[432].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 80)
	surfaceElements.labels[432] = surface.makeLabelField(176, 148, 10, 1)

	surfaceElements.buttons[433] = surface.makeButton(187, 143, 10, 10)
	surfaceElements.buttons[433].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 81)
	surfaceElements.labels[433] = surface.makeLabelField(187, 148, 10, 1)

	surfaceElements.buttons[434] = surface.makeButton(198, 143, 10, 10)
	surfaceElements.buttons[434].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 82)
	surfaceElements.labels[434] = surface.makeLabelField(198, 148, 10, 1)

	surfaceElements.buttons[435] = surface.makeButton(209, 143, 10, 10)
	surfaceElements.buttons[435].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 83)
	surfaceElements.labels[435] = surface.makeLabelField(209, 148, 10, 1)

	surfaceElements.buttons[436] = surface.makeButton(220, 143, 10, 10)
	surfaceElements.buttons[436].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 84)
	surfaceElements.labels[436] = surface.makeLabelField(220, 148, 10, 1)

	surfaceElements.buttons[437] = surface.makeButton(231, 143, 10, 10)
	surfaceElements.buttons[437].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 85)
	surfaceElements.labels[437] = surface.makeLabelField(231, 148, 10, 1)

	surfaceElements.buttons[438] = surface.makeButton(242, 143, 10, 10)
	surfaceElements.buttons[438].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 86)
	surfaceElements.labels[438] = surface.makeLabelField(242, 148, 10, 1)

	surfaceElements.buttons[439] = surface.makeButton(253, 143, 10, 10)
	surfaceElements.buttons[439].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 87)
	surfaceElements.labels[439] = surface.makeLabelField(253, 148, 10, 1)

	surfaceElements.buttons[440] = surface.makeButton(264, 143, 10, 10)
	surfaceElements.buttons[440].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 88)
	surfaceElements.labels[440] = surface.makeLabelField(264, 148, 10, 1)

	surfaceElements.buttons[441] = surface.makeButton(275, 143, 10, 10)
	surfaceElements.buttons[441].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 89)
	surfaceElements.labels[441] = surface.makeLabelField(275, 148, 10, 1)

	surfaceElements.buttons[442] = surface.makeButton(286, 143, 10, 10)
	surfaceElements.buttons[442].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 90)
	surfaceElements.labels[442] = surface.makeLabelField(286, 148, 10, 1)

	surfaceElements.buttons[443] = surface.makeButton(297, 143, 10, 10)
	surfaceElements.buttons[443].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 91)
	surfaceElements.labels[443] = surface.makeLabelField(297, 148, 10, 1)

	surfaceElements.buttons[444] = surface.makeButton(308, 143, 10, 10)
	surfaceElements.buttons[444].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 92)
	surfaceElements.labels[444] = surface.makeLabelField(308, 148, 10, 1)

	surfaceElements.buttons[445] = surface.makeButton(319, 143, 10, 10)
	surfaceElements.buttons[445].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 93)
	surfaceElements.labels[445] = surface.makeLabelField(319, 148, 10, 1)

	surfaceElements.buttons[446] = surface.makeButton(330, 143, 10, 10)
	surfaceElements.buttons[446].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 94)
	surfaceElements.labels[446] = surface.makeLabelField(330, 148, 10, 1)

	surfaceElements.buttons[447] = surface.makeButton(341, 143, 10, 10)
	surfaceElements.buttons[447].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 95)
	surfaceElements.labels[447] = surface.makeLabelField(341, 148, 10, 1)

	surfaceElements.buttons[448] = surface.makeButton(0, 154, 10, 10)
	surfaceElements.buttons[448].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 96)
	surfaceElements.labels[448] = surface.makeLabelField(0, 159, 10, 1)

	surfaceElements.buttons[449] = surface.makeButton(11, 154, 10, 10)
	surfaceElements.buttons[449].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 97)
	surfaceElements.labels[449] = surface.makeLabelField(11, 159, 10, 1)

	surfaceElements.buttons[450] = surface.makeButton(22, 154, 10, 10)
	surfaceElements.buttons[450].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 98)
	surfaceElements.labels[450] = surface.makeLabelField(22, 159, 10, 1)

	surfaceElements.buttons[451] = surface.makeButton(33, 154, 10, 10)
	surfaceElements.buttons[451].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 99)
	surfaceElements.labels[451] = surface.makeLabelField(33, 159, 10, 1)

	surfaceElements.buttons[452] = surface.makeButton(44, 154, 10, 10)
	surfaceElements.buttons[452].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 100)
	surfaceElements.labels[452] = surface.makeLabelField(44, 159, 10, 1)

	surfaceElements.buttons[453] = surface.makeButton(55, 154, 10, 10)
	surfaceElements.buttons[453].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 101)
	surfaceElements.labels[453] = surface.makeLabelField(55, 159, 10, 1)

	surfaceElements.buttons[454] = surface.makeButton(66, 154, 10, 10)
	surfaceElements.buttons[454].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 102)
	surfaceElements.labels[454] = surface.makeLabelField(66, 159, 10, 1)

	surfaceElements.buttons[455] = surface.makeButton(77, 154, 10, 10)
	surfaceElements.buttons[455].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 103)
	surfaceElements.labels[455] = surface.makeLabelField(77, 159, 10, 1)

	surfaceElements.buttons[456] = surface.makeButton(88, 154, 10, 10)
	surfaceElements.buttons[456].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 104)
	surfaceElements.labels[456] = surface.makeLabelField(88, 159, 10, 1)

	surfaceElements.buttons[457] = surface.makeButton(99, 154, 10, 10)
	surfaceElements.buttons[457].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 105)
	surfaceElements.labels[457] = surface.makeLabelField(99, 159, 10, 1)

	surfaceElements.buttons[458] = surface.makeButton(110, 154, 10, 10)
	surfaceElements.buttons[458].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 106)
	surfaceElements.labels[458] = surface.makeLabelField(110, 159, 10, 1)

	surfaceElements.buttons[459] = surface.makeButton(121, 154, 10, 10)
	surfaceElements.buttons[459].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 107)
	surfaceElements.labels[459] = surface.makeLabelField(121, 159, 10, 1)

	surfaceElements.buttons[460] = surface.makeButton(132, 154, 10, 10)
	surfaceElements.buttons[460].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 108)
	surfaceElements.labels[460] = surface.makeLabelField(132, 159, 10, 1)

	surfaceElements.buttons[461] = surface.makeButton(143, 154, 10, 10)
	surfaceElements.buttons[461].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 109)
	surfaceElements.labels[461] = surface.makeLabelField(143, 159, 10, 1)

	surfaceElements.buttons[462] = surface.makeButton(154, 154, 10, 10)
	surfaceElements.buttons[462].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 110)
	surfaceElements.labels[462] = surface.makeLabelField(154, 159, 10, 1)

	surfaceElements.buttons[463] = surface.makeButton(165, 154, 10, 10)
	surfaceElements.buttons[463].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 111)
	surfaceElements.labels[463] = surface.makeLabelField(165, 159, 10, 1)

	surfaceElements.buttons[464] = surface.makeButton(176, 154, 10, 10)
	surfaceElements.buttons[464].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 112)
	surfaceElements.labels[464] = surface.makeLabelField(176, 159, 10, 1)

	surfaceElements.buttons[465] = surface.makeButton(187, 154, 10, 10)
	surfaceElements.buttons[465].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 113)
	surfaceElements.labels[465] = surface.makeLabelField(187, 159, 10, 1)

	surfaceElements.buttons[466] = surface.makeButton(198, 154, 10, 10)
	surfaceElements.buttons[466].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 114)
	surfaceElements.labels[466] = surface.makeLabelField(198, 159, 10, 1)

	surfaceElements.buttons[467] = surface.makeButton(209, 154, 10, 10)
	surfaceElements.buttons[467].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 115)
	surfaceElements.labels[467] = surface.makeLabelField(209, 159, 10, 1)

	surfaceElements.buttons[468] = surface.makeButton(220, 154, 10, 10)
	surfaceElements.buttons[468].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 116)
	surfaceElements.labels[468] = surface.makeLabelField(220, 159, 10, 1)

	surfaceElements.buttons[469] = surface.makeButton(231, 154, 10, 10)
	surfaceElements.buttons[469].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 117)
	surfaceElements.labels[469] = surface.makeLabelField(231, 159, 10, 1)

	surfaceElements.buttons[470] = surface.makeButton(242, 154, 10, 10)
	surfaceElements.buttons[470].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 118)
	surfaceElements.labels[470] = surface.makeLabelField(242, 159, 10, 1)

	surfaceElements.buttons[471] = surface.makeButton(253, 154, 10, 10)
	surfaceElements.buttons[471].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 119)
	surfaceElements.labels[471] = surface.makeLabelField(253, 159, 10, 1)

	surfaceElements.buttons[472] = surface.makeButton(264, 154, 10, 10)
	surfaceElements.buttons[472].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 120)
	surfaceElements.labels[472] = surface.makeLabelField(264, 159, 10, 1)

	surfaceElements.buttons[473] = surface.makeButton(275, 154, 10, 10)
	surfaceElements.buttons[473].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 121)
	surfaceElements.labels[473] = surface.makeLabelField(275, 159, 10, 1)

	surfaceElements.buttons[474] = surface.makeButton(286, 154, 10, 10)
	surfaceElements.buttons[474].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 122)
	surfaceElements.labels[474] = surface.makeLabelField(286, 159, 10, 1)

	surfaceElements.buttons[475] = surface.makeButton(297, 154, 10, 10)
	surfaceElements.buttons[475].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 123)
	surfaceElements.labels[475] = surface.makeLabelField(297, 159, 10, 1)

	surfaceElements.buttons[476] = surface.makeButton(308, 154, 10, 10)
	surfaceElements.buttons[476].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 124)
	surfaceElements.labels[476] = surface.makeLabelField(308, 159, 10, 1)

	surfaceElements.buttons[477] = surface.makeButton(319, 154, 10, 10)
	surfaceElements.buttons[477].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 125)
	surfaceElements.labels[477] = surface.makeLabelField(319, 159, 10, 1)

	surfaceElements.buttons[478] = surface.makeButton(330, 154, 10, 10)
	surfaceElements.buttons[478].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 126)
	surfaceElements.labels[478] = surface.makeLabelField(330, 159, 10, 1)

	surfaceElements.buttons[479] = surface.makeButton(341, 154, 10, 10)
	surfaceElements.buttons[479].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 127)
	surfaceElements.labels[479] = surface.makeLabelField(341, 159, 10, 1)

	surfaceElements.buttons[480] = surface.makeButton(0, 165, 10, 10)
	surfaceElements.buttons[480].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 111)
	surfaceElements.labels[480] = surface.makeLabelField(0, 170, 10, 1)

	surfaceElements.buttons[481] = surface.makeButton(11, 165, 10, 10)
	surfaceElements.buttons[481].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 112)
	surfaceElements.labels[481] = surface.makeLabelField(11, 170, 10, 1)

	surfaceElements.buttons[482] = surface.makeButton(22, 165, 10, 10)
	surfaceElements.buttons[482].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 113)
	surfaceElements.labels[482] = surface.makeLabelField(22, 170, 10, 1)

	surfaceElements.buttons[483] = surface.makeButton(33, 165, 10, 10)
	surfaceElements.buttons[483].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 114)
	surfaceElements.labels[483] = surface.makeLabelField(33, 170, 10, 1)

	surfaceElements.buttons[484] = surface.makeButton(44, 165, 10, 10)
	surfaceElements.buttons[484].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 115)
	surfaceElements.labels[484] = surface.makeLabelField(44, 170, 10, 1)

	surfaceElements.buttons[485] = surface.makeButton(55, 165, 10, 10)
	surfaceElements.buttons[485].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 116)
	surfaceElements.labels[485] = surface.makeLabelField(55, 170, 10, 1)

	surfaceElements.buttons[486] = surface.makeButton(66, 165, 10, 10)
	surfaceElements.buttons[486].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 117)
	surfaceElements.labels[486] = surface.makeLabelField(66, 170, 10, 1)

	surfaceElements.buttons[487] = surface.makeButton(77, 165, 10, 10)
	surfaceElements.buttons[487].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 118)
	surfaceElements.labels[487] = surface.makeLabelField(77, 170, 10, 1)

	surfaceElements.buttons[488] = surface.makeButton(88, 165, 10, 10)
	surfaceElements.buttons[488].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 119)
	surfaceElements.labels[488] = surface.makeLabelField(88, 170, 10, 1)

	surfaceElements.buttons[489] = surface.makeButton(99, 165, 10, 10)
	surfaceElements.buttons[489].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 120)
	surfaceElements.labels[489] = surface.makeLabelField(99, 170, 10, 1)

	surfaceElements.buttons[490] = surface.makeButton(110, 165, 10, 10)
	surfaceElements.buttons[490].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 121)
	surfaceElements.labels[490] = surface.makeLabelField(110, 170, 10, 1)

	surfaceElements.buttons[491] = surface.makeButton(121, 165, 10, 10)
	surfaceElements.buttons[491].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 122)
	surfaceElements.labels[491] = surface.makeLabelField(121, 170, 10, 1)

	surfaceElements.buttons[492] = surface.makeButton(132, 165, 10, 10)
	surfaceElements.buttons[492].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 123)
	surfaceElements.labels[492] = surface.makeLabelField(132, 170, 10, 1)

	surfaceElements.buttons[493] = surface.makeButton(143, 165, 10, 10)
	surfaceElements.buttons[493].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 124)
	surfaceElements.labels[493] = surface.makeLabelField(143, 170, 10, 1)

	surfaceElements.buttons[494] = surface.makeButton(154, 165, 10, 10)
	surfaceElements.buttons[494].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 125)
	surfaceElements.labels[494] = surface.makeLabelField(154, 170, 10, 1)

	surfaceElements.buttons[495] = surface.makeButton(165, 165, 10, 10)
	surfaceElements.buttons[495].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 126)
	surfaceElements.labels[495] = surface.makeLabelField(165, 170, 10, 1)

	surfaceElements.buttons[496] = surface.makeButton(176, 165, 10, 10)
	surfaceElements.buttons[496].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 127)
	surfaceElements.labels[496] = surface.makeLabelField(176, 170, 10, 1)

	surfaceElements.buttons[497] = surface.makeButton(187, 165, 10, 10)
	surfaceElements.buttons[497].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 121)
	surfaceElements.labels[497] = surface.makeLabelField(187, 170, 10, 1)

	surfaceElements.buttons[498] = surface.makeButton(198, 165, 10, 10)
	surfaceElements.buttons[498].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 122)
	surfaceElements.labels[498] = surface.makeLabelField(198, 170, 10, 1)

	surfaceElements.buttons[499] = surface.makeButton(209, 165, 10, 10)
	surfaceElements.buttons[499].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 123)
	surfaceElements.labels[499] = surface.makeLabelField(209, 170, 10, 1)

	surfaceElements.buttons[500] = surface.makeButton(220, 165, 10, 10)
	surfaceElements.buttons[500].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 124)
	surfaceElements.labels[500] = surface.makeLabelField(220, 170, 10, 1)

	surfaceElements.buttons[501] = surface.makeButton(231, 165, 10, 10)
	surfaceElements.buttons[501].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 125)
	surfaceElements.labels[501] = surface.makeLabelField(231, 170, 10, 1)

	surfaceElements.buttons[502] = surface.makeButton(242, 165, 10, 10)
	surfaceElements.buttons[502].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 11)
	surfaceElements.labels[502] = surface.makeLabelField(242, 170, 10, 1)

	surfaceElements.buttons[503] = surface.makeButton(253, 165, 10, 10)
	surfaceElements.buttons[503].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 12)
	surfaceElements.labels[503] = surface.makeLabelField(253, 170, 10, 1)

	surfaceElements.buttons[504] = surface.makeButton(264, 165, 10, 10)
	surfaceElements.buttons[504].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 13)
	surfaceElements.labels[504] = surface.makeLabelField(264, 170, 10, 1)

	surfaceElements.buttons[505] = surface.makeButton(275, 165, 10, 10)
	surfaceElements.buttons[505].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 14)
	surfaceElements.labels[505] = surface.makeLabelField(275, 170, 10, 1)

	surfaceElements.buttons[506] = surface.makeButton(286, 165, 10, 10)
	surfaceElements.buttons[506].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 15)
	surfaceElements.labels[506] = surface.makeLabelField(286, 170, 10, 1)

	surfaceElements.buttons[507] = surface.makeButton(297, 165, 10, 10)
	surfaceElements.buttons[507].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 16)
	surfaceElements.labels[507] = surface.makeLabelField(297, 170, 10, 1)

	surfaceElements.buttons[508] = surface.makeButton(308, 165, 10, 10)
	surfaceElements.buttons[508].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 17)
	surfaceElements.labels[508] = surface.makeLabelField(308, 170, 10, 1)

	surfaceElements.buttons[509] = surface.makeButton(319, 165, 10, 10)
	surfaceElements.buttons[509].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 18)
	surfaceElements.labels[509] = surface.makeLabelField(319, 170, 10, 1)

	surfaceElements.buttons[510] = surface.makeButton(330, 165, 10, 10)
	surfaceElements.buttons[510].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 19)
	surfaceElements.labels[510] = surface.makeLabelField(330, 170, 10, 1)

	surfaceElements.buttons[511] = surface.makeButton(341, 165, 10, 10)
	surfaceElements.buttons[511].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 20)
	surfaceElements.labels[511] = surface.makeLabelField(341, 170, 10, 1)

	surfaceElements.buttons[512] = surface.makeButton(0, 176, 10, 10)
	surfaceElements.buttons[512].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 21)
	surfaceElements.labels[512] = surface.makeLabelField(0, 181, 10, 1)

	surfaceElements.buttons[513] = surface.makeButton(11, 176, 10, 10)
	surfaceElements.buttons[513].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 22)
	surfaceElements.labels[513] = surface.makeLabelField(11, 181, 10, 1)

	surfaceElements.buttons[514] = surface.makeButton(22, 176, 10, 10)
	surfaceElements.buttons[514].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 23)
	surfaceElements.labels[514] = surface.makeLabelField(22, 181, 10, 1)

	surfaceElements.buttons[515] = surface.makeButton(33, 176, 10, 10)
	surfaceElements.buttons[515].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 24)
	surfaceElements.labels[515] = surface.makeLabelField(33, 181, 10, 1)

	surfaceElements.buttons[516] = surface.makeButton(44, 176, 10, 10)
	surfaceElements.buttons[516].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 25)
	surfaceElements.labels[516] = surface.makeLabelField(44, 181, 10, 1)

	surfaceElements.buttons[517] = surface.makeButton(55, 176, 10, 10)
	surfaceElements.buttons[517].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 26)
	surfaceElements.labels[517] = surface.makeLabelField(55, 181, 10, 1)

	surfaceElements.buttons[518] = surface.makeButton(66, 176, 10, 10)
	surfaceElements.buttons[518].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 27)
	surfaceElements.labels[518] = surface.makeLabelField(66, 181, 10, 1)

	surfaceElements.buttons[519] = surface.makeButton(77, 176, 10, 10)
	surfaceElements.buttons[519].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 28)
	surfaceElements.labels[519] = surface.makeLabelField(77, 181, 10, 1)

	surfaceElements.buttons[520] = surface.makeButton(88, 176, 10, 10)
	surfaceElements.buttons[520].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 29)
	surfaceElements.labels[520] = surface.makeLabelField(88, 181, 10, 1)

	surfaceElements.buttons[521] = surface.makeButton(99, 176, 10, 10)
	surfaceElements.buttons[521].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 30)
	surfaceElements.labels[521] = surface.makeLabelField(99, 181, 10, 1)

	surfaceElements.buttons[522] = surface.makeButton(110, 176, 10, 10)
	surfaceElements.buttons[522].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 31)
	surfaceElements.labels[522] = surface.makeLabelField(110, 181, 10, 1)

	surfaceElements.buttons[523] = surface.makeButton(121, 176, 10, 10)
	surfaceElements.buttons[523].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 32)
	surfaceElements.labels[523] = surface.makeLabelField(121, 181, 10, 1)

	surfaceElements.buttons[524] = surface.makeButton(132, 176, 10, 10)
	surfaceElements.buttons[524].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 33)
	surfaceElements.labels[524] = surface.makeLabelField(132, 181, 10, 1)

	surfaceElements.buttons[525] = surface.makeButton(143, 176, 10, 10)
	surfaceElements.buttons[525].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 34)
	surfaceElements.labels[525] = surface.makeLabelField(143, 181, 10, 1)

	surfaceElements.buttons[526] = surface.makeButton(154, 176, 10, 10)
	surfaceElements.buttons[526].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 35)
	surfaceElements.labels[526] = surface.makeLabelField(154, 181, 10, 1)

	surfaceElements.buttons[527] = surface.makeButton(165, 176, 10, 10)
	surfaceElements.buttons[527].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 36)
	surfaceElements.labels[527] = surface.makeLabelField(165, 181, 10, 1)

	surfaceElements.buttons[528] = surface.makeButton(176, 176, 10, 10)
	surfaceElements.buttons[528].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 37)
	surfaceElements.labels[528] = surface.makeLabelField(176, 181, 10, 1)

	surfaceElements.buttons[529] = surface.makeButton(187, 176, 10, 10)
	surfaceElements.buttons[529].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 38)
	surfaceElements.labels[529] = surface.makeLabelField(187, 181, 10, 1)

	surfaceElements.buttons[530] = surface.makeButton(198, 176, 10, 10)
	surfaceElements.buttons[530].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 39)
	surfaceElements.labels[530] = surface.makeLabelField(198, 181, 10, 1)

	surfaceElements.buttons[531] = surface.makeButton(209, 176, 10, 10)
	surfaceElements.buttons[531].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 40)
	surfaceElements.labels[531] = surface.makeLabelField(209, 181, 10, 1)

	surfaceElements.buttons[532] = surface.makeButton(220, 176, 10, 10)
	surfaceElements.buttons[532].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 41)
	surfaceElements.labels[532] = surface.makeLabelField(220, 181, 10, 1)

	surfaceElements.buttons[533] = surface.makeButton(231, 176, 10, 10)
	surfaceElements.buttons[533].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 42)
	surfaceElements.labels[533] = surface.makeLabelField(231, 181, 10, 1)

	surfaceElements.buttons[534] = surface.makeButton(242, 176, 10, 10)
	surfaceElements.buttons[534].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 43)
	surfaceElements.labels[534] = surface.makeLabelField(242, 181, 10, 1)

	surfaceElements.buttons[535] = surface.makeButton(253, 176, 10, 10)
	surfaceElements.buttons[535].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 44)
	surfaceElements.labels[535] = surface.makeLabelField(253, 181, 10, 1)

	surfaceElements.buttons[536] = surface.makeButton(264, 176, 10, 10)
	surfaceElements.buttons[536].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 45)
	surfaceElements.labels[536] = surface.makeLabelField(264, 181, 10, 1)

	surfaceElements.buttons[537] = surface.makeButton(275, 176, 10, 10)
	surfaceElements.buttons[537].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 46)
	surfaceElements.labels[537] = surface.makeLabelField(275, 181, 10, 1)

	surfaceElements.buttons[538] = surface.makeButton(286, 176, 10, 10)
	surfaceElements.buttons[538].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 47)
	surfaceElements.labels[538] = surface.makeLabelField(286, 181, 10, 1)

	surfaceElements.buttons[539] = surface.makeButton(297, 176, 10, 10)
	surfaceElements.buttons[539].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 48)
	surfaceElements.labels[539] = surface.makeLabelField(297, 181, 10, 1)

	surfaceElements.buttons[540] = surface.makeButton(308, 176, 10, 10)
	surfaceElements.buttons[540].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 49)
	surfaceElements.labels[540] = surface.makeLabelField(308, 181, 10, 1)

	surfaceElements.buttons[541] = surface.makeButton(319, 176, 10, 10)
	surfaceElements.buttons[541].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 50)
	surfaceElements.labels[541] = surface.makeLabelField(319, 181, 10, 1)

	surfaceElements.buttons[542] = surface.makeButton(330, 176, 10, 10)
	surfaceElements.buttons[542].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 51)
	surfaceElements.labels[542] = surface.makeLabelField(330, 181, 10, 1)

	surfaceElements.buttons[543] = surface.makeButton(341, 176, 10, 10)
	surfaceElements.buttons[543].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 52)
	surfaceElements.labels[543] = surface.makeLabelField(341, 181, 10, 1)

	surfaceElements.buttons[544] = surface.makeButton(0, 187, 10, 10)
	surfaceElements.buttons[544].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 53)
	surfaceElements.labels[544] = surface.makeLabelField(0, 192, 10, 1)

	surfaceElements.buttons[545] = surface.makeButton(11, 187, 10, 10)
	surfaceElements.buttons[545].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 54)
	surfaceElements.labels[545] = surface.makeLabelField(11, 192, 10, 1)

	surfaceElements.buttons[546] = surface.makeButton(22, 187, 10, 10)
	surfaceElements.buttons[546].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 55)
	surfaceElements.labels[546] = surface.makeLabelField(22, 192, 10, 1)

	surfaceElements.buttons[547] = surface.makeButton(33, 187, 10, 10)
	surfaceElements.buttons[547].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 56)
	surfaceElements.labels[547] = surface.makeLabelField(33, 192, 10, 1)

	surfaceElements.buttons[548] = surface.makeButton(44, 187, 10, 10)
	surfaceElements.buttons[548].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 57)
	surfaceElements.labels[548] = surface.makeLabelField(44, 192, 10, 1)

	surfaceElements.buttons[549] = surface.makeButton(55, 187, 10, 10)
	surfaceElements.buttons[549].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 58)
	surfaceElements.labels[549] = surface.makeLabelField(55, 192, 10, 1)

	surfaceElements.buttons[550] = surface.makeButton(66, 187, 10, 10)
	surfaceElements.buttons[550].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 59)
	surfaceElements.labels[550] = surface.makeLabelField(66, 192, 10, 1)

	surfaceElements.buttons[551] = surface.makeButton(77, 187, 10, 10)
	surfaceElements.buttons[551].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 60)
	surfaceElements.labels[551] = surface.makeLabelField(77, 192, 10, 1)

	surfaceElements.buttons[552] = surface.makeButton(88, 187, 10, 10)
	surfaceElements.buttons[552].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 61)
	surfaceElements.labels[552] = surface.makeLabelField(88, 192, 10, 1)

	surfaceElements.buttons[553] = surface.makeButton(99, 187, 10, 10)
	surfaceElements.buttons[553].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 62)
	surfaceElements.labels[553] = surface.makeLabelField(99, 192, 10, 1)

	surfaceElements.buttons[554] = surface.makeButton(110, 187, 10, 10)
	surfaceElements.buttons[554].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 63)
	surfaceElements.labels[554] = surface.makeLabelField(110, 192, 10, 1)

	surfaceElements.buttons[555] = surface.makeButton(121, 187, 10, 10)
	surfaceElements.buttons[555].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 64)
	surfaceElements.labels[555] = surface.makeLabelField(121, 192, 10, 1)

	surfaceElements.buttons[556] = surface.makeButton(132, 187, 10, 10)
	surfaceElements.buttons[556].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 65)
	surfaceElements.labels[556] = surface.makeLabelField(132, 192, 10, 1)

	surfaceElements.buttons[557] = surface.makeButton(143, 187, 10, 10)
	surfaceElements.buttons[557].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 66)
	surfaceElements.labels[557] = surface.makeLabelField(143, 192, 10, 1)

	surfaceElements.buttons[558] = surface.makeButton(154, 187, 10, 10)
	surfaceElements.buttons[558].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 67)
	surfaceElements.labels[558] = surface.makeLabelField(154, 192, 10, 1)

	surfaceElements.buttons[559] = surface.makeButton(165, 187, 10, 10)
	surfaceElements.buttons[559].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 68)
	surfaceElements.labels[559] = surface.makeLabelField(165, 192, 10, 1)

	surfaceElements.buttons[560] = surface.makeButton(176, 187, 10, 10)
	surfaceElements.buttons[560].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 69)
	surfaceElements.labels[560] = surface.makeLabelField(176, 192, 10, 1)

	surfaceElements.buttons[561] = surface.makeButton(187, 187, 10, 10)
	surfaceElements.buttons[561].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 70)
	surfaceElements.labels[561] = surface.makeLabelField(187, 192, 10, 1)

	surfaceElements.buttons[562] = surface.makeButton(198, 187, 10, 10)
	surfaceElements.buttons[562].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 71)
	surfaceElements.labels[562] = surface.makeLabelField(198, 192, 10, 1)

	surfaceElements.buttons[563] = surface.makeButton(209, 187, 10, 10)
	surfaceElements.buttons[563].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 72)
	surfaceElements.labels[563] = surface.makeLabelField(209, 192, 10, 1)

	surfaceElements.buttons[564] = surface.makeButton(220, 187, 10, 10)
	surfaceElements.buttons[564].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 73)
	surfaceElements.labels[564] = surface.makeLabelField(220, 192, 10, 1)

	surfaceElements.buttons[565] = surface.makeButton(231, 187, 10, 10)
	surfaceElements.buttons[565].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 74)
	surfaceElements.labels[565] = surface.makeLabelField(231, 192, 10, 1)

	surfaceElements.buttons[566] = surface.makeButton(242, 187, 10, 10)
	surfaceElements.buttons[566].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 75)
	surfaceElements.labels[566] = surface.makeLabelField(242, 192, 10, 1)

	surfaceElements.buttons[567] = surface.makeButton(253, 187, 10, 10)
	surfaceElements.buttons[567].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 76)
	surfaceElements.labels[567] = surface.makeLabelField(253, 192, 10, 1)

	surfaceElements.buttons[568] = surface.makeButton(264, 187, 10, 10)
	surfaceElements.buttons[568].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 77)
	surfaceElements.labels[568] = surface.makeLabelField(264, 192, 10, 1)

	surfaceElements.buttons[569] = surface.makeButton(275, 187, 10, 10)
	surfaceElements.buttons[569].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 78)
	surfaceElements.labels[569] = surface.makeLabelField(275, 192, 10, 1)

	surfaceElements.buttons[570] = surface.makeButton(286, 187, 10, 10)
	surfaceElements.buttons[570].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 79)
	surfaceElements.labels[570] = surface.makeLabelField(286, 192, 10, 1)

	surfaceElements.buttons[571] = surface.makeButton(297, 187, 10, 10)
	surfaceElements.buttons[571].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 80)
	surfaceElements.labels[571] = surface.makeLabelField(297, 192, 10, 1)

	surfaceElements.buttons[572] = surface.makeButton(308, 187, 10, 10)
	surfaceElements.buttons[572].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 81)
	surfaceElements.labels[572] = surface.makeLabelField(308, 192, 10, 1)

	surfaceElements.buttons[573] = surface.makeButton(319, 187, 10, 10)
	surfaceElements.buttons[573].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 82)
	surfaceElements.labels[573] = surface.makeLabelField(319, 192, 10, 1)

	surfaceElements.buttons[574] = surface.makeButton(330, 187, 10, 10)
	surfaceElements.buttons[574].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 83)
	surfaceElements.labels[574] = surface.makeLabelField(330, 192, 10, 1)

	surfaceElements.buttons[575] = surface.makeButton(341, 187, 10, 10)
	surfaceElements.buttons[575].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 84)
	surfaceElements.labels[575] = surface.makeLabelField(341, 192, 10, 1)

	surfaceElements.buttons[576] = surface.makeButton(0, 198, 10, 10)
	surfaceElements.buttons[576].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 85)
	surfaceElements.labels[576] = surface.makeLabelField(0, 203, 10, 1)

	surfaceElements.buttons[577] = surface.makeButton(11, 198, 10, 10)
	surfaceElements.buttons[577].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 86)
	surfaceElements.labels[577] = surface.makeLabelField(11, 203, 10, 1)

	surfaceElements.buttons[578] = surface.makeButton(22, 198, 10, 10)
	surfaceElements.buttons[578].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 87)
	surfaceElements.labels[578] = surface.makeLabelField(22, 203, 10, 1)

	surfaceElements.buttons[579] = surface.makeButton(33, 198, 10, 10)
	surfaceElements.buttons[579].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 88)
	surfaceElements.labels[579] = surface.makeLabelField(33, 203, 10, 1)

	surfaceElements.buttons[580] = surface.makeButton(44, 198, 10, 10)
	surfaceElements.buttons[580].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 89)
	surfaceElements.labels[580] = surface.makeLabelField(44, 203, 10, 1)

	surfaceElements.buttons[581] = surface.makeButton(55, 198, 10, 10)
	surfaceElements.buttons[581].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 90)
	surfaceElements.labels[581] = surface.makeLabelField(55, 203, 10, 1)

	surfaceElements.buttons[582] = surface.makeButton(66, 198, 10, 10)
	surfaceElements.buttons[582].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 91)
	surfaceElements.labels[582] = surface.makeLabelField(66, 203, 10, 1)

	surfaceElements.buttons[583] = surface.makeButton(77, 198, 10, 10)
	surfaceElements.buttons[583].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 92)
	surfaceElements.labels[583] = surface.makeLabelField(77, 203, 10, 1)

	surfaceElements.buttons[584] = surface.makeButton(88, 198, 10, 10)
	surfaceElements.buttons[584].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 93)
	surfaceElements.labels[584] = surface.makeLabelField(88, 203, 10, 1)

	surfaceElements.buttons[585] = surface.makeButton(99, 198, 10, 10)
	surfaceElements.buttons[585].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 94)
	surfaceElements.labels[585] = surface.makeLabelField(99, 203, 10, 1)

	surfaceElements.buttons[586] = surface.makeButton(110, 198, 10, 10)
	surfaceElements.buttons[586].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 95)
	surfaceElements.labels[586] = surface.makeLabelField(110, 203, 10, 1)

	surfaceElements.buttons[587] = surface.makeButton(121, 198, 10, 10)
	surfaceElements.buttons[587].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 96)
	surfaceElements.labels[587] = surface.makeLabelField(121, 203, 10, 1)

	surfaceElements.buttons[588] = surface.makeButton(132, 198, 10, 10)
	surfaceElements.buttons[588].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 97)
	surfaceElements.labels[588] = surface.makeLabelField(132, 203, 10, 1)

	surfaceElements.buttons[589] = surface.makeButton(143, 198, 10, 10)
	surfaceElements.buttons[589].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 98)
	surfaceElements.labels[589] = surface.makeLabelField(143, 203, 10, 1)

	surfaceElements.buttons[590] = surface.makeButton(154, 198, 10, 10)
	surfaceElements.buttons[590].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 99)
	surfaceElements.labels[590] = surface.makeLabelField(154, 203, 10, 1)

	surfaceElements.buttons[591] = surface.makeButton(165, 198, 10, 10)
	surfaceElements.buttons[591].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 100)
	surfaceElements.labels[591] = surface.makeLabelField(165, 203, 10, 1)

	surfaceElements.buttons[592] = surface.makeButton(176, 198, 10, 10)
	surfaceElements.buttons[592].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 101)
	surfaceElements.labels[592] = surface.makeLabelField(176, 203, 10, 1)

	surfaceElements.buttons[593] = surface.makeButton(187, 198, 10, 10)
	surfaceElements.buttons[593].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 102)
	surfaceElements.labels[593] = surface.makeLabelField(187, 203, 10, 1)

	surfaceElements.buttons[594] = surface.makeButton(198, 198, 10, 10)
	surfaceElements.buttons[594].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 103)
	surfaceElements.labels[594] = surface.makeLabelField(198, 203, 10, 1)

	surfaceElements.buttons[595] = surface.makeButton(209, 198, 10, 10)
	surfaceElements.buttons[595].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 104)
	surfaceElements.labels[595] = surface.makeLabelField(209, 203, 10, 1)

	surfaceElements.buttons[596] = surface.makeButton(220, 198, 10, 10)
	surfaceElements.buttons[596].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 105)
	surfaceElements.labels[596] = surface.makeLabelField(220, 203, 10, 1)

	surfaceElements.buttons[597] = surface.makeButton(231, 198, 10, 10)
	surfaceElements.buttons[597].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 106)
	surfaceElements.labels[597] = surface.makeLabelField(231, 203, 10, 1)

	surfaceElements.buttons[598] = surface.makeButton(242, 198, 10, 10)
	surfaceElements.buttons[598].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 107)
	surfaceElements.labels[598] = surface.makeLabelField(242, 203, 10, 1)

	surfaceElements.buttons[599] = surface.makeButton(253, 198, 10, 10)
	surfaceElements.buttons[599].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 108)
	surfaceElements.labels[599] = surface.makeLabelField(253, 203, 10, 1)

	surfaceElements.buttons[600] = surface.makeButton(264, 198, 10, 10)
	surfaceElements.buttons[600].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 109)
	surfaceElements.labels[600] = surface.makeLabelField(264, 203, 10, 1)

	surfaceElements.buttons[601] = surface.makeButton(275, 198, 10, 10)
	surfaceElements.buttons[601].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 110)
	surfaceElements.labels[601] = surface.makeLabelField(275, 203, 10, 1)

	surfaceElements.buttons[602] = surface.makeButton(286, 198, 10, 10)
	surfaceElements.buttons[602].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 1)
	surfaceElements.labels[602] = surface.makeLabelField(286, 203, 10, 1)

	surfaceElements.buttons[603] = surface.makeButton(297, 198, 10, 10)
	surfaceElements.buttons[603].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 2)
	surfaceElements.labels[603] = surface.makeLabelField(297, 203, 10, 1)

	surfaceElements.buttons[604] = surface.makeButton(308, 198, 10, 10)
	surfaceElements.buttons[604].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 3)
	surfaceElements.labels[604] = surface.makeLabelField(308, 203, 10, 1)

	surfaceElements.buttons[605] = surface.makeButton(319, 198, 10, 10)
	surfaceElements.buttons[605].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 4)
	surfaceElements.labels[605] = surface.makeLabelField(319, 203, 10, 1)

	surfaceElements.buttons[606] = surface.makeButton(330, 198, 10, 10)
	surfaceElements.buttons[606].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 5)
	surfaceElements.labels[606] = surface.makeLabelField(330, 203, 10, 1)

	surfaceElements.buttons[607] = surface.makeButton(341, 198, 10, 10)
	surfaceElements.buttons[607].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 6)
	surfaceElements.labels[607] = surface.makeLabelField(341, 203, 10, 1)

	surfaceElements.buttons[608] = surface.makeButton(0, 209, 10, 10)
	surfaceElements.buttons[608].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 7)
	surfaceElements.labels[608] = surface.makeLabelField(0, 214, 10, 1)

	surfaceElements.buttons[609] = surface.makeButton(11, 209, 10, 10)
	surfaceElements.buttons[609].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 8)
	surfaceElements.labels[609] = surface.makeLabelField(11, 214, 10, 1)

	surfaceElements.buttons[610] = surface.makeButton(22, 209, 10, 10)
	surfaceElements.buttons[610].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 9)
	surfaceElements.labels[610] = surface.makeLabelField(22, 214, 10, 1)

	surfaceElements.buttons[611] = surface.makeButton(33, 209, 10, 10)
	surfaceElements.buttons[611].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 10)
	surfaceElements.labels[611] = surface.makeLabelField(33, 214, 10, 1)

	surfaceElements.buttons[612] = surface.makeButton(44, 209, 10, 10)
	surfaceElements.buttons[612].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 11)
	surfaceElements.labels[612] = surface.makeLabelField(44, 214, 10, 1)

	surfaceElements.buttons[613] = surface.makeButton(55, 209, 10, 10)
	surfaceElements.buttons[613].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 12)
	surfaceElements.labels[613] = surface.makeLabelField(55, 214, 10, 1)

	surfaceElements.buttons[614] = surface.makeButton(66, 209, 10, 10)
	surfaceElements.buttons[614].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 13)
	surfaceElements.labels[614] = surface.makeLabelField(66, 214, 10, 1)

	surfaceElements.buttons[615] = surface.makeButton(77, 209, 10, 10)
	surfaceElements.buttons[615].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 14)
	surfaceElements.labels[615] = surface.makeLabelField(77, 214, 10, 1)

	surfaceElements.buttons[616] = surface.makeButton(88, 209, 10, 10)
	surfaceElements.buttons[616].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 15)
	surfaceElements.labels[616] = surface.makeLabelField(88, 214, 10, 1)

	surfaceElements.buttons[617] = surface.makeButton(99, 209, 10, 10)
	surfaceElements.buttons[617].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 16)
	surfaceElements.labels[617] = surface.makeLabelField(99, 214, 10, 1)

	surfaceElements.buttons[618] = surface.makeButton(110, 209, 10, 10)
	surfaceElements.buttons[618].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 17)
	surfaceElements.labels[618] = surface.makeLabelField(110, 214, 10, 1)

	surfaceElements.buttons[619] = surface.makeButton(121, 209, 10, 10)
	surfaceElements.buttons[619].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 18)
	surfaceElements.labels[619] = surface.makeLabelField(121, 214, 10, 1)

	surfaceElements.buttons[620] = surface.makeButton(132, 209, 10, 10)
	surfaceElements.buttons[620].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 19)
	surfaceElements.labels[620] = surface.makeLabelField(132, 214, 10, 1)

	surfaceElements.buttons[621] = surface.makeButton(143, 209, 10, 10)
	surfaceElements.buttons[621].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 20)
	surfaceElements.labels[621] = surface.makeLabelField(143, 214, 10, 1)

	surfaceElements.buttons[622] = surface.makeButton(154, 209, 10, 10)
	surfaceElements.buttons[622].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 21)
	surfaceElements.labels[622] = surface.makeLabelField(154, 214, 10, 1)

	surfaceElements.buttons[623] = surface.makeButton(165, 209, 10, 10)
	surfaceElements.buttons[623].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 22)
	surfaceElements.labels[623] = surface.makeLabelField(165, 214, 10, 1)

	surfaceElements.buttons[624] = surface.makeButton(176, 209, 10, 10)
	surfaceElements.buttons[624].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 23)
	surfaceElements.labels[624] = surface.makeLabelField(176, 214, 10, 1)

	surfaceElements.buttons[625] = surface.makeButton(187, 209, 10, 10)
	surfaceElements.buttons[625].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 24)
	surfaceElements.labels[625] = surface.makeLabelField(187, 214, 10, 1)

	surfaceElements.buttons[626] = surface.makeButton(198, 209, 10, 10)
	surfaceElements.buttons[626].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 25)
	surfaceElements.labels[626] = surface.makeLabelField(198, 214, 10, 1)

	surfaceElements.buttons[627] = surface.makeButton(209, 209, 10, 10)
	surfaceElements.buttons[627].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 26)
	surfaceElements.labels[627] = surface.makeLabelField(209, 214, 10, 1)

	surfaceElements.buttons[628] = surface.makeButton(220, 209, 10, 10)
	surfaceElements.buttons[628].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 27)
	surfaceElements.labels[628] = surface.makeLabelField(220, 214, 10, 1)

	surfaceElements.buttons[629] = surface.makeButton(231, 209, 10, 10)
	surfaceElements.buttons[629].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 28)
	surfaceElements.labels[629] = surface.makeLabelField(231, 214, 10, 1)

	surfaceElements.buttons[630] = surface.makeButton(242, 209, 10, 10)
	surfaceElements.buttons[630].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 29)
	surfaceElements.labels[630] = surface.makeLabelField(242, 214, 10, 1)

	surfaceElements.buttons[631] = surface.makeButton(253, 209, 10, 10)
	surfaceElements.buttons[631].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 30)
	surfaceElements.labels[631] = surface.makeLabelField(253, 214, 10, 1)

	surfaceElements.buttons[632] = surface.makeButton(264, 209, 10, 10)
	surfaceElements.buttons[632].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 31)
	surfaceElements.labels[632] = surface.makeLabelField(264, 214, 10, 1)

	surfaceElements.buttons[633] = surface.makeButton(275, 209, 10, 10)
	surfaceElements.buttons[633].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 32)
	surfaceElements.labels[633] = surface.makeLabelField(275, 214, 10, 1)

	surfaceElements.buttons[634] = surface.makeButton(286, 209, 10, 10)
	surfaceElements.buttons[634].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 33)
	surfaceElements.labels[634] = surface.makeLabelField(286, 214, 10, 1)

	surfaceElements.buttons[635] = surface.makeButton(297, 209, 10, 10)
	surfaceElements.buttons[635].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 34)
	surfaceElements.labels[635] = surface.makeLabelField(297, 214, 10, 1)

	surfaceElements.buttons[636] = surface.makeButton(308, 209, 10, 10)
	surfaceElements.buttons[636].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 35)
	surfaceElements.labels[636] = surface.makeLabelField(308, 214, 10, 1)

	surfaceElements.buttons[637] = surface.makeButton(319, 209, 10, 10)
	surfaceElements.buttons[637].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 36)
	surfaceElements.labels[637] = surface.makeLabelField(319, 214, 10, 1)

	surfaceElements.buttons[638] = surface.makeButton(330, 209, 10, 10)
	surfaceElements.buttons[638].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 37)
	surfaceElements.labels[638] = surface.makeLabelField(330, 214, 10, 1)

	surfaceElements.buttons[639] = surface.makeButton(341, 209, 10, 10)
	surfaceElements.buttons[639].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 38)
	surfaceElements.labels[639] = surface.makeLabelField(341, 214, 10, 1)

	surfaceElements.buttons[640] = surface.makeButton(0, 220, 10, 10)
	surfaceElements.buttons[640].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 39)
	surfaceElements.labels[640] = surface.makeLabelField(0, 225, 10, 1)

	surfaceElements.buttons[641] = surface.makeButton(11, 220, 10, 10)
	surfaceElements.buttons[641].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 40)
	surfaceElements.labels[641] = surface.makeLabelField(11, 225, 10, 1)

	surfaceElements.buttons[642] = surface.makeButton(22, 220, 10, 10)
	surfaceElements.buttons[642].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 41)
	surfaceElements.labels[642] = surface.makeLabelField(22, 225, 10, 1)

	surfaceElements.buttons[643] = surface.makeButton(33, 220, 10, 10)
	surfaceElements.buttons[643].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 42)
	surfaceElements.labels[643] = surface.makeLabelField(33, 225, 10, 1)

	surfaceElements.buttons[644] = surface.makeButton(44, 220, 10, 10)
	surfaceElements.buttons[644].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 43)
	surfaceElements.labels[644] = surface.makeLabelField(44, 225, 10, 1)

	surfaceElements.buttons[645] = surface.makeButton(55, 220, 10, 10)
	surfaceElements.buttons[645].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 44)
	surfaceElements.labels[645] = surface.makeLabelField(55, 225, 10, 1)

	surfaceElements.buttons[646] = surface.makeButton(66, 220, 10, 10)
	surfaceElements.buttons[646].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 45)
	surfaceElements.labels[646] = surface.makeLabelField(66, 225, 10, 1)

	surfaceElements.buttons[647] = surface.makeButton(77, 220, 10, 10)
	surfaceElements.buttons[647].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 46)
	surfaceElements.labels[647] = surface.makeLabelField(77, 225, 10, 1)

	surfaceElements.buttons[648] = surface.makeButton(88, 220, 10, 10)
	surfaceElements.buttons[648].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 47)
	surfaceElements.labels[648] = surface.makeLabelField(88, 225, 10, 1)

	surfaceElements.buttons[649] = surface.makeButton(99, 220, 10, 10)
	surfaceElements.buttons[649].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 48)
	surfaceElements.labels[649] = surface.makeLabelField(99, 225, 10, 1)

	surfaceElements.buttons[650] = surface.makeButton(110, 220, 10, 10)
	surfaceElements.buttons[650].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 49)
	surfaceElements.labels[650] = surface.makeLabelField(110, 225, 10, 1)

	surfaceElements.buttons[651] = surface.makeButton(121, 220, 10, 10)
	surfaceElements.buttons[651].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 50)
	surfaceElements.labels[651] = surface.makeLabelField(121, 225, 10, 1)

	surfaceElements.buttons[652] = surface.makeButton(132, 220, 10, 10)
	surfaceElements.buttons[652].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 51)
	surfaceElements.labels[652] = surface.makeLabelField(132, 225, 10, 1)

	surfaceElements.buttons[653] = surface.makeButton(143, 220, 10, 10)
	surfaceElements.buttons[653].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 52)
	surfaceElements.labels[653] = surface.makeLabelField(143, 225, 10, 1)

	surfaceElements.buttons[654] = surface.makeButton(154, 220, 10, 10)
	surfaceElements.buttons[654].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 53)
	surfaceElements.labels[654] = surface.makeLabelField(154, 225, 10, 1)

	surfaceElements.buttons[655] = surface.makeButton(165, 220, 10, 10)
	surfaceElements.buttons[655].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 54)
	surfaceElements.labels[655] = surface.makeLabelField(165, 225, 10, 1)

	surfaceElements.buttons[656] = surface.makeButton(176, 220, 10, 10)
	surfaceElements.buttons[656].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 55)
	surfaceElements.labels[656] = surface.makeLabelField(176, 225, 10, 1)

	surfaceElements.buttons[657] = surface.makeButton(187, 220, 10, 10)
	surfaceElements.buttons[657].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 56)
	surfaceElements.labels[657] = surface.makeLabelField(187, 225, 10, 1)

	surfaceElements.buttons[658] = surface.makeButton(198, 220, 10, 10)
	surfaceElements.buttons[658].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 57)
	surfaceElements.labels[658] = surface.makeLabelField(198, 225, 10, 1)

	surfaceElements.buttons[659] = surface.makeButton(209, 220, 10, 10)
	surfaceElements.buttons[659].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 58)
	surfaceElements.labels[659] = surface.makeLabelField(209, 225, 10, 1)

	surfaceElements.buttons[660] = surface.makeButton(220, 220, 10, 10)
	surfaceElements.buttons[660].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 59)
	surfaceElements.labels[660] = surface.makeLabelField(220, 225, 10, 1)

	surfaceElements.buttons[661] = surface.makeButton(231, 220, 10, 10)
	surfaceElements.buttons[661].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 60)
	surfaceElements.labels[661] = surface.makeLabelField(231, 225, 10, 1)

	surfaceElements.buttons[662] = surface.makeButton(242, 220, 10, 10)
	surfaceElements.buttons[662].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 61)
	surfaceElements.labels[662] = surface.makeLabelField(242, 225, 10, 1)

	surfaceElements.buttons[663] = surface.makeButton(253, 220, 10, 10)
	surfaceElements.buttons[663].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 62)
	surfaceElements.labels[663] = surface.makeLabelField(253, 225, 10, 1)

	surfaceElements.buttons[664] = surface.makeButton(264, 220, 10, 10)
	surfaceElements.buttons[664].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 63)
	surfaceElements.labels[664] = surface.makeLabelField(264, 225, 10, 1)

	surfaceElements.buttons[665] = surface.makeButton(275, 220, 10, 10)
	surfaceElements.buttons[665].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 64)
	surfaceElements.labels[665] = surface.makeLabelField(275, 225, 10, 1)

	surfaceElements.buttons[666] = surface.makeButton(286, 220, 10, 10)
	surfaceElements.buttons[666].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 65)
	surfaceElements.labels[666] = surface.makeLabelField(286, 225, 10, 1)

	surfaceElements.buttons[667] = surface.makeButton(297, 220, 10, 10)
	surfaceElements.buttons[667].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 66)
	surfaceElements.labels[667] = surface.makeLabelField(297, 225, 10, 1)

	surfaceElements.buttons[668] = surface.makeButton(308, 220, 10, 10)
	surfaceElements.buttons[668].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 67)
	surfaceElements.labels[668] = surface.makeLabelField(308, 225, 10, 1)

	surfaceElements.buttons[669] = surface.makeButton(319, 220, 10, 10)
	surfaceElements.buttons[669].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 68)
	surfaceElements.labels[669] = surface.makeLabelField(319, 225, 10, 1)

	surfaceElements.buttons[670] = surface.makeButton(330, 220, 10, 10)
	surfaceElements.buttons[670].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 69)
	surfaceElements.labels[670] = surface.makeLabelField(330, 225, 10, 1)

	surfaceElements.buttons[671] = surface.makeButton(341, 220, 10, 10)
	surfaceElements.buttons[671].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 70)
	surfaceElements.labels[671] = surface.makeLabelField(341, 225, 10, 1)

	surfaceElements.buttons[672] = surface.makeButton(0, 231, 10, 10)
	surfaceElements.buttons[672].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 71)
	surfaceElements.labels[672] = surface.makeLabelField(0, 236, 10, 1)

	surfaceElements.buttons[673] = surface.makeButton(11, 231, 10, 10)
	surfaceElements.buttons[673].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 72)
	surfaceElements.labels[673] = surface.makeLabelField(11, 236, 10, 1)

	surfaceElements.buttons[674] = surface.makeButton(22, 231, 10, 10)
	surfaceElements.buttons[674].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 73)
	surfaceElements.labels[674] = surface.makeLabelField(22, 236, 10, 1)

	surfaceElements.buttons[675] = surface.makeButton(33, 231, 10, 10)
	surfaceElements.buttons[675].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 74)
	surfaceElements.labels[675] = surface.makeLabelField(33, 236, 10, 1)

	surfaceElements.buttons[676] = surface.makeButton(44, 231, 10, 10)
	surfaceElements.buttons[676].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 75)
	surfaceElements.labels[676] = surface.makeLabelField(44, 236, 10, 1)

	surfaceElements.buttons[677] = surface.makeButton(55, 231, 10, 10)
	surfaceElements.buttons[677].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 76)
	surfaceElements.labels[677] = surface.makeLabelField(55, 236, 10, 1)

	surfaceElements.buttons[678] = surface.makeButton(66, 231, 10, 10)
	surfaceElements.buttons[678].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 77)
	surfaceElements.labels[678] = surface.makeLabelField(66, 236, 10, 1)

	surfaceElements.buttons[679] = surface.makeButton(77, 231, 10, 10)
	surfaceElements.buttons[679].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 78)
	surfaceElements.labels[679] = surface.makeLabelField(77, 236, 10, 1)

	surfaceElements.buttons[680] = surface.makeButton(88, 231, 10, 10)
	surfaceElements.buttons[680].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 79)
	surfaceElements.labels[680] = surface.makeLabelField(88, 236, 10, 1)

	surfaceElements.buttons[681] = surface.makeButton(99, 231, 10, 10)
	surfaceElements.buttons[681].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 80)
	surfaceElements.labels[681] = surface.makeLabelField(99, 236, 10, 1)

	surfaceElements.buttons[682] = surface.makeButton(110, 231, 10, 10)
	surfaceElements.buttons[682].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 81)
	surfaceElements.labels[682] = surface.makeLabelField(110, 236, 10, 1)

	surfaceElements.buttons[683] = surface.makeButton(121, 231, 10, 10)
	surfaceElements.buttons[683].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 82)
	surfaceElements.labels[683] = surface.makeLabelField(121, 236, 10, 1)

	surfaceElements.buttons[684] = surface.makeButton(132, 231, 10, 10)
	surfaceElements.buttons[684].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 83)
	surfaceElements.labels[684] = surface.makeLabelField(132, 236, 10, 1)

	surfaceElements.buttons[685] = surface.makeButton(143, 231, 10, 10)
	surfaceElements.buttons[685].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 84)
	surfaceElements.labels[685] = surface.makeLabelField(143, 236, 10, 1)

	surfaceElements.buttons[686] = surface.makeButton(154, 231, 10, 10)
	surfaceElements.buttons[686].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 85)
	surfaceElements.labels[686] = surface.makeLabelField(154, 236, 10, 1)

	surfaceElements.buttons[687] = surface.makeButton(165, 231, 10, 10)
	surfaceElements.buttons[687].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 86)
	surfaceElements.labels[687] = surface.makeLabelField(165, 236, 10, 1)

	surfaceElements.buttons[688] = surface.makeButton(176, 231, 10, 10)
	surfaceElements.buttons[688].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 87)
	surfaceElements.labels[688] = surface.makeLabelField(176, 236, 10, 1)

	surfaceElements.buttons[689] = surface.makeButton(187, 231, 10, 10)
	surfaceElements.buttons[689].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 88)
	surfaceElements.labels[689] = surface.makeLabelField(187, 236, 10, 1)

	surfaceElements.buttons[690] = surface.makeButton(198, 231, 10, 10)
	surfaceElements.buttons[690].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 89)
	surfaceElements.labels[690] = surface.makeLabelField(198, 236, 10, 1)

	surfaceElements.buttons[691] = surface.makeButton(209, 231, 10, 10)
	surfaceElements.buttons[691].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 90)
	surfaceElements.labels[691] = surface.makeLabelField(209, 236, 10, 1)

	surfaceElements.buttons[692] = surface.makeButton(220, 231, 10, 10)
	surfaceElements.buttons[692].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 91)
	surfaceElements.labels[692] = surface.makeLabelField(220, 236, 10, 1)

	surfaceElements.buttons[693] = surface.makeButton(231, 231, 10, 10)
	surfaceElements.buttons[693].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 92)
	surfaceElements.labels[693] = surface.makeLabelField(231, 236, 10, 1)

	surfaceElements.buttons[694] = surface.makeButton(242, 231, 10, 10)
	surfaceElements.buttons[694].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 93)
	surfaceElements.labels[694] = surface.makeLabelField(242, 236, 10, 1)

	surfaceElements.buttons[695] = surface.makeButton(253, 231, 10, 10)
	surfaceElements.buttons[695].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 94)
	surfaceElements.labels[695] = surface.makeLabelField(253, 236, 10, 1)

	surfaceElements.buttons[696] = surface.makeButton(264, 231, 10, 10)
	surfaceElements.buttons[696].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 95)
	surfaceElements.labels[696] = surface.makeLabelField(264, 236, 10, 1)

	surfaceElements.buttons[697] = surface.makeButton(275, 231, 10, 10)
	surfaceElements.buttons[697].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 96)
	surfaceElements.labels[697] = surface.makeLabelField(275, 236, 10, 1)

	surfaceElements.buttons[698] = surface.makeButton(286, 231, 10, 10)
	surfaceElements.buttons[698].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 97)
	surfaceElements.labels[698] = surface.makeLabelField(286, 236, 10, 1)

	surfaceElements.buttons[699] = surface.makeButton(297, 231, 10, 10)
	surfaceElements.buttons[699].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 98)
	surfaceElements.labels[699] = surface.makeLabelField(297, 236, 10, 1)

	surfaceElements.buttons[700] = surface.makeButton(308, 231, 10, 10)
	surfaceElements.buttons[700].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 99)
	surfaceElements.labels[700] = surface.makeLabelField(308, 236, 10, 1)

	surfaceElements.buttons[701] = surface.makeButton(319, 231, 10, 10)
	surfaceElements.buttons[701].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 100)
	surfaceElements.labels[701] = surface.makeLabelField(319, 236, 10, 1)

	surfaceElements.buttons[702] = surface.makeButton(330, 231, 10, 10)
	surfaceElements.buttons[702].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 11)
	surfaceElements.labels[702] = surface.makeLabelField(330, 236, 10, 1)

	surfaceElements.buttons[703] = surface.makeButton(341, 231, 10, 10)
	surfaceElements.buttons[703].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 12)
	surfaceElements.labels[703] = surface.makeLabelField(341, 236, 10, 1)

	surfaceElements.buttons[704] = surface.makeButton(0, 242, 10, 10)
	surfaceElements.buttons[704].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 13)
	surfaceElements.labels[704] = surface.makeLabelField(0, 247, 10, 1)

	surfaceElements.buttons[705] = surface.makeButton(11, 242, 10, 10)
	surfaceElements.buttons[705].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 14)
	surfaceElements.labels[705] = surface.makeLabelField(11, 247, 10, 1)

	surfaceElements.buttons[706] = surface.makeButton(22, 242, 10, 10)
	surfaceElements.buttons[706].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 15)
	surfaceElements.labels[706] = surface.makeLabelField(22, 247, 10, 1)

	surfaceElements.buttons[707] = surface.makeButton(33, 242, 10, 10)
	surfaceElements.buttons[707].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 16)
	surfaceElements.labels[707] = surface.makeLabelField(33, 247, 10, 1)

	surfaceElements.buttons[708] = surface.makeButton(44, 242, 10, 10)
	surfaceElements.buttons[708].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 17)
	surfaceElements.labels[708] = surface.makeLabelField(44, 247, 10, 1)

	surfaceElements.buttons[709] = surface.makeButton(55, 242, 10, 10)
	surfaceElements.buttons[709].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 18)
	surfaceElements.labels[709] = surface.makeLabelField(55, 247, 10, 1)

	surfaceElements.buttons[710] = surface.makeButton(66, 242, 10, 10)
	surfaceElements.buttons[710].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 19)
	surfaceElements.labels[710] = surface.makeLabelField(66, 247, 10, 1)

	surfaceElements.buttons[711] = surface.makeButton(77, 242, 10, 10)
	surfaceElements.buttons[711].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 20)
	surfaceElements.labels[711] = surface.makeLabelField(77, 247, 10, 1)

	surfaceElements.buttons[712] = surface.makeButton(88, 242, 10, 10)
	surfaceElements.buttons[712].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 21)
	surfaceElements.labels[712] = surface.makeLabelField(88, 247, 10, 1)

	surfaceElements.buttons[713] = surface.makeButton(99, 242, 10, 10)
	surfaceElements.buttons[713].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 22)
	surfaceElements.labels[713] = surface.makeLabelField(99, 247, 10, 1)

	surfaceElements.buttons[714] = surface.makeButton(110, 242, 10, 10)
	surfaceElements.buttons[714].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 23)
	surfaceElements.labels[714] = surface.makeLabelField(110, 247, 10, 1)

	surfaceElements.buttons[715] = surface.makeButton(121, 242, 10, 10)
	surfaceElements.buttons[715].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 24)
	surfaceElements.labels[715] = surface.makeLabelField(121, 247, 10, 1)

	surfaceElements.buttons[716] = surface.makeButton(132, 242, 10, 10)
	surfaceElements.buttons[716].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 25)
	surfaceElements.labels[716] = surface.makeLabelField(132, 247, 10, 1)

	surfaceElements.buttons[717] = surface.makeButton(143, 242, 10, 10)
	surfaceElements.buttons[717].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 26)
	surfaceElements.labels[717] = surface.makeLabelField(143, 247, 10, 1)

	surfaceElements.buttons[718] = surface.makeButton(154, 242, 10, 10)
	surfaceElements.buttons[718].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 27)
	surfaceElements.labels[718] = surface.makeLabelField(154, 247, 10, 1)

	surfaceElements.buttons[719] = surface.makeButton(165, 242, 10, 10)
	surfaceElements.buttons[719].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 28)
	surfaceElements.labels[719] = surface.makeLabelField(165, 247, 10, 1)

	surfaceElements.buttons[720] = surface.makeButton(176, 242, 10, 10)
	surfaceElements.buttons[720].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 29)
	surfaceElements.labels[720] = surface.makeLabelField(176, 247, 10, 1)

	surfaceElements.buttons[721] = surface.makeButton(187, 242, 10, 10)
	surfaceElements.buttons[721].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 30)
	surfaceElements.labels[721] = surface.makeLabelField(187, 247, 10, 1)

	surfaceElements.buttons[722] = surface.makeButton(198, 242, 10, 10)
	surfaceElements.buttons[722].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 31)
	surfaceElements.labels[722] = surface.makeLabelField(198, 247, 10, 1)

	surfaceElements.buttons[723] = surface.makeButton(209, 242, 10, 10)
	surfaceElements.buttons[723].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 32)
	surfaceElements.labels[723] = surface.makeLabelField(209, 247, 10, 1)

	surfaceElements.buttons[724] = surface.makeButton(220, 242, 10, 10)
	surfaceElements.buttons[724].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 33)
	surfaceElements.labels[724] = surface.makeLabelField(220, 247, 10, 1)

	surfaceElements.buttons[725] = surface.makeButton(231, 242, 10, 10)
	surfaceElements.buttons[725].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 34)
	surfaceElements.labels[725] = surface.makeLabelField(231, 247, 10, 1)

	surfaceElements.buttons[726] = surface.makeButton(242, 242, 10, 10)
	surfaceElements.buttons[726].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 35)
	surfaceElements.labels[726] = surface.makeLabelField(242, 247, 10, 1)

	surfaceElements.buttons[727] = surface.makeButton(253, 242, 10, 10)
	surfaceElements.buttons[727].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 36)
	surfaceElements.labels[727] = surface.makeLabelField(253, 247, 10, 1)

	surfaceElements.buttons[728] = surface.makeButton(264, 242, 10, 10)
	surfaceElements.buttons[728].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 37)
	surfaceElements.labels[728] = surface.makeLabelField(264, 247, 10, 1)

	surfaceElements.buttons[729] = surface.makeButton(275, 242, 10, 10)
	surfaceElements.buttons[729].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 38)
	surfaceElements.labels[729] = surface.makeLabelField(275, 247, 10, 1)

	surfaceElements.buttons[730] = surface.makeButton(286, 242, 10, 10)
	surfaceElements.buttons[730].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 39)
	surfaceElements.labels[730] = surface.makeLabelField(286, 247, 10, 1)

	surfaceElements.buttons[731] = surface.makeButton(297, 242, 10, 10)
	surfaceElements.buttons[731].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 40)
	surfaceElements.labels[731] = surface.makeLabelField(297, 247, 10, 1)

	surfaceElements.buttons[732] = surface.makeButton(308, 242, 10, 10)
	surfaceElements.buttons[732].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 41)
	surfaceElements.labels[732] = surface.makeLabelField(308, 247, 10, 1)

	surfaceElements.buttons[733] = surface.makeButton(319, 242, 10, 10)
	surfaceElements.buttons[733].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 42)
	surfaceElements.labels[733] = surface.makeLabelField(319, 247, 10, 1)

	surfaceElements.buttons[734] = surface.makeButton(330, 242, 10, 10)
	surfaceElements.buttons[734].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 43)
	surfaceElements.labels[734] = surface.makeLabelField(330, 247, 10, 1)

	surfaceElements.buttons[735] = surface.makeButton(341, 242, 10, 10)
	surfaceElements.buttons[735].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 44)
	surfaceElements.labels[735] = surface.makeLabelField(341, 247, 10, 1)

	surfaceElements.buttons[736] = surface.makeButton(0, 253, 10, 10)
	surfaceElements.buttons[736].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 45)
	surfaceElements.labels[736] = surface.makeLabelField(0, 258, 10, 1)

	surfaceElements.buttons[737] = surface.makeButton(11, 253, 10, 10)
	surfaceElements.buttons[737].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 46)
	surfaceElements.labels[737] = surface.makeLabelField(11, 258, 10, 1)

	surfaceElements.buttons[738] = surface.makeButton(22, 253, 10, 10)
	surfaceElements.buttons[738].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 47)
	surfaceElements.labels[738] = surface.makeLabelField(22, 258, 10, 1)

	surfaceElements.buttons[739] = surface.makeButton(33, 253, 10, 10)
	surfaceElements.buttons[739].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 48)
	surfaceElements.labels[739] = surface.makeLabelField(33, 258, 10, 1)

	surfaceElements.buttons[740] = surface.makeButton(44, 253, 10, 10)
	surfaceElements.buttons[740].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 49)
	surfaceElements.labels[740] = surface.makeLabelField(44, 258, 10, 1)

	surfaceElements.buttons[741] = surface.makeButton(55, 253, 10, 10)
	surfaceElements.buttons[741].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 50)
	surfaceElements.labels[741] = surface.makeLabelField(55, 258, 10, 1)

	surfaceElements.buttons[742] = surface.makeButton(66, 253, 10, 10)
	surfaceElements.buttons[742].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 51)
	surfaceElements.labels[742] = surface.makeLabelField(66, 258, 10, 1)

	surfaceElements.buttons[743] = surface.makeButton(77, 253, 10, 10)
	surfaceElements.buttons[743].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 52)
	surfaceElements.labels[743] = surface.makeLabelField(77, 258, 10, 1)

	surfaceElements.buttons[744] = surface.makeButton(88, 253, 10, 10)
	surfaceElements.buttons[744].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 53)
	surfaceElements.labels[744] = surface.makeLabelField(88, 258, 10, 1)

	surfaceElements.buttons[745] = surface.makeButton(99, 253, 10, 10)
	surfaceElements.buttons[745].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 54)
	surfaceElements.labels[745] = surface.makeLabelField(99, 258, 10, 1)

	surfaceElements.buttons[746] = surface.makeButton(110, 253, 10, 10)
	surfaceElements.buttons[746].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 55)
	surfaceElements.labels[746] = surface.makeLabelField(110, 258, 10, 1)

	surfaceElements.buttons[747] = surface.makeButton(121, 253, 10, 10)
	surfaceElements.buttons[747].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 56)
	surfaceElements.labels[747] = surface.makeLabelField(121, 258, 10, 1)

	surfaceElements.buttons[748] = surface.makeButton(132, 253, 10, 10)
	surfaceElements.buttons[748].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 57)
	surfaceElements.labels[748] = surface.makeLabelField(132, 258, 10, 1)

	surfaceElements.buttons[749] = surface.makeButton(143, 253, 10, 10)
	surfaceElements.buttons[749].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 58)
	surfaceElements.labels[749] = surface.makeLabelField(143, 258, 10, 1)

	surfaceElements.buttons[750] = surface.makeButton(154, 253, 10, 10)
	surfaceElements.buttons[750].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 59)
	surfaceElements.labels[750] = surface.makeLabelField(154, 258, 10, 1)

	surfaceElements.buttons[751] = surface.makeButton(165, 253, 10, 10)
	surfaceElements.buttons[751].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 60)
	surfaceElements.labels[751] = surface.makeLabelField(165, 258, 10, 1)

	surfaceElements.buttons[752] = surface.makeButton(176, 253, 10, 10)
	surfaceElements.buttons[752].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 61)
	surfaceElements.labels[752] = surface.makeLabelField(176, 258, 10, 1)

	surfaceElements.buttons[753] = surface.makeButton(187, 253, 10, 10)
	surfaceElements.buttons[753].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 62)
	surfaceElements.labels[753] = surface.makeLabelField(187, 258, 10, 1)

	surfaceElements.buttons[754] = surface.makeButton(198, 253, 10, 10)
	surfaceElements.buttons[754].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 63)
	surfaceElements.labels[754] = surface.makeLabelField(198, 258, 10, 1)

	surfaceElements.buttons[755] = surface.makeButton(209, 253, 10, 10)
	surfaceElements.buttons[755].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 64)
	surfaceElements.labels[755] = surface.makeLabelField(209, 258, 10, 1)

	surfaceElements.buttons[756] = surface.makeButton(220, 253, 10, 10)
	surfaceElements.buttons[756].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 65)
	surfaceElements.labels[756] = surface.makeLabelField(220, 258, 10, 1)

	surfaceElements.buttons[757] = surface.makeButton(231, 253, 10, 10)
	surfaceElements.buttons[757].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 66)
	surfaceElements.labels[757] = surface.makeLabelField(231, 258, 10, 1)

	surfaceElements.buttons[758] = surface.makeButton(242, 253, 10, 10)
	surfaceElements.buttons[758].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 67)
	surfaceElements.labels[758] = surface.makeLabelField(242, 258, 10, 1)

	surfaceElements.buttons[759] = surface.makeButton(253, 253, 10, 10)
	surfaceElements.buttons[759].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 68)
	surfaceElements.labels[759] = surface.makeLabelField(253, 258, 10, 1)

	surfaceElements.buttons[760] = surface.makeButton(264, 253, 10, 10)
	surfaceElements.buttons[760].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 69)
	surfaceElements.labels[760] = surface.makeLabelField(264, 258, 10, 1)

	surfaceElements.buttons[761] = surface.makeButton(275, 253, 10, 10)
	surfaceElements.buttons[761].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 70)
	surfaceElements.labels[761] = surface.makeLabelField(275, 258, 10, 1)

	surfaceElements.buttons[762] = surface.makeButton(286, 253, 10, 10)
	surfaceElements.buttons[762].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 71)
	surfaceElements.labels[762] = surface.makeLabelField(286, 258, 10, 1)

	surfaceElements.buttons[763] = surface.makeButton(297, 253, 10, 10)
	surfaceElements.buttons[763].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 72)
	surfaceElements.labels[763] = surface.makeLabelField(297, 258, 10, 1)

	surfaceElements.buttons[764] = surface.makeButton(308, 253, 10, 10)
	surfaceElements.buttons[764].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 73)
	surfaceElements.labels[764] = surface.makeLabelField(308, 258, 10, 1)

	surfaceElements.buttons[765] = surface.makeButton(319, 253, 10, 10)
	surfaceElements.buttons[765].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 74)
	surfaceElements.labels[765] = surface.makeLabelField(319, 258, 10, 1)

	surfaceElements.buttons[766] = surface.makeButton(330, 253, 10, 10)
	surfaceElements.buttons[766].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 75)
	surfaceElements.labels[766] = surface.makeLabelField(330, 258, 10, 1)

	surfaceElements.buttons[767] = surface.makeButton(341, 253, 10, 10)
	surfaceElements.buttons[767].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 76)
	surfaceElements.labels[767] = surface.makeLabelField(341, 258, 10, 1)

	surfaceElements.buttons[768] = surface.makeButton(0, 264, 10, 10)
	surfaceElements.buttons[768].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 77)
	surfaceElements.labels[768] = surface.makeLabelField(0, 269, 10, 1)

	surfaceElements.buttons[769] = surface.makeButton(11, 264, 10, 10)
	surfaceElements.buttons[769].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 78)
	surfaceElements.labels[769] = surface.makeLabelField(11, 269, 10, 1)

	surfaceElements.buttons[770] = surface.makeButton(22, 264, 10, 10)
	surfaceElements.buttons[770].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 79)
	surfaceElements.labels[770] = surface.makeLabelField(22, 269, 10, 1)

	surfaceElements.buttons[771] = surface.makeButton(33, 264, 10, 10)
	surfaceElements.buttons[771].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 80)
	surfaceElements.labels[771] = surface.makeLabelField(33, 269, 10, 1)

	surfaceElements.buttons[772] = surface.makeButton(44, 264, 10, 10)
	surfaceElements.buttons[772].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 81)
	surfaceElements.labels[772] = surface.makeLabelField(44, 269, 10, 1)

	surfaceElements.buttons[773] = surface.makeButton(55, 264, 10, 10)
	surfaceElements.buttons[773].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 82)
	surfaceElements.labels[773] = surface.makeLabelField(55, 269, 10, 1)

	surfaceElements.buttons[774] = surface.makeButton(66, 264, 10, 10)
	surfaceElements.buttons[774].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 83)
	surfaceElements.labels[774] = surface.makeLabelField(66, 269, 10, 1)

	surfaceElements.buttons[775] = surface.makeButton(77, 264, 10, 10)
	surfaceElements.buttons[775].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 84)
	surfaceElements.labels[775] = surface.makeLabelField(77, 269, 10, 1)

	surfaceElements.buttons[776] = surface.makeButton(88, 264, 10, 10)
	surfaceElements.buttons[776].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 85)
	surfaceElements.labels[776] = surface.makeLabelField(88, 269, 10, 1)

	surfaceElements.buttons[777] = surface.makeButton(99, 264, 10, 10)
	surfaceElements.buttons[777].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 86)
	surfaceElements.labels[777] = surface.makeLabelField(99, 269, 10, 1)

	surfaceElements.buttons[778] = surface.makeButton(110, 264, 10, 10)
	surfaceElements.buttons[778].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 87)
	surfaceElements.labels[778] = surface.makeLabelField(110, 269, 10, 1)

	surfaceElements.buttons[779] = surface.makeButton(121, 264, 10, 10)
	surfaceElements.buttons[779].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 88)
	surfaceElements.labels[779] = surface.makeLabelField(121, 269, 10, 1)

	surfaceElements.buttons[780] = surface.makeButton(132, 264, 10, 10)
	surfaceElements.buttons[780].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 89)
	surfaceElements.labels[780] = surface.makeLabelField(132, 269, 10, 1)

	surfaceElements.buttons[781] = surface.makeButton(143, 264, 10, 10)
	surfaceElements.buttons[781].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 90)
	surfaceElements.labels[781] = surface.makeLabelField(143, 269, 10, 1)

	surfaceElements.buttons[782] = surface.makeButton(154, 264, 10, 10)
	surfaceElements.buttons[782].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 91)
	surfaceElements.labels[782] = surface.makeLabelField(154, 269, 10, 1)

	surfaceElements.buttons[783] = surface.makeButton(165, 264, 10, 10)
	surfaceElements.buttons[783].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 92)
	surfaceElements.labels[783] = surface.makeLabelField(165, 269, 10, 1)

	surfaceElements.buttons[784] = surface.makeButton(176, 264, 10, 10)
	surfaceElements.buttons[784].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 93)
	surfaceElements.labels[784] = surface.makeLabelField(176, 269, 10, 1)

	surfaceElements.buttons[785] = surface.makeButton(187, 264, 10, 10)
	surfaceElements.buttons[785].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 94)
	surfaceElements.labels[785] = surface.makeLabelField(187, 269, 10, 1)

	surfaceElements.buttons[786] = surface.makeButton(198, 264, 10, 10)
	surfaceElements.buttons[786].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 95)
	surfaceElements.labels[786] = surface.makeLabelField(198, 269, 10, 1)

	surfaceElements.buttons[787] = surface.makeButton(209, 264, 10, 10)
	surfaceElements.buttons[787].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 96)
	surfaceElements.labels[787] = surface.makeLabelField(209, 269, 10, 1)

	surfaceElements.buttons[788] = surface.makeButton(220, 264, 10, 10)
	surfaceElements.buttons[788].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 97)
	surfaceElements.labels[788] = surface.makeLabelField(220, 269, 10, 1)

	surfaceElements.buttons[789] = surface.makeButton(231, 264, 10, 10)
	surfaceElements.buttons[789].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 98)
	surfaceElements.labels[789] = surface.makeLabelField(231, 269, 10, 1)

	surfaceElements.buttons[790] = surface.makeButton(242, 264, 10, 10)
	surfaceElements.buttons[790].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 99)
	surfaceElements.labels[790] = surface.makeLabelField(242, 269, 10, 1)

	surfaceElements.buttons[791] = surface.makeButton(253, 264, 10, 10)
	surfaceElements.buttons[791].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 100)
	surfaceElements.labels[791] = surface.makeLabelField(253, 269, 10, 1)

	surfaceElements.buttons[792] = surface.makeButton(264, 264, 10, 10)
	surfaceElements.buttons[792].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 101)
	surfaceElements.labels[792] = surface.makeLabelField(264, 269, 10, 1)

	surfaceElements.buttons[793] = surface.makeButton(275, 264, 10, 10)
	surfaceElements.buttons[793].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 102)
	surfaceElements.labels[793] = surface.makeLabelField(275, 269, 10, 1)

	surfaceElements.buttons[794] = surface.makeButton(286, 264, 10, 10)
	surfaceElements.buttons[794].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 103)
	surfaceElements.labels[794] = surface.makeLabelField(286, 269, 10, 1)

	surfaceElements.buttons[795] = surface.makeButton(297, 264, 10, 10)
	surfaceElements.buttons[795].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 104)
	surfaceElements.labels[795] = surface.makeLabelField(297, 269, 10, 1)

	surfaceElements.buttons[796] = surface.makeButton(308, 264, 10, 10)
	surfaceElements.buttons[796].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 105)
	surfaceElements.labels[796] = surface.makeLabelField(308, 269, 10, 1)

	surfaceElements.buttons[797] = surface.makeButton(319, 264, 10, 10)
	surfaceElements.buttons[797].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 106)
	surfaceElements.labels[797] = surface.makeLabelField(319, 269, 10, 1)

	surfaceElements.buttons[798] = surface.makeButton(330, 264, 10, 10)
	surfaceElements.buttons[798].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 107)
	surfaceElements.labels[798] = surface.makeLabelField(330, 269, 10, 1)

	surfaceElements.buttons[799] = surface.makeButton(341, 264, 10, 10)
	surfaceElements.buttons[799].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 108)
	surfaceElements.labels[799] = surface.makeLabelField(341, 269, 10, 1)

	surfaceElements.buttons[800] = surface.makeButton(0, 275, 10, 10)
	surfaceElements.buttons[800].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 109)
	surfaceElements.labels[800] = surface.makeLabelField(0, 280, 10, 1)

	surfaceElements.buttons[801] = surface.makeButton(11, 275, 10, 10)
	surfaceElements.buttons[801].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 110)
	surfaceElements.labels[801] = surface.makeLabelField(11, 280, 10, 1)

	surfaceElements.buttons[802] = surface.makeButton(22, 275, 10, 10)
	surfaceElements.buttons[802].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 9)
	surfaceElements.labels[802] = surface.makeLabelField(22, 280, 10, 1)

	surfaceElements.buttons[803] = surface.makeButton(33, 275, 10, 10)
	surfaceElements.buttons[803].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 10)
	surfaceElements.labels[803] = surface.makeLabelField(33, 280, 10, 1)

	surfaceElements.buttons[804] = surface.makeButton(44, 275, 10, 10)
	surfaceElements.buttons[804].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 101)
	surfaceElements.labels[804] = surface.makeLabelField(44, 280, 10, 1)

	surfaceElements.buttons[805] = surface.makeButton(55, 275, 10, 10)
	surfaceElements.buttons[805].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 102)
	surfaceElements.labels[805] = surface.makeLabelField(55, 280, 10, 1)

	surfaceElements.buttons[806] = surface.makeButton(66, 275, 10, 10)
	surfaceElements.buttons[806].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 103)
	surfaceElements.labels[806] = surface.makeLabelField(66, 280, 10, 1)

	surfaceElements.buttons[807] = surface.makeButton(77, 275, 10, 10)
	surfaceElements.buttons[807].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 104)
	surfaceElements.labels[807] = surface.makeLabelField(77, 280, 10, 1)

	surfaceElements.buttons[808] = surface.makeButton(88, 275, 10, 10)
	surfaceElements.buttons[808].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 105)
	surfaceElements.labels[808] = surface.makeLabelField(88, 280, 10, 1)

	surfaceElements.buttons[809] = surface.makeButton(99, 275, 10, 10)
	surfaceElements.buttons[809].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 106)
	surfaceElements.labels[809] = surface.makeLabelField(99, 280, 10, 1)

	surfaceElements.buttons[810] = surface.makeButton(110, 275, 10, 10)
	surfaceElements.buttons[810].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 107)
	surfaceElements.labels[810] = surface.makeLabelField(110, 280, 10, 1)

	surfaceElements.buttons[811] = surface.makeButton(121, 275, 10, 10)
	surfaceElements.buttons[811].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 108)
	surfaceElements.labels[811] = surface.makeLabelField(121, 280, 10, 1)

	surfaceElements.buttons[812] = surface.makeButton(132, 275, 10, 10)
	surfaceElements.buttons[812].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 109)
	surfaceElements.labels[812] = surface.makeLabelField(132, 280, 10, 1)

	surfaceElements.buttons[813] = surface.makeButton(143, 275, 10, 10)
	surfaceElements.buttons[813].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 110)
	surfaceElements.labels[813] = surface.makeLabelField(143, 280, 10, 1)

	surfaceElements.buttons[814] = surface.makeButton(154, 275, 10, 10)
	surfaceElements.buttons[814].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 111)
	surfaceElements.labels[814] = surface.makeLabelField(154, 280, 10, 1)

	surfaceElements.buttons[815] = surface.makeButton(165, 275, 10, 10)
	surfaceElements.buttons[815].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 112)
	surfaceElements.labels[815] = surface.makeLabelField(165, 280, 10, 1)

	surfaceElements.buttons[816] = surface.makeButton(176, 275, 10, 10)
	surfaceElements.buttons[816].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 113)
	surfaceElements.labels[816] = surface.makeLabelField(176, 280, 10, 1)

	surfaceElements.buttons[817] = surface.makeButton(187, 275, 10, 10)
	surfaceElements.buttons[817].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 114)
	surfaceElements.labels[817] = surface.makeLabelField(187, 280, 10, 1)

	surfaceElements.buttons[818] = surface.makeButton(198, 275, 10, 10)
	surfaceElements.buttons[818].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 115)
	surfaceElements.labels[818] = surface.makeLabelField(198, 280, 10, 1)

	surfaceElements.buttons[819] = surface.makeButton(209, 275, 10, 10)
	surfaceElements.buttons[819].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 116)
	surfaceElements.labels[819] = surface.makeLabelField(209, 280, 10, 1)

	surfaceElements.buttons[820] = surface.makeButton(220, 275, 10, 10)
	surfaceElements.buttons[820].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 117)
	surfaceElements.labels[820] = surface.makeLabelField(220, 280, 10, 1)

	surfaceElements.buttons[821] = surface.makeButton(231, 275, 10, 10)
	surfaceElements.buttons[821].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 118)
	surfaceElements.labels[821] = surface.makeLabelField(231, 280, 10, 1)

	surfaceElements.buttons[822] = surface.makeButton(242, 275, 10, 10)
	surfaceElements.buttons[822].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 119)
	surfaceElements.labels[822] = surface.makeLabelField(242, 280, 10, 1)

	surfaceElements.buttons[823] = surface.makeButton(253, 275, 10, 10)
	surfaceElements.buttons[823].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 120)
	surfaceElements.labels[823] = surface.makeLabelField(253, 280, 10, 1)

	surfaceElements.buttons[824] = surface.makeButton(264, 275, 10, 10)
	surfaceElements.buttons[824].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 121)
	surfaceElements.labels[824] = surface.makeLabelField(264, 280, 10, 1)

	surfaceElements.buttons[825] = surface.makeButton(275, 275, 10, 10)
	surfaceElements.buttons[825].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 122)
	surfaceElements.labels[825] = surface.makeLabelField(275, 280, 10, 1)

	surfaceElements.buttons[826] = surface.makeButton(286, 275, 10, 10)
	surfaceElements.buttons[826].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 123)
	surfaceElements.labels[826] = surface.makeLabelField(286, 280, 10, 1)

	surfaceElements.buttons[827] = surface.makeButton(297, 275, 10, 10)
	surfaceElements.buttons[827].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 124)
	surfaceElements.labels[827] = surface.makeLabelField(297, 280, 10, 1)

	surfaceElements.buttons[828] = surface.makeButton(308, 275, 10, 10)
	surfaceElements.buttons[828].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 125)
	surfaceElements.labels[828] = surface.makeLabelField(308, 280, 10, 1)

	surfaceElements.buttons[829] = surface.makeButton(319, 275, 10, 10)
	surfaceElements.buttons[829].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 126)
	surfaceElements.labels[829] = surface.makeLabelField(319, 280, 10, 1)

	surfaceElements.buttons[830] = surface.makeButton(330, 275, 10, 10)
	surfaceElements.buttons[830].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 111)
	surfaceElements.labels[830] = surface.makeLabelField(330, 280, 10, 1)

	surfaceElements.buttons[831] = surface.makeButton(341, 275, 10, 10)
	surfaceElements.buttons[831].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 112)
	surfaceElements.labels[831] = surface.makeLabelField(341, 280, 10, 1)

	surfaceElements.buttons[832] = surface.makeButton(0, 286, 10, 10)
	surfaceElements.buttons[832].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 113)
	surfaceElements.labels[832] = surface.makeLabelField(0, 291, 10, 1)

	surfaceElements.buttons[833] = surface.makeButton(11, 286, 10, 10)
	surfaceElements.buttons[833].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 114)
	surfaceElements.labels[833] = surface.makeLabelField(11, 291, 10, 1)

	surfaceElements.buttons[834] = surface.makeButton(22, 286, 10, 10)
	surfaceElements.buttons[834].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 115)
	surfaceElements.labels[834] = surface.makeLabelField(22, 291, 10, 1)

	surfaceElements.buttons[835] = surface.makeButton(33, 286, 10, 10)
	surfaceElements.buttons[835].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 116)
	surfaceElements.labels[835] = surface.makeLabelField(33, 291, 10, 1)

	surfaceElements.buttons[836] = surface.makeButton(44, 286, 10, 10)
	surfaceElements.buttons[836].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 117)
	surfaceElements.labels[836] = surface.makeLabelField(44, 291, 10, 1)

	surfaceElements.buttons[837] = surface.makeButton(55, 286, 10, 10)
	surfaceElements.buttons[837].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 118)
	surfaceElements.labels[837] = surface.makeLabelField(55, 291, 10, 1)

	surfaceElements.buttons[838] = surface.makeButton(66, 286, 10, 10)
	surfaceElements.buttons[838].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 119)
	surfaceElements.labels[838] = surface.makeLabelField(66, 291, 10, 1)

	surfaceElements.buttons[839] = surface.makeButton(77, 286, 10, 10)
	surfaceElements.buttons[839].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 120)
	surfaceElements.labels[839] = surface.makeLabelField(77, 291, 10, 1)

	surfaceElements.buttons[840] = surface.makeButton(88, 286, 10, 10)
	surfaceElements.buttons[840].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 121)
	surfaceElements.labels[840] = surface.makeLabelField(88, 291, 10, 1)

	surfaceElements.buttons[841] = surface.makeButton(99, 286, 10, 10)
	surfaceElements.buttons[841].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 122)
	surfaceElements.labels[841] = surface.makeLabelField(99, 291, 10, 1)

	surfaceElements.buttons[842] = surface.makeButton(110, 286, 10, 10)
	surfaceElements.buttons[842].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 123)
	surfaceElements.labels[842] = surface.makeLabelField(110, 291, 10, 1)

	surfaceElements.buttons[843] = surface.makeButton(121, 286, 10, 10)
	surfaceElements.buttons[843].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 124)
	surfaceElements.labels[843] = surface.makeLabelField(121, 291, 10, 1)

	surfaceElements.buttons[844] = surface.makeButton(132, 286, 10, 10)
	surfaceElements.buttons[844].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 125)
	surfaceElements.labels[844] = surface.makeLabelField(132, 291, 10, 1)

	surfaceElements.buttons[845] = surface.makeButton(143, 286, 10, 10)
	surfaceElements.buttons[845].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 126)
	surfaceElements.labels[845] = surface.makeLabelField(143, 291, 10, 1)

	surfaceElements.buttons[846] = surface.makeButton(154, 286, 10, 10)
	surfaceElements.buttons[846].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 127)
	surfaceElements.labels[846] = surface.makeLabelField(154, 291, 10, 1)

	surfaceElements.buttons[847] = surface.makeButton(165, 286, 10, 10)
	surfaceElements.buttons[847].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 87)
	surfaceElements.labels[847] = surface.makeLabelField(165, 291, 10, 1)

	surfaceElements.buttons[848] = surface.makeButton(176, 286, 10, 10)
	surfaceElements.buttons[848].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 88)
	surfaceElements.labels[848] = surface.makeLabelField(176, 291, 10, 1)

	surfaceElements.buttons[849] = surface.makeButton(187, 286, 10, 10)
	surfaceElements.buttons[849].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 89)
	surfaceElements.labels[849] = surface.makeLabelField(187, 291, 10, 1)

	surfaceElements.buttons[850] = surface.makeButton(198, 286, 10, 10)
	surfaceElements.buttons[850].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 90)
	surfaceElements.labels[850] = surface.makeLabelField(198, 291, 10, 1)

	surfaceElements.buttons[851] = surface.makeButton(209, 286, 10, 10)
	surfaceElements.buttons[851].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 91)
	surfaceElements.labels[851] = surface.makeLabelField(209, 291, 10, 1)

	surfaceElements.buttons[852] = surface.makeButton(220, 286, 10, 10)
	surfaceElements.buttons[852].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 92)
	surfaceElements.labels[852] = surface.makeLabelField(220, 291, 10, 1)

	surfaceElements.buttons[853] = surface.makeButton(231, 286, 10, 10)
	surfaceElements.buttons[853].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 93)
	surfaceElements.labels[853] = surface.makeLabelField(231, 291, 10, 1)

	surfaceElements.buttons[854] = surface.makeButton(242, 286, 10, 10)
	surfaceElements.buttons[854].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 94)
	surfaceElements.labels[854] = surface.makeLabelField(242, 291, 10, 1)

	surfaceElements.buttons[855] = surface.makeButton(253, 286, 10, 10)
	surfaceElements.buttons[855].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 95)
	surfaceElements.labels[855] = surface.makeLabelField(253, 291, 10, 1)

	surfaceElements.buttons[856] = surface.makeButton(264, 286, 10, 10)
	surfaceElements.buttons[856].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 96)
	surfaceElements.labels[856] = surface.makeLabelField(264, 291, 10, 1)

	surfaceElements.buttons[857] = surface.makeButton(275, 286, 10, 10)
	surfaceElements.buttons[857].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 97)
	surfaceElements.labels[857] = surface.makeLabelField(275, 291, 10, 1)

	surfaceElements.buttons[858] = surface.makeButton(286, 286, 10, 10)
	surfaceElements.buttons[858].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 98)
	surfaceElements.labels[858] = surface.makeLabelField(286, 291, 10, 1)

	surfaceElements.buttons[859] = surface.makeButton(297, 286, 10, 10)
	surfaceElements.buttons[859].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 99)
	surfaceElements.labels[859] = surface.makeLabelField(297, 291, 10, 1)

	surfaceElements.buttons[860] = surface.makeButton(308, 286, 10, 10)
	surfaceElements.buttons[860].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 100)
	surfaceElements.labels[860] = surface.makeLabelField(308, 291, 10, 1)

	surfaceElements.buttons[861] = surface.makeButton(319, 286, 10, 10)
	surfaceElements.buttons[861].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 101)
	surfaceElements.labels[861] = surface.makeLabelField(319, 291, 10, 1)

	surfaceElements.buttons[862] = surface.makeButton(330, 286, 10, 10)
	surfaceElements.buttons[862].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 102)
	surfaceElements.labels[862] = surface.makeLabelField(330, 291, 10, 1)

	surfaceElements.buttons[863] = surface.makeButton(341, 286, 10, 10)
	surfaceElements.buttons[863].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 103)
	surfaceElements.labels[863] = surface.makeLabelField(341, 291, 10, 1)

	surfaceElements.buttons[864] = surface.makeButton(0, 297, 10, 10)
	surfaceElements.buttons[864].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 104)
	surfaceElements.labels[864] = surface.makeLabelField(0, 302, 10, 1)

	surfaceElements.buttons[865] = surface.makeButton(11, 297, 10, 10)
	surfaceElements.buttons[865].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 105)
	surfaceElements.labels[865] = surface.makeLabelField(11, 302, 10, 1)

	surfaceElements.buttons[866] = surface.makeButton(22, 297, 10, 10)
	surfaceElements.buttons[866].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 106)
	surfaceElements.labels[866] = surface.makeLabelField(22, 302, 10, 1)

	surfaceElements.buttons[867] = surface.makeButton(33, 297, 10, 10)
	surfaceElements.buttons[867].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 107)
	surfaceElements.labels[867] = surface.makeLabelField(33, 302, 10, 1)

	surfaceElements.buttons[868] = surface.makeButton(44, 297, 10, 10)
	surfaceElements.buttons[868].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 108)
	surfaceElements.labels[868] = surface.makeLabelField(44, 302, 10, 1)

	surfaceElements.buttons[869] = surface.makeButton(55, 297, 10, 10)
	surfaceElements.buttons[869].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 109)
	surfaceElements.labels[869] = surface.makeLabelField(55, 302, 10, 1)

	surfaceElements.buttons[870] = surface.makeButton(66, 297, 10, 10)
	surfaceElements.buttons[870].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 110)
	surfaceElements.labels[870] = surface.makeLabelField(66, 302, 10, 1)

	surfaceElements.buttons[871] = surface.makeButton(77, 297, 10, 10)
	surfaceElements.buttons[871].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 111)
	surfaceElements.labels[871] = surface.makeLabelField(77, 302, 10, 1)

	surfaceElements.buttons[872] = surface.makeButton(88, 297, 10, 10)
	surfaceElements.buttons[872].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 112)
	surfaceElements.labels[872] = surface.makeLabelField(88, 302, 10, 1)

	surfaceElements.buttons[873] = surface.makeButton(99, 297, 10, 10)
	surfaceElements.buttons[873].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 113)
	surfaceElements.labels[873] = surface.makeLabelField(99, 302, 10, 1)

	surfaceElements.buttons[874] = surface.makeButton(110, 297, 10, 10)
	surfaceElements.buttons[874].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 114)
	surfaceElements.labels[874] = surface.makeLabelField(110, 302, 10, 1)

	surfaceElements.buttons[875] = surface.makeButton(121, 297, 10, 10)
	surfaceElements.buttons[875].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 115)
	surfaceElements.labels[875] = surface.makeLabelField(121, 302, 10, 1)

	surfaceElements.buttons[876] = surface.makeButton(132, 297, 10, 10)
	surfaceElements.buttons[876].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 83)
	surfaceElements.labels[876] = surface.makeLabelField(132, 302, 10, 1)

	surfaceElements.buttons[877] = surface.makeButton(143, 297, 10, 10)
	surfaceElements.buttons[877].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 84)
	surfaceElements.labels[877] = surface.makeLabelField(143, 302, 10, 1)

	surfaceElements.buttons[878] = surface.makeButton(154, 297, 10, 10)
	surfaceElements.buttons[878].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 85)
	surfaceElements.labels[878] = surface.makeLabelField(154, 302, 10, 1)

	surfaceElements.buttons[879] = surface.makeButton(165, 297, 10, 10)
	surfaceElements.buttons[879].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 86)
	surfaceElements.labels[879] = surface.makeLabelField(165, 302, 10, 1)

	surfaceElements.buttons[880] = surface.makeButton(176, 297, 10, 10)
	surfaceElements.buttons[880].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 87)
	surfaceElements.labels[880] = surface.makeLabelField(176, 302, 10, 1)

	surfaceElements.buttons[881] = surface.makeButton(187, 297, 10, 10)
	surfaceElements.buttons[881].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 88)
	surfaceElements.labels[881] = surface.makeLabelField(187, 302, 10, 1)

	surfaceElements.buttons[882] = surface.makeButton(198, 297, 10, 10)
	surfaceElements.buttons[882].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 89)
	surfaceElements.labels[882] = surface.makeLabelField(198, 302, 10, 1)

	surfaceElements.buttons[883] = surface.makeButton(209, 297, 10, 10)
	surfaceElements.buttons[883].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 90)
	surfaceElements.labels[883] = surface.makeLabelField(209, 302, 10, 1)

	surfaceElements.buttons[884] = surface.makeButton(220, 297, 10, 10)
	surfaceElements.buttons[884].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 91)
	surfaceElements.labels[884] = surface.makeLabelField(220, 302, 10, 1)

	surfaceElements.buttons[885] = surface.makeButton(231, 297, 10, 10)
	surfaceElements.buttons[885].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 92)
	surfaceElements.labels[885] = surface.makeLabelField(231, 302, 10, 1)

	surfaceElements.buttons[886] = surface.makeButton(242, 297, 10, 10)
	surfaceElements.buttons[886].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 93)
	surfaceElements.labels[886] = surface.makeLabelField(242, 302, 10, 1)

	surfaceElements.buttons[887] = surface.makeButton(253, 297, 10, 10)
	surfaceElements.buttons[887].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 94)
	surfaceElements.labels[887] = surface.makeLabelField(253, 302, 10, 1)

	surfaceElements.buttons[888] = surface.makeButton(264, 297, 10, 10)
	surfaceElements.buttons[888].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 95)
	surfaceElements.labels[888] = surface.makeLabelField(264, 302, 10, 1)

	surfaceElements.buttons[889] = surface.makeButton(275, 297, 10, 10)
	surfaceElements.buttons[889].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 96)
	surfaceElements.labels[889] = surface.makeLabelField(275, 302, 10, 1)

	surfaceElements.buttons[890] = surface.makeButton(286, 297, 10, 10)
	surfaceElements.buttons[890].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 97)
	surfaceElements.labels[890] = surface.makeLabelField(286, 302, 10, 1)

	surfaceElements.buttons[891] = surface.makeButton(297, 297, 10, 10)
	surfaceElements.buttons[891].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 98)
	surfaceElements.labels[891] = surface.makeLabelField(297, 302, 10, 1)

	surfaceElements.buttons[892] = surface.makeButton(308, 297, 10, 10)
	surfaceElements.buttons[892].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 99)
	surfaceElements.labels[892] = surface.makeLabelField(308, 302, 10, 1)

	surfaceElements.buttons[893] = surface.makeButton(319, 297, 10, 10)
	surfaceElements.buttons[893].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 100)
	surfaceElements.labels[893] = surface.makeLabelField(319, 302, 10, 1)

	surfaceElements.buttons[894] = surface.makeButton(330, 297, 10, 10)
	surfaceElements.buttons[894].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 101)
	surfaceElements.labels[894] = surface.makeLabelField(330, 302, 10, 1)

	surfaceElements.buttons[895] = surface.makeButton(341, 297, 10, 10)
	surfaceElements.buttons[895].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 102)
	surfaceElements.labels[895] = surface.makeLabelField(341, 302, 10, 1)

	surfaceElements.buttons[896] = surface.makeButton(0, 308, 10, 10)
	surfaceElements.buttons[896].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 103)
	surfaceElements.labels[896] = surface.makeLabelField(0, 313, 10, 1)

	surfaceElements.buttons[897] = surface.makeButton(11, 308, 10, 10)
	surfaceElements.buttons[897].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 104)
	surfaceElements.labels[897] = surface.makeLabelField(11, 313, 10, 1)

	surfaceElements.buttons[898] = surface.makeButton(22, 308, 10, 10)
	surfaceElements.buttons[898].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 105)
	surfaceElements.labels[898] = surface.makeLabelField(22, 313, 10, 1)

	surfaceElements.buttons[899] = surface.makeButton(33, 308, 10, 10)
	surfaceElements.buttons[899].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 106)
	surfaceElements.labels[899] = surface.makeLabelField(33, 313, 10, 1)

	surfaceElements.buttons[900] = surface.makeButton(44, 308, 10, 10)
	surfaceElements.buttons[900].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 107)
	surfaceElements.labels[900] = surface.makeLabelField(44, 313, 10, 1)

	surfaceElements.buttons[901] = surface.makeButton(55, 308, 10, 10)
	surfaceElements.buttons[901].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 108)
	surfaceElements.labels[901] = surface.makeLabelField(55, 313, 10, 1)

	surfaceElements.buttons[902] = surface.makeButton(66, 308, 10, 10)
	surfaceElements.buttons[902].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 109)
	surfaceElements.labels[902] = surface.makeLabelField(66, 313, 10, 1)

	surfaceElements.buttons[903] = surface.makeButton(77, 308, 10, 10)
	surfaceElements.buttons[903].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 110)
	surfaceElements.labels[903] = surface.makeLabelField(77, 313, 10, 1)

	surfaceElements.buttons[904] = surface.makeButton(88, 308, 10, 10)
	surfaceElements.buttons[904].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 111)
	surfaceElements.labels[904] = surface.makeLabelField(88, 313, 10, 1)

	surfaceElements.buttons[905] = surface.makeButton(99, 308, 10, 10)
	surfaceElements.buttons[905].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 112)
	surfaceElements.labels[905] = surface.makeLabelField(99, 313, 10, 1)

	surfaceElements.buttons[906] = surface.makeButton(110, 308, 10, 10)
	surfaceElements.buttons[906].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 113)
	surfaceElements.labels[906] = surface.makeLabelField(110, 313, 10, 1)

	surfaceElements.buttons[907] = surface.makeButton(121, 308, 10, 10)
	surfaceElements.buttons[907].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 114)
	surfaceElements.labels[907] = surface.makeLabelField(121, 313, 10, 1)

	surfaceElements.buttons[908] = surface.makeButton(132, 308, 10, 10)
	surfaceElements.buttons[908].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 115)
	surfaceElements.labels[908] = surface.makeLabelField(132, 313, 10, 1)

	surfaceElements.buttons[909] = surface.makeButton(143, 308, 10, 10)
	surfaceElements.buttons[909].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 116)
	surfaceElements.labels[909] = surface.makeLabelField(143, 313, 10, 1)

	surfaceElements.buttons[910] = surface.makeButton(154, 308, 10, 10)
	surfaceElements.buttons[910].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 117)
	surfaceElements.labels[910] = surface.makeLabelField(154, 313, 10, 1)

	surfaceElements.buttons[911] = surface.makeButton(165, 308, 10, 10)
	surfaceElements.buttons[911].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 118)
	surfaceElements.labels[911] = surface.makeLabelField(165, 313, 10, 1)

	surfaceElements.buttons[912] = surface.makeButton(176, 308, 10, 10)
	surfaceElements.buttons[912].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 119)
	surfaceElements.labels[912] = surface.makeLabelField(176, 313, 10, 1)

	surfaceElements.buttons[913] = surface.makeButton(187, 308, 10, 10)
	surfaceElements.buttons[913].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 120)
	surfaceElements.labels[913] = surface.makeLabelField(187, 313, 10, 1)

	surfaceElements.buttons[914] = surface.makeButton(198, 308, 10, 10)
	surfaceElements.buttons[914].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 121)
	surfaceElements.labels[914] = surface.makeLabelField(198, 313, 10, 1)

	surfaceElements.buttons[915] = surface.makeButton(209, 308, 10, 10)
	surfaceElements.buttons[915].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 122)
	surfaceElements.labels[915] = surface.makeLabelField(209, 313, 10, 1)

	surfaceElements.buttons[916] = surface.makeButton(220, 308, 10, 10)
	surfaceElements.buttons[916].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 123)
	surfaceElements.labels[916] = surface.makeLabelField(220, 313, 10, 1)

	surfaceElements.buttons[917] = surface.makeButton(231, 308, 10, 10)
	surfaceElements.buttons[917].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 124)
	surfaceElements.labels[917] = surface.makeLabelField(231, 313, 10, 1)

	surfaceElements.buttons[918] = surface.makeButton(242, 308, 10, 10)
	surfaceElements.buttons[918].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 125)
	surfaceElements.labels[918] = surface.makeLabelField(242, 313, 10, 1)

	surfaceElements.buttons[919] = surface.makeButton(253, 308, 10, 10)
	surfaceElements.buttons[919].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 126)
	surfaceElements.labels[919] = surface.makeLabelField(253, 313, 10, 1)

	surfaceElements.buttons[920] = surface.makeButton(264, 308, 10, 10)
	surfaceElements.buttons[920].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 127)
	surfaceElements.labels[920] = surface.makeLabelField(264, 313, 10, 1)

	surfaceElements.buttons[921] = surface.makeButton(275, 308, 10, 10)
	surfaceElements.buttons[921].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 67)
	surfaceElements.labels[921] = surface.makeLabelField(275, 313, 10, 1)

	surfaceElements.buttons[922] = surface.makeButton(286, 308, 10, 10)
	surfaceElements.buttons[922].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 68)
	surfaceElements.labels[922] = surface.makeLabelField(286, 313, 10, 1)

	surfaceElements.buttons[923] = surface.makeButton(297, 308, 10, 10)
	surfaceElements.buttons[923].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 69)
	surfaceElements.labels[923] = surface.makeLabelField(297, 313, 10, 1)

	surfaceElements.buttons[924] = surface.makeButton(308, 308, 10, 10)
	surfaceElements.buttons[924].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 70)
	surfaceElements.labels[924] = surface.makeLabelField(308, 313, 10, 1)

	surfaceElements.buttons[925] = surface.makeButton(319, 308, 10, 10)
	surfaceElements.buttons[925].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 71)
	surfaceElements.labels[925] = surface.makeLabelField(319, 313, 10, 1)

	surfaceElements.buttons[926] = surface.makeButton(330, 308, 10, 10)
	surfaceElements.buttons[926].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 72)
	surfaceElements.labels[926] = surface.makeLabelField(330, 313, 10, 1)

	surfaceElements.buttons[927] = surface.makeButton(341, 308, 10, 10)
	surfaceElements.buttons[927].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 73)
	surfaceElements.labels[927] = surface.makeLabelField(341, 313, 10, 1)

	surfaceElements.buttons[928] = surface.makeButton(0, 319, 10, 10)
	surfaceElements.buttons[928].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 74)
	surfaceElements.labels[928] = surface.makeLabelField(0, 324, 10, 1)

	surfaceElements.buttons[929] = surface.makeButton(11, 319, 10, 10)
	surfaceElements.buttons[929].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 75)
	surfaceElements.labels[929] = surface.makeLabelField(11, 324, 10, 1)

	surfaceElements.buttons[930] = surface.makeButton(22, 319, 10, 10)
	surfaceElements.buttons[930].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 76)
	surfaceElements.labels[930] = surface.makeLabelField(22, 324, 10, 1)

	surfaceElements.buttons[931] = surface.makeButton(33, 319, 10, 10)
	surfaceElements.buttons[931].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 77)
	surfaceElements.labels[931] = surface.makeLabelField(33, 324, 10, 1)

	surfaceElements.buttons[932] = surface.makeButton(44, 319, 10, 10)
	surfaceElements.buttons[932].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 78)
	surfaceElements.labels[932] = surface.makeLabelField(44, 324, 10, 1)

	surfaceElements.buttons[933] = surface.makeButton(55, 319, 10, 10)
	surfaceElements.buttons[933].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 79)
	surfaceElements.labels[933] = surface.makeLabelField(55, 324, 10, 1)

	surfaceElements.buttons[934] = surface.makeButton(66, 319, 10, 10)
	surfaceElements.buttons[934].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 80)
	surfaceElements.labels[934] = surface.makeLabelField(66, 324, 10, 1)

	surfaceElements.buttons[935] = surface.makeButton(77, 319, 10, 10)
	surfaceElements.buttons[935].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 81)
	surfaceElements.labels[935] = surface.makeLabelField(77, 324, 10, 1)

	surfaceElements.buttons[936] = surface.makeButton(88, 319, 10, 10)
	surfaceElements.buttons[936].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 82)
	surfaceElements.labels[936] = surface.makeLabelField(88, 324, 10, 1)

	surfaceElements.buttons[937] = surface.makeButton(99, 319, 10, 10)
	surfaceElements.buttons[937].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 83)
	surfaceElements.labels[937] = surface.makeLabelField(99, 324, 10, 1)

	surfaceElements.buttons[938] = surface.makeButton(110, 319, 10, 10)
	surfaceElements.buttons[938].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 84)
	surfaceElements.labels[938] = surface.makeLabelField(110, 324, 10, 1)

	surfaceElements.buttons[939] = surface.makeButton(121, 319, 10, 10)
	surfaceElements.buttons[939].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 85)
	surfaceElements.labels[939] = surface.makeLabelField(121, 324, 10, 1)

	surfaceElements.buttons[940] = surface.makeButton(132, 319, 10, 10)
	surfaceElements.buttons[940].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 86)
	surfaceElements.labels[940] = surface.makeLabelField(132, 324, 10, 1)

	surfaceElements.buttons[941] = surface.makeButton(143, 319, 10, 10)
	surfaceElements.buttons[941].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 87)
	surfaceElements.labels[941] = surface.makeLabelField(143, 324, 10, 1)

	surfaceElements.buttons[942] = surface.makeButton(154, 319, 10, 10)
	surfaceElements.buttons[942].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 88)
	surfaceElements.labels[942] = surface.makeLabelField(154, 324, 10, 1)

	surfaceElements.buttons[943] = surface.makeButton(165, 319, 10, 10)
	surfaceElements.buttons[943].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 89)
	surfaceElements.labels[943] = surface.makeLabelField(165, 324, 10, 1)

	surfaceElements.buttons[944] = surface.makeButton(176, 319, 10, 10)
	surfaceElements.buttons[944].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 90)
	surfaceElements.labels[944] = surface.makeLabelField(176, 324, 10, 1)

	surfaceElements.buttons[945] = surface.makeButton(187, 319, 10, 10)
	surfaceElements.buttons[945].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 91)
	surfaceElements.labels[945] = surface.makeLabelField(187, 324, 10, 1)

	surfaceElements.buttons[946] = surface.makeButton(198, 319, 10, 10)
	surfaceElements.buttons[946].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 92)
	surfaceElements.labels[946] = surface.makeLabelField(198, 324, 10, 1)

	surfaceElements.buttons[947] = surface.makeButton(209, 319, 10, 10)
	surfaceElements.buttons[947].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 93)
	surfaceElements.labels[947] = surface.makeLabelField(209, 324, 10, 1)

	surfaceElements.buttons[948] = surface.makeButton(220, 319, 10, 10)
	surfaceElements.buttons[948].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 94)
	surfaceElements.labels[948] = surface.makeLabelField(220, 324, 10, 1)

	surfaceElements.buttons[949] = surface.makeButton(231, 319, 10, 10)
	surfaceElements.buttons[949].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 95)
	surfaceElements.labels[949] = surface.makeLabelField(231, 324, 10, 1)

	surfaceElements.buttons[950] = surface.makeButton(242, 319, 10, 10)
	surfaceElements.buttons[950].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 96)
	surfaceElements.labels[950] = surface.makeLabelField(242, 324, 10, 1)

	surfaceElements.buttons[951] = surface.makeButton(253, 319, 10, 10)
	surfaceElements.buttons[951].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 97)
	surfaceElements.labels[951] = surface.makeLabelField(253, 324, 10, 1)

	surfaceElements.buttons[952] = surface.makeButton(264, 319, 10, 10)
	surfaceElements.buttons[952].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 98)
	surfaceElements.labels[952] = surface.makeLabelField(264, 324, 10, 1)

	surfaceElements.buttons[953] = surface.makeButton(275, 319, 10, 10)
	surfaceElements.buttons[953].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 99)
	surfaceElements.labels[953] = surface.makeLabelField(275, 324, 10, 1)

	surfaceElements.buttons[954] = surface.makeButton(286, 319, 10, 10)
	surfaceElements.buttons[954].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 100)
	surfaceElements.labels[954] = surface.makeLabelField(286, 324, 10, 1)

	surfaceElements.buttons[955] = surface.makeButton(297, 319, 10, 10)
	surfaceElements.buttons[955].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 101)
	surfaceElements.labels[955] = surface.makeLabelField(297, 324, 10, 1)

	surfaceElements.buttons[956] = surface.makeButton(308, 319, 10, 10)
	surfaceElements.buttons[956].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 102)
	surfaceElements.labels[956] = surface.makeLabelField(308, 324, 10, 1)

	surfaceElements.buttons[957] = surface.makeButton(319, 319, 10, 10)
	surfaceElements.buttons[957].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 103)
	surfaceElements.labels[957] = surface.makeLabelField(319, 324, 10, 1)

	surfaceElements.buttons[958] = surface.makeButton(330, 319, 10, 10)
	surfaceElements.buttons[958].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 104)
	surfaceElements.labels[958] = surface.makeLabelField(330, 324, 10, 1)

	surfaceElements.buttons[959] = surface.makeButton(341, 319, 10, 10)
	surfaceElements.buttons[959].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 105)
	surfaceElements.labels[959] = surface.makeLabelField(341, 324, 10, 1)

	surfaceElements.buttons[960] = surface.makeButton(0, 330, 10, 10)
	surfaceElements.buttons[960].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 106)
	surfaceElements.labels[960] = surface.makeLabelField(0, 335, 10, 1)

	surfaceElements.buttons[961] = surface.makeButton(11, 330, 10, 10)
	surfaceElements.buttons[961].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 107)
	surfaceElements.labels[961] = surface.makeLabelField(11, 335, 10, 1)

	surfaceElements.buttons[962] = surface.makeButton(22, 330, 10, 10)
	surfaceElements.buttons[962].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 108)
	surfaceElements.labels[962] = surface.makeLabelField(22, 335, 10, 1)

	surfaceElements.buttons[963] = surface.makeButton(33, 330, 10, 10)
	surfaceElements.buttons[963].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 109)
	surfaceElements.labels[963] = surface.makeLabelField(33, 335, 10, 1)

	surfaceElements.buttons[964] = surface.makeButton(44, 330, 10, 10)
	surfaceElements.buttons[964].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 110)
	surfaceElements.labels[964] = surface.makeLabelField(44, 335, 10, 1)

	surfaceElements.buttons[965] = surface.makeButton(55, 330, 10, 10)
	surfaceElements.buttons[965].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 111)
	surfaceElements.labels[965] = surface.makeLabelField(55, 335, 10, 1)

	surfaceElements.buttons[966] = surface.makeButton(66, 330, 10, 10)
	surfaceElements.buttons[966].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 112)
	surfaceElements.labels[966] = surface.makeLabelField(66, 335, 10, 1)

	surfaceElements.buttons[967] = surface.makeButton(77, 330, 10, 10)
	surfaceElements.buttons[967].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 113)
	surfaceElements.labels[967] = surface.makeLabelField(77, 335, 10, 1)

	surfaceElements.buttons[968] = surface.makeButton(88, 330, 10, 10)
	surfaceElements.buttons[968].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 114)
	surfaceElements.labels[968] = surface.makeLabelField(88, 335, 10, 1)

	surfaceElements.buttons[969] = surface.makeButton(99, 330, 10, 10)
	surfaceElements.buttons[969].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 115)
	surfaceElements.labels[969] = surface.makeLabelField(99, 335, 10, 1)

	surfaceElements.buttons[970] = surface.makeButton(110, 330, 10, 10)
	surfaceElements.buttons[970].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 116)
	surfaceElements.labels[970] = surface.makeLabelField(110, 335, 10, 1)

	surfaceElements.buttons[971] = surface.makeButton(121, 330, 10, 10)
	surfaceElements.buttons[971].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 117)
	surfaceElements.labels[971] = surface.makeLabelField(121, 335, 10, 1)

	surfaceElements.buttons[972] = surface.makeButton(132, 330, 10, 10)
	surfaceElements.buttons[972].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 118)
	surfaceElements.labels[972] = surface.makeLabelField(132, 335, 10, 1)

	surfaceElements.buttons[973] = surface.makeButton(143, 330, 10, 10)
	surfaceElements.buttons[973].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 119)
	surfaceElements.labels[973] = surface.makeLabelField(143, 335, 10, 1)

	surfaceElements.buttons[974] = surface.makeButton(154, 330, 10, 10)
	surfaceElements.buttons[974].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 120)
	surfaceElements.labels[974] = surface.makeLabelField(154, 335, 10, 1)

	surfaceElements.buttons[975] = surface.makeButton(165, 330, 10, 10)
	surfaceElements.buttons[975].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 121)
	surfaceElements.labels[975] = surface.makeLabelField(165, 335, 10, 1)

	surfaceElements.buttons[976] = surface.makeButton(176, 330, 10, 10)
	surfaceElements.buttons[976].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 122)
	surfaceElements.labels[976] = surface.makeLabelField(176, 335, 10, 1)

	surfaceElements.buttons[977] = surface.makeButton(187, 330, 10, 10)
	surfaceElements.buttons[977].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 123)
	surfaceElements.labels[977] = surface.makeLabelField(187, 335, 10, 1)

	surfaceElements.buttons[978] = surface.makeButton(198, 330, 10, 10)
	surfaceElements.buttons[978].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 124)
	surfaceElements.labels[978] = surface.makeLabelField(198, 335, 10, 1)

	surfaceElements.buttons[979] = surface.makeButton(209, 330, 10, 10)
	surfaceElements.buttons[979].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 125)
	surfaceElements.labels[979] = surface.makeLabelField(209, 335, 10, 1)

	surfaceElements.buttons[980] = surface.makeButton(220, 330, 10, 10)
	surfaceElements.buttons[980].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 126)
	surfaceElements.labels[980] = surface.makeLabelField(220, 335, 10, 1)

	surfaceElements.buttons[981] = surface.makeButton(231, 330, 10, 10)
	surfaceElements.buttons[981].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 127)
	surfaceElements.labels[981] = surface.makeLabelField(231, 335, 10, 1)

	surfaceElements.buttons[982] = surface.makeButton(242, 330, 10, 10)
	surfaceElements.buttons[982].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 111)
	surfaceElements.labels[982] = surface.makeLabelField(242, 335, 10, 1)

	surfaceElements.buttons[983] = surface.makeButton(253, 330, 10, 10)
	surfaceElements.buttons[983].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 112)
	surfaceElements.labels[983] = surface.makeLabelField(253, 335, 10, 1)

	surfaceElements.buttons[984] = surface.makeButton(264, 330, 10, 10)
	surfaceElements.buttons[984].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 113)
	surfaceElements.labels[984] = surface.makeLabelField(264, 335, 10, 1)

	surfaceElements.buttons[985] = surface.makeButton(275, 330, 10, 10)
	surfaceElements.buttons[985].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 114)
	surfaceElements.labels[985] = surface.makeLabelField(275, 335, 10, 1)

	surfaceElements.buttons[986] = surface.makeButton(286, 330, 10, 10)
	surfaceElements.buttons[986].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 115)
	surfaceElements.labels[986] = surface.makeLabelField(286, 335, 10, 1)

	surfaceElements.buttons[987] = surface.makeButton(297, 330, 10, 10)
	surfaceElements.buttons[987].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 116)
	surfaceElements.labels[987] = surface.makeLabelField(297, 335, 10, 1)

	surfaceElements.buttons[988] = surface.makeButton(308, 330, 10, 10)
	surfaceElements.buttons[988].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 117)
	surfaceElements.labels[988] = surface.makeLabelField(308, 335, 10, 1)

	surfaceElements.buttons[989] = surface.makeButton(319, 330, 10, 10)
	surfaceElements.buttons[989].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 118)
	surfaceElements.labels[989] = surface.makeLabelField(319, 335, 10, 1)

	surfaceElements.buttons[990] = surface.makeButton(330, 330, 10, 10)
	surfaceElements.buttons[990].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 119)
	surfaceElements.labels[990] = surface.makeLabelField(330, 335, 10, 1)

	surfaceElements.buttons[991] = surface.makeButton(341, 330, 10, 10)
	surfaceElements.buttons[991].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 120)
	surfaceElements.labels[991] = surface.makeLabelField(341, 335, 10, 1)

	surfaceElements.buttons[992] = surface.makeButton(0, 341, 10, 10)
	surfaceElements.buttons[992].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 121)
	surfaceElements.labels[992] = surface.makeLabelField(0, 346, 10, 1)

	surfaceElements.buttons[993] = surface.makeButton(11, 341, 10, 10)
	surfaceElements.buttons[993].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 122)
	surfaceElements.labels[993] = surface.makeLabelField(11, 346, 10, 1)

	surfaceElements.buttons[994] = surface.makeButton(22, 341, 10, 10)
	surfaceElements.buttons[994].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 123)
	surfaceElements.labels[994] = surface.makeLabelField(22, 346, 10, 1)

	surfaceElements.buttons[995] = surface.makeButton(33, 341, 10, 10)
	surfaceElements.buttons[995].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 124)
	surfaceElements.labels[995] = surface.makeLabelField(33, 346, 10, 1)

	surfaceElements.buttons[996] = surface.makeButton(44, 341, 10, 10)
	surfaceElements.buttons[996].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 125)
	surfaceElements.labels[996] = surface.makeLabelField(44, 346, 10, 1)

	surfaceElements.buttons[997] = surface.makeButton(55, 341, 10, 10)
	surfaceElements.buttons[997].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 126)
	surfaceElements.labels[997] = surface.makeLabelField(55, 346, 10, 1)

	surfaceElements.buttons[998] = surface.makeButton(66, 341, 10, 10)
	surfaceElements.buttons[998].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 127)
	surfaceElements.labels[998] = surface.makeLabelField(66, 346, 10, 1)

	surfaceElements.buttons[999] = surface.makeButton(77, 341, 10, 10)
	surfaceElements.buttons[999].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 121)
	surfaceElements.labels[999] = surface.makeLabelField(77, 346, 10, 1)

	surfaceElements.buttons[1000] = surface.makeButton(88, 341, 10, 10)
	surfaceElements.buttons[1000].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 122)
	surfaceElements.labels[1000] = surface.makeLabelField(88, 346, 10, 1)

	surfaceElements.buttons[1001] = surface.makeButton(99, 341, 10, 10)
	surfaceElements.buttons[1001].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 123)
	surfaceElements.labels[1001] = surface.makeLabelField(99, 346, 10, 1)

	surfaceElements.buttons[1002] = surface.makeButton(110, 341, 10, 10)
	surfaceElements.buttons[1002].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 124)
	surfaceElements.labels[1002] = surface.makeLabelField(110, 346, 10, 1)

	surfaceElements.buttons[1003] = surface.makeButton(121, 341, 10, 10)
	surfaceElements.buttons[1003].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 125)
	surfaceElements.labels[1003] = surface.makeLabelField(121, 346, 10, 1)

	return surfaceElements
}

var surfaceElements = makeSurfaceElements()
// var labelElements = makeLabelElements()

//----------------------------------------------------------------------------------------------------------------------
// 3. HOST MAPPING - create mapping pages and host bindings
//----------------------------------------------------------------------------------------------------------------------
function makePageWithDefaults(name) {
	var page = deviceDriver.mMapping.makePage(name)
	return page
}

//----------------------------------------------------------------------------------------------------------------------
function makePageMacros() {
	var page = makePageWithDefaults('Macros')

	page.makeCommandBinding(surfaceElements.buttons[200].mSurfaceValue, "Process Project Logical Editor", "Scene001")
	page.setLabelFieldText(surfaceElements.labels[200], "Scene 001")

	page.makeCommandBinding(surfaceElements.buttons[201].mSurfaceValue, "Process Project Logical Editor", "Scene002")
	page.setLabelFieldText(surfaceElements.labels[201], "Scene 002")

	page.makeCommandBinding(surfaceElements.buttons[202].mSurfaceValue, "Process Project Logical Editor", "Scene003")
	page.setLabelFieldText(surfaceElements.labels[202], "Scene 003")

	page.makeCommandBinding(surfaceElements.buttons[203].mSurfaceValue, "Process Project Logical Editor", "Scene004")
	page.setLabelFieldText(surfaceElements.labels[203], "Scene 004")

	page.makeCommandBinding(surfaceElements.buttons[204].mSurfaceValue, "Process Project Logical Editor", "Scene005")
	page.setLabelFieldText(surfaceElements.labels[204], "Scene 005")

	page.makeCommandBinding(surfaceElements.buttons[205].mSurfaceValue, "Process Project Logical Editor", "Scene006")
	page.setLabelFieldText(surfaceElements.labels[205], "Scene 006")

	page.makeCommandBinding(surfaceElements.buttons[206].mSurfaceValue, "Process Project Logical Editor", "Scene007")
	page.setLabelFieldText(surfaceElements.labels[206], "Scene 007")

	page.makeCommandBinding(surfaceElements.buttons[207].mSurfaceValue, "Process Project Logical Editor", "Scene008")
	page.setLabelFieldText(surfaceElements.labels[207], "Scene 008")

	page.makeCommandBinding(surfaceElements.buttons[208].mSurfaceValue, "Process Project Logical Editor", "Scene009")
	page.setLabelFieldText(surfaceElements.labels[208], "Scene 009")

	page.makeCommandBinding(surfaceElements.buttons[209].mSurfaceValue, "Process Project Logical Editor", "Scene010")
	page.setLabelFieldText(surfaceElements.labels[209], "Scene 010")

	page.makeCommandBinding(surfaceElements.buttons[210].mSurfaceValue, "Process Project Logical Editor", "Scene011")
	page.setLabelFieldText(surfaceElements.labels[210], "Scene 011")

	page.makeCommandBinding(surfaceElements.buttons[211].mSurfaceValue, "Process Project Logical Editor", "Scene012")
	page.setLabelFieldText(surfaceElements.labels[211], "Scene 012")

	page.makeCommandBinding(surfaceElements.buttons[212].mSurfaceValue, "Process Project Logical Editor", "Scene013")
	page.setLabelFieldText(surfaceElements.labels[212], "Scene 013")

	page.makeCommandBinding(surfaceElements.buttons[213].mSurfaceValue, "Process Project Logical Editor", "Scene014")
	page.setLabelFieldText(surfaceElements.labels[213], "Scene 014")

	page.makeCommandBinding(surfaceElements.buttons[214].mSurfaceValue, "Process Project Logical Editor", "Scene015")
	page.setLabelFieldText(surfaceElements.labels[214], "Scene 015")

	page.makeCommandBinding(surfaceElements.buttons[215].mSurfaceValue, "Process Project Logical Editor", "Scene016")
	page.setLabelFieldText(surfaceElements.labels[215], "Scene 016")

	page.makeCommandBinding(surfaceElements.buttons[216].mSurfaceValue, "Process Project Logical Editor", "Scene017")
	page.setLabelFieldText(surfaceElements.labels[216], "Scene 017")

	page.makeCommandBinding(surfaceElements.buttons[217].mSurfaceValue, "Process Project Logical Editor", "Scene018")
	page.setLabelFieldText(surfaceElements.labels[217], "Scene 018")

	page.makeCommandBinding(surfaceElements.buttons[218].mSurfaceValue, "Process Project Logical Editor", "Scene019")
	page.setLabelFieldText(surfaceElements.labels[218], "Scene 019")

	page.makeCommandBinding(surfaceElements.buttons[219].mSurfaceValue, "Process Project Logical Editor", "Scene020")
	page.setLabelFieldText(surfaceElements.labels[219], "Scene 020")

	page.makeCommandBinding(surfaceElements.buttons[220].mSurfaceValue, "Process Project Logical Editor", "Scene021")
	page.setLabelFieldText(surfaceElements.labels[220], "Scene 021")

	page.makeCommandBinding(surfaceElements.buttons[221].mSurfaceValue, "Process Project Logical Editor", "Scene022")
	page.setLabelFieldText(surfaceElements.labels[221], "Scene 022")

	page.makeCommandBinding(surfaceElements.buttons[222].mSurfaceValue, "Process Project Logical Editor", "Scene023")
	page.setLabelFieldText(surfaceElements.labels[222], "Scene 023")

	page.makeCommandBinding(surfaceElements.buttons[223].mSurfaceValue, "Process Project Logical Editor", "Scene024")
	page.setLabelFieldText(surfaceElements.labels[223], "Scene 024")

	page.makeCommandBinding(surfaceElements.buttons[224].mSurfaceValue, "Process Project Logical Editor", "Scene025")
	page.setLabelFieldText(surfaceElements.labels[224], "Scene 025")

	page.makeCommandBinding(surfaceElements.buttons[225].mSurfaceValue, "Process Project Logical Editor", "Scene026")
	page.setLabelFieldText(surfaceElements.labels[225], "Scene 026")

	page.makeCommandBinding(surfaceElements.buttons[226].mSurfaceValue, "Process Project Logical Editor", "Scene027")
	page.setLabelFieldText(surfaceElements.labels[226], "Scene 027")

	page.makeCommandBinding(surfaceElements.buttons[227].mSurfaceValue, "Process Project Logical Editor", "Scene028")
	page.setLabelFieldText(surfaceElements.labels[227], "Scene 028")

	page.makeCommandBinding(surfaceElements.buttons[228].mSurfaceValue, "Process Project Logical Editor", "Scene029")
	page.setLabelFieldText(surfaceElements.labels[228], "Scene 029")

	page.makeCommandBinding(surfaceElements.buttons[229].mSurfaceValue, "Process Project Logical Editor", "Scene030")
	page.setLabelFieldText(surfaceElements.labels[229], "Scene 030")

	page.makeCommandBinding(surfaceElements.buttons[230].mSurfaceValue, "Process Project Logical Editor", "Scene031")
	page.setLabelFieldText(surfaceElements.labels[230], "Scene 031")

	page.makeCommandBinding(surfaceElements.buttons[231].mSurfaceValue, "Process Project Logical Editor", "Scene032")
	page.setLabelFieldText(surfaceElements.labels[231], "Scene 032")

	page.makeCommandBinding(surfaceElements.buttons[232].mSurfaceValue, "Process Project Logical Editor", "Scene033")
	page.setLabelFieldText(surfaceElements.labels[232], "Scene 033")

	page.makeCommandBinding(surfaceElements.buttons[233].mSurfaceValue, "Process Project Logical Editor", "Scene034")
	page.setLabelFieldText(surfaceElements.labels[233], "Scene 034")

	page.makeCommandBinding(surfaceElements.buttons[234].mSurfaceValue, "Process Project Logical Editor", "Scene035")
	page.setLabelFieldText(surfaceElements.labels[234], "Scene 035")

	page.makeCommandBinding(surfaceElements.buttons[235].mSurfaceValue, "Process Project Logical Editor", "Scene036")
	page.setLabelFieldText(surfaceElements.labels[235], "Scene 036")

	page.makeCommandBinding(surfaceElements.buttons[236].mSurfaceValue, "Process Project Logical Editor", "Scene037")
	page.setLabelFieldText(surfaceElements.labels[236], "Scene 037")

	page.makeCommandBinding(surfaceElements.buttons[237].mSurfaceValue, "Process Project Logical Editor", "Scene038")
	page.setLabelFieldText(surfaceElements.labels[237], "Scene 038")

	page.makeCommandBinding(surfaceElements.buttons[238].mSurfaceValue, "Process Project Logical Editor", "Scene039")
	page.setLabelFieldText(surfaceElements.labels[238], "Scene 039")

	page.makeCommandBinding(surfaceElements.buttons[239].mSurfaceValue, "Process Project Logical Editor", "Scene040")
	page.setLabelFieldText(surfaceElements.labels[239], "Scene 040")

	page.makeCommandBinding(surfaceElements.buttons[240].mSurfaceValue, "Process Project Logical Editor", "Scene041")
	page.setLabelFieldText(surfaceElements.labels[240], "Scene 041")

	page.makeCommandBinding(surfaceElements.buttons[241].mSurfaceValue, "Process Project Logical Editor", "Scene042")
	page.setLabelFieldText(surfaceElements.labels[241], "Scene 042")

	page.makeCommandBinding(surfaceElements.buttons[242].mSurfaceValue, "Process Project Logical Editor", "Scene043")
	page.setLabelFieldText(surfaceElements.labels[242], "Scene 043")

	page.makeCommandBinding(surfaceElements.buttons[243].mSurfaceValue, "Process Project Logical Editor", "Scene044")
	page.setLabelFieldText(surfaceElements.labels[243], "Scene 044")

	page.makeCommandBinding(surfaceElements.buttons[244].mSurfaceValue, "Process Project Logical Editor", "Scene045")
	page.setLabelFieldText(surfaceElements.labels[244], "Scene 045")

	page.makeCommandBinding(surfaceElements.buttons[245].mSurfaceValue, "Process Project Logical Editor", "Scene046")
	page.setLabelFieldText(surfaceElements.labels[245], "Scene 046")

	page.makeCommandBinding(surfaceElements.buttons[246].mSurfaceValue, "Process Project Logical Editor", "Scene047")
	page.setLabelFieldText(surfaceElements.labels[246], "Scene 047")

	page.makeCommandBinding(surfaceElements.buttons[247].mSurfaceValue, "Process Project Logical Editor", "Scene048")
	page.setLabelFieldText(surfaceElements.labels[247], "Scene 048")

	page.makeCommandBinding(surfaceElements.buttons[248].mSurfaceValue, "Process Project Logical Editor", "Scene049")
	page.setLabelFieldText(surfaceElements.labels[248], "Scene 049")

	page.makeCommandBinding(surfaceElements.buttons[249].mSurfaceValue, "Process Project Logical Editor", "Scene050")
	page.setLabelFieldText(surfaceElements.labels[249], "Scene 050")

	page.makeCommandBinding(surfaceElements.buttons[250].mSurfaceValue, "Process Project Logical Editor", "Scene051")
	page.setLabelFieldText(surfaceElements.labels[250], "Scene 051")

	page.makeCommandBinding(surfaceElements.buttons[251].mSurfaceValue, "Process Project Logical Editor", "Scene052")
	page.setLabelFieldText(surfaceElements.labels[251], "Scene 052")

	page.makeCommandBinding(surfaceElements.buttons[252].mSurfaceValue, "Process Project Logical Editor", "Scene053")
	page.setLabelFieldText(surfaceElements.labels[252], "Scene 053")

	page.makeCommandBinding(surfaceElements.buttons[253].mSurfaceValue, "Process Project Logical Editor", "Scene054")
	page.setLabelFieldText(surfaceElements.labels[253], "Scene 054")

	page.makeCommandBinding(surfaceElements.buttons[254].mSurfaceValue, "Process Project Logical Editor", "Scene055")
	page.setLabelFieldText(surfaceElements.labels[254], "Scene 055")

	page.makeCommandBinding(surfaceElements.buttons[255].mSurfaceValue, "Process Project Logical Editor", "Scene056")
	page.setLabelFieldText(surfaceElements.labels[255], "Scene 056")

	page.makeCommandBinding(surfaceElements.buttons[256].mSurfaceValue, "Process Project Logical Editor", "Scene057")
	page.setLabelFieldText(surfaceElements.labels[256], "Scene 057")

	page.makeCommandBinding(surfaceElements.buttons[257].mSurfaceValue, "Process Project Logical Editor", "Scene058")
	page.setLabelFieldText(surfaceElements.labels[257], "Scene 058")

	page.makeCommandBinding(surfaceElements.buttons[258].mSurfaceValue, "Process Project Logical Editor", "Scene059")
	page.setLabelFieldText(surfaceElements.labels[258], "Scene 059")

	page.makeCommandBinding(surfaceElements.buttons[259].mSurfaceValue, "Process Project Logical Editor", "Scene060")
	page.setLabelFieldText(surfaceElements.labels[259], "Scene 060")

	page.makeCommandBinding(surfaceElements.buttons[260].mSurfaceValue, "Process Project Logical Editor", "Scene061")
	page.setLabelFieldText(surfaceElements.labels[260], "Scene 061")

	page.makeCommandBinding(surfaceElements.buttons[261].mSurfaceValue, "Process Project Logical Editor", "Scene062")
	page.setLabelFieldText(surfaceElements.labels[261], "Scene 062")

	page.makeCommandBinding(surfaceElements.buttons[262].mSurfaceValue, "Process Project Logical Editor", "Scene063")
	page.setLabelFieldText(surfaceElements.labels[262], "Scene 063")

	page.makeCommandBinding(surfaceElements.buttons[263].mSurfaceValue, "Process Project Logical Editor", "Scene064")
	page.setLabelFieldText(surfaceElements.labels[263], "Scene 064")

	page.makeCommandBinding(surfaceElements.buttons[264].mSurfaceValue, "Process Project Logical Editor", "Scene065")
	page.setLabelFieldText(surfaceElements.labels[264], "Scene 065")

	page.makeCommandBinding(surfaceElements.buttons[265].mSurfaceValue, "Process Project Logical Editor", "Scene066")
	page.setLabelFieldText(surfaceElements.labels[265], "Scene 066")

	page.makeCommandBinding(surfaceElements.buttons[266].mSurfaceValue, "Process Project Logical Editor", "Scene067")
	page.setLabelFieldText(surfaceElements.labels[266], "Scene 067")

	page.makeCommandBinding(surfaceElements.buttons[267].mSurfaceValue, "Process Project Logical Editor", "Scene068")
	page.setLabelFieldText(surfaceElements.labels[267], "Scene 068")

	page.makeCommandBinding(surfaceElements.buttons[268].mSurfaceValue, "Process Project Logical Editor", "Scene069")
	page.setLabelFieldText(surfaceElements.labels[268], "Scene 069")

	page.makeCommandBinding(surfaceElements.buttons[269].mSurfaceValue, "Process Project Logical Editor", "Scene070")
	page.setLabelFieldText(surfaceElements.labels[269], "Scene 070")

	page.makeCommandBinding(surfaceElements.buttons[270].mSurfaceValue, "Process Project Logical Editor", "Scene071")
	page.setLabelFieldText(surfaceElements.labels[270], "Scene 071")

	page.makeCommandBinding(surfaceElements.buttons[271].mSurfaceValue, "Process Project Logical Editor", "Scene072")
	page.setLabelFieldText(surfaceElements.labels[271], "Scene 072")

	page.makeCommandBinding(surfaceElements.buttons[272].mSurfaceValue, "Process Project Logical Editor", "Scene073")
	page.setLabelFieldText(surfaceElements.labels[272], "Scene 073")

	page.makeCommandBinding(surfaceElements.buttons[273].mSurfaceValue, "Process Project Logical Editor", "Scene074")
	page.setLabelFieldText(surfaceElements.labels[273], "Scene 074")

	page.makeCommandBinding(surfaceElements.buttons[274].mSurfaceValue, "Process Project Logical Editor", "Scene075")
	page.setLabelFieldText(surfaceElements.labels[274], "Scene 075")

	page.makeCommandBinding(surfaceElements.buttons[275].mSurfaceValue, "Process Project Logical Editor", "Scene076")
	page.setLabelFieldText(surfaceElements.labels[275], "Scene 076")

	page.makeCommandBinding(surfaceElements.buttons[276].mSurfaceValue, "Process Project Logical Editor", "Scene077")
	page.setLabelFieldText(surfaceElements.labels[276], "Scene 077")

	page.makeCommandBinding(surfaceElements.buttons[277].mSurfaceValue, "Process Project Logical Editor", "Scene078")
	page.setLabelFieldText(surfaceElements.labels[277], "Scene 078")

	page.makeCommandBinding(surfaceElements.buttons[278].mSurfaceValue, "Process Project Logical Editor", "Scene079")
	page.setLabelFieldText(surfaceElements.labels[278], "Scene 079")

	page.makeCommandBinding(surfaceElements.buttons[279].mSurfaceValue, "Process Project Logical Editor", "Scene080")
	page.setLabelFieldText(surfaceElements.labels[279], "Scene 080")

	page.makeCommandBinding(surfaceElements.buttons[280].mSurfaceValue, "Process Project Logical Editor", "Scene081")
	page.setLabelFieldText(surfaceElements.labels[280], "Scene 081")

	page.makeCommandBinding(surfaceElements.buttons[281].mSurfaceValue, "Process Project Logical Editor", "Scene082")
	page.setLabelFieldText(surfaceElements.labels[281], "Scene 082")

	page.makeCommandBinding(surfaceElements.buttons[282].mSurfaceValue, "Process Project Logical Editor", "Scene083")
	page.setLabelFieldText(surfaceElements.labels[282], "Scene 083")

	page.makeCommandBinding(surfaceElements.buttons[283].mSurfaceValue, "Process Project Logical Editor", "Scene084")
	page.setLabelFieldText(surfaceElements.labels[283], "Scene 084")

	page.makeCommandBinding(surfaceElements.buttons[284].mSurfaceValue, "Process Project Logical Editor", "Scene085")
	page.setLabelFieldText(surfaceElements.labels[284], "Scene 085")

	page.makeCommandBinding(surfaceElements.buttons[285].mSurfaceValue, "Process Project Logical Editor", "Scene086")
	page.setLabelFieldText(surfaceElements.labels[285], "Scene 086")

	page.makeCommandBinding(surfaceElements.buttons[286].mSurfaceValue, "Process Project Logical Editor", "Scene087")
	page.setLabelFieldText(surfaceElements.labels[286], "Scene 087")

	page.makeCommandBinding(surfaceElements.buttons[287].mSurfaceValue, "Process Project Logical Editor", "Scene088")
	page.setLabelFieldText(surfaceElements.labels[287], "Scene 088")

	page.makeCommandBinding(surfaceElements.buttons[288].mSurfaceValue, "Process Project Logical Editor", "Scene089")
	page.setLabelFieldText(surfaceElements.labels[288], "Scene 089")

	page.makeCommandBinding(surfaceElements.buttons[289].mSurfaceValue, "Process Project Logical Editor", "Scene090")
	page.setLabelFieldText(surfaceElements.labels[289], "Scene 090")

	page.makeCommandBinding(surfaceElements.buttons[290].mSurfaceValue, "Process Project Logical Editor", "Scene091")
	page.setLabelFieldText(surfaceElements.labels[290], "Scene 091")

	page.makeCommandBinding(surfaceElements.buttons[291].mSurfaceValue, "Process Project Logical Editor", "Scene092")
	page.setLabelFieldText(surfaceElements.labels[291], "Scene 092")

	page.makeCommandBinding(surfaceElements.buttons[292].mSurfaceValue, "Process Project Logical Editor", "Scene093")
	page.setLabelFieldText(surfaceElements.labels[292], "Scene 093")

	page.makeCommandBinding(surfaceElements.buttons[293].mSurfaceValue, "Process Project Logical Editor", "Scene094")
	page.setLabelFieldText(surfaceElements.labels[293], "Scene 094")

	page.makeCommandBinding(surfaceElements.buttons[294].mSurfaceValue, "Process Project Logical Editor", "Scene095")
	page.setLabelFieldText(surfaceElements.labels[294], "Scene 095")

	page.makeCommandBinding(surfaceElements.buttons[295].mSurfaceValue, "Process Project Logical Editor", "Scene096")
	page.setLabelFieldText(surfaceElements.labels[295], "Scene 096")

	page.makeCommandBinding(surfaceElements.buttons[296].mSurfaceValue, "Process Project Logical Editor", "Scene097")
	page.setLabelFieldText(surfaceElements.labels[296], "Scene 097")

	page.makeCommandBinding(surfaceElements.buttons[297].mSurfaceValue, "Process Project Logical Editor", "Scene098")
	page.setLabelFieldText(surfaceElements.labels[297], "Scene 098")

	page.makeCommandBinding(surfaceElements.buttons[298].mSurfaceValue, "Process Project Logical Editor", "Scene099")
	page.setLabelFieldText(surfaceElements.labels[298], "Scene 099")

	page.makeCommandBinding(surfaceElements.buttons[299].mSurfaceValue, "Process Project Logical Editor", "Scene100")
	page.setLabelFieldText(surfaceElements.labels[299], "Scene 100")

	page.makeCommandBinding(surfaceElements.buttons[300].mSurfaceValue, "Process Project Logical Editor", "Hide All")
	page.setLabelFieldText(surfaceElements.labels[300], "Hide All")

	page.makeCommandBinding(surfaceElements.buttons[301].mSurfaceValue, "Process Project Logical Editor", "MG_Unfold_All_Visible")
	page.setLabelFieldText(surfaceElements.labels[301], "Unfold All")

	page.makeCommandBinding(surfaceElements.buttons[702].mSurfaceValue, "Process Project Logical Editor", "Scene001")
	page.setLabelFieldText(surfaceElements.labels[702], "Scene 001")

	page.makeCommandBinding(surfaceElements.buttons[703].mSurfaceValue, "Process Project Logical Editor", "Scene002")
	page.setLabelFieldText(surfaceElements.labels[703], "Scene 002")

	page.makeCommandBinding(surfaceElements.buttons[704].mSurfaceValue, "Process Project Logical Editor", "Scene003")
	page.setLabelFieldText(surfaceElements.labels[704], "Scene 003")

	page.makeCommandBinding(surfaceElements.buttons[705].mSurfaceValue, "Process Project Logical Editor", "Scene004")
	page.setLabelFieldText(surfaceElements.labels[705], "Scene 004")

	page.makeCommandBinding(surfaceElements.buttons[706].mSurfaceValue, "Process Project Logical Editor", "Scene005")
	page.setLabelFieldText(surfaceElements.labels[706], "Scene 005")

	page.makeCommandBinding(surfaceElements.buttons[707].mSurfaceValue, "Process Project Logical Editor", "Scene006")
	page.setLabelFieldText(surfaceElements.labels[707], "Scene 006")

	page.makeCommandBinding(surfaceElements.buttons[708].mSurfaceValue, "Process Project Logical Editor", "Scene007")
	page.setLabelFieldText(surfaceElements.labels[708], "Scene 007")

	page.makeCommandBinding(surfaceElements.buttons[709].mSurfaceValue, "Process Project Logical Editor", "Scene008")
	page.setLabelFieldText(surfaceElements.labels[709], "Scene 008")

	page.makeCommandBinding(surfaceElements.buttons[710].mSurfaceValue, "Process Project Logical Editor", "Scene009")
	page.setLabelFieldText(surfaceElements.labels[710], "Scene 009")

	page.makeCommandBinding(surfaceElements.buttons[711].mSurfaceValue, "Process Project Logical Editor", "Scene010")
	page.setLabelFieldText(surfaceElements.labels[711], "Scene 010")

	page.makeCommandBinding(surfaceElements.buttons[712].mSurfaceValue, "Process Project Logical Editor", "Scene011")
	page.setLabelFieldText(surfaceElements.labels[712], "Scene 011")

	page.makeCommandBinding(surfaceElements.buttons[713].mSurfaceValue, "Process Project Logical Editor", "Scene012")
	page.setLabelFieldText(surfaceElements.labels[713], "Scene 012")

	page.makeCommandBinding(surfaceElements.buttons[714].mSurfaceValue, "Process Project Logical Editor", "Scene013")
	page.setLabelFieldText(surfaceElements.labels[714], "Scene 013")

	page.makeCommandBinding(surfaceElements.buttons[715].mSurfaceValue, "Process Project Logical Editor", "Scene014")
	page.setLabelFieldText(surfaceElements.labels[715], "Scene 014")

	page.makeCommandBinding(surfaceElements.buttons[716].mSurfaceValue, "Process Project Logical Editor", "Scene015")
	page.setLabelFieldText(surfaceElements.labels[716], "Scene 015")

	page.makeCommandBinding(surfaceElements.buttons[717].mSurfaceValue, "Process Project Logical Editor", "Scene016")
	page.setLabelFieldText(surfaceElements.labels[717], "Scene 016")

	page.makeCommandBinding(surfaceElements.buttons[718].mSurfaceValue, "Process Project Logical Editor", "Scene017")
	page.setLabelFieldText(surfaceElements.labels[718], "Scene 017")

	page.makeCommandBinding(surfaceElements.buttons[719].mSurfaceValue, "Process Project Logical Editor", "Scene018")
	page.setLabelFieldText(surfaceElements.labels[719], "Scene 018")

	page.makeCommandBinding(surfaceElements.buttons[720].mSurfaceValue, "Process Project Logical Editor", "Scene019")
	page.setLabelFieldText(surfaceElements.labels[720], "Scene 019")

	page.makeCommandBinding(surfaceElements.buttons[721].mSurfaceValue, "Process Project Logical Editor", "Scene020")
	page.setLabelFieldText(surfaceElements.labels[721], "Scene 020")

	page.makeCommandBinding(surfaceElements.buttons[722].mSurfaceValue, "Process Project Logical Editor", "Scene021")
	page.setLabelFieldText(surfaceElements.labels[722], "Scene 021")

	page.makeCommandBinding(surfaceElements.buttons[723].mSurfaceValue, "Process Project Logical Editor", "Scene022")
	page.setLabelFieldText(surfaceElements.labels[723], "Scene 022")

	page.makeCommandBinding(surfaceElements.buttons[724].mSurfaceValue, "Process Project Logical Editor", "Scene023")
	page.setLabelFieldText(surfaceElements.labels[724], "Scene 023")

	page.makeCommandBinding(surfaceElements.buttons[725].mSurfaceValue, "Process Project Logical Editor", "Scene024")
	page.setLabelFieldText(surfaceElements.labels[725], "Scene 024")

	page.makeCommandBinding(surfaceElements.buttons[726].mSurfaceValue, "Process Project Logical Editor", "Scene025")
	page.setLabelFieldText(surfaceElements.labels[726], "Scene 025")

	page.makeCommandBinding(surfaceElements.buttons[727].mSurfaceValue, "Process Project Logical Editor", "Scene026")
	page.setLabelFieldText(surfaceElements.labels[727], "Scene 026")

	page.makeCommandBinding(surfaceElements.buttons[728].mSurfaceValue, "Process Project Logical Editor", "Scene027")
	page.setLabelFieldText(surfaceElements.labels[728], "Scene 027")

	page.makeCommandBinding(surfaceElements.buttons[729].mSurfaceValue, "Process Project Logical Editor", "Scene028")
	page.setLabelFieldText(surfaceElements.labels[729], "Scene 028")

	page.makeCommandBinding(surfaceElements.buttons[730].mSurfaceValue, "Process Project Logical Editor", "Scene029")
	page.setLabelFieldText(surfaceElements.labels[730], "Scene 029")

	page.makeCommandBinding(surfaceElements.buttons[731].mSurfaceValue, "Process Project Logical Editor", "Scene030")
	page.setLabelFieldText(surfaceElements.labels[731], "Scene 030")

	page.makeCommandBinding(surfaceElements.buttons[732].mSurfaceValue, "Process Project Logical Editor", "Scene031")
	page.setLabelFieldText(surfaceElements.labels[732], "Scene 031")

	page.makeCommandBinding(surfaceElements.buttons[733].mSurfaceValue, "Process Project Logical Editor", "Scene032")
	page.setLabelFieldText(surfaceElements.labels[733], "Scene 032")

	page.makeCommandBinding(surfaceElements.buttons[734].mSurfaceValue, "Process Project Logical Editor", "Scene033")
	page.setLabelFieldText(surfaceElements.labels[734], "Scene 033")

	page.makeCommandBinding(surfaceElements.buttons[735].mSurfaceValue, "Process Project Logical Editor", "Scene034")
	page.setLabelFieldText(surfaceElements.labels[735], "Scene 034")

	page.makeCommandBinding(surfaceElements.buttons[736].mSurfaceValue, "Process Project Logical Editor", "Scene035")
	page.setLabelFieldText(surfaceElements.labels[736], "Scene 035")

	page.makeCommandBinding(surfaceElements.buttons[737].mSurfaceValue, "Process Project Logical Editor", "Scene036")
	page.setLabelFieldText(surfaceElements.labels[737], "Scene 036")

	page.makeCommandBinding(surfaceElements.buttons[738].mSurfaceValue, "Process Project Logical Editor", "Scene037")
	page.setLabelFieldText(surfaceElements.labels[738], "Scene 037")

	page.makeCommandBinding(surfaceElements.buttons[739].mSurfaceValue, "Process Project Logical Editor", "Scene038")
	page.setLabelFieldText(surfaceElements.labels[739], "Scene 038")

	page.makeCommandBinding(surfaceElements.buttons[740].mSurfaceValue, "Process Project Logical Editor", "Scene039")
	page.setLabelFieldText(surfaceElements.labels[740], "Scene 039")

	page.makeCommandBinding(surfaceElements.buttons[741].mSurfaceValue, "Process Project Logical Editor", "Scene040")
	page.setLabelFieldText(surfaceElements.labels[741], "Scene 040")

	page.makeCommandBinding(surfaceElements.buttons[742].mSurfaceValue, "Process Project Logical Editor", "Scene041")
	page.setLabelFieldText(surfaceElements.labels[742], "Scene 041")

	page.makeCommandBinding(surfaceElements.buttons[743].mSurfaceValue, "Process Project Logical Editor", "Scene042")
	page.setLabelFieldText(surfaceElements.labels[743], "Scene 042")

	page.makeCommandBinding(surfaceElements.buttons[744].mSurfaceValue, "Process Project Logical Editor", "Scene043")
	page.setLabelFieldText(surfaceElements.labels[744], "Scene 043")

	page.makeCommandBinding(surfaceElements.buttons[745].mSurfaceValue, "Process Project Logical Editor", "Scene044")
	page.setLabelFieldText(surfaceElements.labels[745], "Scene 044")

	page.makeCommandBinding(surfaceElements.buttons[746].mSurfaceValue, "Process Project Logical Editor", "Scene045")
	page.setLabelFieldText(surfaceElements.labels[746], "Scene 045")

	page.makeCommandBinding(surfaceElements.buttons[747].mSurfaceValue, "Process Project Logical Editor", "Scene046")
	page.setLabelFieldText(surfaceElements.labels[747], "Scene 046")

	page.makeCommandBinding(surfaceElements.buttons[748].mSurfaceValue, "Process Project Logical Editor", "Scene047")
	page.setLabelFieldText(surfaceElements.labels[748], "Scene 047")

	page.makeCommandBinding(surfaceElements.buttons[749].mSurfaceValue, "Process Project Logical Editor", "Scene048")
	page.setLabelFieldText(surfaceElements.labels[749], "Scene 048")

	page.makeCommandBinding(surfaceElements.buttons[750].mSurfaceValue, "Process Project Logical Editor", "Scene049")
	page.setLabelFieldText(surfaceElements.labels[750], "Scene 049")

	page.makeCommandBinding(surfaceElements.buttons[751].mSurfaceValue, "Process Project Logical Editor", "Scene050")
	page.setLabelFieldText(surfaceElements.labels[751], "Scene 050")

	page.makeCommandBinding(surfaceElements.buttons[752].mSurfaceValue, "Process Project Logical Editor", "Scene051")
	page.setLabelFieldText(surfaceElements.labels[752], "Scene 051")

	page.makeCommandBinding(surfaceElements.buttons[753].mSurfaceValue, "Process Project Logical Editor", "Scene052")
	page.setLabelFieldText(surfaceElements.labels[753], "Scene 052")

	page.makeCommandBinding(surfaceElements.buttons[754].mSurfaceValue, "Process Project Logical Editor", "Scene053")
	page.setLabelFieldText(surfaceElements.labels[754], "Scene 053")

	page.makeCommandBinding(surfaceElements.buttons[755].mSurfaceValue, "Process Project Logical Editor", "Scene054")
	page.setLabelFieldText(surfaceElements.labels[755], "Scene 054")

	page.makeCommandBinding(surfaceElements.buttons[756].mSurfaceValue, "Process Project Logical Editor", "Scene055")
	page.setLabelFieldText(surfaceElements.labels[756], "Scene 055")

	page.makeCommandBinding(surfaceElements.buttons[757].mSurfaceValue, "Process Project Logical Editor", "Scene056")
	page.setLabelFieldText(surfaceElements.labels[757], "Scene 056")

	page.makeCommandBinding(surfaceElements.buttons[758].mSurfaceValue, "Process Project Logical Editor", "Scene057")
	page.setLabelFieldText(surfaceElements.labels[758], "Scene 057")

	page.makeCommandBinding(surfaceElements.buttons[759].mSurfaceValue, "Process Project Logical Editor", "Scene058")
	page.setLabelFieldText(surfaceElements.labels[759], "Scene 058")

	page.makeCommandBinding(surfaceElements.buttons[760].mSurfaceValue, "Process Project Logical Editor", "Scene059")
	page.setLabelFieldText(surfaceElements.labels[760], "Scene 059")

	page.makeCommandBinding(surfaceElements.buttons[761].mSurfaceValue, "Process Project Logical Editor", "Scene060")
	page.setLabelFieldText(surfaceElements.labels[761], "Scene 060")

	page.makeCommandBinding(surfaceElements.buttons[762].mSurfaceValue, "Process Project Logical Editor", "Scene061")
	page.setLabelFieldText(surfaceElements.labels[762], "Scene 061")

	page.makeCommandBinding(surfaceElements.buttons[763].mSurfaceValue, "Process Project Logical Editor", "Scene062")
	page.setLabelFieldText(surfaceElements.labels[763], "Scene 062")

	page.makeCommandBinding(surfaceElements.buttons[764].mSurfaceValue, "Process Project Logical Editor", "Scene063")
	page.setLabelFieldText(surfaceElements.labels[764], "Scene 063")

	page.makeCommandBinding(surfaceElements.buttons[765].mSurfaceValue, "Process Project Logical Editor", "Scene064")
	page.setLabelFieldText(surfaceElements.labels[765], "Scene 064")

	page.makeCommandBinding(surfaceElements.buttons[766].mSurfaceValue, "Process Project Logical Editor", "Scene065")
	page.setLabelFieldText(surfaceElements.labels[766], "Scene 065")

	page.makeCommandBinding(surfaceElements.buttons[767].mSurfaceValue, "Process Project Logical Editor", "Scene066")
	page.setLabelFieldText(surfaceElements.labels[767], "Scene 066")

	page.makeCommandBinding(surfaceElements.buttons[768].mSurfaceValue, "Process Project Logical Editor", "Scene067")
	page.setLabelFieldText(surfaceElements.labels[768], "Scene 067")

	page.makeCommandBinding(surfaceElements.buttons[769].mSurfaceValue, "Process Project Logical Editor", "Scene068")
	page.setLabelFieldText(surfaceElements.labels[769], "Scene 068")

	page.makeCommandBinding(surfaceElements.buttons[770].mSurfaceValue, "Process Project Logical Editor", "Scene069")
	page.setLabelFieldText(surfaceElements.labels[770], "Scene 069")

	page.makeCommandBinding(surfaceElements.buttons[771].mSurfaceValue, "Process Project Logical Editor", "Scene070")
	page.setLabelFieldText(surfaceElements.labels[771], "Scene 070")

	page.makeCommandBinding(surfaceElements.buttons[772].mSurfaceValue, "Process Project Logical Editor", "Scene071")
	page.setLabelFieldText(surfaceElements.labels[772], "Scene 071")

	page.makeCommandBinding(surfaceElements.buttons[773].mSurfaceValue, "Process Project Logical Editor", "Scene072")
	page.setLabelFieldText(surfaceElements.labels[773], "Scene 072")

	page.makeCommandBinding(surfaceElements.buttons[774].mSurfaceValue, "Process Project Logical Editor", "Scene073")
	page.setLabelFieldText(surfaceElements.labels[774], "Scene 073")

	page.makeCommandBinding(surfaceElements.buttons[775].mSurfaceValue, "Process Project Logical Editor", "Scene074")
	page.setLabelFieldText(surfaceElements.labels[775], "Scene 074")

	page.makeCommandBinding(surfaceElements.buttons[776].mSurfaceValue, "Process Project Logical Editor", "Scene075")
	page.setLabelFieldText(surfaceElements.labels[776], "Scene 075")

	page.makeCommandBinding(surfaceElements.buttons[777].mSurfaceValue, "Process Project Logical Editor", "Scene076")
	page.setLabelFieldText(surfaceElements.labels[777], "Scene 076")

	page.makeCommandBinding(surfaceElements.buttons[778].mSurfaceValue, "Process Project Logical Editor", "Scene077")
	page.setLabelFieldText(surfaceElements.labels[778], "Scene 077")

	page.makeCommandBinding(surfaceElements.buttons[779].mSurfaceValue, "Process Project Logical Editor", "Scene078")
	page.setLabelFieldText(surfaceElements.labels[779], "Scene 078")

	page.makeCommandBinding(surfaceElements.buttons[780].mSurfaceValue, "Process Project Logical Editor", "Scene079")
	page.setLabelFieldText(surfaceElements.labels[780], "Scene 079")

	page.makeCommandBinding(surfaceElements.buttons[781].mSurfaceValue, "Process Project Logical Editor", "Scene080")
	page.setLabelFieldText(surfaceElements.labels[781], "Scene 080")

	page.makeCommandBinding(surfaceElements.buttons[782].mSurfaceValue, "Process Project Logical Editor", "Scene081")
	page.setLabelFieldText(surfaceElements.labels[782], "Scene 081")

	page.makeCommandBinding(surfaceElements.buttons[783].mSurfaceValue, "Process Project Logical Editor", "Scene082")
	page.setLabelFieldText(surfaceElements.labels[783], "Scene 082")

	page.makeCommandBinding(surfaceElements.buttons[784].mSurfaceValue, "Process Project Logical Editor", "Scene083")
	page.setLabelFieldText(surfaceElements.labels[784], "Scene 083")

	page.makeCommandBinding(surfaceElements.buttons[785].mSurfaceValue, "Process Project Logical Editor", "Scene084")
	page.setLabelFieldText(surfaceElements.labels[785], "Scene 084")

	page.makeCommandBinding(surfaceElements.buttons[786].mSurfaceValue, "Process Project Logical Editor", "Scene085")
	page.setLabelFieldText(surfaceElements.labels[786], "Scene 085")

	page.makeCommandBinding(surfaceElements.buttons[787].mSurfaceValue, "Process Project Logical Editor", "Scene086")
	page.setLabelFieldText(surfaceElements.labels[787], "Scene 086")

	page.makeCommandBinding(surfaceElements.buttons[788].mSurfaceValue, "Process Project Logical Editor", "Scene087")
	page.setLabelFieldText(surfaceElements.labels[788], "Scene 087")

	page.makeCommandBinding(surfaceElements.buttons[789].mSurfaceValue, "Process Project Logical Editor", "Scene088")
	page.setLabelFieldText(surfaceElements.labels[789], "Scene 088")

	page.makeCommandBinding(surfaceElements.buttons[790].mSurfaceValue, "Process Project Logical Editor", "Scene089")
	page.setLabelFieldText(surfaceElements.labels[790], "Scene 089")

	page.makeCommandBinding(surfaceElements.buttons[791].mSurfaceValue, "Process Project Logical Editor", "Scene090")
	page.setLabelFieldText(surfaceElements.labels[791], "Scene 090")

	page.makeCommandBinding(surfaceElements.buttons[792].mSurfaceValue, "Process Project Logical Editor", "Scene091")
	page.setLabelFieldText(surfaceElements.labels[792], "Scene 091")

	page.makeCommandBinding(surfaceElements.buttons[793].mSurfaceValue, "Process Project Logical Editor", "Scene092")
	page.setLabelFieldText(surfaceElements.labels[793], "Scene 092")

	page.makeCommandBinding(surfaceElements.buttons[794].mSurfaceValue, "Process Project Logical Editor", "Scene093")
	page.setLabelFieldText(surfaceElements.labels[794], "Scene 093")

	page.makeCommandBinding(surfaceElements.buttons[795].mSurfaceValue, "Process Project Logical Editor", "Scene094")
	page.setLabelFieldText(surfaceElements.labels[795], "Scene 094")

	page.makeCommandBinding(surfaceElements.buttons[796].mSurfaceValue, "Process Project Logical Editor", "Scene095")
	page.setLabelFieldText(surfaceElements.labels[796], "Scene 095")

	page.makeCommandBinding(surfaceElements.buttons[797].mSurfaceValue, "Process Project Logical Editor", "Scene096")
	page.setLabelFieldText(surfaceElements.labels[797], "Scene 096")

	page.makeCommandBinding(surfaceElements.buttons[798].mSurfaceValue, "Process Project Logical Editor", "Scene097")
	page.setLabelFieldText(surfaceElements.labels[798], "Scene 097")

	page.makeCommandBinding(surfaceElements.buttons[799].mSurfaceValue, "Process Project Logical Editor", "Scene098")
	page.setLabelFieldText(surfaceElements.labels[799], "Scene 098")

	page.makeCommandBinding(surfaceElements.buttons[800].mSurfaceValue, "Process Project Logical Editor", "Scene099")
	page.setLabelFieldText(surfaceElements.labels[800], "Scene 099")

	page.makeCommandBinding(surfaceElements.buttons[801].mSurfaceValue, "Process Project Logical Editor", "Scene100")
	page.setLabelFieldText(surfaceElements.labels[801], "Scene 100")

	page.makeCommandBinding(surfaceElements.buttons[802].mSurfaceValue, "Process Project Logical Editor", "Hide All")
	page.setLabelFieldText(surfaceElements.labels[802], "Hide All")

	page.makeCommandBinding(surfaceElements.buttons[803].mSurfaceValue, "Process Project Logical Editor", "MG_Unfold_All_Visible")
	page.setLabelFieldText(surfaceElements.labels[803], "Unfold All")

	return page
}

//----------------------------------------------------------------------------------------------------------------------
// Construct Pages
//----------------------------------------------------------------------------------------------------------------------
function onActivatePageDefault(context) {
}

deviceDriver.mOnActivate = function (context) {
	console.log('Metagrid Macros script has been activated.')
}

var pageMacros = makePageMacros()

pageMacros.mOnActivate = function (context) {
	onActivatePageDefault(context)
	console.log('from script: Metagrid Macros page activated')
}
//----------------------------------------------------------------------------------------------------------------------
// 1. DRIVER SETUP - create driver object, midi ports and detection information
//----------------------------------------------------------------------------------------------------------------------
var midiremote_api = require('midiremote_api_v1')
var deviceDriver = midiremote_api.makeDeviceDriver('Metasystem', 'metagridMacros', 'Martin Jirsak')

var midiInput = deviceDriver.mPorts.makeMidiInput()
var midiOutput = deviceDriver.mPorts.makeMidiOutput()

deviceDriver.makeDetectionUnit().detectPortPair(midiInput, midiOutput)
	.expectInputNameContains('Metasystem - CubaseMacros - In')
	.expectOutputNameContains('Metasystem - CubaseMacros - Out')

var surface = deviceDriver.mSurface

//----------------------------------------------------------------------------------------------------------------------
// 2. SURFACE LAYOUT - create control elements and midi bindings
//----------------------------------------------------------------------------------------------------------------------
function makeSurfaceElements() {
	var surfaceElements = {}
	surfaceElements.buttons = {}
	surfaceElements.labels = {}

	surfaceElements.buttons[0] = surface.makeButton(0, 0, 10, 10)
	surfaceElements.buttons[0].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 11)
	surfaceElements.labels[0] = surface.makeLabelField(0, 5, 10, 1)

	surfaceElements.buttons[1] = surface.makeButton(11, 0, 10, 10)
	surfaceElements.buttons[1].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 12)
	surfaceElements.labels[1] = surface.makeLabelField(11, 5, 10, 1)

	surfaceElements.buttons[2] = surface.makeButton(22, 0, 10, 10)
	surfaceElements.buttons[2].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 13)
	surfaceElements.labels[2] = surface.makeLabelField(22, 5, 10, 1)

	surfaceElements.buttons[3] = surface.makeButton(33, 0, 10, 10)
	surfaceElements.buttons[3].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 14)
	surfaceElements.labels[3] = surface.makeLabelField(33, 5, 10, 1)

	surfaceElements.buttons[4] = surface.makeButton(44, 0, 10, 10)
	surfaceElements.buttons[4].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 15)
	surfaceElements.labels[4] = surface.makeLabelField(44, 5, 10, 1)

	surfaceElements.buttons[5] = surface.makeButton(55, 0, 10, 10)
	surfaceElements.buttons[5].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 16)
	surfaceElements.labels[5] = surface.makeLabelField(55, 5, 10, 1)

	surfaceElements.buttons[6] = surface.makeButton(66, 0, 10, 10)
	surfaceElements.buttons[6].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 17)
	surfaceElements.labels[6] = surface.makeLabelField(66, 5, 10, 1)

	surfaceElements.buttons[7] = surface.makeButton(77, 0, 10, 10)
	surfaceElements.buttons[7].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 18)
	surfaceElements.labels[7] = surface.makeLabelField(77, 5, 10, 1)

	surfaceElements.buttons[8] = surface.makeButton(88, 0, 10, 10)
	surfaceElements.buttons[8].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 19)
	surfaceElements.labels[8] = surface.makeLabelField(88, 5, 10, 1)

	surfaceElements.buttons[9] = surface.makeButton(99, 0, 10, 10)
	surfaceElements.buttons[9].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 20)
	surfaceElements.labels[9] = surface.makeLabelField(99, 5, 10, 1)

	surfaceElements.buttons[10] = surface.makeButton(110, 0, 10, 10)
	surfaceElements.buttons[10].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 21)
	surfaceElements.labels[10] = surface.makeLabelField(110, 5, 10, 1)

	surfaceElements.buttons[11] = surface.makeButton(121, 0, 10, 10)
	surfaceElements.buttons[11].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 22)
	surfaceElements.labels[11] = surface.makeLabelField(121, 5, 10, 1)

	surfaceElements.buttons[12] = surface.makeButton(132, 0, 10, 10)
	surfaceElements.buttons[12].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 23)
	surfaceElements.labels[12] = surface.makeLabelField(132, 5, 10, 1)

	surfaceElements.buttons[13] = surface.makeButton(143, 0, 10, 10)
	surfaceElements.buttons[13].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 24)
	surfaceElements.labels[13] = surface.makeLabelField(143, 5, 10, 1)

	surfaceElements.buttons[14] = surface.makeButton(154, 0, 10, 10)
	surfaceElements.buttons[14].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 25)
	surfaceElements.labels[14] = surface.makeLabelField(154, 5, 10, 1)

	surfaceElements.buttons[15] = surface.makeButton(165, 0, 10, 10)
	surfaceElements.buttons[15].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 26)
	surfaceElements.labels[15] = surface.makeLabelField(165, 5, 10, 1)

	surfaceElements.buttons[16] = surface.makeButton(176, 0, 10, 10)
	surfaceElements.buttons[16].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 27)
	surfaceElements.labels[16] = surface.makeLabelField(176, 5, 10, 1)

	surfaceElements.buttons[17] = surface.makeButton(187, 0, 10, 10)
	surfaceElements.buttons[17].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 28)
	surfaceElements.labels[17] = surface.makeLabelField(187, 5, 10, 1)

	surfaceElements.buttons[18] = surface.makeButton(198, 0, 10, 10)
	surfaceElements.buttons[18].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 29)
	surfaceElements.labels[18] = surface.makeLabelField(198, 5, 10, 1)

	surfaceElements.buttons[19] = surface.makeButton(209, 0, 10, 10)
	surfaceElements.buttons[19].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 30)
	surfaceElements.labels[19] = surface.makeLabelField(209, 5, 10, 1)

	surfaceElements.buttons[20] = surface.makeButton(220, 0, 10, 10)
	surfaceElements.buttons[20].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 31)
	surfaceElements.labels[20] = surface.makeLabelField(220, 5, 10, 1)

	surfaceElements.buttons[21] = surface.makeButton(231, 0, 10, 10)
	surfaceElements.buttons[21].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 32)
	surfaceElements.labels[21] = surface.makeLabelField(231, 5, 10, 1)

	surfaceElements.buttons[22] = surface.makeButton(242, 0, 10, 10)
	surfaceElements.buttons[22].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 33)
	surfaceElements.labels[22] = surface.makeLabelField(242, 5, 10, 1)

	surfaceElements.buttons[23] = surface.makeButton(0, 11, 10, 10)
	surfaceElements.buttons[23].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 34)
	surfaceElements.labels[23] = surface.makeLabelField(0, 16, 10, 1)

	surfaceElements.buttons[24] = surface.makeButton(11, 11, 10, 10)
	surfaceElements.buttons[24].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 35)
	surfaceElements.labels[24] = surface.makeLabelField(11, 16, 10, 1)

	surfaceElements.buttons[25] = surface.makeButton(22, 11, 10, 10)
	surfaceElements.buttons[25].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 36)
	surfaceElements.labels[25] = surface.makeLabelField(22, 16, 10, 1)

	surfaceElements.buttons[26] = surface.makeButton(33, 11, 10, 10)
	surfaceElements.buttons[26].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 37)
	surfaceElements.labels[26] = surface.makeLabelField(33, 16, 10, 1)

	surfaceElements.buttons[27] = surface.makeButton(44, 11, 10, 10)
	surfaceElements.buttons[27].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 38)
	surfaceElements.labels[27] = surface.makeLabelField(44, 16, 10, 1)

	surfaceElements.buttons[28] = surface.makeButton(55, 11, 10, 10)
	surfaceElements.buttons[28].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 39)
	surfaceElements.labels[28] = surface.makeLabelField(55, 16, 10, 1)

	surfaceElements.buttons[29] = surface.makeButton(66, 11, 10, 10)
	surfaceElements.buttons[29].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 40)
	surfaceElements.labels[29] = surface.makeLabelField(66, 16, 10, 1)

	surfaceElements.buttons[30] = surface.makeButton(77, 11, 10, 10)
	surfaceElements.buttons[30].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 41)
	surfaceElements.labels[30] = surface.makeLabelField(77, 16, 10, 1)

	surfaceElements.buttons[31] = surface.makeButton(88, 11, 10, 10)
	surfaceElements.buttons[31].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 42)
	surfaceElements.labels[31] = surface.makeLabelField(88, 16, 10, 1)

	surfaceElements.buttons[32] = surface.makeButton(99, 11, 10, 10)
	surfaceElements.buttons[32].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 43)
	surfaceElements.labels[32] = surface.makeLabelField(99, 16, 10, 1)

	surfaceElements.buttons[33] = surface.makeButton(110, 11, 10, 10)
	surfaceElements.buttons[33].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 44)
	surfaceElements.labels[33] = surface.makeLabelField(110, 16, 10, 1)

	surfaceElements.buttons[34] = surface.makeButton(121, 11, 10, 10)
	surfaceElements.buttons[34].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 45)
	surfaceElements.labels[34] = surface.makeLabelField(121, 16, 10, 1)

	surfaceElements.buttons[35] = surface.makeButton(132, 11, 10, 10)
	surfaceElements.buttons[35].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 46)
	surfaceElements.labels[35] = surface.makeLabelField(132, 16, 10, 1)

	surfaceElements.buttons[36] = surface.makeButton(143, 11, 10, 10)
	surfaceElements.buttons[36].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 47)
	surfaceElements.labels[36] = surface.makeLabelField(143, 16, 10, 1)

	surfaceElements.buttons[37] = surface.makeButton(154, 11, 10, 10)
	surfaceElements.buttons[37].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 48)
	surfaceElements.labels[37] = surface.makeLabelField(154, 16, 10, 1)

	surfaceElements.buttons[38] = surface.makeButton(165, 11, 10, 10)
	surfaceElements.buttons[38].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 49)
	surfaceElements.labels[38] = surface.makeLabelField(165, 16, 10, 1)

	surfaceElements.buttons[39] = surface.makeButton(176, 11, 10, 10)
	surfaceElements.buttons[39].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 50)
	surfaceElements.labels[39] = surface.makeLabelField(176, 16, 10, 1)

	surfaceElements.buttons[40] = surface.makeButton(187, 11, 10, 10)
	surfaceElements.buttons[40].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 51)
	surfaceElements.labels[40] = surface.makeLabelField(187, 16, 10, 1)

	surfaceElements.buttons[41] = surface.makeButton(198, 11, 10, 10)
	surfaceElements.buttons[41].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 52)
	surfaceElements.labels[41] = surface.makeLabelField(198, 16, 10, 1)

	surfaceElements.buttons[42] = surface.makeButton(209, 11, 10, 10)
	surfaceElements.buttons[42].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 53)
	surfaceElements.labels[42] = surface.makeLabelField(209, 16, 10, 1)

	surfaceElements.buttons[43] = surface.makeButton(220, 11, 10, 10)
	surfaceElements.buttons[43].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 54)
	surfaceElements.labels[43] = surface.makeLabelField(220, 16, 10, 1)

	surfaceElements.buttons[44] = surface.makeButton(231, 11, 10, 10)
	surfaceElements.buttons[44].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 55)
	surfaceElements.labels[44] = surface.makeLabelField(231, 16, 10, 1)

	surfaceElements.buttons[45] = surface.makeButton(242, 11, 10, 10)
	surfaceElements.buttons[45].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 56)
	surfaceElements.labels[45] = surface.makeLabelField(242, 16, 10, 1)

	surfaceElements.buttons[46] = surface.makeButton(0, 22, 10, 10)
	surfaceElements.buttons[46].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 57)
	surfaceElements.labels[46] = surface.makeLabelField(0, 27, 10, 1)

	surfaceElements.buttons[47] = surface.makeButton(11, 22, 10, 10)
	surfaceElements.buttons[47].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 58)
	surfaceElements.labels[47] = surface.makeLabelField(11, 27, 10, 1)

	surfaceElements.buttons[48] = surface.makeButton(22, 22, 10, 10)
	surfaceElements.buttons[48].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 59)
	surfaceElements.labels[48] = surface.makeLabelField(22, 27, 10, 1)

	surfaceElements.buttons[49] = surface.makeButton(33, 22, 10, 10)
	surfaceElements.buttons[49].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 60)
	surfaceElements.labels[49] = surface.makeLabelField(33, 27, 10, 1)

	surfaceElements.buttons[50] = surface.makeButton(44, 22, 10, 10)
	surfaceElements.buttons[50].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 61)
	surfaceElements.labels[50] = surface.makeLabelField(44, 27, 10, 1)

	surfaceElements.buttons[51] = surface.makeButton(55, 22, 10, 10)
	surfaceElements.buttons[51].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 62)
	surfaceElements.labels[51] = surface.makeLabelField(55, 27, 10, 1)

	surfaceElements.buttons[52] = surface.makeButton(66, 22, 10, 10)
	surfaceElements.buttons[52].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 63)
	surfaceElements.labels[52] = surface.makeLabelField(66, 27, 10, 1)

	surfaceElements.buttons[53] = surface.makeButton(77, 22, 10, 10)
	surfaceElements.buttons[53].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 64)
	surfaceElements.labels[53] = surface.makeLabelField(77, 27, 10, 1)

	surfaceElements.buttons[54] = surface.makeButton(88, 22, 10, 10)
	surfaceElements.buttons[54].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 65)
	surfaceElements.labels[54] = surface.makeLabelField(88, 27, 10, 1)

	surfaceElements.buttons[55] = surface.makeButton(99, 22, 10, 10)
	surfaceElements.buttons[55].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 66)
	surfaceElements.labels[55] = surface.makeLabelField(99, 27, 10, 1)

	surfaceElements.buttons[56] = surface.makeButton(110, 22, 10, 10)
	surfaceElements.buttons[56].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 67)
	surfaceElements.labels[56] = surface.makeLabelField(110, 27, 10, 1)

	surfaceElements.buttons[57] = surface.makeButton(121, 22, 10, 10)
	surfaceElements.buttons[57].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 68)
	surfaceElements.labels[57] = surface.makeLabelField(121, 27, 10, 1)

	surfaceElements.buttons[58] = surface.makeButton(132, 22, 10, 10)
	surfaceElements.buttons[58].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 69)
	surfaceElements.labels[58] = surface.makeLabelField(132, 27, 10, 1)

	surfaceElements.buttons[59] = surface.makeButton(143, 22, 10, 10)
	surfaceElements.buttons[59].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 70)
	surfaceElements.labels[59] = surface.makeLabelField(143, 27, 10, 1)

	surfaceElements.buttons[60] = surface.makeButton(154, 22, 10, 10)
	surfaceElements.buttons[60].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 71)
	surfaceElements.labels[60] = surface.makeLabelField(154, 27, 10, 1)

	surfaceElements.buttons[61] = surface.makeButton(165, 22, 10, 10)
	surfaceElements.buttons[61].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 72)
	surfaceElements.labels[61] = surface.makeLabelField(165, 27, 10, 1)

	surfaceElements.buttons[62] = surface.makeButton(176, 22, 10, 10)
	surfaceElements.buttons[62].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 73)
	surfaceElements.labels[62] = surface.makeLabelField(176, 27, 10, 1)

	surfaceElements.buttons[63] = surface.makeButton(187, 22, 10, 10)
	surfaceElements.buttons[63].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 74)
	surfaceElements.labels[63] = surface.makeLabelField(187, 27, 10, 1)

	surfaceElements.buttons[64] = surface.makeButton(198, 22, 10, 10)
	surfaceElements.buttons[64].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 75)
	surfaceElements.labels[64] = surface.makeLabelField(198, 27, 10, 1)

	surfaceElements.buttons[65] = surface.makeButton(209, 22, 10, 10)
	surfaceElements.buttons[65].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 76)
	surfaceElements.labels[65] = surface.makeLabelField(209, 27, 10, 1)

	surfaceElements.buttons[66] = surface.makeButton(220, 22, 10, 10)
	surfaceElements.buttons[66].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 77)
	surfaceElements.labels[66] = surface.makeLabelField(220, 27, 10, 1)

	surfaceElements.buttons[67] = surface.makeButton(231, 22, 10, 10)
	surfaceElements.buttons[67].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 78)
	surfaceElements.labels[67] = surface.makeLabelField(231, 27, 10, 1)

	surfaceElements.buttons[68] = surface.makeButton(242, 22, 10, 10)
	surfaceElements.buttons[68].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 79)
	surfaceElements.labels[68] = surface.makeLabelField(242, 27, 10, 1)

	surfaceElements.buttons[69] = surface.makeButton(0, 33, 10, 10)
	surfaceElements.buttons[69].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 80)
	surfaceElements.labels[69] = surface.makeLabelField(0, 38, 10, 1)

	surfaceElements.buttons[70] = surface.makeButton(11, 33, 10, 10)
	surfaceElements.buttons[70].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 81)
	surfaceElements.labels[70] = surface.makeLabelField(11, 38, 10, 1)

	surfaceElements.buttons[71] = surface.makeButton(22, 33, 10, 10)
	surfaceElements.buttons[71].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 82)
	surfaceElements.labels[71] = surface.makeLabelField(22, 38, 10, 1)

	surfaceElements.buttons[72] = surface.makeButton(33, 33, 10, 10)
	surfaceElements.buttons[72].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 83)
	surfaceElements.labels[72] = surface.makeLabelField(33, 38, 10, 1)

	surfaceElements.buttons[73] = surface.makeButton(44, 33, 10, 10)
	surfaceElements.buttons[73].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 84)
	surfaceElements.labels[73] = surface.makeLabelField(44, 38, 10, 1)

	surfaceElements.buttons[74] = surface.makeButton(55, 33, 10, 10)
	surfaceElements.buttons[74].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 85)
	surfaceElements.labels[74] = surface.makeLabelField(55, 38, 10, 1)

	surfaceElements.buttons[75] = surface.makeButton(66, 33, 10, 10)
	surfaceElements.buttons[75].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 86)
	surfaceElements.labels[75] = surface.makeLabelField(66, 38, 10, 1)

	surfaceElements.buttons[76] = surface.makeButton(77, 33, 10, 10)
	surfaceElements.buttons[76].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 87)
	surfaceElements.labels[76] = surface.makeLabelField(77, 38, 10, 1)

	surfaceElements.buttons[77] = surface.makeButton(88, 33, 10, 10)
	surfaceElements.buttons[77].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 88)
	surfaceElements.labels[77] = surface.makeLabelField(88, 38, 10, 1)

	surfaceElements.buttons[78] = surface.makeButton(99, 33, 10, 10)
	surfaceElements.buttons[78].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 89)
	surfaceElements.labels[78] = surface.makeLabelField(99, 38, 10, 1)

	surfaceElements.buttons[79] = surface.makeButton(110, 33, 10, 10)
	surfaceElements.buttons[79].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 90)
	surfaceElements.labels[79] = surface.makeLabelField(110, 38, 10, 1)

	surfaceElements.buttons[80] = surface.makeButton(121, 33, 10, 10)
	surfaceElements.buttons[80].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 91)
	surfaceElements.labels[80] = surface.makeLabelField(121, 38, 10, 1)

	surfaceElements.buttons[81] = surface.makeButton(132, 33, 10, 10)
	surfaceElements.buttons[81].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 92)
	surfaceElements.labels[81] = surface.makeLabelField(132, 38, 10, 1)

	surfaceElements.buttons[82] = surface.makeButton(143, 33, 10, 10)
	surfaceElements.buttons[82].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 93)
	surfaceElements.labels[82] = surface.makeLabelField(143, 38, 10, 1)

	surfaceElements.buttons[83] = surface.makeButton(154, 33, 10, 10)
	surfaceElements.buttons[83].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 94)
	surfaceElements.labels[83] = surface.makeLabelField(154, 38, 10, 1)

	surfaceElements.buttons[84] = surface.makeButton(165, 33, 10, 10)
	surfaceElements.buttons[84].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 95)
	surfaceElements.labels[84] = surface.makeLabelField(165, 38, 10, 1)

	surfaceElements.buttons[85] = surface.makeButton(176, 33, 10, 10)
	surfaceElements.buttons[85].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 96)
	surfaceElements.labels[85] = surface.makeLabelField(176, 38, 10, 1)

	surfaceElements.buttons[86] = surface.makeButton(187, 33, 10, 10)
	surfaceElements.buttons[86].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 97)
	surfaceElements.labels[86] = surface.makeLabelField(187, 38, 10, 1)

	surfaceElements.buttons[87] = surface.makeButton(198, 33, 10, 10)
	surfaceElements.buttons[87].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 98)
	surfaceElements.labels[87] = surface.makeLabelField(198, 38, 10, 1)

	surfaceElements.buttons[88] = surface.makeButton(209, 33, 10, 10)
	surfaceElements.buttons[88].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 99)
	surfaceElements.labels[88] = surface.makeLabelField(209, 38, 10, 1)

	surfaceElements.buttons[89] = surface.makeButton(220, 33, 10, 10)
	surfaceElements.buttons[89].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 100)
	surfaceElements.labels[89] = surface.makeLabelField(220, 38, 10, 1)

	surfaceElements.buttons[90] = surface.makeButton(231, 33, 10, 10)
	surfaceElements.buttons[90].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 101)
	surfaceElements.labels[90] = surface.makeLabelField(231, 38, 10, 1)

	surfaceElements.buttons[91] = surface.makeButton(242, 33, 10, 10)
	surfaceElements.buttons[91].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 102)
	surfaceElements.labels[91] = surface.makeLabelField(242, 38, 10, 1)

	surfaceElements.buttons[92] = surface.makeButton(0, 44, 10, 10)
	surfaceElements.buttons[92].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 103)
	surfaceElements.labels[92] = surface.makeLabelField(0, 49, 10, 1)

	surfaceElements.buttons[93] = surface.makeButton(11, 44, 10, 10)
	surfaceElements.buttons[93].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 104)
	surfaceElements.labels[93] = surface.makeLabelField(11, 49, 10, 1)

	surfaceElements.buttons[94] = surface.makeButton(22, 44, 10, 10)
	surfaceElements.buttons[94].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 105)
	surfaceElements.labels[94] = surface.makeLabelField(22, 49, 10, 1)

	surfaceElements.buttons[95] = surface.makeButton(33, 44, 10, 10)
	surfaceElements.buttons[95].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 106)
	surfaceElements.labels[95] = surface.makeLabelField(33, 49, 10, 1)

	surfaceElements.buttons[96] = surface.makeButton(44, 44, 10, 10)
	surfaceElements.buttons[96].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 107)
	surfaceElements.labels[96] = surface.makeLabelField(44, 49, 10, 1)

	surfaceElements.buttons[97] = surface.makeButton(55, 44, 10, 10)
	surfaceElements.buttons[97].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 108)
	surfaceElements.labels[97] = surface.makeLabelField(55, 49, 10, 1)

	surfaceElements.buttons[98] = surface.makeButton(66, 44, 10, 10)
	surfaceElements.buttons[98].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 109)
	surfaceElements.labels[98] = surface.makeLabelField(66, 49, 10, 1)

	surfaceElements.buttons[99] = surface.makeButton(77, 44, 10, 10)
	surfaceElements.buttons[99].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 110)
	surfaceElements.labels[99] = surface.makeLabelField(77, 49, 10, 1)

	surfaceElements.buttons[100] = surface.makeButton(88, 44, 10, 10)
	surfaceElements.buttons[100].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 1)
	surfaceElements.labels[100] = surface.makeLabelField(88, 49, 10, 1)

	surfaceElements.buttons[101] = surface.makeButton(99, 44, 10, 10)
	surfaceElements.buttons[101].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 2)
	surfaceElements.labels[101] = surface.makeLabelField(99, 49, 10, 1)

	surfaceElements.buttons[102] = surface.makeButton(110, 44, 10, 10)
	surfaceElements.buttons[102].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 3)
	surfaceElements.labels[102] = surface.makeLabelField(110, 49, 10, 1)

	surfaceElements.buttons[103] = surface.makeButton(121, 44, 10, 10)
	surfaceElements.buttons[103].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 4)
	surfaceElements.labels[103] = surface.makeLabelField(121, 49, 10, 1)

	surfaceElements.buttons[104] = surface.makeButton(132, 44, 10, 10)
	surfaceElements.buttons[104].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 5)
	surfaceElements.labels[104] = surface.makeLabelField(132, 49, 10, 1)

	surfaceElements.buttons[105] = surface.makeButton(143, 44, 10, 10)
	surfaceElements.buttons[105].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 6)
	surfaceElements.labels[105] = surface.makeLabelField(143, 49, 10, 1)

	surfaceElements.buttons[106] = surface.makeButton(154, 44, 10, 10)
	surfaceElements.buttons[106].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 7)
	surfaceElements.labels[106] = surface.makeLabelField(154, 49, 10, 1)

	surfaceElements.buttons[107] = surface.makeButton(165, 44, 10, 10)
	surfaceElements.buttons[107].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 8)
	surfaceElements.labels[107] = surface.makeLabelField(165, 49, 10, 1)

	surfaceElements.buttons[108] = surface.makeButton(176, 44, 10, 10)
	surfaceElements.buttons[108].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 9)
	surfaceElements.labels[108] = surface.makeLabelField(176, 49, 10, 1)

	surfaceElements.buttons[109] = surface.makeButton(187, 44, 10, 10)
	surfaceElements.buttons[109].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 10)
	surfaceElements.labels[109] = surface.makeLabelField(187, 49, 10, 1)

	surfaceElements.buttons[110] = surface.makeButton(198, 44, 10, 10)
	surfaceElements.buttons[110].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 11)
	surfaceElements.labels[110] = surface.makeLabelField(198, 49, 10, 1)

	surfaceElements.buttons[111] = surface.makeButton(209, 44, 10, 10)
	surfaceElements.buttons[111].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 12)
	surfaceElements.labels[111] = surface.makeLabelField(209, 49, 10, 1)

	surfaceElements.buttons[112] = surface.makeButton(220, 44, 10, 10)
	surfaceElements.buttons[112].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 13)
	surfaceElements.labels[112] = surface.makeLabelField(220, 49, 10, 1)

	surfaceElements.buttons[113] = surface.makeButton(231, 44, 10, 10)
	surfaceElements.buttons[113].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 14)
	surfaceElements.labels[113] = surface.makeLabelField(231, 49, 10, 1)

	surfaceElements.buttons[114] = surface.makeButton(242, 44, 10, 10)
	surfaceElements.buttons[114].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 15)
	surfaceElements.labels[114] = surface.makeLabelField(242, 49, 10, 1)

	surfaceElements.buttons[115] = surface.makeButton(0, 55, 10, 10)
	surfaceElements.buttons[115].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 16)
	surfaceElements.labels[115] = surface.makeLabelField(0, 60, 10, 1)

	surfaceElements.buttons[116] = surface.makeButton(11, 55, 10, 10)
	surfaceElements.buttons[116].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 17)
	surfaceElements.labels[116] = surface.makeLabelField(11, 60, 10, 1)

	surfaceElements.buttons[117] = surface.makeButton(22, 55, 10, 10)
	surfaceElements.buttons[117].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 18)
	surfaceElements.labels[117] = surface.makeLabelField(22, 60, 10, 1)

	surfaceElements.buttons[118] = surface.makeButton(33, 55, 10, 10)
	surfaceElements.buttons[118].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 19)
	surfaceElements.labels[118] = surface.makeLabelField(33, 60, 10, 1)

	surfaceElements.buttons[119] = surface.makeButton(44, 55, 10, 10)
	surfaceElements.buttons[119].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 20)
	surfaceElements.labels[119] = surface.makeLabelField(44, 60, 10, 1)

	surfaceElements.buttons[120] = surface.makeButton(55, 55, 10, 10)
	surfaceElements.buttons[120].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 21)
	surfaceElements.labels[120] = surface.makeLabelField(55, 60, 10, 1)

	surfaceElements.buttons[121] = surface.makeButton(66, 55, 10, 10)
	surfaceElements.buttons[121].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 22)
	surfaceElements.labels[121] = surface.makeLabelField(66, 60, 10, 1)

	surfaceElements.buttons[122] = surface.makeButton(77, 55, 10, 10)
	surfaceElements.buttons[122].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 23)
	surfaceElements.labels[122] = surface.makeLabelField(77, 60, 10, 1)

	surfaceElements.buttons[123] = surface.makeButton(88, 55, 10, 10)
	surfaceElements.buttons[123].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 24)
	surfaceElements.labels[123] = surface.makeLabelField(88, 60, 10, 1)

	surfaceElements.buttons[124] = surface.makeButton(99, 55, 10, 10)
	surfaceElements.buttons[124].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 25)
	surfaceElements.labels[124] = surface.makeLabelField(99, 60, 10, 1)

	surfaceElements.buttons[125] = surface.makeButton(110, 55, 10, 10)
	surfaceElements.buttons[125].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 26)
	surfaceElements.labels[125] = surface.makeLabelField(110, 60, 10, 1)

	surfaceElements.buttons[126] = surface.makeButton(121, 55, 10, 10)
	surfaceElements.buttons[126].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 27)
	surfaceElements.labels[126] = surface.makeLabelField(121, 60, 10, 1)

	surfaceElements.buttons[127] = surface.makeButton(132, 55, 10, 10)
	surfaceElements.buttons[127].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 28)
	surfaceElements.labels[127] = surface.makeLabelField(132, 60, 10, 1)

	surfaceElements.buttons[128] = surface.makeButton(143, 55, 10, 10)
	surfaceElements.buttons[128].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 29)
	surfaceElements.labels[128] = surface.makeLabelField(143, 60, 10, 1)

	surfaceElements.buttons[129] = surface.makeButton(154, 55, 10, 10)
	surfaceElements.buttons[129].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 30)
	surfaceElements.labels[129] = surface.makeLabelField(154, 60, 10, 1)

	surfaceElements.buttons[130] = surface.makeButton(165, 55, 10, 10)
	surfaceElements.buttons[130].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 31)
	surfaceElements.labels[130] = surface.makeLabelField(165, 60, 10, 1)

	surfaceElements.buttons[131] = surface.makeButton(176, 55, 10, 10)
	surfaceElements.buttons[131].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 32)
	surfaceElements.labels[131] = surface.makeLabelField(176, 60, 10, 1)

	surfaceElements.buttons[132] = surface.makeButton(187, 55, 10, 10)
	surfaceElements.buttons[132].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 33)
	surfaceElements.labels[132] = surface.makeLabelField(187, 60, 10, 1)

	surfaceElements.buttons[133] = surface.makeButton(198, 55, 10, 10)
	surfaceElements.buttons[133].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 34)
	surfaceElements.labels[133] = surface.makeLabelField(198, 60, 10, 1)

	surfaceElements.buttons[134] = surface.makeButton(209, 55, 10, 10)
	surfaceElements.buttons[134].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 35)
	surfaceElements.labels[134] = surface.makeLabelField(209, 60, 10, 1)

	surfaceElements.buttons[135] = surface.makeButton(220, 55, 10, 10)
	surfaceElements.buttons[135].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 36)
	surfaceElements.labels[135] = surface.makeLabelField(220, 60, 10, 1)

	surfaceElements.buttons[136] = surface.makeButton(231, 55, 10, 10)
	surfaceElements.buttons[136].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 37)
	surfaceElements.labels[136] = surface.makeLabelField(231, 60, 10, 1)

	surfaceElements.buttons[137] = surface.makeButton(242, 55, 10, 10)
	surfaceElements.buttons[137].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 38)
	surfaceElements.labels[137] = surface.makeLabelField(242, 60, 10, 1)

	surfaceElements.buttons[138] = surface.makeButton(0, 66, 10, 10)
	surfaceElements.buttons[138].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 39)
	surfaceElements.labels[138] = surface.makeLabelField(0, 71, 10, 1)

	surfaceElements.buttons[139] = surface.makeButton(11, 66, 10, 10)
	surfaceElements.buttons[139].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 40)
	surfaceElements.labels[139] = surface.makeLabelField(11, 71, 10, 1)

	surfaceElements.buttons[140] = surface.makeButton(22, 66, 10, 10)
	surfaceElements.buttons[140].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 41)
	surfaceElements.labels[140] = surface.makeLabelField(22, 71, 10, 1)

	surfaceElements.buttons[141] = surface.makeButton(33, 66, 10, 10)
	surfaceElements.buttons[141].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 42)
	surfaceElements.labels[141] = surface.makeLabelField(33, 71, 10, 1)

	surfaceElements.buttons[142] = surface.makeButton(44, 66, 10, 10)
	surfaceElements.buttons[142].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 43)
	surfaceElements.labels[142] = surface.makeLabelField(44, 71, 10, 1)

	surfaceElements.buttons[143] = surface.makeButton(55, 66, 10, 10)
	surfaceElements.buttons[143].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 44)
	surfaceElements.labels[143] = surface.makeLabelField(55, 71, 10, 1)

	surfaceElements.buttons[144] = surface.makeButton(66, 66, 10, 10)
	surfaceElements.buttons[144].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 45)
	surfaceElements.labels[144] = surface.makeLabelField(66, 71, 10, 1)

	surfaceElements.buttons[145] = surface.makeButton(77, 66, 10, 10)
	surfaceElements.buttons[145].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 46)
	surfaceElements.labels[145] = surface.makeLabelField(77, 71, 10, 1)

	surfaceElements.buttons[146] = surface.makeButton(88, 66, 10, 10)
	surfaceElements.buttons[146].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 47)
	surfaceElements.labels[146] = surface.makeLabelField(88, 71, 10, 1)

	surfaceElements.buttons[147] = surface.makeButton(99, 66, 10, 10)
	surfaceElements.buttons[147].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 48)
	surfaceElements.labels[147] = surface.makeLabelField(99, 71, 10, 1)

	surfaceElements.buttons[148] = surface.makeButton(110, 66, 10, 10)
	surfaceElements.buttons[148].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 49)
	surfaceElements.labels[148] = surface.makeLabelField(110, 71, 10, 1)

	surfaceElements.buttons[149] = surface.makeButton(121, 66, 10, 10)
	surfaceElements.buttons[149].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 50)
	surfaceElements.labels[149] = surface.makeLabelField(121, 71, 10, 1)

	surfaceElements.buttons[150] = surface.makeButton(132, 66, 10, 10)
	surfaceElements.buttons[150].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 51)
	surfaceElements.labels[150] = surface.makeLabelField(132, 71, 10, 1)

	surfaceElements.buttons[151] = surface.makeButton(143, 66, 10, 10)
	surfaceElements.buttons[151].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 52)
	surfaceElements.labels[151] = surface.makeLabelField(143, 71, 10, 1)

	surfaceElements.buttons[152] = surface.makeButton(154, 66, 10, 10)
	surfaceElements.buttons[152].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 53)
	surfaceElements.labels[152] = surface.makeLabelField(154, 71, 10, 1)

	surfaceElements.buttons[153] = surface.makeButton(165, 66, 10, 10)
	surfaceElements.buttons[153].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 54)
	surfaceElements.labels[153] = surface.makeLabelField(165, 71, 10, 1)

	surfaceElements.buttons[154] = surface.makeButton(176, 66, 10, 10)
	surfaceElements.buttons[154].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 55)
	surfaceElements.labels[154] = surface.makeLabelField(176, 71, 10, 1)

	surfaceElements.buttons[155] = surface.makeButton(187, 66, 10, 10)
	surfaceElements.buttons[155].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 56)
	surfaceElements.labels[155] = surface.makeLabelField(187, 71, 10, 1)

	surfaceElements.buttons[156] = surface.makeButton(198, 66, 10, 10)
	surfaceElements.buttons[156].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 57)
	surfaceElements.labels[156] = surface.makeLabelField(198, 71, 10, 1)

	surfaceElements.buttons[157] = surface.makeButton(209, 66, 10, 10)
	surfaceElements.buttons[157].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 58)
	surfaceElements.labels[157] = surface.makeLabelField(209, 71, 10, 1)

	surfaceElements.buttons[158] = surface.makeButton(220, 66, 10, 10)
	surfaceElements.buttons[158].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 59)
	surfaceElements.labels[158] = surface.makeLabelField(220, 71, 10, 1)

	surfaceElements.buttons[159] = surface.makeButton(231, 66, 10, 10)
	surfaceElements.buttons[159].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 60)
	surfaceElements.labels[159] = surface.makeLabelField(231, 71, 10, 1)

	surfaceElements.buttons[160] = surface.makeButton(242, 66, 10, 10)
	surfaceElements.buttons[160].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 61)
	surfaceElements.labels[160] = surface.makeLabelField(242, 71, 10, 1)

	surfaceElements.buttons[161] = surface.makeButton(0, 77, 10, 10)
	surfaceElements.buttons[161].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 62)
	surfaceElements.labels[161] = surface.makeLabelField(0, 82, 10, 1)

	surfaceElements.buttons[162] = surface.makeButton(11, 77, 10, 10)
	surfaceElements.buttons[162].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 63)
	surfaceElements.labels[162] = surface.makeLabelField(11, 82, 10, 1)

	surfaceElements.buttons[163] = surface.makeButton(22, 77, 10, 10)
	surfaceElements.buttons[163].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 64)
	surfaceElements.labels[163] = surface.makeLabelField(22, 82, 10, 1)

	surfaceElements.buttons[164] = surface.makeButton(33, 77, 10, 10)
	surfaceElements.buttons[164].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 65)
	surfaceElements.labels[164] = surface.makeLabelField(33, 82, 10, 1)

	surfaceElements.buttons[165] = surface.makeButton(44, 77, 10, 10)
	surfaceElements.buttons[165].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 66)
	surfaceElements.labels[165] = surface.makeLabelField(44, 82, 10, 1)

	surfaceElements.buttons[166] = surface.makeButton(55, 77, 10, 10)
	surfaceElements.buttons[166].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 67)
	surfaceElements.labels[166] = surface.makeLabelField(55, 82, 10, 1)

	surfaceElements.buttons[167] = surface.makeButton(66, 77, 10, 10)
	surfaceElements.buttons[167].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 68)
	surfaceElements.labels[167] = surface.makeLabelField(66, 82, 10, 1)

	surfaceElements.buttons[168] = surface.makeButton(77, 77, 10, 10)
	surfaceElements.buttons[168].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 69)
	surfaceElements.labels[168] = surface.makeLabelField(77, 82, 10, 1)

	surfaceElements.buttons[169] = surface.makeButton(88, 77, 10, 10)
	surfaceElements.buttons[169].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 70)
	surfaceElements.labels[169] = surface.makeLabelField(88, 82, 10, 1)

	surfaceElements.buttons[170] = surface.makeButton(99, 77, 10, 10)
	surfaceElements.buttons[170].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 71)
	surfaceElements.labels[170] = surface.makeLabelField(99, 82, 10, 1)

	surfaceElements.buttons[171] = surface.makeButton(110, 77, 10, 10)
	surfaceElements.buttons[171].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 72)
	surfaceElements.labels[171] = surface.makeLabelField(110, 82, 10, 1)

	surfaceElements.buttons[172] = surface.makeButton(121, 77, 10, 10)
	surfaceElements.buttons[172].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 73)
	surfaceElements.labels[172] = surface.makeLabelField(121, 82, 10, 1)

	surfaceElements.buttons[173] = surface.makeButton(132, 77, 10, 10)
	surfaceElements.buttons[173].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 74)
	surfaceElements.labels[173] = surface.makeLabelField(132, 82, 10, 1)

	surfaceElements.buttons[174] = surface.makeButton(143, 77, 10, 10)
	surfaceElements.buttons[174].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 75)
	surfaceElements.labels[174] = surface.makeLabelField(143, 82, 10, 1)

	surfaceElements.buttons[175] = surface.makeButton(154, 77, 10, 10)
	surfaceElements.buttons[175].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 76)
	surfaceElements.labels[175] = surface.makeLabelField(154, 82, 10, 1)

	surfaceElements.buttons[176] = surface.makeButton(165, 77, 10, 10)
	surfaceElements.buttons[176].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 77)
	surfaceElements.labels[176] = surface.makeLabelField(165, 82, 10, 1)

	surfaceElements.buttons[177] = surface.makeButton(176, 77, 10, 10)
	surfaceElements.buttons[177].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 78)
	surfaceElements.labels[177] = surface.makeLabelField(176, 82, 10, 1)

	surfaceElements.buttons[178] = surface.makeButton(187, 77, 10, 10)
	surfaceElements.buttons[178].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 79)
	surfaceElements.labels[178] = surface.makeLabelField(187, 82, 10, 1)

	surfaceElements.buttons[179] = surface.makeButton(198, 77, 10, 10)
	surfaceElements.buttons[179].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 80)
	surfaceElements.labels[179] = surface.makeLabelField(198, 82, 10, 1)

	surfaceElements.buttons[180] = surface.makeButton(209, 77, 10, 10)
	surfaceElements.buttons[180].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 81)
	surfaceElements.labels[180] = surface.makeLabelField(209, 82, 10, 1)

	surfaceElements.buttons[181] = surface.makeButton(220, 77, 10, 10)
	surfaceElements.buttons[181].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 82)
	surfaceElements.labels[181] = surface.makeLabelField(220, 82, 10, 1)

	surfaceElements.buttons[182] = surface.makeButton(231, 77, 10, 10)
	surfaceElements.buttons[182].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 83)
	surfaceElements.labels[182] = surface.makeLabelField(231, 82, 10, 1)

	surfaceElements.buttons[183] = surface.makeButton(242, 77, 10, 10)
	surfaceElements.buttons[183].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 84)
	surfaceElements.labels[183] = surface.makeLabelField(242, 82, 10, 1)

	surfaceElements.buttons[184] = surface.makeButton(0, 88, 10, 10)
	surfaceElements.buttons[184].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 85)
	surfaceElements.labels[184] = surface.makeLabelField(0, 93, 10, 1)

	surfaceElements.buttons[185] = surface.makeButton(11, 88, 10, 10)
	surfaceElements.buttons[185].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 86)
	surfaceElements.labels[185] = surface.makeLabelField(11, 93, 10, 1)

	surfaceElements.buttons[186] = surface.makeButton(22, 88, 10, 10)
	surfaceElements.buttons[186].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 87)
	surfaceElements.labels[186] = surface.makeLabelField(22, 93, 10, 1)

	surfaceElements.buttons[187] = surface.makeButton(33, 88, 10, 10)
	surfaceElements.buttons[187].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 88)
	surfaceElements.labels[187] = surface.makeLabelField(33, 93, 10, 1)

	surfaceElements.buttons[188] = surface.makeButton(44, 88, 10, 10)
	surfaceElements.buttons[188].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 89)
	surfaceElements.labels[188] = surface.makeLabelField(44, 93, 10, 1)

	surfaceElements.buttons[189] = surface.makeButton(55, 88, 10, 10)
	surfaceElements.buttons[189].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 90)
	surfaceElements.labels[189] = surface.makeLabelField(55, 93, 10, 1)

	surfaceElements.buttons[190] = surface.makeButton(66, 88, 10, 10)
	surfaceElements.buttons[190].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 91)
	surfaceElements.labels[190] = surface.makeLabelField(66, 93, 10, 1)

	surfaceElements.buttons[191] = surface.makeButton(77, 88, 10, 10)
	surfaceElements.buttons[191].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 92)
	surfaceElements.labels[191] = surface.makeLabelField(77, 93, 10, 1)

	surfaceElements.buttons[192] = surface.makeButton(88, 88, 10, 10)
	surfaceElements.buttons[192].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 93)
	surfaceElements.labels[192] = surface.makeLabelField(88, 93, 10, 1)

	surfaceElements.buttons[193] = surface.makeButton(99, 88, 10, 10)
	surfaceElements.buttons[193].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 94)
	surfaceElements.labels[193] = surface.makeLabelField(99, 93, 10, 1)

	surfaceElements.buttons[194] = surface.makeButton(110, 88, 10, 10)
	surfaceElements.buttons[194].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 95)
	surfaceElements.labels[194] = surface.makeLabelField(110, 93, 10, 1)

	surfaceElements.buttons[195] = surface.makeButton(121, 88, 10, 10)
	surfaceElements.buttons[195].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 96)
	surfaceElements.labels[195] = surface.makeLabelField(121, 93, 10, 1)

	surfaceElements.buttons[196] = surface.makeButton(132, 88, 10, 10)
	surfaceElements.buttons[196].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 97)
	surfaceElements.labels[196] = surface.makeLabelField(132, 93, 10, 1)

	surfaceElements.buttons[197] = surface.makeButton(143, 88, 10, 10)
	surfaceElements.buttons[197].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 98)
	surfaceElements.labels[197] = surface.makeLabelField(143, 93, 10, 1)

	surfaceElements.buttons[198] = surface.makeButton(154, 88, 10, 10)
	surfaceElements.buttons[198].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 99)
	surfaceElements.labels[198] = surface.makeLabelField(154, 93, 10, 1)

	surfaceElements.buttons[199] = surface.makeButton(165, 88, 10, 10)
	surfaceElements.buttons[199].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 100)
	surfaceElements.labels[199] = surface.makeLabelField(165, 93, 10, 1)

	surfaceElements.buttons[200] = surface.makeButton(176, 88, 10, 10)
	surfaceElements.buttons[200].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 11)
	surfaceElements.labels[200] = surface.makeLabelField(176, 93, 10, 1)

	surfaceElements.buttons[201] = surface.makeButton(187, 88, 10, 10)
	surfaceElements.buttons[201].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 12)
	surfaceElements.labels[201] = surface.makeLabelField(187, 93, 10, 1)

	surfaceElements.buttons[202] = surface.makeButton(198, 88, 10, 10)
	surfaceElements.buttons[202].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 13)
	surfaceElements.labels[202] = surface.makeLabelField(198, 93, 10, 1)

	surfaceElements.buttons[203] = surface.makeButton(209, 88, 10, 10)
	surfaceElements.buttons[203].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 14)
	surfaceElements.labels[203] = surface.makeLabelField(209, 93, 10, 1)

	surfaceElements.buttons[204] = surface.makeButton(220, 88, 10, 10)
	surfaceElements.buttons[204].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 15)
	surfaceElements.labels[204] = surface.makeLabelField(220, 93, 10, 1)

	surfaceElements.buttons[205] = surface.makeButton(231, 88, 10, 10)
	surfaceElements.buttons[205].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 16)
	surfaceElements.labels[205] = surface.makeLabelField(231, 93, 10, 1)

	surfaceElements.buttons[206] = surface.makeButton(242, 88, 10, 10)
	surfaceElements.buttons[206].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 17)
	surfaceElements.labels[206] = surface.makeLabelField(242, 93, 10, 1)

	surfaceElements.buttons[207] = surface.makeButton(0, 99, 10, 10)
	surfaceElements.buttons[207].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 18)
	surfaceElements.labels[207] = surface.makeLabelField(0, 104, 10, 1)

	surfaceElements.buttons[208] = surface.makeButton(11, 99, 10, 10)
	surfaceElements.buttons[208].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 19)
	surfaceElements.labels[208] = surface.makeLabelField(11, 104, 10, 1)

	surfaceElements.buttons[209] = surface.makeButton(22, 99, 10, 10)
	surfaceElements.buttons[209].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 20)
	surfaceElements.labels[209] = surface.makeLabelField(22, 104, 10, 1)

	surfaceElements.buttons[210] = surface.makeButton(33, 99, 10, 10)
	surfaceElements.buttons[210].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 21)
	surfaceElements.labels[210] = surface.makeLabelField(33, 104, 10, 1)

	surfaceElements.buttons[211] = surface.makeButton(44, 99, 10, 10)
	surfaceElements.buttons[211].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 22)
	surfaceElements.labels[211] = surface.makeLabelField(44, 104, 10, 1)

	surfaceElements.buttons[212] = surface.makeButton(55, 99, 10, 10)
	surfaceElements.buttons[212].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 23)
	surfaceElements.labels[212] = surface.makeLabelField(55, 104, 10, 1)

	surfaceElements.buttons[213] = surface.makeButton(66, 99, 10, 10)
	surfaceElements.buttons[213].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 24)
	surfaceElements.labels[213] = surface.makeLabelField(66, 104, 10, 1)

	surfaceElements.buttons[214] = surface.makeButton(77, 99, 10, 10)
	surfaceElements.buttons[214].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 25)
	surfaceElements.labels[214] = surface.makeLabelField(77, 104, 10, 1)

	surfaceElements.buttons[215] = surface.makeButton(88, 99, 10, 10)
	surfaceElements.buttons[215].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 26)
	surfaceElements.labels[215] = surface.makeLabelField(88, 104, 10, 1)

	surfaceElements.buttons[216] = surface.makeButton(99, 99, 10, 10)
	surfaceElements.buttons[216].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 27)
	surfaceElements.labels[216] = surface.makeLabelField(99, 104, 10, 1)

	surfaceElements.buttons[217] = surface.makeButton(110, 99, 10, 10)
	surfaceElements.buttons[217].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 28)
	surfaceElements.labels[217] = surface.makeLabelField(110, 104, 10, 1)

	surfaceElements.buttons[218] = surface.makeButton(121, 99, 10, 10)
	surfaceElements.buttons[218].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 29)
	surfaceElements.labels[218] = surface.makeLabelField(121, 104, 10, 1)

	surfaceElements.buttons[219] = surface.makeButton(132, 99, 10, 10)
	surfaceElements.buttons[219].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 30)
	surfaceElements.labels[219] = surface.makeLabelField(132, 104, 10, 1)

	surfaceElements.buttons[220] = surface.makeButton(143, 99, 10, 10)
	surfaceElements.buttons[220].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 31)
	surfaceElements.labels[220] = surface.makeLabelField(143, 104, 10, 1)

	surfaceElements.buttons[221] = surface.makeButton(154, 99, 10, 10)
	surfaceElements.buttons[221].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 32)
	surfaceElements.labels[221] = surface.makeLabelField(154, 104, 10, 1)

	surfaceElements.buttons[222] = surface.makeButton(165, 99, 10, 10)
	surfaceElements.buttons[222].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 33)
	surfaceElements.labels[222] = surface.makeLabelField(165, 104, 10, 1)

	surfaceElements.buttons[223] = surface.makeButton(176, 99, 10, 10)
	surfaceElements.buttons[223].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 34)
	surfaceElements.labels[223] = surface.makeLabelField(176, 104, 10, 1)

	surfaceElements.buttons[224] = surface.makeButton(187, 99, 10, 10)
	surfaceElements.buttons[224].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 35)
	surfaceElements.labels[224] = surface.makeLabelField(187, 104, 10, 1)

	surfaceElements.buttons[225] = surface.makeButton(198, 99, 10, 10)
	surfaceElements.buttons[225].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 36)
	surfaceElements.labels[225] = surface.makeLabelField(198, 104, 10, 1)

	surfaceElements.buttons[226] = surface.makeButton(209, 99, 10, 10)
	surfaceElements.buttons[226].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 37)
	surfaceElements.labels[226] = surface.makeLabelField(209, 104, 10, 1)

	surfaceElements.buttons[227] = surface.makeButton(220, 99, 10, 10)
	surfaceElements.buttons[227].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 38)
	surfaceElements.labels[227] = surface.makeLabelField(220, 104, 10, 1)

	surfaceElements.buttons[228] = surface.makeButton(231, 99, 10, 10)
	surfaceElements.buttons[228].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 39)
	surfaceElements.labels[228] = surface.makeLabelField(231, 104, 10, 1)

	surfaceElements.buttons[229] = surface.makeButton(242, 99, 10, 10)
	surfaceElements.buttons[229].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 40)
	surfaceElements.labels[229] = surface.makeLabelField(242, 104, 10, 1)

	surfaceElements.buttons[230] = surface.makeButton(0, 110, 10, 10)
	surfaceElements.buttons[230].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 41)
	surfaceElements.labels[230] = surface.makeLabelField(0, 115, 10, 1)

	surfaceElements.buttons[231] = surface.makeButton(11, 110, 10, 10)
	surfaceElements.buttons[231].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 42)
	surfaceElements.labels[231] = surface.makeLabelField(11, 115, 10, 1)

	surfaceElements.buttons[232] = surface.makeButton(22, 110, 10, 10)
	surfaceElements.buttons[232].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 43)
	surfaceElements.labels[232] = surface.makeLabelField(22, 115, 10, 1)

	surfaceElements.buttons[233] = surface.makeButton(33, 110, 10, 10)
	surfaceElements.buttons[233].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 44)
	surfaceElements.labels[233] = surface.makeLabelField(33, 115, 10, 1)

	surfaceElements.buttons[234] = surface.makeButton(44, 110, 10, 10)
	surfaceElements.buttons[234].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 45)
	surfaceElements.labels[234] = surface.makeLabelField(44, 115, 10, 1)

	surfaceElements.buttons[235] = surface.makeButton(55, 110, 10, 10)
	surfaceElements.buttons[235].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 46)
	surfaceElements.labels[235] = surface.makeLabelField(55, 115, 10, 1)

	surfaceElements.buttons[236] = surface.makeButton(66, 110, 10, 10)
	surfaceElements.buttons[236].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 47)
	surfaceElements.labels[236] = surface.makeLabelField(66, 115, 10, 1)

	surfaceElements.buttons[237] = surface.makeButton(77, 110, 10, 10)
	surfaceElements.buttons[237].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 48)
	surfaceElements.labels[237] = surface.makeLabelField(77, 115, 10, 1)

	surfaceElements.buttons[238] = surface.makeButton(88, 110, 10, 10)
	surfaceElements.buttons[238].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 49)
	surfaceElements.labels[238] = surface.makeLabelField(88, 115, 10, 1)

	surfaceElements.buttons[239] = surface.makeButton(99, 110, 10, 10)
	surfaceElements.buttons[239].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 50)
	surfaceElements.labels[239] = surface.makeLabelField(99, 115, 10, 1)

	surfaceElements.buttons[240] = surface.makeButton(110, 110, 10, 10)
	surfaceElements.buttons[240].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 51)
	surfaceElements.labels[240] = surface.makeLabelField(110, 115, 10, 1)

	surfaceElements.buttons[241] = surface.makeButton(121, 110, 10, 10)
	surfaceElements.buttons[241].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 52)
	surfaceElements.labels[241] = surface.makeLabelField(121, 115, 10, 1)

	surfaceElements.buttons[242] = surface.makeButton(132, 110, 10, 10)
	surfaceElements.buttons[242].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 53)
	surfaceElements.labels[242] = surface.makeLabelField(132, 115, 10, 1)

	surfaceElements.buttons[243] = surface.makeButton(143, 110, 10, 10)
	surfaceElements.buttons[243].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 54)
	surfaceElements.labels[243] = surface.makeLabelField(143, 115, 10, 1)

	surfaceElements.buttons[244] = surface.makeButton(154, 110, 10, 10)
	surfaceElements.buttons[244].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 55)
	surfaceElements.labels[244] = surface.makeLabelField(154, 115, 10, 1)

	surfaceElements.buttons[245] = surface.makeButton(165, 110, 10, 10)
	surfaceElements.buttons[245].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 56)
	surfaceElements.labels[245] = surface.makeLabelField(165, 115, 10, 1)

	surfaceElements.buttons[246] = surface.makeButton(176, 110, 10, 10)
	surfaceElements.buttons[246].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 57)
	surfaceElements.labels[246] = surface.makeLabelField(176, 115, 10, 1)

	surfaceElements.buttons[247] = surface.makeButton(187, 110, 10, 10)
	surfaceElements.buttons[247].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 58)
	surfaceElements.labels[247] = surface.makeLabelField(187, 115, 10, 1)

	surfaceElements.buttons[248] = surface.makeButton(198, 110, 10, 10)
	surfaceElements.buttons[248].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 59)
	surfaceElements.labels[248] = surface.makeLabelField(198, 115, 10, 1)

	surfaceElements.buttons[249] = surface.makeButton(209, 110, 10, 10)
	surfaceElements.buttons[249].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 60)
	surfaceElements.labels[249] = surface.makeLabelField(209, 115, 10, 1)

	surfaceElements.buttons[250] = surface.makeButton(220, 110, 10, 10)
	surfaceElements.buttons[250].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 61)
	surfaceElements.labels[250] = surface.makeLabelField(220, 115, 10, 1)

	surfaceElements.buttons[251] = surface.makeButton(231, 110, 10, 10)
	surfaceElements.buttons[251].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 62)
	surfaceElements.labels[251] = surface.makeLabelField(231, 115, 10, 1)

	surfaceElements.buttons[252] = surface.makeButton(242, 110, 10, 10)
	surfaceElements.buttons[252].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 63)
	surfaceElements.labels[252] = surface.makeLabelField(242, 115, 10, 1)

	surfaceElements.buttons[253] = surface.makeButton(0, 121, 10, 10)
	surfaceElements.buttons[253].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 64)
	surfaceElements.labels[253] = surface.makeLabelField(0, 126, 10, 1)

	surfaceElements.buttons[254] = surface.makeButton(11, 121, 10, 10)
	surfaceElements.buttons[254].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 65)
	surfaceElements.labels[254] = surface.makeLabelField(11, 126, 10, 1)

	surfaceElements.buttons[255] = surface.makeButton(22, 121, 10, 10)
	surfaceElements.buttons[255].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 66)
	surfaceElements.labels[255] = surface.makeLabelField(22, 126, 10, 1)

	surfaceElements.buttons[256] = surface.makeButton(33, 121, 10, 10)
	surfaceElements.buttons[256].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 67)
	surfaceElements.labels[256] = surface.makeLabelField(33, 126, 10, 1)

	surfaceElements.buttons[257] = surface.makeButton(44, 121, 10, 10)
	surfaceElements.buttons[257].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 68)
	surfaceElements.labels[257] = surface.makeLabelField(44, 126, 10, 1)

	surfaceElements.buttons[258] = surface.makeButton(55, 121, 10, 10)
	surfaceElements.buttons[258].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 69)
	surfaceElements.labels[258] = surface.makeLabelField(55, 126, 10, 1)

	surfaceElements.buttons[259] = surface.makeButton(66, 121, 10, 10)
	surfaceElements.buttons[259].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 70)
	surfaceElements.labels[259] = surface.makeLabelField(66, 126, 10, 1)

	surfaceElements.buttons[260] = surface.makeButton(77, 121, 10, 10)
	surfaceElements.buttons[260].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 71)
	surfaceElements.labels[260] = surface.makeLabelField(77, 126, 10, 1)

	surfaceElements.buttons[261] = surface.makeButton(88, 121, 10, 10)
	surfaceElements.buttons[261].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 72)
	surfaceElements.labels[261] = surface.makeLabelField(88, 126, 10, 1)

	surfaceElements.buttons[262] = surface.makeButton(99, 121, 10, 10)
	surfaceElements.buttons[262].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 73)
	surfaceElements.labels[262] = surface.makeLabelField(99, 126, 10, 1)

	surfaceElements.buttons[263] = surface.makeButton(110, 121, 10, 10)
	surfaceElements.buttons[263].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 74)
	surfaceElements.labels[263] = surface.makeLabelField(110, 126, 10, 1)

	surfaceElements.buttons[264] = surface.makeButton(121, 121, 10, 10)
	surfaceElements.buttons[264].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 75)
	surfaceElements.labels[264] = surface.makeLabelField(121, 126, 10, 1)

	surfaceElements.buttons[265] = surface.makeButton(132, 121, 10, 10)
	surfaceElements.buttons[265].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 76)
	surfaceElements.labels[265] = surface.makeLabelField(132, 126, 10, 1)

	surfaceElements.buttons[266] = surface.makeButton(143, 121, 10, 10)
	surfaceElements.buttons[266].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 77)
	surfaceElements.labels[266] = surface.makeLabelField(143, 126, 10, 1)

	surfaceElements.buttons[267] = surface.makeButton(154, 121, 10, 10)
	surfaceElements.buttons[267].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 78)
	surfaceElements.labels[267] = surface.makeLabelField(154, 126, 10, 1)

	surfaceElements.buttons[268] = surface.makeButton(165, 121, 10, 10)
	surfaceElements.buttons[268].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 79)
	surfaceElements.labels[268] = surface.makeLabelField(165, 126, 10, 1)

	surfaceElements.buttons[269] = surface.makeButton(176, 121, 10, 10)
	surfaceElements.buttons[269].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 80)
	surfaceElements.labels[269] = surface.makeLabelField(176, 126, 10, 1)

	surfaceElements.buttons[270] = surface.makeButton(187, 121, 10, 10)
	surfaceElements.buttons[270].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 81)
	surfaceElements.labels[270] = surface.makeLabelField(187, 126, 10, 1)

	surfaceElements.buttons[271] = surface.makeButton(198, 121, 10, 10)
	surfaceElements.buttons[271].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 82)
	surfaceElements.labels[271] = surface.makeLabelField(198, 126, 10, 1)

	surfaceElements.buttons[272] = surface.makeButton(209, 121, 10, 10)
	surfaceElements.buttons[272].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 83)
	surfaceElements.labels[272] = surface.makeLabelField(209, 126, 10, 1)

	surfaceElements.buttons[273] = surface.makeButton(220, 121, 10, 10)
	surfaceElements.buttons[273].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 84)
	surfaceElements.labels[273] = surface.makeLabelField(220, 126, 10, 1)

	surfaceElements.buttons[274] = surface.makeButton(231, 121, 10, 10)
	surfaceElements.buttons[274].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 85)
	surfaceElements.labels[274] = surface.makeLabelField(231, 126, 10, 1)

	surfaceElements.buttons[275] = surface.makeButton(242, 121, 10, 10)
	surfaceElements.buttons[275].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 86)
	surfaceElements.labels[275] = surface.makeLabelField(242, 126, 10, 1)

	surfaceElements.buttons[276] = surface.makeButton(0, 132, 10, 10)
	surfaceElements.buttons[276].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 87)
	surfaceElements.labels[276] = surface.makeLabelField(0, 137, 10, 1)

	surfaceElements.buttons[277] = surface.makeButton(11, 132, 10, 10)
	surfaceElements.buttons[277].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 88)
	surfaceElements.labels[277] = surface.makeLabelField(11, 137, 10, 1)

	surfaceElements.buttons[278] = surface.makeButton(22, 132, 10, 10)
	surfaceElements.buttons[278].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 89)
	surfaceElements.labels[278] = surface.makeLabelField(22, 137, 10, 1)

	surfaceElements.buttons[279] = surface.makeButton(33, 132, 10, 10)
	surfaceElements.buttons[279].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 90)
	surfaceElements.labels[279] = surface.makeLabelField(33, 137, 10, 1)

	surfaceElements.buttons[280] = surface.makeButton(44, 132, 10, 10)
	surfaceElements.buttons[280].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 91)
	surfaceElements.labels[280] = surface.makeLabelField(44, 137, 10, 1)

	surfaceElements.buttons[281] = surface.makeButton(55, 132, 10, 10)
	surfaceElements.buttons[281].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 92)
	surfaceElements.labels[281] = surface.makeLabelField(55, 137, 10, 1)

	surfaceElements.buttons[282] = surface.makeButton(66, 132, 10, 10)
	surfaceElements.buttons[282].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 93)
	surfaceElements.labels[282] = surface.makeLabelField(66, 137, 10, 1)

	surfaceElements.buttons[283] = surface.makeButton(77, 132, 10, 10)
	surfaceElements.buttons[283].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 94)
	surfaceElements.labels[283] = surface.makeLabelField(77, 137, 10, 1)

	surfaceElements.buttons[284] = surface.makeButton(88, 132, 10, 10)
	surfaceElements.buttons[284].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 95)
	surfaceElements.labels[284] = surface.makeLabelField(88, 137, 10, 1)

	surfaceElements.buttons[285] = surface.makeButton(99, 132, 10, 10)
	surfaceElements.buttons[285].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 96)
	surfaceElements.labels[285] = surface.makeLabelField(99, 137, 10, 1)

	surfaceElements.buttons[286] = surface.makeButton(110, 132, 10, 10)
	surfaceElements.buttons[286].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 97)
	surfaceElements.labels[286] = surface.makeLabelField(110, 137, 10, 1)

	surfaceElements.buttons[287] = surface.makeButton(121, 132, 10, 10)
	surfaceElements.buttons[287].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 98)
	surfaceElements.labels[287] = surface.makeLabelField(121, 137, 10, 1)

	surfaceElements.buttons[288] = surface.makeButton(132, 132, 10, 10)
	surfaceElements.buttons[288].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 99)
	surfaceElements.labels[288] = surface.makeLabelField(132, 137, 10, 1)

	surfaceElements.buttons[289] = surface.makeButton(143, 132, 10, 10)
	surfaceElements.buttons[289].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 100)
	surfaceElements.labels[289] = surface.makeLabelField(143, 137, 10, 1)

	surfaceElements.buttons[290] = surface.makeButton(154, 132, 10, 10)
	surfaceElements.buttons[290].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 101)
	surfaceElements.labels[290] = surface.makeLabelField(154, 137, 10, 1)

	surfaceElements.buttons[291] = surface.makeButton(165, 132, 10, 10)
	surfaceElements.buttons[291].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 102)
	surfaceElements.labels[291] = surface.makeLabelField(165, 137, 10, 1)

	surfaceElements.buttons[292] = surface.makeButton(176, 132, 10, 10)
	surfaceElements.buttons[292].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 103)
	surfaceElements.labels[292] = surface.makeLabelField(176, 137, 10, 1)

	surfaceElements.buttons[293] = surface.makeButton(187, 132, 10, 10)
	surfaceElements.buttons[293].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 104)
	surfaceElements.labels[293] = surface.makeLabelField(187, 137, 10, 1)

	surfaceElements.buttons[294] = surface.makeButton(198, 132, 10, 10)
	surfaceElements.buttons[294].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 105)
	surfaceElements.labels[294] = surface.makeLabelField(198, 137, 10, 1)

	surfaceElements.buttons[295] = surface.makeButton(209, 132, 10, 10)
	surfaceElements.buttons[295].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 106)
	surfaceElements.labels[295] = surface.makeLabelField(209, 137, 10, 1)

	surfaceElements.buttons[296] = surface.makeButton(220, 132, 10, 10)
	surfaceElements.buttons[296].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 107)
	surfaceElements.labels[296] = surface.makeLabelField(220, 137, 10, 1)

	surfaceElements.buttons[297] = surface.makeButton(231, 132, 10, 10)
	surfaceElements.buttons[297].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 108)
	surfaceElements.labels[297] = surface.makeLabelField(231, 137, 10, 1)

	surfaceElements.buttons[298] = surface.makeButton(242, 132, 10, 10)
	surfaceElements.buttons[298].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 109)
	surfaceElements.labels[298] = surface.makeLabelField(242, 137, 10, 1)

	surfaceElements.buttons[299] = surface.makeButton(0, 143, 10, 10)
	surfaceElements.buttons[299].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 110)
	surfaceElements.labels[299] = surface.makeLabelField(0, 148, 10, 1)

	surfaceElements.buttons[300] = surface.makeButton(11, 143, 10, 10)
	surfaceElements.buttons[300].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 9)
	surfaceElements.labels[300] = surface.makeLabelField(11, 148, 10, 1)

	surfaceElements.buttons[301] = surface.makeButton(22, 143, 10, 10)
	surfaceElements.buttons[301].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 10)
	surfaceElements.labels[301] = surface.makeLabelField(22, 148, 10, 1)

	surfaceElements.buttons[302] = surface.makeButton(33, 143, 10, 10)
	surfaceElements.buttons[302].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 101)
	surfaceElements.labels[302] = surface.makeLabelField(33, 148, 10, 1)

	surfaceElements.buttons[303] = surface.makeButton(44, 143, 10, 10)
	surfaceElements.buttons[303].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 102)
	surfaceElements.labels[303] = surface.makeLabelField(44, 148, 10, 1)

	surfaceElements.buttons[304] = surface.makeButton(55, 143, 10, 10)
	surfaceElements.buttons[304].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 103)
	surfaceElements.labels[304] = surface.makeLabelField(55, 148, 10, 1)

	surfaceElements.buttons[305] = surface.makeButton(66, 143, 10, 10)
	surfaceElements.buttons[305].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 104)
	surfaceElements.labels[305] = surface.makeLabelField(66, 148, 10, 1)

	surfaceElements.buttons[306] = surface.makeButton(77, 143, 10, 10)
	surfaceElements.buttons[306].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 105)
	surfaceElements.labels[306] = surface.makeLabelField(77, 148, 10, 1)

	surfaceElements.buttons[307] = surface.makeButton(88, 143, 10, 10)
	surfaceElements.buttons[307].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 106)
	surfaceElements.labels[307] = surface.makeLabelField(88, 148, 10, 1)

	surfaceElements.buttons[308] = surface.makeButton(99, 143, 10, 10)
	surfaceElements.buttons[308].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 107)
	surfaceElements.labels[308] = surface.makeLabelField(99, 148, 10, 1)

	surfaceElements.buttons[309] = surface.makeButton(110, 143, 10, 10)
	surfaceElements.buttons[309].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 108)
	surfaceElements.labels[309] = surface.makeLabelField(110, 148, 10, 1)

	surfaceElements.buttons[310] = surface.makeButton(121, 143, 10, 10)
	surfaceElements.buttons[310].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 109)
	surfaceElements.labels[310] = surface.makeLabelField(121, 148, 10, 1)

	surfaceElements.buttons[311] = surface.makeButton(132, 143, 10, 10)
	surfaceElements.buttons[311].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 110)
	surfaceElements.labels[311] = surface.makeLabelField(132, 148, 10, 1)

	surfaceElements.buttons[312] = surface.makeButton(143, 143, 10, 10)
	surfaceElements.buttons[312].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 111)
	surfaceElements.labels[312] = surface.makeLabelField(143, 148, 10, 1)

	surfaceElements.buttons[313] = surface.makeButton(154, 143, 10, 10)
	surfaceElements.buttons[313].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 112)
	surfaceElements.labels[313] = surface.makeLabelField(154, 148, 10, 1)

	surfaceElements.buttons[314] = surface.makeButton(165, 143, 10, 10)
	surfaceElements.buttons[314].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 113)
	surfaceElements.labels[314] = surface.makeLabelField(165, 148, 10, 1)

	surfaceElements.buttons[315] = surface.makeButton(176, 143, 10, 10)
	surfaceElements.buttons[315].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 114)
	surfaceElements.labels[315] = surface.makeLabelField(176, 148, 10, 1)

	surfaceElements.buttons[316] = surface.makeButton(187, 143, 10, 10)
	surfaceElements.buttons[316].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 115)
	surfaceElements.labels[316] = surface.makeLabelField(187, 148, 10, 1)

	surfaceElements.buttons[317] = surface.makeButton(198, 143, 10, 10)
	surfaceElements.buttons[317].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 116)
	surfaceElements.labels[317] = surface.makeLabelField(198, 148, 10, 1)

	surfaceElements.buttons[318] = surface.makeButton(209, 143, 10, 10)
	surfaceElements.buttons[318].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 117)
	surfaceElements.labels[318] = surface.makeLabelField(209, 148, 10, 1)

	surfaceElements.buttons[319] = surface.makeButton(220, 143, 10, 10)
	surfaceElements.buttons[319].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 118)
	surfaceElements.labels[319] = surface.makeLabelField(220, 148, 10, 1)

	surfaceElements.buttons[320] = surface.makeButton(231, 143, 10, 10)
	surfaceElements.buttons[320].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 119)
	surfaceElements.labels[320] = surface.makeLabelField(231, 148, 10, 1)

	surfaceElements.buttons[321] = surface.makeButton(242, 143, 10, 10)
	surfaceElements.buttons[321].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 120)
	surfaceElements.labels[321] = surface.makeLabelField(242, 148, 10, 1)

	surfaceElements.buttons[322] = surface.makeButton(0, 154, 10, 10)
	surfaceElements.buttons[322].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 121)
	surfaceElements.labels[322] = surface.makeLabelField(0, 159, 10, 1)

	surfaceElements.buttons[323] = surface.makeButton(11, 154, 10, 10)
	surfaceElements.buttons[323].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 122)
	surfaceElements.labels[323] = surface.makeLabelField(11, 159, 10, 1)

	surfaceElements.buttons[324] = surface.makeButton(22, 154, 10, 10)
	surfaceElements.buttons[324].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 123)
	surfaceElements.labels[324] = surface.makeLabelField(22, 159, 10, 1)

	surfaceElements.buttons[325] = surface.makeButton(33, 154, 10, 10)
	surfaceElements.buttons[325].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 124)
	surfaceElements.labels[325] = surface.makeLabelField(33, 159, 10, 1)

	surfaceElements.buttons[326] = surface.makeButton(44, 154, 10, 10)
	surfaceElements.buttons[326].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 125)
	surfaceElements.labels[326] = surface.makeLabelField(44, 159, 10, 1)

	surfaceElements.buttons[327] = surface.makeButton(55, 154, 10, 10)
	surfaceElements.buttons[327].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(9, 126)
	surfaceElements.labels[327] = surface.makeLabelField(55, 159, 10, 1)

	surfaceElements.buttons[328] = surface.makeButton(66, 154, 10, 10)
	surfaceElements.buttons[328].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 111)
	surfaceElements.labels[328] = surface.makeLabelField(66, 159, 10, 1)

	surfaceElements.buttons[329] = surface.makeButton(77, 154, 10, 10)
	surfaceElements.buttons[329].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 112)
	surfaceElements.labels[329] = surface.makeLabelField(77, 159, 10, 1)

	surfaceElements.buttons[330] = surface.makeButton(88, 154, 10, 10)
	surfaceElements.buttons[330].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 113)
	surfaceElements.labels[330] = surface.makeLabelField(88, 159, 10, 1)

	surfaceElements.buttons[331] = surface.makeButton(99, 154, 10, 10)
	surfaceElements.buttons[331].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 114)
	surfaceElements.labels[331] = surface.makeLabelField(99, 159, 10, 1)

	surfaceElements.buttons[332] = surface.makeButton(110, 154, 10, 10)
	surfaceElements.buttons[332].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 115)
	surfaceElements.labels[332] = surface.makeLabelField(110, 159, 10, 1)

	surfaceElements.buttons[333] = surface.makeButton(121, 154, 10, 10)
	surfaceElements.buttons[333].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 116)
	surfaceElements.labels[333] = surface.makeLabelField(121, 159, 10, 1)

	surfaceElements.buttons[334] = surface.makeButton(132, 154, 10, 10)
	surfaceElements.buttons[334].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 117)
	surfaceElements.labels[334] = surface.makeLabelField(132, 159, 10, 1)

	surfaceElements.buttons[335] = surface.makeButton(143, 154, 10, 10)
	surfaceElements.buttons[335].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 118)
	surfaceElements.labels[335] = surface.makeLabelField(143, 159, 10, 1)

	surfaceElements.buttons[336] = surface.makeButton(154, 154, 10, 10)
	surfaceElements.buttons[336].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 119)
	surfaceElements.labels[336] = surface.makeLabelField(154, 159, 10, 1)

	surfaceElements.buttons[337] = surface.makeButton(165, 154, 10, 10)
	surfaceElements.buttons[337].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 120)
	surfaceElements.labels[337] = surface.makeLabelField(165, 159, 10, 1)

	surfaceElements.buttons[338] = surface.makeButton(176, 154, 10, 10)
	surfaceElements.buttons[338].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 121)
	surfaceElements.labels[338] = surface.makeLabelField(176, 159, 10, 1)

	surfaceElements.buttons[339] = surface.makeButton(187, 154, 10, 10)
	surfaceElements.buttons[339].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 122)
	surfaceElements.labels[339] = surface.makeLabelField(187, 159, 10, 1)

	surfaceElements.buttons[340] = surface.makeButton(198, 154, 10, 10)
	surfaceElements.buttons[340].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 123)
	surfaceElements.labels[340] = surface.makeLabelField(198, 159, 10, 1)

	surfaceElements.buttons[341] = surface.makeButton(209, 154, 10, 10)
	surfaceElements.buttons[341].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 124)
	surfaceElements.labels[341] = surface.makeLabelField(209, 159, 10, 1)

	surfaceElements.buttons[342] = surface.makeButton(220, 154, 10, 10)
	surfaceElements.buttons[342].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 125)
	surfaceElements.labels[342] = surface.makeLabelField(220, 159, 10, 1)

	surfaceElements.buttons[343] = surface.makeButton(231, 154, 10, 10)
	surfaceElements.buttons[343].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 126)
	surfaceElements.labels[343] = surface.makeLabelField(231, 159, 10, 1)

	surfaceElements.buttons[344] = surface.makeButton(242, 154, 10, 10)
	surfaceElements.buttons[344].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(8, 127)
	surfaceElements.labels[344] = surface.makeLabelField(242, 159, 10, 1)

	surfaceElements.buttons[345] = surface.makeButton(0, 165, 10, 10)
	surfaceElements.buttons[345].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 87)
	surfaceElements.labels[345] = surface.makeLabelField(0, 170, 10, 1)

	surfaceElements.buttons[346] = surface.makeButton(11, 165, 10, 10)
	surfaceElements.buttons[346].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 88)
	surfaceElements.labels[346] = surface.makeLabelField(11, 170, 10, 1)

	surfaceElements.buttons[347] = surface.makeButton(22, 165, 10, 10)
	surfaceElements.buttons[347].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 89)
	surfaceElements.labels[347] = surface.makeLabelField(22, 170, 10, 1)

	surfaceElements.buttons[348] = surface.makeButton(33, 165, 10, 10)
	surfaceElements.buttons[348].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 90)
	surfaceElements.labels[348] = surface.makeLabelField(33, 170, 10, 1)

	surfaceElements.buttons[349] = surface.makeButton(44, 165, 10, 10)
	surfaceElements.buttons[349].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 91)
	surfaceElements.labels[349] = surface.makeLabelField(44, 170, 10, 1)

	surfaceElements.buttons[350] = surface.makeButton(55, 165, 10, 10)
	surfaceElements.buttons[350].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 92)
	surfaceElements.labels[350] = surface.makeLabelField(55, 170, 10, 1)

	surfaceElements.buttons[351] = surface.makeButton(66, 165, 10, 10)
	surfaceElements.buttons[351].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 93)
	surfaceElements.labels[351] = surface.makeLabelField(66, 170, 10, 1)

	surfaceElements.buttons[352] = surface.makeButton(77, 165, 10, 10)
	surfaceElements.buttons[352].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 94)
	surfaceElements.labels[352] = surface.makeLabelField(77, 170, 10, 1)

	surfaceElements.buttons[353] = surface.makeButton(88, 165, 10, 10)
	surfaceElements.buttons[353].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 95)
	surfaceElements.labels[353] = surface.makeLabelField(88, 170, 10, 1)

	surfaceElements.buttons[354] = surface.makeButton(99, 165, 10, 10)
	surfaceElements.buttons[354].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 96)
	surfaceElements.labels[354] = surface.makeLabelField(99, 170, 10, 1)

	surfaceElements.buttons[355] = surface.makeButton(110, 165, 10, 10)
	surfaceElements.buttons[355].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 97)
	surfaceElements.labels[355] = surface.makeLabelField(110, 170, 10, 1)

	surfaceElements.buttons[356] = surface.makeButton(121, 165, 10, 10)
	surfaceElements.buttons[356].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 98)
	surfaceElements.labels[356] = surface.makeLabelField(121, 170, 10, 1)

	surfaceElements.buttons[357] = surface.makeButton(132, 165, 10, 10)
	surfaceElements.buttons[357].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 99)
	surfaceElements.labels[357] = surface.makeLabelField(132, 170, 10, 1)

	surfaceElements.buttons[358] = surface.makeButton(143, 165, 10, 10)
	surfaceElements.buttons[358].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 100)
	surfaceElements.labels[358] = surface.makeLabelField(143, 170, 10, 1)

	surfaceElements.buttons[359] = surface.makeButton(154, 165, 10, 10)
	surfaceElements.buttons[359].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 101)
	surfaceElements.labels[359] = surface.makeLabelField(154, 170, 10, 1)

	surfaceElements.buttons[360] = surface.makeButton(165, 165, 10, 10)
	surfaceElements.buttons[360].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 102)
	surfaceElements.labels[360] = surface.makeLabelField(165, 170, 10, 1)

	surfaceElements.buttons[361] = surface.makeButton(176, 165, 10, 10)
	surfaceElements.buttons[361].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 103)
	surfaceElements.labels[361] = surface.makeLabelField(176, 170, 10, 1)

	surfaceElements.buttons[362] = surface.makeButton(187, 165, 10, 10)
	surfaceElements.buttons[362].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 104)
	surfaceElements.labels[362] = surface.makeLabelField(187, 170, 10, 1)

	surfaceElements.buttons[363] = surface.makeButton(198, 165, 10, 10)
	surfaceElements.buttons[363].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 105)
	surfaceElements.labels[363] = surface.makeLabelField(198, 170, 10, 1)

	surfaceElements.buttons[364] = surface.makeButton(209, 165, 10, 10)
	surfaceElements.buttons[364].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 106)
	surfaceElements.labels[364] = surface.makeLabelField(209, 170, 10, 1)

	surfaceElements.buttons[365] = surface.makeButton(220, 165, 10, 10)
	surfaceElements.buttons[365].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 107)
	surfaceElements.labels[365] = surface.makeLabelField(220, 170, 10, 1)

	surfaceElements.buttons[366] = surface.makeButton(231, 165, 10, 10)
	surfaceElements.buttons[366].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 108)
	surfaceElements.labels[366] = surface.makeLabelField(231, 170, 10, 1)

	surfaceElements.buttons[367] = surface.makeButton(242, 165, 10, 10)
	surfaceElements.buttons[367].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 109)
	surfaceElements.labels[367] = surface.makeLabelField(242, 170, 10, 1)

	surfaceElements.buttons[368] = surface.makeButton(0, 176, 10, 10)
	surfaceElements.buttons[368].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 110)
	surfaceElements.labels[368] = surface.makeLabelField(0, 181, 10, 1)

	surfaceElements.buttons[369] = surface.makeButton(11, 176, 10, 10)
	surfaceElements.buttons[369].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 111)
	surfaceElements.labels[369] = surface.makeLabelField(11, 181, 10, 1)

	surfaceElements.buttons[370] = surface.makeButton(22, 176, 10, 10)
	surfaceElements.buttons[370].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 112)
	surfaceElements.labels[370] = surface.makeLabelField(22, 181, 10, 1)

	surfaceElements.buttons[371] = surface.makeButton(33, 176, 10, 10)
	surfaceElements.buttons[371].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 113)
	surfaceElements.labels[371] = surface.makeLabelField(33, 181, 10, 1)

	surfaceElements.buttons[372] = surface.makeButton(44, 176, 10, 10)
	surfaceElements.buttons[372].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 114)
	surfaceElements.labels[372] = surface.makeLabelField(44, 181, 10, 1)

	surfaceElements.buttons[373] = surface.makeButton(55, 176, 10, 10)
	surfaceElements.buttons[373].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(0, 115)
	surfaceElements.labels[373] = surface.makeLabelField(55, 181, 10, 1)

	surfaceElements.buttons[374] = surface.makeButton(66, 176, 10, 10)
	surfaceElements.buttons[374].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 83)
	surfaceElements.labels[374] = surface.makeLabelField(66, 181, 10, 1)

	surfaceElements.buttons[375] = surface.makeButton(77, 176, 10, 10)
	surfaceElements.buttons[375].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 84)
	surfaceElements.labels[375] = surface.makeLabelField(77, 181, 10, 1)

	surfaceElements.buttons[376] = surface.makeButton(88, 176, 10, 10)
	surfaceElements.buttons[376].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 85)
	surfaceElements.labels[376] = surface.makeLabelField(88, 181, 10, 1)

	surfaceElements.buttons[377] = surface.makeButton(99, 176, 10, 10)
	surfaceElements.buttons[377].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 86)
	surfaceElements.labels[377] = surface.makeLabelField(99, 181, 10, 1)

	surfaceElements.buttons[378] = surface.makeButton(110, 176, 10, 10)
	surfaceElements.buttons[378].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 87)
	surfaceElements.labels[378] = surface.makeLabelField(110, 181, 10, 1)

	surfaceElements.buttons[379] = surface.makeButton(121, 176, 10, 10)
	surfaceElements.buttons[379].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 88)
	surfaceElements.labels[379] = surface.makeLabelField(121, 181, 10, 1)

	surfaceElements.buttons[380] = surface.makeButton(132, 176, 10, 10)
	surfaceElements.buttons[380].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 89)
	surfaceElements.labels[380] = surface.makeLabelField(132, 181, 10, 1)

	surfaceElements.buttons[381] = surface.makeButton(143, 176, 10, 10)
	surfaceElements.buttons[381].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 90)
	surfaceElements.labels[381] = surface.makeLabelField(143, 181, 10, 1)

	surfaceElements.buttons[382] = surface.makeButton(154, 176, 10, 10)
	surfaceElements.buttons[382].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 91)
	surfaceElements.labels[382] = surface.makeLabelField(154, 181, 10, 1)

	surfaceElements.buttons[383] = surface.makeButton(165, 176, 10, 10)
	surfaceElements.buttons[383].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 92)
	surfaceElements.labels[383] = surface.makeLabelField(165, 181, 10, 1)

	surfaceElements.buttons[384] = surface.makeButton(176, 176, 10, 10)
	surfaceElements.buttons[384].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 93)
	surfaceElements.labels[384] = surface.makeLabelField(176, 181, 10, 1)

	surfaceElements.buttons[385] = surface.makeButton(187, 176, 10, 10)
	surfaceElements.buttons[385].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 94)
	surfaceElements.labels[385] = surface.makeLabelField(187, 181, 10, 1)

	surfaceElements.buttons[386] = surface.makeButton(198, 176, 10, 10)
	surfaceElements.buttons[386].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 95)
	surfaceElements.labels[386] = surface.makeLabelField(198, 181, 10, 1)

	surfaceElements.buttons[387] = surface.makeButton(209, 176, 10, 10)
	surfaceElements.buttons[387].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 96)
	surfaceElements.labels[387] = surface.makeLabelField(209, 181, 10, 1)

	surfaceElements.buttons[388] = surface.makeButton(220, 176, 10, 10)
	surfaceElements.buttons[388].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 97)
	surfaceElements.labels[388] = surface.makeLabelField(220, 181, 10, 1)

	surfaceElements.buttons[389] = surface.makeButton(231, 176, 10, 10)
	surfaceElements.buttons[389].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 98)
	surfaceElements.labels[389] = surface.makeLabelField(231, 181, 10, 1)

	surfaceElements.buttons[390] = surface.makeButton(242, 176, 10, 10)
	surfaceElements.buttons[390].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 99)
	surfaceElements.labels[390] = surface.makeLabelField(242, 181, 10, 1)

	surfaceElements.buttons[391] = surface.makeButton(0, 187, 10, 10)
	surfaceElements.buttons[391].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 100)
	surfaceElements.labels[391] = surface.makeLabelField(0, 192, 10, 1)

	surfaceElements.buttons[392] = surface.makeButton(11, 187, 10, 10)
	surfaceElements.buttons[392].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 101)
	surfaceElements.labels[392] = surface.makeLabelField(11, 192, 10, 1)

	surfaceElements.buttons[393] = surface.makeButton(22, 187, 10, 10)
	surfaceElements.buttons[393].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 102)
	surfaceElements.labels[393] = surface.makeLabelField(22, 192, 10, 1)

	surfaceElements.buttons[394] = surface.makeButton(33, 187, 10, 10)
	surfaceElements.buttons[394].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 103)
	surfaceElements.labels[394] = surface.makeLabelField(33, 192, 10, 1)

	surfaceElements.buttons[395] = surface.makeButton(44, 187, 10, 10)
	surfaceElements.buttons[395].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 104)
	surfaceElements.labels[395] = surface.makeLabelField(44, 192, 10, 1)

	surfaceElements.buttons[396] = surface.makeButton(55, 187, 10, 10)
	surfaceElements.buttons[396].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 105)
	surfaceElements.labels[396] = surface.makeLabelField(55, 192, 10, 1)

	surfaceElements.buttons[397] = surface.makeButton(66, 187, 10, 10)
	surfaceElements.buttons[397].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 106)
	surfaceElements.labels[397] = surface.makeLabelField(66, 192, 10, 1)

	surfaceElements.buttons[398] = surface.makeButton(77, 187, 10, 10)
	surfaceElements.buttons[398].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 107)
	surfaceElements.labels[398] = surface.makeLabelField(77, 192, 10, 1)

	surfaceElements.buttons[399] = surface.makeButton(88, 187, 10, 10)
	surfaceElements.buttons[399].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 108)
	surfaceElements.labels[399] = surface.makeLabelField(88, 192, 10, 1)

	surfaceElements.buttons[400] = surface.makeButton(99, 187, 10, 10)
	surfaceElements.buttons[400].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 109)
	surfaceElements.labels[400] = surface.makeLabelField(99, 192, 10, 1)

	surfaceElements.buttons[401] = surface.makeButton(110, 187, 10, 10)
	surfaceElements.buttons[401].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 110)
	surfaceElements.labels[401] = surface.makeLabelField(110, 192, 10, 1)

	surfaceElements.buttons[402] = surface.makeButton(121, 187, 10, 10)
	surfaceElements.buttons[402].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 111)
	surfaceElements.labels[402] = surface.makeLabelField(121, 192, 10, 1)

	surfaceElements.buttons[403] = surface.makeButton(132, 187, 10, 10)
	surfaceElements.buttons[403].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 112)
	surfaceElements.labels[403] = surface.makeLabelField(132, 192, 10, 1)

	surfaceElements.buttons[404] = surface.makeButton(143, 187, 10, 10)
	surfaceElements.buttons[404].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 113)
	surfaceElements.labels[404] = surface.makeLabelField(143, 192, 10, 1)

	surfaceElements.buttons[405] = surface.makeButton(154, 187, 10, 10)
	surfaceElements.buttons[405].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 114)
	surfaceElements.labels[405] = surface.makeLabelField(154, 192, 10, 1)

	surfaceElements.buttons[406] = surface.makeButton(165, 187, 10, 10)
	surfaceElements.buttons[406].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 115)
	surfaceElements.labels[406] = surface.makeLabelField(165, 192, 10, 1)

	surfaceElements.buttons[407] = surface.makeButton(176, 187, 10, 10)
	surfaceElements.buttons[407].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 116)
	surfaceElements.labels[407] = surface.makeLabelField(176, 192, 10, 1)

	surfaceElements.buttons[408] = surface.makeButton(187, 187, 10, 10)
	surfaceElements.buttons[408].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 117)
	surfaceElements.labels[408] = surface.makeLabelField(187, 192, 10, 1)

	surfaceElements.buttons[409] = surface.makeButton(198, 187, 10, 10)
	surfaceElements.buttons[409].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 118)
	surfaceElements.labels[409] = surface.makeLabelField(198, 192, 10, 1)

	surfaceElements.buttons[410] = surface.makeButton(209, 187, 10, 10)
	surfaceElements.buttons[410].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 119)
	surfaceElements.labels[410] = surface.makeLabelField(209, 192, 10, 1)

	surfaceElements.buttons[411] = surface.makeButton(220, 187, 10, 10)
	surfaceElements.buttons[411].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 120)
	surfaceElements.labels[411] = surface.makeLabelField(220, 192, 10, 1)

	surfaceElements.buttons[412] = surface.makeButton(231, 187, 10, 10)
	surfaceElements.buttons[412].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 121)
	surfaceElements.labels[412] = surface.makeLabelField(231, 192, 10, 1)

	surfaceElements.buttons[413] = surface.makeButton(242, 187, 10, 10)
	surfaceElements.buttons[413].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 122)
	surfaceElements.labels[413] = surface.makeLabelField(242, 192, 10, 1)

	surfaceElements.buttons[414] = surface.makeButton(0, 198, 10, 10)
	surfaceElements.buttons[414].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 123)
	surfaceElements.labels[414] = surface.makeLabelField(0, 203, 10, 1)

	surfaceElements.buttons[415] = surface.makeButton(11, 198, 10, 10)
	surfaceElements.buttons[415].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 124)
	surfaceElements.labels[415] = surface.makeLabelField(11, 203, 10, 1)

	surfaceElements.buttons[416] = surface.makeButton(22, 198, 10, 10)
	surfaceElements.buttons[416].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 125)
	surfaceElements.labels[416] = surface.makeLabelField(22, 203, 10, 1)

	surfaceElements.buttons[417] = surface.makeButton(33, 198, 10, 10)
	surfaceElements.buttons[417].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 126)
	surfaceElements.labels[417] = surface.makeLabelField(33, 203, 10, 1)

	surfaceElements.buttons[418] = surface.makeButton(44, 198, 10, 10)
	surfaceElements.buttons[418].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(12, 127)
	surfaceElements.labels[418] = surface.makeLabelField(44, 203, 10, 1)

	surfaceElements.buttons[419] = surface.makeButton(55, 198, 10, 10)
	surfaceElements.buttons[419].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 67)
	surfaceElements.labels[419] = surface.makeLabelField(55, 203, 10, 1)

	surfaceElements.buttons[420] = surface.makeButton(66, 198, 10, 10)
	surfaceElements.buttons[420].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 68)
	surfaceElements.labels[420] = surface.makeLabelField(66, 203, 10, 1)

	surfaceElements.buttons[421] = surface.makeButton(77, 198, 10, 10)
	surfaceElements.buttons[421].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 69)
	surfaceElements.labels[421] = surface.makeLabelField(77, 203, 10, 1)

	surfaceElements.buttons[422] = surface.makeButton(88, 198, 10, 10)
	surfaceElements.buttons[422].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 70)
	surfaceElements.labels[422] = surface.makeLabelField(88, 203, 10, 1)

	surfaceElements.buttons[423] = surface.makeButton(99, 198, 10, 10)
	surfaceElements.buttons[423].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 71)
	surfaceElements.labels[423] = surface.makeLabelField(99, 203, 10, 1)

	surfaceElements.buttons[424] = surface.makeButton(110, 198, 10, 10)
	surfaceElements.buttons[424].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 72)
	surfaceElements.labels[424] = surface.makeLabelField(110, 203, 10, 1)

	surfaceElements.buttons[425] = surface.makeButton(121, 198, 10, 10)
	surfaceElements.buttons[425].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 73)
	surfaceElements.labels[425] = surface.makeLabelField(121, 203, 10, 1)

	surfaceElements.buttons[426] = surface.makeButton(132, 198, 10, 10)
	surfaceElements.buttons[426].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 74)
	surfaceElements.labels[426] = surface.makeLabelField(132, 203, 10, 1)

	surfaceElements.buttons[427] = surface.makeButton(143, 198, 10, 10)
	surfaceElements.buttons[427].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 75)
	surfaceElements.labels[427] = surface.makeLabelField(143, 203, 10, 1)

	surfaceElements.buttons[428] = surface.makeButton(154, 198, 10, 10)
	surfaceElements.buttons[428].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 76)
	surfaceElements.labels[428] = surface.makeLabelField(154, 203, 10, 1)

	surfaceElements.buttons[429] = surface.makeButton(165, 198, 10, 10)
	surfaceElements.buttons[429].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 77)
	surfaceElements.labels[429] = surface.makeLabelField(165, 203, 10, 1)

	surfaceElements.buttons[430] = surface.makeButton(176, 198, 10, 10)
	surfaceElements.buttons[430].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 78)
	surfaceElements.labels[430] = surface.makeLabelField(176, 203, 10, 1)

	surfaceElements.buttons[431] = surface.makeButton(187, 198, 10, 10)
	surfaceElements.buttons[431].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 79)
	surfaceElements.labels[431] = surface.makeLabelField(187, 203, 10, 1)

	surfaceElements.buttons[432] = surface.makeButton(198, 198, 10, 10)
	surfaceElements.buttons[432].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 80)
	surfaceElements.labels[432] = surface.makeLabelField(198, 203, 10, 1)

	surfaceElements.buttons[433] = surface.makeButton(209, 198, 10, 10)
	surfaceElements.buttons[433].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 81)
	surfaceElements.labels[433] = surface.makeLabelField(209, 203, 10, 1)

	surfaceElements.buttons[434] = surface.makeButton(220, 198, 10, 10)
	surfaceElements.buttons[434].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 82)
	surfaceElements.labels[434] = surface.makeLabelField(220, 203, 10, 1)

	surfaceElements.buttons[435] = surface.makeButton(231, 198, 10, 10)
	surfaceElements.buttons[435].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 83)
	surfaceElements.labels[435] = surface.makeLabelField(231, 203, 10, 1)

	surfaceElements.buttons[436] = surface.makeButton(242, 198, 10, 10)
	surfaceElements.buttons[436].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 84)
	surfaceElements.labels[436] = surface.makeLabelField(242, 203, 10, 1)

	surfaceElements.buttons[437] = surface.makeButton(0, 209, 10, 10)
	surfaceElements.buttons[437].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 85)
	surfaceElements.labels[437] = surface.makeLabelField(0, 214, 10, 1)

	surfaceElements.buttons[438] = surface.makeButton(11, 209, 10, 10)
	surfaceElements.buttons[438].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 86)
	surfaceElements.labels[438] = surface.makeLabelField(11, 214, 10, 1)

	surfaceElements.buttons[439] = surface.makeButton(22, 209, 10, 10)
	surfaceElements.buttons[439].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 87)
	surfaceElements.labels[439] = surface.makeLabelField(22, 214, 10, 1)

	surfaceElements.buttons[440] = surface.makeButton(33, 209, 10, 10)
	surfaceElements.buttons[440].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 88)
	surfaceElements.labels[440] = surface.makeLabelField(33, 214, 10, 1)

	surfaceElements.buttons[441] = surface.makeButton(44, 209, 10, 10)
	surfaceElements.buttons[441].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 89)
	surfaceElements.labels[441] = surface.makeLabelField(44, 214, 10, 1)

	surfaceElements.buttons[442] = surface.makeButton(55, 209, 10, 10)
	surfaceElements.buttons[442].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 90)
	surfaceElements.labels[442] = surface.makeLabelField(55, 214, 10, 1)

	surfaceElements.buttons[443] = surface.makeButton(66, 209, 10, 10)
	surfaceElements.buttons[443].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 91)
	surfaceElements.labels[443] = surface.makeLabelField(66, 214, 10, 1)

	surfaceElements.buttons[444] = surface.makeButton(77, 209, 10, 10)
	surfaceElements.buttons[444].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 92)
	surfaceElements.labels[444] = surface.makeLabelField(77, 214, 10, 1)

	surfaceElements.buttons[445] = surface.makeButton(88, 209, 10, 10)
	surfaceElements.buttons[445].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 93)
	surfaceElements.labels[445] = surface.makeLabelField(88, 214, 10, 1)

	surfaceElements.buttons[446] = surface.makeButton(99, 209, 10, 10)
	surfaceElements.buttons[446].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 94)
	surfaceElements.labels[446] = surface.makeLabelField(99, 214, 10, 1)

	surfaceElements.buttons[447] = surface.makeButton(110, 209, 10, 10)
	surfaceElements.buttons[447].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 95)
	surfaceElements.labels[447] = surface.makeLabelField(110, 214, 10, 1)

	surfaceElements.buttons[448] = surface.makeButton(121, 209, 10, 10)
	surfaceElements.buttons[448].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 96)
	surfaceElements.labels[448] = surface.makeLabelField(121, 214, 10, 1)

	surfaceElements.buttons[449] = surface.makeButton(132, 209, 10, 10)
	surfaceElements.buttons[449].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 97)
	surfaceElements.labels[449] = surface.makeLabelField(132, 214, 10, 1)

	surfaceElements.buttons[450] = surface.makeButton(143, 209, 10, 10)
	surfaceElements.buttons[450].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 98)
	surfaceElements.labels[450] = surface.makeLabelField(143, 214, 10, 1)

	surfaceElements.buttons[451] = surface.makeButton(154, 209, 10, 10)
	surfaceElements.buttons[451].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 99)
	surfaceElements.labels[451] = surface.makeLabelField(154, 214, 10, 1)

	surfaceElements.buttons[452] = surface.makeButton(165, 209, 10, 10)
	surfaceElements.buttons[452].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 100)
	surfaceElements.labels[452] = surface.makeLabelField(165, 214, 10, 1)

	surfaceElements.buttons[453] = surface.makeButton(176, 209, 10, 10)
	surfaceElements.buttons[453].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 101)
	surfaceElements.labels[453] = surface.makeLabelField(176, 214, 10, 1)

	surfaceElements.buttons[454] = surface.makeButton(187, 209, 10, 10)
	surfaceElements.buttons[454].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 102)
	surfaceElements.labels[454] = surface.makeLabelField(187, 214, 10, 1)

	surfaceElements.buttons[455] = surface.makeButton(198, 209, 10, 10)
	surfaceElements.buttons[455].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 103)
	surfaceElements.labels[455] = surface.makeLabelField(198, 214, 10, 1)

	surfaceElements.buttons[456] = surface.makeButton(209, 209, 10, 10)
	surfaceElements.buttons[456].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 104)
	surfaceElements.labels[456] = surface.makeLabelField(209, 214, 10, 1)

	surfaceElements.buttons[457] = surface.makeButton(220, 209, 10, 10)
	surfaceElements.buttons[457].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 105)
	surfaceElements.labels[457] = surface.makeLabelField(220, 214, 10, 1)

	surfaceElements.buttons[458] = surface.makeButton(231, 209, 10, 10)
	surfaceElements.buttons[458].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 106)
	surfaceElements.labels[458] = surface.makeLabelField(231, 214, 10, 1)

	surfaceElements.buttons[459] = surface.makeButton(242, 209, 10, 10)
	surfaceElements.buttons[459].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 107)
	surfaceElements.labels[459] = surface.makeLabelField(242, 214, 10, 1)

	surfaceElements.buttons[460] = surface.makeButton(0, 220, 10, 10)
	surfaceElements.buttons[460].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 108)
	surfaceElements.labels[460] = surface.makeLabelField(0, 225, 10, 1)

	surfaceElements.buttons[461] = surface.makeButton(11, 220, 10, 10)
	surfaceElements.buttons[461].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 109)
	surfaceElements.labels[461] = surface.makeLabelField(11, 225, 10, 1)

	surfaceElements.buttons[462] = surface.makeButton(22, 220, 10, 10)
	surfaceElements.buttons[462].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 110)
	surfaceElements.labels[462] = surface.makeLabelField(22, 225, 10, 1)

	surfaceElements.buttons[463] = surface.makeButton(33, 220, 10, 10)
	surfaceElements.buttons[463].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 111)
	surfaceElements.labels[463] = surface.makeLabelField(33, 225, 10, 1)

	surfaceElements.buttons[464] = surface.makeButton(44, 220, 10, 10)
	surfaceElements.buttons[464].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 112)
	surfaceElements.labels[464] = surface.makeLabelField(44, 225, 10, 1)

	surfaceElements.buttons[465] = surface.makeButton(55, 220, 10, 10)
	surfaceElements.buttons[465].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 113)
	surfaceElements.labels[465] = surface.makeLabelField(55, 225, 10, 1)

	surfaceElements.buttons[466] = surface.makeButton(66, 220, 10, 10)
	surfaceElements.buttons[466].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 114)
	surfaceElements.labels[466] = surface.makeLabelField(66, 225, 10, 1)

	surfaceElements.buttons[467] = surface.makeButton(77, 220, 10, 10)
	surfaceElements.buttons[467].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 115)
	surfaceElements.labels[467] = surface.makeLabelField(77, 225, 10, 1)

	surfaceElements.buttons[468] = surface.makeButton(88, 220, 10, 10)
	surfaceElements.buttons[468].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 116)
	surfaceElements.labels[468] = surface.makeLabelField(88, 225, 10, 1)

	surfaceElements.buttons[469] = surface.makeButton(99, 220, 10, 10)
	surfaceElements.buttons[469].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 117)
	surfaceElements.labels[469] = surface.makeLabelField(99, 225, 10, 1)

	surfaceElements.buttons[470] = surface.makeButton(110, 220, 10, 10)
	surfaceElements.buttons[470].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 118)
	surfaceElements.labels[470] = surface.makeLabelField(110, 225, 10, 1)

	surfaceElements.buttons[471] = surface.makeButton(121, 220, 10, 10)
	surfaceElements.buttons[471].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 119)
	surfaceElements.labels[471] = surface.makeLabelField(121, 225, 10, 1)

	surfaceElements.buttons[472] = surface.makeButton(132, 220, 10, 10)
	surfaceElements.buttons[472].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 120)
	surfaceElements.labels[472] = surface.makeLabelField(132, 225, 10, 1)

	surfaceElements.buttons[473] = surface.makeButton(143, 220, 10, 10)
	surfaceElements.buttons[473].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 121)
	surfaceElements.labels[473] = surface.makeLabelField(143, 225, 10, 1)

	surfaceElements.buttons[474] = surface.makeButton(154, 220, 10, 10)
	surfaceElements.buttons[474].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 122)
	surfaceElements.labels[474] = surface.makeLabelField(154, 225, 10, 1)

	surfaceElements.buttons[475] = surface.makeButton(165, 220, 10, 10)
	surfaceElements.buttons[475].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 123)
	surfaceElements.labels[475] = surface.makeLabelField(165, 225, 10, 1)

	surfaceElements.buttons[476] = surface.makeButton(176, 220, 10, 10)
	surfaceElements.buttons[476].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 124)
	surfaceElements.labels[476] = surface.makeLabelField(176, 225, 10, 1)

	surfaceElements.buttons[477] = surface.makeButton(187, 220, 10, 10)
	surfaceElements.buttons[477].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 125)
	surfaceElements.labels[477] = surface.makeLabelField(187, 225, 10, 1)

	surfaceElements.buttons[478] = surface.makeButton(198, 220, 10, 10)
	surfaceElements.buttons[478].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 126)
	surfaceElements.labels[478] = surface.makeLabelField(198, 225, 10, 1)

	surfaceElements.buttons[479] = surface.makeButton(209, 220, 10, 10)
	surfaceElements.buttons[479].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(5, 127)
	surfaceElements.labels[479] = surface.makeLabelField(209, 225, 10, 1)

	surfaceElements.buttons[480] = surface.makeButton(220, 220, 10, 10)
	surfaceElements.buttons[480].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 111)
	surfaceElements.labels[480] = surface.makeLabelField(220, 225, 10, 1)

	surfaceElements.buttons[481] = surface.makeButton(231, 220, 10, 10)
	surfaceElements.buttons[481].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 112)
	surfaceElements.labels[481] = surface.makeLabelField(231, 225, 10, 1)

	surfaceElements.buttons[482] = surface.makeButton(242, 220, 10, 10)
	surfaceElements.buttons[482].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 113)
	surfaceElements.labels[482] = surface.makeLabelField(242, 225, 10, 1)

	surfaceElements.buttons[483] = surface.makeButton(0, 231, 10, 10)
	surfaceElements.buttons[483].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 114)
	surfaceElements.labels[483] = surface.makeLabelField(0, 236, 10, 1)

	surfaceElements.buttons[484] = surface.makeButton(11, 231, 10, 10)
	surfaceElements.buttons[484].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 115)
	surfaceElements.labels[484] = surface.makeLabelField(11, 236, 10, 1)

	surfaceElements.buttons[485] = surface.makeButton(22, 231, 10, 10)
	surfaceElements.buttons[485].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 116)
	surfaceElements.labels[485] = surface.makeLabelField(22, 236, 10, 1)

	surfaceElements.buttons[486] = surface.makeButton(33, 231, 10, 10)
	surfaceElements.buttons[486].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 117)
	surfaceElements.labels[486] = surface.makeLabelField(33, 236, 10, 1)

	surfaceElements.buttons[487] = surface.makeButton(44, 231, 10, 10)
	surfaceElements.buttons[487].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 118)
	surfaceElements.labels[487] = surface.makeLabelField(44, 236, 10, 1)

	surfaceElements.buttons[488] = surface.makeButton(55, 231, 10, 10)
	surfaceElements.buttons[488].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 119)
	surfaceElements.labels[488] = surface.makeLabelField(55, 236, 10, 1)

	surfaceElements.buttons[489] = surface.makeButton(66, 231, 10, 10)
	surfaceElements.buttons[489].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 120)
	surfaceElements.labels[489] = surface.makeLabelField(66, 236, 10, 1)

	surfaceElements.buttons[490] = surface.makeButton(77, 231, 10, 10)
	surfaceElements.buttons[490].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 121)
	surfaceElements.labels[490] = surface.makeLabelField(77, 236, 10, 1)

	surfaceElements.buttons[491] = surface.makeButton(88, 231, 10, 10)
	surfaceElements.buttons[491].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 122)
	surfaceElements.labels[491] = surface.makeLabelField(88, 236, 10, 1)

	surfaceElements.buttons[492] = surface.makeButton(99, 231, 10, 10)
	surfaceElements.buttons[492].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 123)
	surfaceElements.labels[492] = surface.makeLabelField(99, 236, 10, 1)

	surfaceElements.buttons[493] = surface.makeButton(110, 231, 10, 10)
	surfaceElements.buttons[493].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 124)
	surfaceElements.labels[493] = surface.makeLabelField(110, 236, 10, 1)

	surfaceElements.buttons[494] = surface.makeButton(121, 231, 10, 10)
	surfaceElements.buttons[494].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 125)
	surfaceElements.labels[494] = surface.makeLabelField(121, 236, 10, 1)

	surfaceElements.buttons[495] = surface.makeButton(132, 231, 10, 10)
	surfaceElements.buttons[495].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 126)
	surfaceElements.labels[495] = surface.makeLabelField(132, 236, 10, 1)

	surfaceElements.buttons[496] = surface.makeButton(143, 231, 10, 10)
	surfaceElements.buttons[496].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(10, 127)
	surfaceElements.labels[496] = surface.makeLabelField(143, 236, 10, 1)

	surfaceElements.buttons[497] = surface.makeButton(154, 231, 10, 10)
	surfaceElements.buttons[497].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 121)
	surfaceElements.labels[497] = surface.makeLabelField(154, 236, 10, 1)

	surfaceElements.buttons[498] = surface.makeButton(165, 231, 10, 10)
	surfaceElements.buttons[498].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 122)
	surfaceElements.labels[498] = surface.makeLabelField(165, 236, 10, 1)

	surfaceElements.buttons[499] = surface.makeButton(176, 231, 10, 10)
	surfaceElements.buttons[499].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 123)
	surfaceElements.labels[499] = surface.makeLabelField(176, 236, 10, 1)

	surfaceElements.buttons[500] = surface.makeButton(187, 231, 10, 10)
	surfaceElements.buttons[500].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 124)
	surfaceElements.labels[500] = surface.makeLabelField(187, 236, 10, 1)

	surfaceElements.buttons[501] = surface.makeButton(198, 231, 10, 10)
	surfaceElements.buttons[501].mSurfaceValue.mMidiBinding.setInputPort(midiInput).setOutputPort(midiOutput).bindToControlChange(4, 125)
	surfaceElements.labels[501] = surface.makeLabelField(198, 236, 10, 1)

	return surfaceElements
}

var surfaceElements = makeSurfaceElements()
// var labelElements = makeLabelElements()

//----------------------------------------------------------------------------------------------------------------------
// 3. HOST MAPPING - create mapping pages and host bindings
//----------------------------------------------------------------------------------------------------------------------
function makePageWithDefaults(name) {
	var page = deviceDriver.mMapping.makePage(name)
	return page
}

//----------------------------------------------------------------------------------------------------------------------
function makePageMacros() {
	var page = makePageWithDefaults('Macros')

	page.makeCommandBinding(surfaceElements.buttons[200].mSurfaceValue, "Process Project Logical Editor", "Scene001")
	page.setLabelFieldText(surfaceElements.labels[200], "Scene 001")

	page.makeCommandBinding(surfaceElements.buttons[201].mSurfaceValue, "Process Project Logical Editor", "Scene002")
	page.setLabelFieldText(surfaceElements.labels[201], "Scene 002")

	page.makeCommandBinding(surfaceElements.buttons[202].mSurfaceValue, "Process Project Logical Editor", "Scene003")
	page.setLabelFieldText(surfaceElements.labels[202], "Scene 003")

	page.makeCommandBinding(surfaceElements.buttons[203].mSurfaceValue, "Process Project Logical Editor", "Scene004")
	page.setLabelFieldText(surfaceElements.labels[203], "Scene 004")

	page.makeCommandBinding(surfaceElements.buttons[204].mSurfaceValue, "Process Project Logical Editor", "Scene005")
	page.setLabelFieldText(surfaceElements.labels[204], "Scene 005")

	page.makeCommandBinding(surfaceElements.buttons[205].mSurfaceValue, "Process Project Logical Editor", "Scene006")
	page.setLabelFieldText(surfaceElements.labels[205], "Scene 006")

	page.makeCommandBinding(surfaceElements.buttons[206].mSurfaceValue, "Process Project Logical Editor", "Scene007")
	page.setLabelFieldText(surfaceElements.labels[206], "Scene 007")

	page.makeCommandBinding(surfaceElements.buttons[207].mSurfaceValue, "Process Project Logical Editor", "Scene008")
	page.setLabelFieldText(surfaceElements.labels[207], "Scene 008")

	page.makeCommandBinding(surfaceElements.buttons[208].mSurfaceValue, "Process Project Logical Editor", "Scene009")
	page.setLabelFieldText(surfaceElements.labels[208], "Scene 009")

	page.makeCommandBinding(surfaceElements.buttons[209].mSurfaceValue, "Process Project Logical Editor", "Scene010")
	page.setLabelFieldText(surfaceElements.labels[209], "Scene 010")

	page.makeCommandBinding(surfaceElements.buttons[210].mSurfaceValue, "Process Project Logical Editor", "Scene011")
	page.setLabelFieldText(surfaceElements.labels[210], "Scene 011")

	page.makeCommandBinding(surfaceElements.buttons[211].mSurfaceValue, "Process Project Logical Editor", "Scene012")
	page.setLabelFieldText(surfaceElements.labels[211], "Scene 012")

	page.makeCommandBinding(surfaceElements.buttons[212].mSurfaceValue, "Process Project Logical Editor", "Scene013")
	page.setLabelFieldText(surfaceElements.labels[212], "Scene 013")

	page.makeCommandBinding(surfaceElements.buttons[213].mSurfaceValue, "Process Project Logical Editor", "Scene014")
	page.setLabelFieldText(surfaceElements.labels[213], "Scene 014")

	page.makeCommandBinding(surfaceElements.buttons[214].mSurfaceValue, "Process Project Logical Editor", "Scene015")
	page.setLabelFieldText(surfaceElements.labels[214], "Scene 015")

	page.makeCommandBinding(surfaceElements.buttons[215].mSurfaceValue, "Process Project Logical Editor", "Scene016")
	page.setLabelFieldText(surfaceElements.labels[215], "Scene 016")

	page.makeCommandBinding(surfaceElements.buttons[216].mSurfaceValue, "Process Project Logical Editor", "Scene017")
	page.setLabelFieldText(surfaceElements.labels[216], "Scene 017")

	page.makeCommandBinding(surfaceElements.buttons[217].mSurfaceValue, "Process Project Logical Editor", "Scene018")
	page.setLabelFieldText(surfaceElements.labels[217], "Scene 018")

	page.makeCommandBinding(surfaceElements.buttons[218].mSurfaceValue, "Process Project Logical Editor", "Scene019")
	page.setLabelFieldText(surfaceElements.labels[218], "Scene 019")

	page.makeCommandBinding(surfaceElements.buttons[219].mSurfaceValue, "Process Project Logical Editor", "Scene020")
	page.setLabelFieldText(surfaceElements.labels[219], "Scene 020")

	page.makeCommandBinding(surfaceElements.buttons[220].mSurfaceValue, "Process Project Logical Editor", "Scene021")
	page.setLabelFieldText(surfaceElements.labels[220], "Scene 021")

	page.makeCommandBinding(surfaceElements.buttons[221].mSurfaceValue, "Process Project Logical Editor", "Scene022")
	page.setLabelFieldText(surfaceElements.labels[221], "Scene 022")

	page.makeCommandBinding(surfaceElements.buttons[222].mSurfaceValue, "Process Project Logical Editor", "Scene023")
	page.setLabelFieldText(surfaceElements.labels[222], "Scene 023")

	page.makeCommandBinding(surfaceElements.buttons[223].mSurfaceValue, "Process Project Logical Editor", "Scene024")
	page.setLabelFieldText(surfaceElements.labels[223], "Scene 024")

	page.makeCommandBinding(surfaceElements.buttons[224].mSurfaceValue, "Process Project Logical Editor", "Scene025")
	page.setLabelFieldText(surfaceElements.labels[224], "Scene 025")

	page.makeCommandBinding(surfaceElements.buttons[225].mSurfaceValue, "Process Project Logical Editor", "Scene026")
	page.setLabelFieldText(surfaceElements.labels[225], "Scene 026")

	page.makeCommandBinding(surfaceElements.buttons[226].mSurfaceValue, "Process Project Logical Editor", "Scene027")
	page.setLabelFieldText(surfaceElements.labels[226], "Scene 027")

	page.makeCommandBinding(surfaceElements.buttons[227].mSurfaceValue, "Process Project Logical Editor", "Scene028")
	page.setLabelFieldText(surfaceElements.labels[227], "Scene 028")

	page.makeCommandBinding(surfaceElements.buttons[228].mSurfaceValue, "Process Project Logical Editor", "Scene029")
	page.setLabelFieldText(surfaceElements.labels[228], "Scene 029")

	page.makeCommandBinding(surfaceElements.buttons[229].mSurfaceValue, "Process Project Logical Editor", "Scene030")
	page.setLabelFieldText(surfaceElements.labels[229], "Scene 030")

	page.makeCommandBinding(surfaceElements.buttons[230].mSurfaceValue, "Process Project Logical Editor", "Scene031")
	page.setLabelFieldText(surfaceElements.labels[230], "Scene 031")

	page.makeCommandBinding(surfaceElements.buttons[231].mSurfaceValue, "Process Project Logical Editor", "Scene032")
	page.setLabelFieldText(surfaceElements.labels[231], "Scene 032")

	page.makeCommandBinding(surfaceElements.buttons[232].mSurfaceValue, "Process Project Logical Editor", "Scene033")
	page.setLabelFieldText(surfaceElements.labels[232], "Scene 033")

	page.makeCommandBinding(surfaceElements.buttons[233].mSurfaceValue, "Process Project Logical Editor", "Scene034")
	page.setLabelFieldText(surfaceElements.labels[233], "Scene 034")

	page.makeCommandBinding(surfaceElements.buttons[234].mSurfaceValue, "Process Project Logical Editor", "Scene035")
	page.setLabelFieldText(surfaceElements.labels[234], "Scene 035")

	page.makeCommandBinding(surfaceElements.buttons[235].mSurfaceValue, "Process Project Logical Editor", "Scene036")
	page.setLabelFieldText(surfaceElements.labels[235], "Scene 036")

	page.makeCommandBinding(surfaceElements.buttons[236].mSurfaceValue, "Process Project Logical Editor", "Scene037")
	page.setLabelFieldText(surfaceElements.labels[236], "Scene 037")

	page.makeCommandBinding(surfaceElements.buttons[237].mSurfaceValue, "Process Project Logical Editor", "Scene038")
	page.setLabelFieldText(surfaceElements.labels[237], "Scene 038")

	page.makeCommandBinding(surfaceElements.buttons[238].mSurfaceValue, "Process Project Logical Editor", "Scene039")
	page.setLabelFieldText(surfaceElements.labels[238], "Scene 039")

	page.makeCommandBinding(surfaceElements.buttons[239].mSurfaceValue, "Process Project Logical Editor", "Scene040")
	page.setLabelFieldText(surfaceElements.labels[239], "Scene 040")

	page.makeCommandBinding(surfaceElements.buttons[240].mSurfaceValue, "Process Project Logical Editor", "Scene041")
	page.setLabelFieldText(surfaceElements.labels[240], "Scene 041")

	page.makeCommandBinding(surfaceElements.buttons[241].mSurfaceValue, "Process Project Logical Editor", "Scene042")
	page.setLabelFieldText(surfaceElements.labels[241], "Scene 042")

	page.makeCommandBinding(surfaceElements.buttons[242].mSurfaceValue, "Process Project Logical Editor", "Scene043")
	page.setLabelFieldText(surfaceElements.labels[242], "Scene 043")

	page.makeCommandBinding(surfaceElements.buttons[243].mSurfaceValue, "Process Project Logical Editor", "Scene044")
	page.setLabelFieldText(surfaceElements.labels[243], "Scene 044")

	page.makeCommandBinding(surfaceElements.buttons[244].mSurfaceValue, "Process Project Logical Editor", "Scene045")
	page.setLabelFieldText(surfaceElements.labels[244], "Scene 045")

	page.makeCommandBinding(surfaceElements.buttons[245].mSurfaceValue, "Process Project Logical Editor", "Scene046")
	page.setLabelFieldText(surfaceElements.labels[245], "Scene 046")

	page.makeCommandBinding(surfaceElements.buttons[246].mSurfaceValue, "Process Project Logical Editor", "Scene047")
	page.setLabelFieldText(surfaceElements.labels[246], "Scene 047")

	page.makeCommandBinding(surfaceElements.buttons[247].mSurfaceValue, "Process Project Logical Editor", "Scene048")
	page.setLabelFieldText(surfaceElements.labels[247], "Scene 048")

	page.makeCommandBinding(surfaceElements.buttons[248].mSurfaceValue, "Process Project Logical Editor", "Scene049")
	page.setLabelFieldText(surfaceElements.labels[248], "Scene 049")

	page.makeCommandBinding(surfaceElements.buttons[249].mSurfaceValue, "Process Project Logical Editor", "Scene050")
	page.setLabelFieldText(surfaceElements.labels[249], "Scene 050")

	page.makeCommandBinding(surfaceElements.buttons[250].mSurfaceValue, "Process Project Logical Editor", "Scene051")
	page.setLabelFieldText(surfaceElements.labels[250], "Scene 051")

	page.makeCommandBinding(surfaceElements.buttons[251].mSurfaceValue, "Process Project Logical Editor", "Scene052")
	page.setLabelFieldText(surfaceElements.labels[251], "Scene 052")

	page.makeCommandBinding(surfaceElements.buttons[252].mSurfaceValue, "Process Project Logical Editor", "Scene053")
	page.setLabelFieldText(surfaceElements.labels[252], "Scene 053")

	page.makeCommandBinding(surfaceElements.buttons[253].mSurfaceValue, "Process Project Logical Editor", "Scene054")
	page.setLabelFieldText(surfaceElements.labels[253], "Scene 054")

	page.makeCommandBinding(surfaceElements.buttons[254].mSurfaceValue, "Process Project Logical Editor", "Scene055")
	page.setLabelFieldText(surfaceElements.labels[254], "Scene 055")

	page.makeCommandBinding(surfaceElements.buttons[255].mSurfaceValue, "Process Project Logical Editor", "Scene056")
	page.setLabelFieldText(surfaceElements.labels[255], "Scene 056")

	page.makeCommandBinding(surfaceElements.buttons[256].mSurfaceValue, "Process Project Logical Editor", "Scene057")
	page.setLabelFieldText(surfaceElements.labels[256], "Scene 057")

	page.makeCommandBinding(surfaceElements.buttons[257].mSurfaceValue, "Process Project Logical Editor", "Scene058")
	page.setLabelFieldText(surfaceElements.labels[257], "Scene 058")

	page.makeCommandBinding(surfaceElements.buttons[258].mSurfaceValue, "Process Project Logical Editor", "Scene059")
	page.setLabelFieldText(surfaceElements.labels[258], "Scene 059")

	page.makeCommandBinding(surfaceElements.buttons[259].mSurfaceValue, "Process Project Logical Editor", "Scene060")
	page.setLabelFieldText(surfaceElements.labels[259], "Scene 060")

	page.makeCommandBinding(surfaceElements.buttons[260].mSurfaceValue, "Process Project Logical Editor", "Scene061")
	page.setLabelFieldText(surfaceElements.labels[260], "Scene 061")

	page.makeCommandBinding(surfaceElements.buttons[261].mSurfaceValue, "Process Project Logical Editor", "Scene062")
	page.setLabelFieldText(surfaceElements.labels[261], "Scene 062")

	page.makeCommandBinding(surfaceElements.buttons[262].mSurfaceValue, "Process Project Logical Editor", "Scene063")
	page.setLabelFieldText(surfaceElements.labels[262], "Scene 063")

	page.makeCommandBinding(surfaceElements.buttons[263].mSurfaceValue, "Process Project Logical Editor", "Scene064")
	page.setLabelFieldText(surfaceElements.labels[263], "Scene 064")

	page.makeCommandBinding(surfaceElements.buttons[264].mSurfaceValue, "Process Project Logical Editor", "Scene065")
	page.setLabelFieldText(surfaceElements.labels[264], "Scene 065")

	page.makeCommandBinding(surfaceElements.buttons[265].mSurfaceValue, "Process Project Logical Editor", "Scene066")
	page.setLabelFieldText(surfaceElements.labels[265], "Scene 066")

	page.makeCommandBinding(surfaceElements.buttons[266].mSurfaceValue, "Process Project Logical Editor", "Scene067")
	page.setLabelFieldText(surfaceElements.labels[266], "Scene 067")

	page.makeCommandBinding(surfaceElements.buttons[267].mSurfaceValue, "Process Project Logical Editor", "Scene068")
	page.setLabelFieldText(surfaceElements.labels[267], "Scene 068")

	page.makeCommandBinding(surfaceElements.buttons[268].mSurfaceValue, "Process Project Logical Editor", "Scene069")
	page.setLabelFieldText(surfaceElements.labels[268], "Scene 069")

	page.makeCommandBinding(surfaceElements.buttons[269].mSurfaceValue, "Process Project Logical Editor", "Scene070")
	page.setLabelFieldText(surfaceElements.labels[269], "Scene 070")

	page.makeCommandBinding(surfaceElements.buttons[270].mSurfaceValue, "Process Project Logical Editor", "Scene071")
	page.setLabelFieldText(surfaceElements.labels[270], "Scene 071")

	page.makeCommandBinding(surfaceElements.buttons[271].mSurfaceValue, "Process Project Logical Editor", "Scene072")
	page.setLabelFieldText(surfaceElements.labels[271], "Scene 072")

	page.makeCommandBinding(surfaceElements.buttons[272].mSurfaceValue, "Process Project Logical Editor", "Scene073")
	page.setLabelFieldText(surfaceElements.labels[272], "Scene 073")

	page.makeCommandBinding(surfaceElements.buttons[273].mSurfaceValue, "Process Project Logical Editor", "Scene074")
	page.setLabelFieldText(surfaceElements.labels[273], "Scene 074")

	page.makeCommandBinding(surfaceElements.buttons[274].mSurfaceValue, "Process Project Logical Editor", "Scene075")
	page.setLabelFieldText(surfaceElements.labels[274], "Scene 075")

	page.makeCommandBinding(surfaceElements.buttons[275].mSurfaceValue, "Process Project Logical Editor", "Scene076")
	page.setLabelFieldText(surfaceElements.labels[275], "Scene 076")

	page.makeCommandBinding(surfaceElements.buttons[276].mSurfaceValue, "Process Project Logical Editor", "Scene077")
	page.setLabelFieldText(surfaceElements.labels[276], "Scene 077")

	page.makeCommandBinding(surfaceElements.buttons[277].mSurfaceValue, "Process Project Logical Editor", "Scene078")
	page.setLabelFieldText(surfaceElements.labels[277], "Scene 078")

	page.makeCommandBinding(surfaceElements.buttons[278].mSurfaceValue, "Process Project Logical Editor", "Scene079")
	page.setLabelFieldText(surfaceElements.labels[278], "Scene 079")

	page.makeCommandBinding(surfaceElements.buttons[279].mSurfaceValue, "Process Project Logical Editor", "Scene080")
	page.setLabelFieldText(surfaceElements.labels[279], "Scene 080")

	page.makeCommandBinding(surfaceElements.buttons[280].mSurfaceValue, "Process Project Logical Editor", "Scene081")
	page.setLabelFieldText(surfaceElements.labels[280], "Scene 081")

	page.makeCommandBinding(surfaceElements.buttons[281].mSurfaceValue, "Process Project Logical Editor", "Scene082")
	page.setLabelFieldText(surfaceElements.labels[281], "Scene 082")

	page.makeCommandBinding(surfaceElements.buttons[282].mSurfaceValue, "Process Project Logical Editor", "Scene083")
	page.setLabelFieldText(surfaceElements.labels[282], "Scene 083")

	page.makeCommandBinding(surfaceElements.buttons[283].mSurfaceValue, "Process Project Logical Editor", "Scene084")
	page.setLabelFieldText(surfaceElements.labels[283], "Scene 084")

	page.makeCommandBinding(surfaceElements.buttons[284].mSurfaceValue, "Process Project Logical Editor", "Scene085")
	page.setLabelFieldText(surfaceElements.labels[284], "Scene 085")

	page.makeCommandBinding(surfaceElements.buttons[285].mSurfaceValue, "Process Project Logical Editor", "Scene086")
	page.setLabelFieldText(surfaceElements.labels[285], "Scene 086")

	page.makeCommandBinding(surfaceElements.buttons[286].mSurfaceValue, "Process Project Logical Editor", "Scene087")
	page.setLabelFieldText(surfaceElements.labels[286], "Scene 087")

	page.makeCommandBinding(surfaceElements.buttons[287].mSurfaceValue, "Process Project Logical Editor", "Scene088")
	page.setLabelFieldText(surfaceElements.labels[287], "Scene 088")

	page.makeCommandBinding(surfaceElements.buttons[288].mSurfaceValue, "Process Project Logical Editor", "Scene089")
	page.setLabelFieldText(surfaceElements.labels[288], "Scene 089")

	page.makeCommandBinding(surfaceElements.buttons[289].mSurfaceValue, "Process Project Logical Editor", "Scene090")
	page.setLabelFieldText(surfaceElements.labels[289], "Scene 090")

	page.makeCommandBinding(surfaceElements.buttons[290].mSurfaceValue, "Process Project Logical Editor", "Scene091")
	page.setLabelFieldText(surfaceElements.labels[290], "Scene 091")

	page.makeCommandBinding(surfaceElements.buttons[291].mSurfaceValue, "Process Project Logical Editor", "Scene092")
	page.setLabelFieldText(surfaceElements.labels[291], "Scene 092")

	page.makeCommandBinding(surfaceElements.buttons[292].mSurfaceValue, "Process Project Logical Editor", "Scene093")
	page.setLabelFieldText(surfaceElements.labels[292], "Scene 093")

	page.makeCommandBinding(surfaceElements.buttons[293].mSurfaceValue, "Process Project Logical Editor", "Scene094")
	page.setLabelFieldText(surfaceElements.labels[293], "Scene 094")

	page.makeCommandBinding(surfaceElements.buttons[294].mSurfaceValue, "Process Project Logical Editor", "Scene095")
	page.setLabelFieldText(surfaceElements.labels[294], "Scene 095")

	page.makeCommandBinding(surfaceElements.buttons[295].mSurfaceValue, "Process Project Logical Editor", "Scene096")
	page.setLabelFieldText(surfaceElements.labels[295], "Scene 096")

	page.makeCommandBinding(surfaceElements.buttons[296].mSurfaceValue, "Process Project Logical Editor", "Scene097")
	page.setLabelFieldText(surfaceElements.labels[296], "Scene 097")

	page.makeCommandBinding(surfaceElements.buttons[297].mSurfaceValue, "Process Project Logical Editor", "Scene098")
	page.setLabelFieldText(surfaceElements.labels[297], "Scene 098")

	page.makeCommandBinding(surfaceElements.buttons[298].mSurfaceValue, "Process Project Logical Editor", "Scene099")
	page.setLabelFieldText(surfaceElements.labels[298], "Scene 099")

	page.makeCommandBinding(surfaceElements.buttons[299].mSurfaceValue, "Process Project Logical Editor", "Scene100")
	page.setLabelFieldText(surfaceElements.labels[299], "Scene 100")

	page.makeCommandBinding(surfaceElements.buttons[300].mSurfaceValue, "Process Project Logical Editor", "Hide All")
	page.setLabelFieldText(surfaceElements.labels[300], "Hide All")

	page.makeCommandBinding(surfaceElements.buttons[301].mSurfaceValue, "Process Project Logical Editor", "MG_Unfold_All_Visible")
	page.setLabelFieldText(surfaceElements.labels[301], "Unfold All")

	return page
}

//----------------------------------------------------------------------------------------------------------------------
// Construct Pages
//----------------------------------------------------------------------------------------------------------------------
function onActivatePageDefault(context) {
}

deviceDriver.mOnActivate = function (context) {
	console.log('Metagrid Macros script has been activated.')
}

var pageMacros = makePageMacros()

pageMacros.mOnActivate = function (context) {
	onActivatePageDefault(context)
	console.log('from script: Metagrid Macros page activated')
}
